library libkuzn_d;

{
  Kuznechik block cipher
  Delphi port by A.Myasnikov
  Mail: amsoftware@ya.ru
  Web: amsoftware.narod.ru
}

uses
  System.SysUtils,
  System.Classes;

{$I kuz.inc}

var
  key: kuz_key_t;

  //

const
  kuz_pi: array [0 .. 255] of u8 = ($FC, $EE, $DD, $11, $CF, $6E, $31, $16,
    // 00..07
    $FB, $C4, $FA, $DA, $23, $C5, $04, $4D, // 08..0F
    $E9, $77, $F0, $DB, $93, $2E, $99, $BA, // 10..17
    $17, $36, $F1, $BB, $14, $CD, $5F, $C1, // 18..1F
    $F9, $18, $65, $5A, $E2, $5C, $EF, $21, // 20..27
    $81, $1C, $3C, $42, $8B, $01, $8E, $4F, // 28..2F
    $05, $84, $02, $AE, $E3, $6A, $8F, $A0, // 30..37
    $06, $0B, $ED, $98, $7F, $D4, $D3, $1F, // 38..3F
    $EB, $34, $2C, $51, $EA, $C8, $48, $AB, // 40..47
    $F2, $2A, $68, $A2, $FD, $3A, $CE, $CC, // 48..4F
    $B5, $70, $0E, $56, $08, $0C, $76, $12, // 50..57
    $BF, $72, $13, $47, $9C, $B7, $5D, $87, // 58..5F
    $15, $A1, $96, $29, $10, $7B, $9A, $C7, // 60..67
    $F3, $91, $78, $6F, $9D, $9E, $B2, $B1, // 68..6F
    $32, $75, $19, $3D, $FF, $35, $8A, $7E, // 70..77
    $6D, $54, $C6, $80, $C3, $BD, $0D, $57, // 78..7F
    $DF, $F5, $24, $A9, $3E, $A8, $43, $C9, // 80..87
    $D7, $79, $D6, $F6, $7C, $22, $B9, $03, // 88..8F
    $E0, $0F, $EC, $DE, $7A, $94, $B0, $BC, // 90..97
    $DC, $E8, $28, $50, $4E, $33, $0A, $4A, // 98..9F
    $A7, $97, $60, $73, $1E, $00, $62, $44, // A0..A7
    $1A, $B8, $38, $82, $64, $9F, $26, $41, // A8..AF
    $AD, $45, $46, $92, $27, $5E, $55, $2F, // B0..B7
    $8C, $A3, $A5, $7D, $69, $D5, $95, $3B, // B8..BF
    $07, $58, $B3, $40, $86, $AC, $1D, $F7, // C0..C7
    $30, $37, $6B, $E4, $88, $D9, $E7, $89, // C8..CF
    $E1, $1B, $83, $49, $4C, $3F, $F8, $FE, // D0..D7
    $8D, $53, $AA, $90, $CA, $D8, $85, $61, // D8..DF
    $20, $71, $67, $A4, $2D, $2B, $09, $5B, // E0..E7
    $CB, $9B, $25, $D0, $BE, $E5, $6C, $52, // E8..EF
    $59, $A6, $74, $D2, $E6, $F4, $B4, $C0, // F0..F7
    $D1, $66, $AF, $C2, $39, $4B, $63, $B6 // F8..FF
    );

const
  kuz_pi_inv: array [0 .. 255] of u8 = ($A5, $2D, $32, $8F, $0E, $30, $38, $C0,
    // 00..07
    $54, $E6, $9E, $39, $55, $7E, $52, $91, // 08..0F
    $64, $03, $57, $5A, $1C, $60, $07, $18, // 10..17
    $21, $72, $A8, $D1, $29, $C6, $A4, $3F, // 18..1F
    $E0, $27, $8D, $0C, $82, $EA, $AE, $B4, // 20..27
    $9A, $63, $49, $E5, $42, $E4, $15, $B7, // 28..2F
    $C8, $06, $70, $9D, $41, $75, $19, $C9, // 30..37
    $AA, $FC, $4D, $BF, $2A, $73, $84, $D5, // 38..3F
    $C3, $AF, $2B, $86, $A7, $B1, $B2, $5B, // 40..47
    $46, $D3, $9F, $FD, $D4, $0F, $9C, $2F, // 48..4F
    $9B, $43, $EF, $D9, $79, $B6, $53, $7F, // 50..57
    $C1, $F0, $23, $E7, $25, $5E, $B5, $1E, // 58..5F
    $A2, $DF, $A6, $FE, $AC, $22, $F9, $E2, // 60..67
    $4A, $BC, $35, $CA, $EE, $78, $05, $6B, // 68..6F
    $51, $E1, $59, $A3, $F2, $71, $56, $11, // 70..77
    $6A, $89, $94, $65, $8C, $BB, $77, $3C, // 78..7F
    $7B, $28, $AB, $D2, $31, $DE, $C4, $5F, // 80..87
    $CC, $CF, $76, $2C, $B8, $D8, $2E, $36, // 88..8F
    $DB, $69, $B3, $14, $95, $BE, $62, $A1, // 90..97
    $3B, $16, $66, $E9, $5C, $6C, $6D, $AD, // 98..9F
    $37, $61, $4B, $B9, $E3, $BA, $F1, $A0, // A0..A7
    $85, $83, $DA, $47, $C5, $B0, $33, $FA, // A8..AF
    $96, $6F, $6E, $C2, $F6, $50, $FF, $5D, // B0..B7
    $A9, $8E, $17, $1B, $97, $7D, $EC, $58, // B8..BF
    $F7, $1F, $FB, $7C, $09, $0D, $7A, $67, // C0..C7
    $45, $87, $DC, $E8, $4F, $1D, $4E, $04, // C8..CF
    $EB, $F8, $F3, $3E, $3D, $BD, $8A, $88, // D0..D7
    $DD, $CD, $0B, $13, $98, $02, $93, $80, // D8..DF
    $90, $D0, $24, $34, $CB, $ED, $F4, $CE, // E0..E7
    $99, $10, $44, $40, $92, $3A, $01, $26, // E8..EF
    $12, $1A, $48, $68, $F5, $81, $8B, $C7, // F0..F7
    $D6, $20, $0A, $08, $00, $4C, $D7, $74 // F8..FF
    );

const
  multTable: array [0 .. 65535] of u8 = (

    $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00,
    $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00,
    $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00,
    $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00,
    $00, $00, $00, $00,

    $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00,
    $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00,
    $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00,
    $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00,
    $00, $00, $00, $00,

    $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00,
    $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00,
    $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00,
    $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00,
    $00, $00, $00, $00,

    $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00,
    $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00,
    $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00,
    $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00,
    $00, $00, $00, $00,

    $00, $01, $02, $03, $04, $05, $06, $07, $08, $09, $0A, $0B, $0C, $0D, $0E,
    $0F, $10, $11, $12, $13, $14, $15, $16, $17, $18, $19, $1A, $1B, $1C, $1D,
    $1E, $1F, $20, $21, $22, $23, $24, $25, $26, $27, $28, $29, $2A, $2B, $2C,
    $2D, $2E, $2F, $30, $31, $32, $33, $34, $35, $36, $37, $38, $39, $3A, $3B,
    $3C, $3D, $3E, $3F, $40, $41, $42, $43, $44, $45, $46, $47, $48, $49, $4A,
    $4B, $4C, $4D, $4E, $4F, $50, $51, $52, $53, $54, $55, $56, $57, $58, $59,
    $5A, $5B, $5C, $5D, $5E, $5F, $60, $61, $62, $63, $64, $65, $66, $67, $68,
    $69, $6A, $6B, $6C, $6D, $6E, $6F, $70, $71, $72, $73, $74, $75, $76, $77,
    $78, $79, $7A, $7B, $7C, $7D, $7E, $7F, $80, $81, $82, $83, $84, $85, $86,
    $87, $88, $89, $8A, $8B, $8C, $8D, $8E, $8F, $90, $91, $92, $93, $94, $95,
    $96, $97, $98, $99, $9A, $9B, $9C, $9D, $9E, $9F, $A0, $A1, $A2, $A3, $A4,
    $A5, $A6, $A7, $A8, $A9, $AA, $AB, $AC, $AD, $AE, $AF, $B0, $B1, $B2, $B3,
    $B4, $B5, $B6, $B7, $B8, $B9, $BA, $BB, $BC, $BD, $BE, $BF, $C0, $C1, $C2,
    $C3, $C4, $C5, $C6, $C7, $C8, $C9, $CA, $CB, $CC, $CD, $CE, $CF, $D0, $D1,
    $D2, $D3, $D4, $D5, $D6, $D7, $D8, $D9, $DA, $DB, $DC, $DD, $DE, $DF, $E0,
    $E1, $E2, $E3, $E4, $E5, $E6, $E7, $E8, $E9, $EA, $EB, $EC, $ED, $EE, $EF,
    $F0, $F1, $F2, $F3, $F4, $F5, $F6, $F7, $F8, $F9, $FA, $FB, $FC, $FD, $FE,
    $FF, $00, $02, $04, $06, $08, $0A, $0C, $0E, $10, $12, $14, $16, $18, $1A,
    $1C, $1E, $20, $22, $24, $26, $28, $2A, $2C, $2E, $30, $32, $34, $36, $38,
    $3A, $3C, $3E, $40, $42, $44, $46, $48, $4A, $4C, $4E, $50, $52, $54, $56,
    $58, $5A, $5C, $5E, $60, $62, $64, $66, $68, $6A, $6C, $6E, $70, $72, $74,
    $76, $78, $7A, $7C, $7E, $80, $82, $84, $86, $88, $8A, $8C, $8E, $90, $92,
    $94, $96, $98, $9A, $9C, $9E, $A0, $A2, $A4, $A6, $A8, $AA, $AC, $AE, $B0,
    $B2, $B4, $B6, $B8, $BA, $BC, $BE, $C0, $C2, $C4, $C6, $C8, $CA, $CC, $CE,
    $D0, $D2, $D4, $D6, $D8, $DA, $DC, $DE, $E0, $E2, $E4, $E6, $E8, $EA, $EC,
    $EE, $F0, $F2, $F4, $F6, $F8, $FA, $FC, $FE, $C3, $C1, $C7, $C5, $CB, $C9,
    $CF, $CD, $D3, $D1, $D7, $D5, $DB, $D9, $DF, $DD, $E3, $E1, $E7, $E5, $EB,
    $E9, $EF, $ED, $F3, $F1, $F7, $F5, $FB, $F9, $FF, $FD, $83, $81, $87, $85,
    $8B, $89, $8F, $8D, $93, $91, $97, $95, $9B, $99, $9F, $9D, $A3, $A1, $A7,
    $A5, $AB, $A9, $AF, $AD, $B3, $B1, $B7, $B5, $BB, $B9, $BF, $BD, $43, $41,
    $47, $45, $4B, $49, $4F, $4D, $53, $51, $57, $55, $5B, $59, $5F, $5D, $63,
    $61, $67, $65, $6B, $69, $6F, $6D, $73, $71, $77, $75, $7B, $79, $7F, $7D,
    $03, $01, $07, $05, $0B, $09, $0F, $0D, $13, $11, $17, $15, $1B, $19, $1F,
    $1D, $23, $21, $27, $25, $2B, $29, $2F, $2D, $33, $31, $37, $35, $3B, $39,
    $3F, $3D, $00, $03, $06, $05, $0C, $0F, $0A, $09, $18, $1B, $1E, $1D, $14,
    $17, $12, $11, $30, $33, $36, $35, $3C, $3F, $3A, $39, $28, $2B, $2E, $2D,
    $24, $27, $22, $21, $60, $63, $66, $65, $6C, $6F, $6A, $69, $78, $7B, $7E,
    $7D, $74, $77, $72, $71, $50, $53, $56, $55, $5C, $5F, $5A, $59, $48, $4B,
    $4E, $4D, $44, $47, $42, $41, $C0, $C3, $C6, $C5, $CC, $CF, $CA, $C9, $D8,
    $DB, $DE, $DD, $D4, $D7, $D2, $D1, $F0, $F3, $F6, $F5, $FC, $FF, $FA, $F9,
    $E8, $EB, $EE, $ED, $E4, $E7, $E2, $E1, $A0, $A3, $A6, $A5, $AC, $AF, $AA,
    $A9, $B8, $BB, $BE, $BD, $B4, $B7, $B2, $B1, $90, $93, $96, $95, $9C, $9F,
    $9A, $99, $88, $8B, $8E, $8D, $84, $87, $82, $81, $43, $40, $45, $46, $4F,
    $4C, $49, $4A, $5B, $58, $5D, $5E, $57, $54, $51, $52, $73, $70, $75, $76,
    $7F, $7C, $79, $7A, $6B, $68, $6D, $6E, $67, $64, $61, $62, $23, $20, $25,
    $26, $2F, $2C, $29, $2A, $3B, $38, $3D, $3E, $37, $34, $31, $32, $13, $10,
    $15, $16, $1F, $1C, $19, $1A, $0B, $08, $0D, $0E, $07, $04, $01, $02, $83,
    $80, $85, $86, $8F, $8C, $89, $8A, $9B, $98, $9D, $9E, $97, $94, $91, $92,
    $B3, $B0, $B5, $B6, $BF, $BC, $B9, $BA, $AB, $A8, $AD, $AE, $A7, $A4, $A1,
    $A2, $E3, $E0, $E5, $E6, $EF, $EC, $E9, $EA, $FB, $F8, $FD, $FE, $F7, $F4,
    $F1, $F2, $D3, $D0, $D5, $D6, $DF, $DC, $D9, $DA, $CB, $C8, $CD, $CE, $C7,
    $C4, $C1, $C2, $00, $04, $08, $0C, $10, $14, $18, $1C, $20, $24, $28, $2C,
    $30, $34, $38, $3C, $40, $44, $48, $4C, $50, $54, $58, $5C, $60, $64, $68,
    $6C, $70, $74, $78, $7C, $80, $84, $88, $8C, $90, $94, $98, $9C, $A0, $A4,
    $A8, $AC, $B0, $B4, $B8, $BC, $C0, $C4, $C8, $CC, $D0, $D4, $D8, $DC, $E0,
    $E4, $E8, $EC, $F0, $F4, $F8, $FC, $C3, $C7, $CB, $CF, $D3, $D7, $DB, $DF,
    $E3, $E7, $EB, $EF, $F3, $F7, $FB, $FF, $83, $87, $8B, $8F, $93, $97, $9B,
    $9F, $A3, $A7, $AB, $AF, $B3, $B7, $BB, $BF, $43, $47, $4B, $4F, $53, $57,
    $5B, $5F, $63, $67, $6B, $6F, $73, $77, $7B, $7F, $03, $07, $0B, $0F, $13,
    $17, $1B, $1F, $23, $27, $2B, $2F, $33, $37, $3B, $3F, $45, $41, $4D, $49,
    $55, $51, $5D, $59, $65, $61, $6D, $69, $75, $71, $7D, $79, $05, $01, $0D,
    $09, $15, $11, $1D, $19, $25, $21, $2D, $29, $35, $31, $3D, $39, $C5, $C1,
    $CD, $C9, $D5, $D1, $DD, $D9, $E5, $E1, $ED, $E9, $F5, $F1, $FD, $F9, $85,
    $81, $8D, $89, $95, $91, $9D, $99, $A5, $A1, $AD, $A9, $B5, $B1, $BD, $B9,
    $86, $82, $8E, $8A, $96, $92, $9E, $9A, $A6, $A2, $AE, $AA, $B6, $B2, $BE,
    $BA, $C6, $C2, $CE, $CA, $D6, $D2, $DE, $DA, $E6, $E2, $EE, $EA, $F6, $F2,
    $FE, $FA, $06, $02, $0E, $0A, $16, $12, $1E, $1A, $26, $22, $2E, $2A, $36,
    $32, $3E, $3A, $46, $42, $4E, $4A, $56, $52, $5E, $5A, $66, $62, $6E, $6A,
    $76, $72, $7E, $7A, $00, $05, $0A, $0F, $14, $11, $1E, $1B, $28, $2D, $22,
    $27, $3C, $39, $36, $33, $50, $55, $5A, $5F, $44, $41, $4E, $4B, $78, $7D,
    $72, $77, $6C, $69, $66, $63, $A0, $A5, $AA, $AF, $B4, $B1, $BE, $BB, $88,
    $8D, $82, $87, $9C, $99, $96, $93, $F0, $F5, $FA, $FF, $E4, $E1, $EE, $EB,
    $D8, $DD, $D2, $D7, $CC, $C9, $C6, $C3, $83, $86, $89, $8C, $97, $92, $9D,
    $98, $AB, $AE, $A1, $A4, $BF, $BA, $B5, $B0, $D3, $D6, $D9, $DC, $C7, $C2,
    $CD, $C8, $FB, $FE, $F1, $F4, $EF, $EA, $E5, $E0, $23, $26, $29, $2C, $37,
    $32, $3D, $38, $0B, $0E, $01, $04, $1F, $1A, $15, $10, $73, $76, $79, $7C,
    $67, $62, $6D, $68, $5B, $5E, $51, $54, $4F, $4A, $45, $40, $C5, $C0, $CF,
    $CA, $D1, $D4, $DB, $DE, $ED, $E8, $E7, $E2, $F9, $FC, $F3, $F6, $95, $90,
    $9F, $9A, $81, $84, $8B, $8E, $BD, $B8, $B7, $B2, $A9, $AC, $A3, $A6, $65,
    $60, $6F, $6A, $71, $74, $7B, $7E, $4D, $48, $47, $42, $59, $5C, $53, $56,
    $35, $30, $3F, $3A, $21, $24, $2B, $2E, $1D, $18, $17, $12, $09, $0C, $03,
    $06, $46, $43, $4C, $49, $52, $57, $58, $5D, $6E, $6B, $64, $61, $7A, $7F,
    $70, $75, $16, $13, $1C, $19, $02, $07, $08, $0D, $3E, $3B, $34, $31, $2A,
    $2F, $20, $25, $E6, $E3, $EC, $E9, $F2, $F7, $F8, $FD, $CE, $CB, $C4, $C1,
    $DA, $DF, $D0, $D5, $B6, $B3, $BC, $B9, $A2, $A7, $A8, $AD, $9E, $9B, $94,
    $91, $8A, $8F, $80, $85, $00, $06, $0C, $0A, $18, $1E, $14, $12, $30, $36,
    $3C, $3A, $28, $2E, $24, $22, $60, $66, $6C, $6A, $78, $7E, $74, $72, $50,
    $56, $5C, $5A, $48, $4E, $44, $42, $C0, $C6, $CC, $CA, $D8, $DE, $D4, $D2,
    $F0, $F6, $FC, $FA, $E8, $EE, $E4, $E2, $A0, $A6, $AC, $AA, $B8, $BE, $B4,
    $B2, $90, $96, $9C, $9A, $88, $8E, $84, $82, $43, $45, $4F, $49, $5B, $5D,
    $57, $51, $73, $75, $7F, $79, $6B, $6D, $67, $61, $23, $25, $2F, $29, $3B,
    $3D, $37, $31, $13, $15, $1F, $19, $0B, $0D, $07, $01, $83, $85, $8F, $89,
    $9B, $9D, $97, $91, $B3, $B5, $BF, $B9, $AB, $AD, $A7, $A1, $E3, $E5, $EF,
    $E9, $FB, $FD, $F7, $F1, $D3, $D5, $DF, $D9, $CB, $CD, $C7, $C1, $86, $80,
    $8A, $8C, $9E, $98, $92, $94, $B6, $B0, $BA, $BC, $AE, $A8, $A2, $A4, $E6,
    $E0, $EA, $EC, $FE, $F8, $F2, $F4, $D6, $D0, $DA, $DC, $CE, $C8, $C2, $C4,
    $46, $40, $4A, $4C, $5E, $58, $52, $54, $76, $70, $7A, $7C, $6E, $68, $62,
    $64, $26, $20, $2A, $2C, $3E, $38, $32, $34, $16, $10, $1A, $1C, $0E, $08,
    $02, $04, $C5, $C3, $C9, $CF, $DD, $DB, $D1, $D7, $F5, $F3, $F9, $FF, $ED,
    $EB, $E1, $E7, $A5, $A3, $A9, $AF, $BD, $BB, $B1, $B7, $95, $93, $99, $9F,
    $8D, $8B, $81, $87, $05, $03, $09, $0F, $1D, $1B, $11, $17, $35, $33, $39,
    $3F, $2D, $2B, $21, $27, $65, $63, $69, $6F, $7D, $7B, $71, $77, $55, $53,
    $59, $5F, $4D, $4B, $41, $47, $00, $07, $0E, $09, $1C, $1B, $12, $15, $38,
    $3F, $36, $31, $24, $23, $2A, $2D, $70, $77, $7E, $79, $6C, $6B, $62, $65,
    $48, $4F, $46, $41, $54, $53, $5A, $5D, $E0, $E7, $EE, $E9, $FC, $FB, $F2,
    $F5, $D8, $DF, $D6, $D1, $C4, $C3, $CA, $CD, $90, $97, $9E, $99, $8C, $8B,
    $82, $85, $A8, $AF, $A6, $A1, $B4, $B3, $BA, $BD, $03, $04, $0D, $0A, $1F,
    $18, $11, $16, $3B, $3C, $35, $32, $27, $20, $29, $2E, $73, $74, $7D, $7A,
    $6F, $68, $61, $66, $4B, $4C, $45, $42, $57, $50, $59, $5E, $E3, $E4, $ED,
    $EA, $FF, $F8, $F1, $F6, $DB, $DC, $D5, $D2, $C7, $C0, $C9, $CE, $93, $94,
    $9D, $9A, $8F, $88, $81, $86, $AB, $AC, $A5, $A2, $B7, $B0, $B9, $BE, $06,
    $01, $08, $0F, $1A, $1D, $14, $13, $3E, $39, $30, $37, $22, $25, $2C, $2B,
    $76, $71, $78, $7F, $6A, $6D, $64, $63, $4E, $49, $40, $47, $52, $55, $5C,
    $5B, $E6, $E1, $E8, $EF, $FA, $FD, $F4, $F3, $DE, $D9, $D0, $D7, $C2, $C5,
    $CC, $CB, $96, $91, $98, $9F, $8A, $8D, $84, $83, $AE, $A9, $A0, $A7, $B2,
    $B5, $BC, $BB, $05, $02, $0B, $0C, $19, $1E, $17, $10, $3D, $3A, $33, $34,
    $21, $26, $2F, $28, $75, $72, $7B, $7C, $69, $6E, $67, $60, $4D, $4A, $43,
    $44, $51, $56, $5F, $58, $E5, $E2, $EB, $EC, $F9, $FE, $F7, $F0, $DD, $DA,
    $D3, $D4, $C1, $C6, $CF, $C8, $95, $92, $9B, $9C, $89, $8E, $87, $80, $AD,
    $AA, $A3, $A4, $B1, $B6, $BF, $B8, $00, $08, $10, $18, $20, $28, $30, $38,
    $40, $48, $50, $58, $60, $68, $70, $78, $80, $88, $90, $98, $A0, $A8, $B0,
    $B8, $C0, $C8, $D0, $D8, $E0, $E8, $F0, $F8, $C3, $CB, $D3, $DB, $E3, $EB,
    $F3, $FB, $83, $8B, $93, $9B, $A3, $AB, $B3, $BB, $43, $4B, $53, $5B, $63,
    $6B, $73, $7B, $03, $0B, $13, $1B, $23, $2B, $33, $3B, $45, $4D, $55, $5D,
    $65, $6D, $75, $7D, $05, $0D, $15, $1D, $25, $2D, $35, $3D, $C5, $CD, $D5,
    $DD, $E5, $ED, $F5, $FD, $85, $8D, $95, $9D, $A5, $AD, $B5, $BD, $86, $8E,
    $96, $9E, $A6, $AE, $B6, $BE, $C6, $CE, $D6, $DE, $E6, $EE, $F6, $FE, $06,
    $0E, $16, $1E, $26, $2E, $36, $3E, $46, $4E, $56, $5E, $66, $6E, $76, $7E,
    $8A, $82, $9A, $92, $AA, $A2, $BA, $B2, $CA, $C2, $DA, $D2, $EA, $E2, $FA,
    $F2, $0A, $02, $1A, $12, $2A, $22, $3A, $32, $4A, $42, $5A, $52, $6A, $62,
    $7A, $72, $49, $41, $59, $51, $69, $61, $79, $71, $09, $01, $19, $11, $29,
    $21, $39, $31, $C9, $C1, $D9, $D1, $E9, $E1, $F9, $F1, $89, $81, $99, $91,
    $A9, $A1, $B9, $B1, $CF, $C7, $DF, $D7, $EF, $E7, $FF, $F7, $8F, $87, $9F,
    $97, $AF, $A7, $BF, $B7, $4F, $47, $5F, $57, $6F, $67, $7F, $77, $0F, $07,
    $1F, $17, $2F, $27, $3F, $37, $0C, $04, $1C, $14, $2C, $24, $3C, $34, $4C,
    $44, $5C, $54, $6C, $64, $7C, $74, $8C, $84, $9C, $94, $AC, $A4, $BC, $B4,
    $CC, $C4, $DC, $D4, $EC, $E4, $FC, $F4, $00, $09, $12, $1B, $24, $2D, $36,
    $3F, $48, $41, $5A, $53, $6C, $65, $7E, $77, $90, $99, $82, $8B, $B4, $BD,
    $A6, $AF, $D8, $D1, $CA, $C3, $FC, $F5, $EE, $E7, $E3, $EA, $F1, $F8, $C7,
    $CE, $D5, $DC, $AB, $A2, $B9, $B0, $8F, $86, $9D, $94, $73, $7A, $61, $68,
    $57, $5E, $45, $4C, $3B, $32, $29, $20, $1F, $16, $0D, $04, $05, $0C, $17,
    $1E, $21, $28, $33, $3A, $4D, $44, $5F, $56, $69, $60, $7B, $72, $95, $9C,
    $87, $8E, $B1, $B8, $A3, $AA, $DD, $D4, $CF, $C6, $F9, $F0, $EB, $E2, $E6,
    $EF, $F4, $FD, $C2, $CB, $D0, $D9, $AE, $A7, $BC, $B5, $8A, $83, $98, $91,
    $76, $7F, $64, $6D, $52, $5B, $40, $49, $3E, $37, $2C, $25, $1A, $13, $08,
    $01, $0A, $03, $18, $11, $2E, $27, $3C, $35, $42, $4B, $50, $59, $66, $6F,
    $74, $7D, $9A, $93, $88, $81, $BE, $B7, $AC, $A5, $D2, $DB, $C0, $C9, $F6,
    $FF, $E4, $ED, $E9, $E0, $FB, $F2, $CD, $C4, $DF, $D6, $A1, $A8, $B3, $BA,
    $85, $8C, $97, $9E, $79, $70, $6B, $62, $5D, $54, $4F, $46, $31, $38, $23,
    $2A, $15, $1C, $07, $0E, $0F, $06, $1D, $14, $2B, $22, $39, $30, $47, $4E,
    $55, $5C, $63, $6A, $71, $78, $9F, $96, $8D, $84, $BB, $B2, $A9, $A0, $D7,
    $DE, $C5, $CC, $F3, $FA, $E1, $E8, $EC, $E5, $FE, $F7, $C8, $C1, $DA, $D3,
    $A4, $AD, $B6, $BF, $80, $89, $92, $9B, $7C, $75, $6E, $67, $58, $51, $4A,
    $43, $34, $3D, $26, $2F, $10, $19, $02, $0B, $00, $0A, $14, $1E, $28, $22,
    $3C, $36, $50, $5A, $44, $4E, $78, $72, $6C, $66, $A0, $AA, $B4, $BE, $88,
    $82, $9C, $96, $F0, $FA, $E4, $EE, $D8, $D2, $CC, $C6, $83, $89, $97, $9D,
    $AB, $A1, $BF, $B5, $D3, $D9, $C7, $CD, $FB, $F1, $EF, $E5, $23, $29, $37,
    $3D, $0B, $01, $1F, $15, $73, $79, $67, $6D, $5B, $51, $4F, $45, $C5, $CF,
    $D1, $DB, $ED, $E7, $F9, $F3, $95, $9F, $81, $8B, $BD, $B7, $A9, $A3, $65,
    $6F, $71, $7B, $4D, $47, $59, $53, $35, $3F, $21, $2B, $1D, $17, $09, $03,
    $46, $4C, $52, $58, $6E, $64, $7A, $70, $16, $1C, $02, $08, $3E, $34, $2A,
    $20, $E6, $EC, $F2, $F8, $CE, $C4, $DA, $D0, $B6, $BC, $A2, $A8, $9E, $94,
    $8A, $80, $49, $43, $5D, $57, $61, $6B, $75, $7F, $19, $13, $0D, $07, $31,
    $3B, $25, $2F, $E9, $E3, $FD, $F7, $C1, $CB, $D5, $DF, $B9, $B3, $AD, $A7,
    $91, $9B, $85, $8F, $CA, $C0, $DE, $D4, $E2, $E8, $F6, $FC, $9A, $90, $8E,
    $84, $B2, $B8, $A6, $AC, $6A, $60, $7E, $74, $42, $48, $56, $5C, $3A, $30,
    $2E, $24, $12, $18, $06, $0C, $8C, $86, $98, $92, $A4, $AE, $B0, $BA, $DC,
    $D6, $C8, $C2, $F4, $FE, $E0, $EA, $2C, $26, $38, $32, $04, $0E, $10, $1A,
    $7C, $76, $68, $62, $54, $5E, $40, $4A, $0F, $05, $1B, $11, $27, $2D, $33,
    $39, $5F, $55, $4B, $41, $77, $7D, $63, $69, $AF, $A5, $BB, $B1, $87, $8D,
    $93, $99, $FF, $F5, $EB, $E1, $D7, $DD, $C3, $C9, $00, $0B, $16, $1D, $2C,
    $27, $3A, $31, $58, $53, $4E, $45, $74, $7F, $62, $69, $B0, $BB, $A6, $AD,
    $9C, $97, $8A, $81, $E8, $E3, $FE, $F5, $C4, $CF, $D2, $D9, $A3, $A8, $B5,
    $BE, $8F, $84, $99, $92, $FB, $F0, $ED, $E6, $D7, $DC, $C1, $CA, $13, $18,
    $05, $0E, $3F, $34, $29, $22, $4B, $40, $5D, $56, $67, $6C, $71, $7A, $85,
    $8E, $93, $98, $A9, $A2, $BF, $B4, $DD, $D6, $CB, $C0, $F1, $FA, $E7, $EC,
    $35, $3E, $23, $28, $19, $12, $0F, $04, $6D, $66, $7B, $70, $41, $4A, $57,
    $5C, $26, $2D, $30, $3B, $0A, $01, $1C, $17, $7E, $75, $68, $63, $52, $59,
    $44, $4F, $96, $9D, $80, $8B, $BA, $B1, $AC, $A7, $CE, $C5, $D8, $D3, $E2,
    $E9, $F4, $FF, $C9, $C2, $DF, $D4, $E5, $EE, $F3, $F8, $91, $9A, $87, $8C,
    $BD, $B6, $AB, $A0, $79, $72, $6F, $64, $55, $5E, $43, $48, $21, $2A, $37,
    $3C, $0D, $06, $1B, $10, $6A, $61, $7C, $77, $46, $4D, $50, $5B, $32, $39,
    $24, $2F, $1E, $15, $08, $03, $DA, $D1, $CC, $C7, $F6, $FD, $E0, $EB, $82,
    $89, $94, $9F, $AE, $A5, $B8, $B3, $4C, $47, $5A, $51, $60, $6B, $76, $7D,
    $14, $1F, $02, $09, $38, $33, $2E, $25, $FC, $F7, $EA, $E1, $D0, $DB, $C6,
    $CD, $A4, $AF, $B2, $B9, $88, $83, $9E, $95, $EF, $E4, $F9, $F2, $C3, $C8,
    $D5, $DE, $B7, $BC, $A1, $AA, $9B, $90, $8D, $86, $5F, $54, $49, $42, $73,
    $78, $65, $6E, $07, $0C, $11, $1A, $2B, $20, $3D, $36, $00, $0C, $18, $14,
    $30, $3C, $28, $24, $60, $6C, $78, $74, $50, $5C, $48, $44, $C0, $CC, $D8,
    $D4, $F0, $FC, $E8, $E4, $A0, $AC, $B8, $B4, $90, $9C, $88, $84, $43, $4F,
    $5B, $57, $73, $7F, $6B, $67, $23, $2F, $3B, $37, $13, $1F, $0B, $07, $83,
    $8F, $9B, $97, $B3, $BF, $AB, $A7, $E3, $EF, $FB, $F7, $D3, $DF, $CB, $C7,
    $86, $8A, $9E, $92, $B6, $BA, $AE, $A2, $E6, $EA, $FE, $F2, $D6, $DA, $CE,
    $C2, $46, $4A, $5E, $52, $76, $7A, $6E, $62, $26, $2A, $3E, $32, $16, $1A,
    $0E, $02, $C5, $C9, $DD, $D1, $F5, $F9, $ED, $E1, $A5, $A9, $BD, $B1, $95,
    $99, $8D, $81, $05, $09, $1D, $11, $35, $39, $2D, $21, $65, $69, $7D, $71,
    $55, $59, $4D, $41, $CF, $C3, $D7, $DB, $FF, $F3, $E7, $EB, $AF, $A3, $B7,
    $BB, $9F, $93, $87, $8B, $0F, $03, $17, $1B, $3F, $33, $27, $2B, $6F, $63,
    $77, $7B, $5F, $53, $47, $4B, $8C, $80, $94, $98, $BC, $B0, $A4, $A8, $EC,
    $E0, $F4, $F8, $DC, $D0, $C4, $C8, $4C, $40, $54, $58, $7C, $70, $64, $68,
    $2C, $20, $34, $38, $1C, $10, $04, $08, $49, $45, $51, $5D, $79, $75, $61,
    $6D, $29, $25, $31, $3D, $19, $15, $01, $0D, $89, $85, $91, $9D, $B9, $B5,
    $A1, $AD, $E9, $E5, $F1, $FD, $D9, $D5, $C1, $CD, $0A, $06, $12, $1E, $3A,
    $36, $22, $2E, $6A, $66, $72, $7E, $5A, $56, $42, $4E, $CA, $C6, $D2, $DE,
    $FA, $F6, $E2, $EE, $AA, $A6, $B2, $BE, $9A, $96, $82, $8E, $00, $0D, $1A,
    $17, $34, $39, $2E, $23, $68, $65, $72, $7F, $5C, $51, $46, $4B, $D0, $DD,
    $CA, $C7, $E4, $E9, $FE, $F3, $B8, $B5, $A2, $AF, $8C, $81, $96, $9B, $63,
    $6E, $79, $74, $57, $5A, $4D, $40, $0B, $06, $11, $1C, $3F, $32, $25, $28,
    $B3, $BE, $A9, $A4, $87, $8A, $9D, $90, $DB, $D6, $C1, $CC, $EF, $E2, $F5,
    $F8, $C6, $CB, $DC, $D1, $F2, $FF, $E8, $E5, $AE, $A3, $B4, $B9, $9A, $97,
    $80, $8D, $16, $1B, $0C, $01, $22, $2F, $38, $35, $7E, $73, $64, $69, $4A,
    $47, $50, $5D, $A5, $A8, $BF, $B2, $91, $9C, $8B, $86, $CD, $C0, $D7, $DA,
    $F9, $F4, $E3, $EE, $75, $78, $6F, $62, $41, $4C, $5B, $56, $1D, $10, $07,
    $0A, $29, $24, $33, $3E, $4F, $42, $55, $58, $7B, $76, $61, $6C, $27, $2A,
    $3D, $30, $13, $1E, $09, $04, $9F, $92, $85, $88, $AB, $A6, $B1, $BC, $F7,
    $FA, $ED, $E0, $C3, $CE, $D9, $D4, $2C, $21, $36, $3B, $18, $15, $02, $0F,
    $44, $49, $5E, $53, $70, $7D, $6A, $67, $FC, $F1, $E6, $EB, $C8, $C5, $D2,
    $DF, $94, $99, $8E, $83, $A0, $AD, $BA, $B7, $89, $84, $93, $9E, $BD, $B0,
    $A7, $AA, $E1, $EC, $FB, $F6, $D5, $D8, $CF, $C2, $59, $54, $43, $4E, $6D,
    $60, $77, $7A, $31, $3C, $2B, $26, $05, $08, $1F, $12, $EA, $E7, $F0, $FD,
    $DE, $D3, $C4, $C9, $82, $8F, $98, $95, $B6, $BB, $AC, $A1, $3A, $37, $20,
    $2D, $0E, $03, $14, $19, $52, $5F, $48, $45, $66, $6B, $7C, $71, $00, $0E,
    $1C, $12, $38, $36, $24, $2A, $70, $7E, $6C, $62, $48, $46, $54, $5A, $E0,
    $EE, $FC, $F2, $D8, $D6, $C4, $CA, $90, $9E, $8C, $82, $A8, $A6, $B4, $BA,
    $03, $0D, $1F, $11, $3B, $35, $27, $29, $73, $7D, $6F, $61, $4B, $45, $57,
    $59, $E3, $ED, $FF, $F1, $DB, $D5, $C7, $C9, $93, $9D, $8F, $81, $AB, $A5,
    $B7, $B9, $06, $08, $1A, $14, $3E, $30, $22, $2C, $76, $78, $6A, $64, $4E,
    $40, $52, $5C, $E6, $E8, $FA, $F4, $DE, $D0, $C2, $CC, $96, $98, $8A, $84,
    $AE, $A0, $B2, $BC, $05, $0B, $19, $17, $3D, $33, $21, $2F, $75, $7B, $69,
    $67, $4D, $43, $51, $5F, $E5, $EB, $F9, $F7, $DD, $D3, $C1, $CF, $95, $9B,
    $89, $87, $AD, $A3, $B1, $BF, $0C, $02, $10, $1E, $34, $3A, $28, $26, $7C,
    $72, $60, $6E, $44, $4A, $58, $56, $EC, $E2, $F0, $FE, $D4, $DA, $C8, $C6,
    $9C, $92, $80, $8E, $A4, $AA, $B8, $B6, $0F, $01, $13, $1D, $37, $39, $2B,
    $25, $7F, $71, $63, $6D, $47, $49, $5B, $55, $EF, $E1, $F3, $FD, $D7, $D9,
    $CB, $C5, $9F, $91, $83, $8D, $A7, $A9, $BB, $B5, $0A, $04, $16, $18, $32,
    $3C, $2E, $20, $7A, $74, $66, $68, $42, $4C, $5E, $50, $EA, $E4, $F6, $F8,
    $D2, $DC, $CE, $C0, $9A, $94, $86, $88, $A2, $AC, $BE, $B0, $09, $07, $15,
    $1B, $31, $3F, $2D, $23, $79, $77, $65, $6B, $41, $4F, $5D, $53, $E9, $E7,
    $F5, $FB, $D1, $DF, $CD, $C3, $99, $97, $85, $8B, $A1, $AF, $BD, $B3, $00,
    $0F, $1E, $11, $3C, $33, $22, $2D, $78, $77, $66, $69, $44, $4B, $5A, $55,
    $F0, $FF, $EE, $E1, $CC, $C3, $D2, $DD, $88, $87, $96, $99, $B4, $BB, $AA,
    $A5, $23, $2C, $3D, $32, $1F, $10, $01, $0E, $5B, $54, $45, $4A, $67, $68,
    $79, $76, $D3, $DC, $CD, $C2, $EF, $E0, $F1, $FE, $AB, $A4, $B5, $BA, $97,
    $98, $89, $86, $46, $49, $58, $57, $7A, $75, $64, $6B, $3E, $31, $20, $2F,
    $02, $0D, $1C, $13, $B6, $B9, $A8, $A7, $8A, $85, $94, $9B, $CE, $C1, $D0,
    $DF, $F2, $FD, $EC, $E3, $65, $6A, $7B, $74, $59, $56, $47, $48, $1D, $12,
    $03, $0C, $21, $2E, $3F, $30, $95, $9A, $8B, $84, $A9, $A6, $B7, $B8, $ED,
    $E2, $F3, $FC, $D1, $DE, $CF, $C0, $8C, $83, $92, $9D, $B0, $BF, $AE, $A1,
    $F4, $FB, $EA, $E5, $C8, $C7, $D6, $D9, $7C, $73, $62, $6D, $40, $4F, $5E,
    $51, $04, $0B, $1A, $15, $38, $37, $26, $29, $AF, $A0, $B1, $BE, $93, $9C,
    $8D, $82, $D7, $D8, $C9, $C6, $EB, $E4, $F5, $FA, $5F, $50, $41, $4E, $63,
    $6C, $7D, $72, $27, $28, $39, $36, $1B, $14, $05, $0A, $CA, $C5, $D4, $DB,
    $F6, $F9, $E8, $E7, $B2, $BD, $AC, $A3, $8E, $81, $90, $9F, $3A, $35, $24,
    $2B, $06, $09, $18, $17, $42, $4D, $5C, $53, $7E, $71, $60, $6F, $E9, $E6,
    $F7, $F8, $D5, $DA, $CB, $C4, $91, $9E, $8F, $80, $AD, $A2, $B3, $BC, $19,
    $16, $07, $08, $25, $2A, $3B, $34, $61, $6E, $7F, $70, $5D, $52, $43, $4C,
    $00, $10, $20, $30, $40, $50, $60, $70, $80, $90, $A0, $B0, $C0, $D0, $E0,
    $F0, $C3, $D3, $E3, $F3, $83, $93, $A3, $B3, $43, $53, $63, $73, $03, $13,
    $23, $33, $45, $55, $65, $75, $05, $15, $25, $35, $C5, $D5, $E5, $F5, $85,
    $95, $A5, $B5, $86, $96, $A6, $B6, $C6, $D6, $E6, $F6, $06, $16, $26, $36,
    $46, $56, $66, $76, $8A, $9A, $AA, $BA, $CA, $DA, $EA, $FA, $0A, $1A, $2A,
    $3A, $4A, $5A, $6A, $7A, $49, $59, $69, $79, $09, $19, $29, $39, $C9, $D9,
    $E9, $F9, $89, $99, $A9, $B9, $CF, $DF, $EF, $FF, $8F, $9F, $AF, $BF, $4F,
    $5F, $6F, $7F, $0F, $1F, $2F, $3F, $0C, $1C, $2C, $3C, $4C, $5C, $6C, $7C,
    $8C, $9C, $AC, $BC, $CC, $DC, $EC, $FC, $D7, $C7, $F7, $E7, $97, $87, $B7,
    $A7, $57, $47, $77, $67, $17, $07, $37, $27, $14, $04, $34, $24, $54, $44,
    $74, $64, $94, $84, $B4, $A4, $D4, $C4, $F4, $E4, $92, $82, $B2, $A2, $D2,
    $C2, $F2, $E2, $12, $02, $32, $22, $52, $42, $72, $62, $51, $41, $71, $61,
    $11, $01, $31, $21, $D1, $C1, $F1, $E1, $91, $81, $B1, $A1, $5D, $4D, $7D,
    $6D, $1D, $0D, $3D, $2D, $DD, $CD, $FD, $ED, $9D, $8D, $BD, $AD, $9E, $8E,
    $BE, $AE, $DE, $CE, $FE, $EE, $1E, $0E, $3E, $2E, $5E, $4E, $7E, $6E, $18,
    $08, $38, $28, $58, $48, $78, $68, $98, $88, $B8, $A8, $D8, $C8, $F8, $E8,
    $DB, $CB, $FB, $EB, $9B, $8B, $BB, $AB, $5B, $4B, $7B, $6B, $1B, $0B, $3B,
    $2B, $00, $11, $22, $33, $44, $55, $66, $77, $88, $99, $AA, $BB, $CC, $DD,
    $EE, $FF, $D3, $C2, $F1, $E0, $97, $86, $B5, $A4, $5B, $4A, $79, $68, $1F,
    $0E, $3D, $2C, $65, $74, $47, $56, $21, $30, $03, $12, $ED, $FC, $CF, $DE,
    $A9, $B8, $8B, $9A, $B6, $A7, $94, $85, $F2, $E3, $D0, $C1, $3E, $2F, $1C,
    $0D, $7A, $6B, $58, $49, $CA, $DB, $E8, $F9, $8E, $9F, $AC, $BD, $42, $53,
    $60, $71, $06, $17, $24, $35, $19, $08, $3B, $2A, $5D, $4C, $7F, $6E, $91,
    $80, $B3, $A2, $D5, $C4, $F7, $E6, $AF, $BE, $8D, $9C, $EB, $FA, $C9, $D8,
    $27, $36, $05, $14, $63, $72, $41, $50, $7C, $6D, $5E, $4F, $38, $29, $1A,
    $0B, $F4, $E5, $D6, $C7, $B0, $A1, $92, $83, $57, $46, $75, $64, $13, $02,
    $31, $20, $DF, $CE, $FD, $EC, $9B, $8A, $B9, $A8, $84, $95, $A6, $B7, $C0,
    $D1, $E2, $F3, $0C, $1D, $2E, $3F, $48, $59, $6A, $7B, $32, $23, $10, $01,
    $76, $67, $54, $45, $BA, $AB, $98, $89, $FE, $EF, $DC, $CD, $E1, $F0, $C3,
    $D2, $A5, $B4, $87, $96, $69, $78, $4B, $5A, $2D, $3C, $0F, $1E, $9D, $8C,
    $BF, $AE, $D9, $C8, $FB, $EA, $15, $04, $37, $26, $51, $40, $73, $62, $4E,
    $5F, $6C, $7D, $0A, $1B, $28, $39, $C6, $D7, $E4, $F5, $82, $93, $A0, $B1,
    $F8, $E9, $DA, $CB, $BC, $AD, $9E, $8F, $70, $61, $52, $43, $34, $25, $16,
    $07, $2B, $3A, $09, $18, $6F, $7E, $4D, $5C, $A3, $B2, $81, $90, $E7, $F6,
    $C5, $D4, $00, $12, $24, $36, $48, $5A, $6C, $7E, $90, $82, $B4, $A6, $D8,
    $CA, $FC, $EE, $E3, $F1, $C7, $D5, $AB, $B9, $8F, $9D, $73, $61, $57, $45,
    $3B, $29, $1F, $0D, $05, $17, $21, $33, $4D, $5F, $69, $7B, $95, $87, $B1,
    $A3, $DD, $CF, $F9, $EB, $E6, $F4, $C2, $D0, $AE, $BC, $8A, $98, $76, $64,
    $52, $40, $3E, $2C, $1A, $08, $0A, $18, $2E, $3C, $42, $50, $66, $74, $9A,
    $88, $BE, $AC, $D2, $C0, $F6, $E4, $E9, $FB, $CD, $DF, $A1, $B3, $85, $97,
    $79, $6B, $5D, $4F, $31, $23, $15, $07, $0F, $1D, $2B, $39, $47, $55, $63,
    $71, $9F, $8D, $BB, $A9, $D7, $C5, $F3, $E1, $EC, $FE, $C8, $DA, $A4, $B6,
    $80, $92, $7C, $6E, $58, $4A, $34, $26, $10, $02, $14, $06, $30, $22, $5C,
    $4E, $78, $6A, $84, $96, $A0, $B2, $CC, $DE, $E8, $FA, $F7, $E5, $D3, $C1,
    $BF, $AD, $9B, $89, $67, $75, $43, $51, $2F, $3D, $0B, $19, $11, $03, $35,
    $27, $59, $4B, $7D, $6F, $81, $93, $A5, $B7, $C9, $DB, $ED, $FF, $F2, $E0,
    $D6, $C4, $BA, $A8, $9E, $8C, $62, $70, $46, $54, $2A, $38, $0E, $1C, $1E,
    $0C, $3A, $28, $56, $44, $72, $60, $8E, $9C, $AA, $B8, $C6, $D4, $E2, $F0,
    $FD, $EF, $D9, $CB, $B5, $A7, $91, $83, $6D, $7F, $49, $5B, $25, $37, $01,
    $13, $1B, $09, $3F, $2D, $53, $41, $77, $65, $8B, $99, $AF, $BD, $C3, $D1,
    $E7, $F5, $F8, $EA, $DC, $CE, $B0, $A2, $94, $86, $68, $7A, $4C, $5E, $20,
    $32, $04, $16, $00, $13, $26, $35, $4C, $5F, $6A, $79, $98, $8B, $BE, $AD,
    $D4, $C7, $F2, $E1, $F3, $E0, $D5, $C6, $BF, $AC, $99, $8A, $6B, $78, $4D,
    $5E, $27, $34, $01, $12, $25, $36, $03, $10, $69, $7A, $4F, $5C, $BD, $AE,
    $9B, $88, $F1, $E2, $D7, $C4, $D6, $C5, $F0, $E3, $9A, $89, $BC, $AF, $4E,
    $5D, $68, $7B, $02, $11, $24, $37, $4A, $59, $6C, $7F, $06, $15, $20, $33,
    $D2, $C1, $F4, $E7, $9E, $8D, $B8, $AB, $B9, $AA, $9F, $8C, $F5, $E6, $D3,
    $C0, $21, $32, $07, $14, $6D, $7E, $4B, $58, $6F, $7C, $49, $5A, $23, $30,
    $05, $16, $F7, $E4, $D1, $C2, $BB, $A8, $9D, $8E, $9C, $8F, $BA, $A9, $D0,
    $C3, $F6, $E5, $04, $17, $22, $31, $48, $5B, $6E, $7D, $94, $87, $B2, $A1,
    $D8, $CB, $FE, $ED, $0C, $1F, $2A, $39, $40, $53, $66, $75, $67, $74, $41,
    $52, $2B, $38, $0D, $1E, $FF, $EC, $D9, $CA, $B3, $A0, $95, $86, $B1, $A2,
    $97, $84, $FD, $EE, $DB, $C8, $29, $3A, $0F, $1C, $65, $76, $43, $50, $42,
    $51, $64, $77, $0E, $1D, $28, $3B, $DA, $C9, $FC, $EF, $96, $85, $B0, $A3,
    $DE, $CD, $F8, $EB, $92, $81, $B4, $A7, $46, $55, $60, $73, $0A, $19, $2C,
    $3F, $2D, $3E, $0B, $18, $61, $72, $47, $54, $B5, $A6, $93, $80, $F9, $EA,
    $DF, $CC, $FB, $E8, $DD, $CE, $B7, $A4, $91, $82, $63, $70, $45, $56, $2F,
    $3C, $09, $1A, $08, $1B, $2E, $3D, $44, $57, $62, $71, $90, $83, $B6, $A5,
    $DC, $CF, $FA, $E9, $00, $14, $28, $3C, $50, $44, $78, $6C, $A0, $B4, $88,
    $9C, $F0, $E4, $D8, $CC, $83, $97, $AB, $BF, $D3, $C7, $FB, $EF, $23, $37,
    $0B, $1F, $73, $67, $5B, $4F, $C5, $D1, $ED, $F9, $95, $81, $BD, $A9, $65,
    $71, $4D, $59, $35, $21, $1D, $09, $46, $52, $6E, $7A, $16, $02, $3E, $2A,
    $E6, $F2, $CE, $DA, $B6, $A2, $9E, $8A, $49, $5D, $61, $75, $19, $0D, $31,
    $25, $E9, $FD, $C1, $D5, $B9, $AD, $91, $85, $CA, $DE, $E2, $F6, $9A, $8E,
    $B2, $A6, $6A, $7E, $42, $56, $3A, $2E, $12, $06, $8C, $98, $A4, $B0, $DC,
    $C8, $F4, $E0, $2C, $38, $04, $10, $7C, $68, $54, $40, $0F, $1B, $27, $33,
    $5F, $4B, $77, $63, $AF, $BB, $87, $93, $FF, $EB, $D7, $C3, $92, $86, $BA,
    $AE, $C2, $D6, $EA, $FE, $32, $26, $1A, $0E, $62, $76, $4A, $5E, $11, $05,
    $39, $2D, $41, $55, $69, $7D, $B1, $A5, $99, $8D, $E1, $F5, $C9, $DD, $57,
    $43, $7F, $6B, $07, $13, $2F, $3B, $F7, $E3, $DF, $CB, $A7, $B3, $8F, $9B,
    $D4, $C0, $FC, $E8, $84, $90, $AC, $B8, $74, $60, $5C, $48, $24, $30, $0C,
    $18, $DB, $CF, $F3, $E7, $8B, $9F, $A3, $B7, $7B, $6F, $53, $47, $2B, $3F,
    $03, $17, $58, $4C, $70, $64, $08, $1C, $20, $34, $F8, $EC, $D0, $C4, $A8,
    $BC, $80, $94, $1E, $0A, $36, $22, $4E, $5A, $66, $72, $BE, $AA, $96, $82,
    $EE, $FA, $C6, $D2, $9D, $89, $B5, $A1, $CD, $D9, $E5, $F1, $3D, $29, $15,
    $01, $6D, $79, $45, $51, $00, $15, $2A, $3F, $54, $41, $7E, $6B, $A8, $BD,
    $82, $97, $FC, $E9, $D6, $C3, $93, $86, $B9, $AC, $C7, $D2, $ED, $F8, $3B,
    $2E, $11, $04, $6F, $7A, $45, $50, $E5, $F0, $CF, $DA, $B1, $A4, $9B, $8E,
    $4D, $58, $67, $72, $19, $0C, $33, $26, $76, $63, $5C, $49, $22, $37, $08,
    $1D, $DE, $CB, $F4, $E1, $8A, $9F, $A0, $B5, $09, $1C, $23, $36, $5D, $48,
    $77, $62, $A1, $B4, $8B, $9E, $F5, $E0, $DF, $CA, $9A, $8F, $B0, $A5, $CE,
    $DB, $E4, $F1, $32, $27, $18, $0D, $66, $73, $4C, $59, $EC, $F9, $C6, $D3,
    $B8, $AD, $92, $87, $44, $51, $6E, $7B, $10, $05, $3A, $2F, $7F, $6A, $55,
    $40, $2B, $3E, $01, $14, $D7, $C2, $FD, $E8, $83, $96, $A9, $BC, $12, $07,
    $38, $2D, $46, $53, $6C, $79, $BA, $AF, $90, $85, $EE, $FB, $C4, $D1, $81,
    $94, $AB, $BE, $D5, $C0, $FF, $EA, $29, $3C, $03, $16, $7D, $68, $57, $42,
    $F7, $E2, $DD, $C8, $A3, $B6, $89, $9C, $5F, $4A, $75, $60, $0B, $1E, $21,
    $34, $64, $71, $4E, $5B, $30, $25, $1A, $0F, $CC, $D9, $E6, $F3, $98, $8D,
    $B2, $A7, $1B, $0E, $31, $24, $4F, $5A, $65, $70, $B3, $A6, $99, $8C, $E7,
    $F2, $CD, $D8, $88, $9D, $A2, $B7, $DC, $C9, $F6, $E3, $20, $35, $0A, $1F,
    $74, $61, $5E, $4B, $FE, $EB, $D4, $C1, $AA, $BF, $80, $95, $56, $43, $7C,
    $69, $02, $17, $28, $3D, $6D, $78, $47, $52, $39, $2C, $13, $06, $C5, $D0,
    $EF, $FA, $91, $84, $BB, $AE, $00, $16, $2C, $3A, $58, $4E, $74, $62, $B0,
    $A6, $9C, $8A, $E8, $FE, $C4, $D2, $A3, $B5, $8F, $99, $FB, $ED, $D7, $C1,
    $13, $05, $3F, $29, $4B, $5D, $67, $71, $85, $93, $A9, $BF, $DD, $CB, $F1,
    $E7, $35, $23, $19, $0F, $6D, $7B, $41, $57, $26, $30, $0A, $1C, $7E, $68,
    $52, $44, $96, $80, $BA, $AC, $CE, $D8, $E2, $F4, $C9, $DF, $E5, $F3, $91,
    $87, $BD, $AB, $79, $6F, $55, $43, $21, $37, $0D, $1B, $6A, $7C, $46, $50,
    $32, $24, $1E, $08, $DA, $CC, $F6, $E0, $82, $94, $AE, $B8, $4C, $5A, $60,
    $76, $14, $02, $38, $2E, $FC, $EA, $D0, $C6, $A4, $B2, $88, $9E, $EF, $F9,
    $C3, $D5, $B7, $A1, $9B, $8D, $5F, $49, $73, $65, $07, $11, $2B, $3D, $51,
    $47, $7D, $6B, $09, $1F, $25, $33, $E1, $F7, $CD, $DB, $B9, $AF, $95, $83,
    $F2, $E4, $DE, $C8, $AA, $BC, $86, $90, $42, $54, $6E, $78, $1A, $0C, $36,
    $20, $D4, $C2, $F8, $EE, $8C, $9A, $A0, $B6, $64, $72, $48, $5E, $3C, $2A,
    $10, $06, $77, $61, $5B, $4D, $2F, $39, $03, $15, $C7, $D1, $EB, $FD, $9F,
    $89, $B3, $A5, $98, $8E, $B4, $A2, $C0, $D6, $EC, $FA, $28, $3E, $04, $12,
    $70, $66, $5C, $4A, $3B, $2D, $17, $01, $63, $75, $4F, $59, $8B, $9D, $A7,
    $B1, $D3, $C5, $FF, $E9, $1D, $0B, $31, $27, $45, $53, $69, $7F, $AD, $BB,
    $81, $97, $F5, $E3, $D9, $CF, $BE, $A8, $92, $84, $E6, $F0, $CA, $DC, $0E,
    $18, $22, $34, $56, $40, $7A, $6C, $00, $17, $2E, $39, $5C, $4B, $72, $65,
    $B8, $AF, $96, $81, $E4, $F3, $CA, $DD, $B3, $A4, $9D, $8A, $EF, $F8, $C1,
    $D6, $0B, $1C, $25, $32, $57, $40, $79, $6E, $A5, $B2, $8B, $9C, $F9, $EE,
    $D7, $C0, $1D, $0A, $33, $24, $41, $56, $6F, $78, $16, $01, $38, $2F, $4A,
    $5D, $64, $73, $AE, $B9, $80, $97, $F2, $E5, $DC, $CB, $89, $9E, $A7, $B0,
    $D5, $C2, $FB, $EC, $31, $26, $1F, $08, $6D, $7A, $43, $54, $3A, $2D, $14,
    $03, $66, $71, $48, $5F, $82, $95, $AC, $BB, $DE, $C9, $F0, $E7, $2C, $3B,
    $02, $15, $70, $67, $5E, $49, $94, $83, $BA, $AD, $C8, $DF, $E6, $F1, $9F,
    $88, $B1, $A6, $C3, $D4, $ED, $FA, $27, $30, $09, $1E, $7B, $6C, $55, $42,
    $D1, $C6, $FF, $E8, $8D, $9A, $A3, $B4, $69, $7E, $47, $50, $35, $22, $1B,
    $0C, $62, $75, $4C, $5B, $3E, $29, $10, $07, $DA, $CD, $F4, $E3, $86, $91,
    $A8, $BF, $74, $63, $5A, $4D, $28, $3F, $06, $11, $CC, $DB, $E2, $F5, $90,
    $87, $BE, $A9, $C7, $D0, $E9, $FE, $9B, $8C, $B5, $A2, $7F, $68, $51, $46,
    $23, $34, $0D, $1A, $58, $4F, $76, $61, $04, $13, $2A, $3D, $E0, $F7, $CE,
    $D9, $BC, $AB, $92, $85, $EB, $FC, $C5, $D2, $B7, $A0, $99, $8E, $53, $44,
    $7D, $6A, $0F, $18, $21, $36, $FD, $EA, $D3, $C4, $A1, $B6, $8F, $98, $45,
    $52, $6B, $7C, $19, $0E, $37, $20, $4E, $59, $60, $77, $12, $05, $3C, $2B,
    $F6, $E1, $D8, $CF, $AA, $BD, $84, $93, $00, $18, $30, $28, $60, $78, $50,
    $48, $C0, $D8, $F0, $E8, $A0, $B8, $90, $88, $43, $5B, $73, $6B, $23, $3B,
    $13, $0B, $83, $9B, $B3, $AB, $E3, $FB, $D3, $CB, $86, $9E, $B6, $AE, $E6,
    $FE, $D6, $CE, $46, $5E, $76, $6E, $26, $3E, $16, $0E, $C5, $DD, $F5, $ED,
    $A5, $BD, $95, $8D, $05, $1D, $35, $2D, $65, $7D, $55, $4D, $CF, $D7, $FF,
    $E7, $AF, $B7, $9F, $87, $0F, $17, $3F, $27, $6F, $77, $5F, $47, $8C, $94,
    $BC, $A4, $EC, $F4, $DC, $C4, $4C, $54, $7C, $64, $2C, $34, $1C, $04, $49,
    $51, $79, $61, $29, $31, $19, $01, $89, $91, $B9, $A1, $E9, $F1, $D9, $C1,
    $0A, $12, $3A, $22, $6A, $72, $5A, $42, $CA, $D2, $FA, $E2, $AA, $B2, $9A,
    $82, $5D, $45, $6D, $75, $3D, $25, $0D, $15, $9D, $85, $AD, $B5, $FD, $E5,
    $CD, $D5, $1E, $06, $2E, $36, $7E, $66, $4E, $56, $DE, $C6, $EE, $F6, $BE,
    $A6, $8E, $96, $DB, $C3, $EB, $F3, $BB, $A3, $8B, $93, $1B, $03, $2B, $33,
    $7B, $63, $4B, $53, $98, $80, $A8, $B0, $F8, $E0, $C8, $D0, $58, $40, $68,
    $70, $38, $20, $08, $10, $92, $8A, $A2, $BA, $F2, $EA, $C2, $DA, $52, $4A,
    $62, $7A, $32, $2A, $02, $1A, $D1, $C9, $E1, $F9, $B1, $A9, $81, $99, $11,
    $09, $21, $39, $71, $69, $41, $59, $14, $0C, $24, $3C, $74, $6C, $44, $5C,
    $D4, $CC, $E4, $FC, $B4, $AC, $84, $9C, $57, $4F, $67, $7F, $37, $2F, $07,
    $1F, $97, $8F, $A7, $BF, $F7, $EF, $C7, $DF, $00, $19, $32, $2B, $64, $7D,
    $56, $4F, $C8, $D1, $FA, $E3, $AC, $B5, $9E, $87, $53, $4A, $61, $78, $37,
    $2E, $05, $1C, $9B, $82, $A9, $B0, $FF, $E6, $CD, $D4, $A6, $BF, $94, $8D,
    $C2, $DB, $F0, $E9, $6E, $77, $5C, $45, $0A, $13, $38, $21, $F5, $EC, $C7,
    $DE, $91, $88, $A3, $BA, $3D, $24, $0F, $16, $59, $40, $6B, $72, $8F, $96,
    $BD, $A4, $EB, $F2, $D9, $C0, $47, $5E, $75, $6C, $23, $3A, $11, $08, $DC,
    $C5, $EE, $F7, $B8, $A1, $8A, $93, $14, $0D, $26, $3F, $70, $69, $42, $5B,
    $29, $30, $1B, $02, $4D, $54, $7F, $66, $E1, $F8, $D3, $CA, $85, $9C, $B7,
    $AE, $7A, $63, $48, $51, $1E, $07, $2C, $35, $B2, $AB, $80, $99, $D6, $CF,
    $E4, $FD, $DD, $C4, $EF, $F6, $B9, $A0, $8B, $92, $15, $0C, $27, $3E, $71,
    $68, $43, $5A, $8E, $97, $BC, $A5, $EA, $F3, $D8, $C1, $46, $5F, $74, $6D,
    $22, $3B, $10, $09, $7B, $62, $49, $50, $1F, $06, $2D, $34, $B3, $AA, $81,
    $98, $D7, $CE, $E5, $FC, $28, $31, $1A, $03, $4C, $55, $7E, $67, $E0, $F9,
    $D2, $CB, $84, $9D, $B6, $AF, $52, $4B, $60, $79, $36, $2F, $04, $1D, $9A,
    $83, $A8, $B1, $FE, $E7, $CC, $D5, $01, $18, $33, $2A, $65, $7C, $57, $4E,
    $C9, $D0, $FB, $E2, $AD, $B4, $9F, $86, $F4, $ED, $C6, $DF, $90, $89, $A2,
    $BB, $3C, $25, $0E, $17, $58, $41, $6A, $73, $A7, $BE, $95, $8C, $C3, $DA,
    $F1, $E8, $6F, $76, $5D, $44, $0B, $12, $39, $20, $00, $1A, $34, $2E, $68,
    $72, $5C, $46, $D0, $CA, $E4, $FE, $B8, $A2, $8C, $96, $63, $79, $57, $4D,
    $0B, $11, $3F, $25, $B3, $A9, $87, $9D, $DB, $C1, $EF, $F5, $C6, $DC, $F2,
    $E8, $AE, $B4, $9A, $80, $16, $0C, $22, $38, $7E, $64, $4A, $50, $A5, $BF,
    $91, $8B, $CD, $D7, $F9, $E3, $75, $6F, $41, $5B, $1D, $07, $29, $33, $4F,
    $55, $7B, $61, $27, $3D, $13, $09, $9F, $85, $AB, $B1, $F7, $ED, $C3, $D9,
    $2C, $36, $18, $02, $44, $5E, $70, $6A, $FC, $E6, $C8, $D2, $94, $8E, $A0,
    $BA, $89, $93, $BD, $A7, $E1, $FB, $D5, $CF, $59, $43, $6D, $77, $31, $2B,
    $05, $1F, $EA, $F0, $DE, $C4, $82, $98, $B6, $AC, $3A, $20, $0E, $14, $52,
    $48, $66, $7C, $9E, $84, $AA, $B0, $F6, $EC, $C2, $D8, $4E, $54, $7A, $60,
    $26, $3C, $12, $08, $FD, $E7, $C9, $D3, $95, $8F, $A1, $BB, $2D, $37, $19,
    $03, $45, $5F, $71, $6B, $58, $42, $6C, $76, $30, $2A, $04, $1E, $88, $92,
    $BC, $A6, $E0, $FA, $D4, $CE, $3B, $21, $0F, $15, $53, $49, $67, $7D, $EB,
    $F1, $DF, $C5, $83, $99, $B7, $AD, $D1, $CB, $E5, $FF, $B9, $A3, $8D, $97,
    $01, $1B, $35, $2F, $69, $73, $5D, $47, $B2, $A8, $86, $9C, $DA, $C0, $EE,
    $F4, $62, $78, $56, $4C, $0A, $10, $3E, $24, $17, $0D, $23, $39, $7F, $65,
    $4B, $51, $C7, $DD, $F3, $E9, $AF, $B5, $9B, $81, $74, $6E, $40, $5A, $1C,
    $06, $28, $32, $A4, $BE, $90, $8A, $CC, $D6, $F8, $E2, $00, $1B, $36, $2D,
    $6C, $77, $5A, $41, $D8, $C3, $EE, $F5, $B4, $AF, $82, $99, $73, $68, $45,
    $5E, $1F, $04, $29, $32, $AB, $B0, $9D, $86, $C7, $DC, $F1, $EA, $E6, $FD,
    $D0, $CB, $8A, $91, $BC, $A7, $3E, $25, $08, $13, $52, $49, $64, $7F, $95,
    $8E, $A3, $B8, $F9, $E2, $CF, $D4, $4D, $56, $7B, $60, $21, $3A, $17, $0C,
    $0F, $14, $39, $22, $63, $78, $55, $4E, $D7, $CC, $E1, $FA, $BB, $A0, $8D,
    $96, $7C, $67, $4A, $51, $10, $0B, $26, $3D, $A4, $BF, $92, $89, $C8, $D3,
    $FE, $E5, $E9, $F2, $DF, $C4, $85, $9E, $B3, $A8, $31, $2A, $07, $1C, $5D,
    $46, $6B, $70, $9A, $81, $AC, $B7, $F6, $ED, $C0, $DB, $42, $59, $74, $6F,
    $2E, $35, $18, $03, $1E, $05, $28, $33, $72, $69, $44, $5F, $C6, $DD, $F0,
    $EB, $AA, $B1, $9C, $87, $6D, $76, $5B, $40, $01, $1A, $37, $2C, $B5, $AE,
    $83, $98, $D9, $C2, $EF, $F4, $F8, $E3, $CE, $D5, $94, $8F, $A2, $B9, $20,
    $3B, $16, $0D, $4C, $57, $7A, $61, $8B, $90, $BD, $A6, $E7, $FC, $D1, $CA,
    $53, $48, $65, $7E, $3F, $24, $09, $12, $11, $0A, $27, $3C, $7D, $66, $4B,
    $50, $C9, $D2, $FF, $E4, $A5, $BE, $93, $88, $62, $79, $54, $4F, $0E, $15,
    $38, $23, $BA, $A1, $8C, $97, $D6, $CD, $E0, $FB, $F7, $EC, $C1, $DA, $9B,
    $80, $AD, $B6, $2F, $34, $19, $02, $43, $58, $75, $6E, $84, $9F, $B2, $A9,
    $E8, $F3, $DE, $C5, $5C, $47, $6A, $71, $30, $2B, $06, $1D, $00, $1C, $38,
    $24, $70, $6C, $48, $54, $E0, $FC, $D8, $C4, $90, $8C, $A8, $B4, $03, $1F,
    $3B, $27, $73, $6F, $4B, $57, $E3, $FF, $DB, $C7, $93, $8F, $AB, $B7, $06,
    $1A, $3E, $22, $76, $6A, $4E, $52, $E6, $FA, $DE, $C2, $96, $8A, $AE, $B2,
    $05, $19, $3D, $21, $75, $69, $4D, $51, $E5, $F9, $DD, $C1, $95, $89, $AD,
    $B1, $0C, $10, $34, $28, $7C, $60, $44, $58, $EC, $F0, $D4, $C8, $9C, $80,
    $A4, $B8, $0F, $13, $37, $2B, $7F, $63, $47, $5B, $EF, $F3, $D7, $CB, $9F,
    $83, $A7, $BB, $0A, $16, $32, $2E, $7A, $66, $42, $5E, $EA, $F6, $D2, $CE,
    $9A, $86, $A2, $BE, $09, $15, $31, $2D, $79, $65, $41, $5D, $E9, $F5, $D1,
    $CD, $99, $85, $A1, $BD, $18, $04, $20, $3C, $68, $74, $50, $4C, $F8, $E4,
    $C0, $DC, $88, $94, $B0, $AC, $1B, $07, $23, $3F, $6B, $77, $53, $4F, $FB,
    $E7, $C3, $DF, $8B, $97, $B3, $AF, $1E, $02, $26, $3A, $6E, $72, $56, $4A,
    $FE, $E2, $C6, $DA, $8E, $92, $B6, $AA, $1D, $01, $25, $39, $6D, $71, $55,
    $49, $FD, $E1, $C5, $D9, $8D, $91, $B5, $A9, $14, $08, $2C, $30, $64, $78,
    $5C, $40, $F4, $E8, $CC, $D0, $84, $98, $BC, $A0, $17, $0B, $2F, $33, $67,
    $7B, $5F, $43, $F7, $EB, $CF, $D3, $87, $9B, $BF, $A3, $12, $0E, $2A, $36,
    $62, $7E, $5A, $46, $F2, $EE, $CA, $D6, $82, $9E, $BA, $A6, $11, $0D, $29,
    $35, $61, $7D, $59, $45, $F1, $ED, $C9, $D5, $81, $9D, $B9, $A5, $00, $1D,
    $3A, $27, $74, $69, $4E, $53, $E8, $F5, $D2, $CF, $9C, $81, $A6, $BB, $13,
    $0E, $29, $34, $67, $7A, $5D, $40, $FB, $E6, $C1, $DC, $8F, $92, $B5, $A8,
    $26, $3B, $1C, $01, $52, $4F, $68, $75, $CE, $D3, $F4, $E9, $BA, $A7, $80,
    $9D, $35, $28, $0F, $12, $41, $5C, $7B, $66, $DD, $C0, $E7, $FA, $A9, $B4,
    $93, $8E, $4C, $51, $76, $6B, $38, $25, $02, $1F, $A4, $B9, $9E, $83, $D0,
    $CD, $EA, $F7, $5F, $42, $65, $78, $2B, $36, $11, $0C, $B7, $AA, $8D, $90,
    $C3, $DE, $F9, $E4, $6A, $77, $50, $4D, $1E, $03, $24, $39, $82, $9F, $B8,
    $A5, $F6, $EB, $CC, $D1, $79, $64, $43, $5E, $0D, $10, $37, $2A, $91, $8C,
    $AB, $B6, $E5, $F8, $DF, $C2, $98, $85, $A2, $BF, $EC, $F1, $D6, $CB, $70,
    $6D, $4A, $57, $04, $19, $3E, $23, $8B, $96, $B1, $AC, $FF, $E2, $C5, $D8,
    $63, $7E, $59, $44, $17, $0A, $2D, $30, $BE, $A3, $84, $99, $CA, $D7, $F0,
    $ED, $56, $4B, $6C, $71, $22, $3F, $18, $05, $AD, $B0, $97, $8A, $D9, $C4,
    $E3, $FE, $45, $58, $7F, $62, $31, $2C, $0B, $16, $D4, $C9, $EE, $F3, $A0,
    $BD, $9A, $87, $3C, $21, $06, $1B, $48, $55, $72, $6F, $C7, $DA, $FD, $E0,
    $B3, $AE, $89, $94, $2F, $32, $15, $08, $5B, $46, $61, $7C, $F2, $EF, $C8,
    $D5, $86, $9B, $BC, $A1, $1A, $07, $20, $3D, $6E, $73, $54, $49, $E1, $FC,
    $DB, $C6, $95, $88, $AF, $B2, $09, $14, $33, $2E, $7D, $60, $47, $5A, $00,
    $1E, $3C, $22, $78, $66, $44, $5A, $F0, $EE, $CC, $D2, $88, $96, $B4, $AA,
    $23, $3D, $1F, $01, $5B, $45, $67, $79, $D3, $CD, $EF, $F1, $AB, $B5, $97,
    $89, $46, $58, $7A, $64, $3E, $20, $02, $1C, $B6, $A8, $8A, $94, $CE, $D0,
    $F2, $EC, $65, $7B, $59, $47, $1D, $03, $21, $3F, $95, $8B, $A9, $B7, $ED,
    $F3, $D1, $CF, $8C, $92, $B0, $AE, $F4, $EA, $C8, $D6, $7C, $62, $40, $5E,
    $04, $1A, $38, $26, $AF, $B1, $93, $8D, $D7, $C9, $EB, $F5, $5F, $41, $63,
    $7D, $27, $39, $1B, $05, $CA, $D4, $F6, $E8, $B2, $AC, $8E, $90, $3A, $24,
    $06, $18, $42, $5C, $7E, $60, $E9, $F7, $D5, $CB, $91, $8F, $AD, $B3, $19,
    $07, $25, $3B, $61, $7F, $5D, $43, $DB, $C5, $E7, $F9, $A3, $BD, $9F, $81,
    $2B, $35, $17, $09, $53, $4D, $6F, $71, $F8, $E6, $C4, $DA, $80, $9E, $BC,
    $A2, $08, $16, $34, $2A, $70, $6E, $4C, $52, $9D, $83, $A1, $BF, $E5, $FB,
    $D9, $C7, $6D, $73, $51, $4F, $15, $0B, $29, $37, $BE, $A0, $82, $9C, $C6,
    $D8, $FA, $E4, $4E, $50, $72, $6C, $36, $28, $0A, $14, $57, $49, $6B, $75,
    $2F, $31, $13, $0D, $A7, $B9, $9B, $85, $DF, $C1, $E3, $FD, $74, $6A, $48,
    $56, $0C, $12, $30, $2E, $84, $9A, $B8, $A6, $FC, $E2, $C0, $DE, $11, $0F,
    $2D, $33, $69, $77, $55, $4B, $E1, $FF, $DD, $C3, $99, $87, $A5, $BB, $32,
    $2C, $0E, $10, $4A, $54, $76, $68, $C2, $DC, $FE, $E0, $BA, $A4, $86, $98,
    $00, $1F, $3E, $21, $7C, $63, $42, $5D, $F8, $E7, $C6, $D9, $84, $9B, $BA,
    $A5, $33, $2C, $0D, $12, $4F, $50, $71, $6E, $CB, $D4, $F5, $EA, $B7, $A8,
    $89, $96, $66, $79, $58, $47, $1A, $05, $24, $3B, $9E, $81, $A0, $BF, $E2,
    $FD, $DC, $C3, $55, $4A, $6B, $74, $29, $36, $17, $08, $AD, $B2, $93, $8C,
    $D1, $CE, $EF, $F0, $CC, $D3, $F2, $ED, $B0, $AF, $8E, $91, $34, $2B, $0A,
    $15, $48, $57, $76, $69, $FF, $E0, $C1, $DE, $83, $9C, $BD, $A2, $07, $18,
    $39, $26, $7B, $64, $45, $5A, $AA, $B5, $94, $8B, $D6, $C9, $E8, $F7, $52,
    $4D, $6C, $73, $2E, $31, $10, $0F, $99, $86, $A7, $B8, $E5, $FA, $DB, $C4,
    $61, $7E, $5F, $40, $1D, $02, $23, $3C, $5B, $44, $65, $7A, $27, $38, $19,
    $06, $A3, $BC, $9D, $82, $DF, $C0, $E1, $FE, $68, $77, $56, $49, $14, $0B,
    $2A, $35, $90, $8F, $AE, $B1, $EC, $F3, $D2, $CD, $3D, $22, $03, $1C, $41,
    $5E, $7F, $60, $C5, $DA, $FB, $E4, $B9, $A6, $87, $98, $0E, $11, $30, $2F,
    $72, $6D, $4C, $53, $F6, $E9, $C8, $D7, $8A, $95, $B4, $AB, $97, $88, $A9,
    $B6, $EB, $F4, $D5, $CA, $6F, $70, $51, $4E, $13, $0C, $2D, $32, $A4, $BB,
    $9A, $85, $D8, $C7, $E6, $F9, $5C, $43, $62, $7D, $20, $3F, $1E, $01, $F1,
    $EE, $CF, $D0, $8D, $92, $B3, $AC, $09, $16, $37, $28, $75, $6A, $4B, $54,
    $C2, $DD, $FC, $E3, $BE, $A1, $80, $9F, $3A, $25, $04, $1B, $46, $59, $78,
    $67, $00, $20, $40, $60, $80, $A0, $C0, $E0, $C3, $E3, $83, $A3, $43, $63,
    $03, $23, $45, $65, $05, $25, $C5, $E5, $85, $A5, $86, $A6, $C6, $E6, $06,
    $26, $46, $66, $8A, $AA, $CA, $EA, $0A, $2A, $4A, $6A, $49, $69, $09, $29,
    $C9, $E9, $89, $A9, $CF, $EF, $8F, $AF, $4F, $6F, $0F, $2F, $0C, $2C, $4C,
    $6C, $8C, $AC, $CC, $EC, $D7, $F7, $97, $B7, $57, $77, $17, $37, $14, $34,
    $54, $74, $94, $B4, $D4, $F4, $92, $B2, $D2, $F2, $12, $32, $52, $72, $51,
    $71, $11, $31, $D1, $F1, $91, $B1, $5D, $7D, $1D, $3D, $DD, $FD, $9D, $BD,
    $9E, $BE, $DE, $FE, $1E, $3E, $5E, $7E, $18, $38, $58, $78, $98, $B8, $D8,
    $F8, $DB, $FB, $9B, $BB, $5B, $7B, $1B, $3B, $6D, $4D, $2D, $0D, $ED, $CD,
    $AD, $8D, $AE, $8E, $EE, $CE, $2E, $0E, $6E, $4E, $28, $08, $68, $48, $A8,
    $88, $E8, $C8, $EB, $CB, $AB, $8B, $6B, $4B, $2B, $0B, $E7, $C7, $A7, $87,
    $67, $47, $27, $07, $24, $04, $64, $44, $A4, $84, $E4, $C4, $A2, $82, $E2,
    $C2, $22, $02, $62, $42, $61, $41, $21, $01, $E1, $C1, $A1, $81, $BA, $9A,
    $FA, $DA, $3A, $1A, $7A, $5A, $79, $59, $39, $19, $F9, $D9, $B9, $99, $FF,
    $DF, $BF, $9F, $7F, $5F, $3F, $1F, $3C, $1C, $7C, $5C, $BC, $9C, $FC, $DC,
    $30, $10, $70, $50, $B0, $90, $F0, $D0, $F3, $D3, $B3, $93, $73, $53, $33,
    $13, $75, $55, $35, $15, $F5, $D5, $B5, $95, $B6, $96, $F6, $D6, $36, $16,
    $76, $56, $00, $21, $42, $63, $84, $A5, $C6, $E7, $CB, $EA, $89, $A8, $4F,
    $6E, $0D, $2C, $55, $74, $17, $36, $D1, $F0, $93, $B2, $9E, $BF, $DC, $FD,
    $1A, $3B, $58, $79, $AA, $8B, $E8, $C9, $2E, $0F, $6C, $4D, $61, $40, $23,
    $02, $E5, $C4, $A7, $86, $FF, $DE, $BD, $9C, $7B, $5A, $39, $18, $34, $15,
    $76, $57, $B0, $91, $F2, $D3, $97, $B6, $D5, $F4, $13, $32, $51, $70, $5C,
    $7D, $1E, $3F, $D8, $F9, $9A, $BB, $C2, $E3, $80, $A1, $46, $67, $04, $25,
    $09, $28, $4B, $6A, $8D, $AC, $CF, $EE, $3D, $1C, $7F, $5E, $B9, $98, $FB,
    $DA, $F6, $D7, $B4, $95, $72, $53, $30, $11, $68, $49, $2A, $0B, $EC, $CD,
    $AE, $8F, $A3, $82, $E1, $C0, $27, $06, $65, $44, $ED, $CC, $AF, $8E, $69,
    $48, $2B, $0A, $26, $07, $64, $45, $A2, $83, $E0, $C1, $B8, $99, $FA, $DB,
    $3C, $1D, $7E, $5F, $73, $52, $31, $10, $F7, $D6, $B5, $94, $47, $66, $05,
    $24, $C3, $E2, $81, $A0, $8C, $AD, $CE, $EF, $08, $29, $4A, $6B, $12, $33,
    $50, $71, $96, $B7, $D4, $F5, $D9, $F8, $9B, $BA, $5D, $7C, $1F, $3E, $7A,
    $5B, $38, $19, $FE, $DF, $BC, $9D, $B1, $90, $F3, $D2, $35, $14, $77, $56,
    $2F, $0E, $6D, $4C, $AB, $8A, $E9, $C8, $E4, $C5, $A6, $87, $60, $41, $22,
    $03, $D0, $F1, $92, $B3, $54, $75, $16, $37, $1B, $3A, $59, $78, $9F, $BE,
    $DD, $FC, $85, $A4, $C7, $E6, $01, $20, $43, $62, $4E, $6F, $0C, $2D, $CA,
    $EB, $88, $A9, $00, $22, $44, $66, $88, $AA, $CC, $EE, $D3, $F1, $97, $B5,
    $5B, $79, $1F, $3D, $65, $47, $21, $03, $ED, $CF, $A9, $8B, $B6, $94, $F2,
    $D0, $3E, $1C, $7A, $58, $CA, $E8, $8E, $AC, $42, $60, $06, $24, $19, $3B,
    $5D, $7F, $91, $B3, $D5, $F7, $AF, $8D, $EB, $C9, $27, $05, $63, $41, $7C,
    $5E, $38, $1A, $F4, $D6, $B0, $92, $57, $75, $13, $31, $DF, $FD, $9B, $B9,
    $84, $A6, $C0, $E2, $0C, $2E, $48, $6A, $32, $10, $76, $54, $BA, $98, $FE,
    $DC, $E1, $C3, $A5, $87, $69, $4B, $2D, $0F, $9D, $BF, $D9, $FB, $15, $37,
    $51, $73, $4E, $6C, $0A, $28, $C6, $E4, $82, $A0, $F8, $DA, $BC, $9E, $70,
    $52, $34, $16, $2B, $09, $6F, $4D, $A3, $81, $E7, $C5, $AE, $8C, $EA, $C8,
    $26, $04, $62, $40, $7D, $5F, $39, $1B, $F5, $D7, $B1, $93, $CB, $E9, $8F,
    $AD, $43, $61, $07, $25, $18, $3A, $5C, $7E, $90, $B2, $D4, $F6, $64, $46,
    $20, $02, $EC, $CE, $A8, $8A, $B7, $95, $F3, $D1, $3F, $1D, $7B, $59, $01,
    $23, $45, $67, $89, $AB, $CD, $EF, $D2, $F0, $96, $B4, $5A, $78, $1E, $3C,
    $F9, $DB, $BD, $9F, $71, $53, $35, $17, $2A, $08, $6E, $4C, $A2, $80, $E6,
    $C4, $9C, $BE, $D8, $FA, $14, $36, $50, $72, $4F, $6D, $0B, $29, $C7, $E5,
    $83, $A1, $33, $11, $77, $55, $BB, $99, $FF, $DD, $E0, $C2, $A4, $86, $68,
    $4A, $2C, $0E, $56, $74, $12, $30, $DE, $FC, $9A, $B8, $85, $A7, $C1, $E3,
    $0D, $2F, $49, $6B, $00, $23, $46, $65, $8C, $AF, $CA, $E9, $DB, $F8, $9D,
    $BE, $57, $74, $11, $32, $75, $56, $33, $10, $F9, $DA, $BF, $9C, $AE, $8D,
    $E8, $CB, $22, $01, $64, $47, $EA, $C9, $AC, $8F, $66, $45, $20, $03, $31,
    $12, $77, $54, $BD, $9E, $FB, $D8, $9F, $BC, $D9, $FA, $13, $30, $55, $76,
    $44, $67, $02, $21, $C8, $EB, $8E, $AD, $17, $34, $51, $72, $9B, $B8, $DD,
    $FE, $CC, $EF, $8A, $A9, $40, $63, $06, $25, $62, $41, $24, $07, $EE, $CD,
    $A8, $8B, $B9, $9A, $FF, $DC, $35, $16, $73, $50, $FD, $DE, $BB, $98, $71,
    $52, $37, $14, $26, $05, $60, $43, $AA, $89, $EC, $CF, $88, $AB, $CE, $ED,
    $04, $27, $42, $61, $53, $70, $15, $36, $DF, $FC, $99, $BA, $2E, $0D, $68,
    $4B, $A2, $81, $E4, $C7, $F5, $D6, $B3, $90, $79, $5A, $3F, $1C, $5B, $78,
    $1D, $3E, $D7, $F4, $91, $B2, $80, $A3, $C6, $E5, $0C, $2F, $4A, $69, $C4,
    $E7, $82, $A1, $48, $6B, $0E, $2D, $1F, $3C, $59, $7A, $93, $B0, $D5, $F6,
    $B1, $92, $F7, $D4, $3D, $1E, $7B, $58, $6A, $49, $2C, $0F, $E6, $C5, $A0,
    $83, $39, $1A, $7F, $5C, $B5, $96, $F3, $D0, $E2, $C1, $A4, $87, $6E, $4D,
    $28, $0B, $4C, $6F, $0A, $29, $C0, $E3, $86, $A5, $97, $B4, $D1, $F2, $1B,
    $38, $5D, $7E, $D3, $F0, $95, $B6, $5F, $7C, $19, $3A, $08, $2B, $4E, $6D,
    $84, $A7, $C2, $E1, $A6, $85, $E0, $C3, $2A, $09, $6C, $4F, $7D, $5E, $3B,
    $18, $F1, $D2, $B7, $94, $00, $24, $48, $6C, $90, $B4, $D8, $FC, $E3, $C7,
    $AB, $8F, $73, $57, $3B, $1F, $05, $21, $4D, $69, $95, $B1, $DD, $F9, $E6,
    $C2, $AE, $8A, $76, $52, $3E, $1A, $0A, $2E, $42, $66, $9A, $BE, $D2, $F6,
    $E9, $CD, $A1, $85, $79, $5D, $31, $15, $0F, $2B, $47, $63, $9F, $BB, $D7,
    $F3, $EC, $C8, $A4, $80, $7C, $58, $34, $10, $14, $30, $5C, $78, $84, $A0,
    $CC, $E8, $F7, $D3, $BF, $9B, $67, $43, $2F, $0B, $11, $35, $59, $7D, $81,
    $A5, $C9, $ED, $F2, $D6, $BA, $9E, $62, $46, $2A, $0E, $1E, $3A, $56, $72,
    $8E, $AA, $C6, $E2, $FD, $D9, $B5, $91, $6D, $49, $25, $01, $1B, $3F, $53,
    $77, $8B, $AF, $C3, $E7, $F8, $DC, $B0, $94, $68, $4C, $20, $04, $28, $0C,
    $60, $44, $B8, $9C, $F0, $D4, $CB, $EF, $83, $A7, $5B, $7F, $13, $37, $2D,
    $09, $65, $41, $BD, $99, $F5, $D1, $CE, $EA, $86, $A2, $5E, $7A, $16, $32,
    $22, $06, $6A, $4E, $B2, $96, $FA, $DE, $C1, $E5, $89, $AD, $51, $75, $19,
    $3D, $27, $03, $6F, $4B, $B7, $93, $FF, $DB, $C4, $E0, $8C, $A8, $54, $70,
    $1C, $38, $3C, $18, $74, $50, $AC, $88, $E4, $C0, $DF, $FB, $97, $B3, $4F,
    $6B, $07, $23, $39, $1D, $71, $55, $A9, $8D, $E1, $C5, $DA, $FE, $92, $B6,
    $4A, $6E, $02, $26, $36, $12, $7E, $5A, $A6, $82, $EE, $CA, $D5, $F1, $9D,
    $B9, $45, $61, $0D, $29, $33, $17, $7B, $5F, $A3, $87, $EB, $CF, $D0, $F4,
    $98, $BC, $40, $64, $08, $2C, $00, $25, $4A, $6F, $94, $B1, $DE, $FB, $EB,
    $CE, $A1, $84, $7F, $5A, $35, $10, $15, $30, $5F, $7A, $81, $A4, $CB, $EE,
    $FE, $DB, $B4, $91, $6A, $4F, $20, $05, $2A, $0F, $60, $45, $BE, $9B, $F4,
    $D1, $C1, $E4, $8B, $AE, $55, $70, $1F, $3A, $3F, $1A, $75, $50, $AB, $8E,
    $E1, $C4, $D4, $F1, $9E, $BB, $40, $65, $0A, $2F, $54, $71, $1E, $3B, $C0,
    $E5, $8A, $AF, $BF, $9A, $F5, $D0, $2B, $0E, $61, $44, $41, $64, $0B, $2E,
    $D5, $F0, $9F, $BA, $AA, $8F, $E0, $C5, $3E, $1B, $74, $51, $7E, $5B, $34,
    $11, $EA, $CF, $A0, $85, $95, $B0, $DF, $FA, $01, $24, $4B, $6E, $6B, $4E,
    $21, $04, $FF, $DA, $B5, $90, $80, $A5, $CA, $EF, $14, $31, $5E, $7B, $A8,
    $8D, $E2, $C7, $3C, $19, $76, $53, $43, $66, $09, $2C, $D7, $F2, $9D, $B8,
    $BD, $98, $F7, $D2, $29, $0C, $63, $46, $56, $73, $1C, $39, $C2, $E7, $88,
    $AD, $82, $A7, $C8, $ED, $16, $33, $5C, $79, $69, $4C, $23, $06, $FD, $D8,
    $B7, $92, $97, $B2, $DD, $F8, $03, $26, $49, $6C, $7C, $59, $36, $13, $E8,
    $CD, $A2, $87, $FC, $D9, $B6, $93, $68, $4D, $22, $07, $17, $32, $5D, $78,
    $83, $A6, $C9, $EC, $E9, $CC, $A3, $86, $7D, $58, $37, $12, $02, $27, $48,
    $6D, $96, $B3, $DC, $F9, $D6, $F3, $9C, $B9, $42, $67, $08, $2D, $3D, $18,
    $77, $52, $A9, $8C, $E3, $C6, $C3, $E6, $89, $AC, $57, $72, $1D, $38, $28,
    $0D, $62, $47, $BC, $99, $F6, $D3, $00, $26, $4C, $6A, $98, $BE, $D4, $F2,
    $F3, $D5, $BF, $99, $6B, $4D, $27, $01, $25, $03, $69, $4F, $BD, $9B, $F1,
    $D7, $D6, $F0, $9A, $BC, $4E, $68, $02, $24, $4A, $6C, $06, $20, $D2, $F4,
    $9E, $B8, $B9, $9F, $F5, $D3, $21, $07, $6D, $4B, $6F, $49, $23, $05, $F7,
    $D1, $BB, $9D, $9C, $BA, $D0, $F6, $04, $22, $48, $6E, $94, $B2, $D8, $FE,
    $0C, $2A, $40, $66, $67, $41, $2B, $0D, $FF, $D9, $B3, $95, $B1, $97, $FD,
    $DB, $29, $0F, $65, $43, $42, $64, $0E, $28, $DA, $FC, $96, $B0, $DE, $F8,
    $92, $B4, $46, $60, $0A, $2C, $2D, $0B, $61, $47, $B5, $93, $F9, $DF, $FB,
    $DD, $B7, $91, $63, $45, $2F, $09, $08, $2E, $44, $62, $90, $B6, $DC, $FA,
    $EB, $CD, $A7, $81, $73, $55, $3F, $19, $18, $3E, $54, $72, $80, $A6, $CC,
    $EA, $CE, $E8, $82, $A4, $56, $70, $1A, $3C, $3D, $1B, $71, $57, $A5, $83,
    $E9, $CF, $A1, $87, $ED, $CB, $39, $1F, $75, $53, $52, $74, $1E, $38, $CA,
    $EC, $86, $A0, $84, $A2, $C8, $EE, $1C, $3A, $50, $76, $77, $51, $3B, $1D,
    $EF, $C9, $A3, $85, $7F, $59, $33, $15, $E7, $C1, $AB, $8D, $8C, $AA, $C0,
    $E6, $14, $32, $58, $7E, $5A, $7C, $16, $30, $C2, $E4, $8E, $A8, $A9, $8F,
    $E5, $C3, $31, $17, $7D, $5B, $35, $13, $79, $5F, $AD, $8B, $E1, $C7, $C6,
    $E0, $8A, $AC, $5E, $78, $12, $34, $10, $36, $5C, $7A, $88, $AE, $C4, $E2,
    $E3, $C5, $AF, $89, $7B, $5D, $37, $11, $00, $27, $4E, $69, $9C, $BB, $D2,
    $F5, $FB, $DC, $B5, $92, $67, $40, $29, $0E, $35, $12, $7B, $5C, $A9, $8E,
    $E7, $C0, $CE, $E9, $80, $A7, $52, $75, $1C, $3B, $6A, $4D, $24, $03, $F6,
    $D1, $B8, $9F, $91, $B6, $DF, $F8, $0D, $2A, $43, $64, $5F, $78, $11, $36,
    $C3, $E4, $8D, $AA, $A4, $83, $EA, $CD, $38, $1F, $76, $51, $D4, $F3, $9A,
    $BD, $48, $6F, $06, $21, $2F, $08, $61, $46, $B3, $94, $FD, $DA, $E1, $C6,
    $AF, $88, $7D, $5A, $33, $14, $1A, $3D, $54, $73, $86, $A1, $C8, $EF, $BE,
    $99, $F0, $D7, $22, $05, $6C, $4B, $45, $62, $0B, $2C, $D9, $FE, $97, $B0,
    $8B, $AC, $C5, $E2, $17, $30, $59, $7E, $70, $57, $3E, $19, $EC, $CB, $A2,
    $85, $6B, $4C, $25, $02, $F7, $D0, $B9, $9E, $90, $B7, $DE, $F9, $0C, $2B,
    $42, $65, $5E, $79, $10, $37, $C2, $E5, $8C, $AB, $A5, $82, $EB, $CC, $39,
    $1E, $77, $50, $01, $26, $4F, $68, $9D, $BA, $D3, $F4, $FA, $DD, $B4, $93,
    $66, $41, $28, $0F, $34, $13, $7A, $5D, $A8, $8F, $E6, $C1, $CF, $E8, $81,
    $A6, $53, $74, $1D, $3A, $BF, $98, $F1, $D6, $23, $04, $6D, $4A, $44, $63,
    $0A, $2D, $D8, $FF, $96, $B1, $8A, $AD, $C4, $E3, $16, $31, $58, $7F, $71,
    $56, $3F, $18, $ED, $CA, $A3, $84, $D5, $F2, $9B, $BC, $49, $6E, $07, $20,
    $2E, $09, $60, $47, $B2, $95, $FC, $DB, $E0, $C7, $AE, $89, $7C, $5B, $32,
    $15, $1B, $3C, $55, $72, $87, $A0, $C9, $EE, $00, $28, $50, $78, $A0, $88,
    $F0, $D8, $83, $AB, $D3, $FB, $23, $0B, $73, $5B, $C5, $ED, $95, $BD, $65,
    $4D, $35, $1D, $46, $6E, $16, $3E, $E6, $CE, $B6, $9E, $49, $61, $19, $31,
    $E9, $C1, $B9, $91, $CA, $E2, $9A, $B2, $6A, $42, $3A, $12, $8C, $A4, $DC,
    $F4, $2C, $04, $7C, $54, $0F, $27, $5F, $77, $AF, $87, $FF, $D7, $92, $BA,
    $C2, $EA, $32, $1A, $62, $4A, $11, $39, $41, $69, $B1, $99, $E1, $C9, $57,
    $7F, $07, $2F, $F7, $DF, $A7, $8F, $D4, $FC, $84, $AC, $74, $5C, $24, $0C,
    $DB, $F3, $8B, $A3, $7B, $53, $2B, $03, $58, $70, $08, $20, $F8, $D0, $A8,
    $80, $1E, $36, $4E, $66, $BE, $96, $EE, $C6, $9D, $B5, $CD, $E5, $3D, $15,
    $6D, $45, $E7, $CF, $B7, $9F, $47, $6F, $17, $3F, $64, $4C, $34, $1C, $C4,
    $EC, $94, $BC, $22, $0A, $72, $5A, $82, $AA, $D2, $FA, $A1, $89, $F1, $D9,
    $01, $29, $51, $79, $AE, $86, $FE, $D6, $0E, $26, $5E, $76, $2D, $05, $7D,
    $55, $8D, $A5, $DD, $F5, $6B, $43, $3B, $13, $CB, $E3, $9B, $B3, $E8, $C0,
    $B8, $90, $48, $60, $18, $30, $75, $5D, $25, $0D, $D5, $FD, $85, $AD, $F6,
    $DE, $A6, $8E, $56, $7E, $06, $2E, $B0, $98, $E0, $C8, $10, $38, $40, $68,
    $33, $1B, $63, $4B, $93, $BB, $C3, $EB, $3C, $14, $6C, $44, $9C, $B4, $CC,
    $E4, $BF, $97, $EF, $C7, $1F, $37, $4F, $67, $F9, $D1, $A9, $81, $59, $71,
    $09, $21, $7A, $52, $2A, $02, $DA, $F2, $8A, $A2, $00, $29, $52, $7B, $A4,
    $8D, $F6, $DF, $8B, $A2, $D9, $F0, $2F, $06, $7D, $54, $D5, $FC, $87, $AE,
    $71, $58, $23, $0A, $5E, $77, $0C, $25, $FA, $D3, $A8, $81, $69, $40, $3B,
    $12, $CD, $E4, $9F, $B6, $E2, $CB, $B0, $99, $46, $6F, $14, $3D, $BC, $95,
    $EE, $C7, $18, $31, $4A, $63, $37, $1E, $65, $4C, $93, $BA, $C1, $E8, $D2,
    $FB, $80, $A9, $76, $5F, $24, $0D, $59, $70, $0B, $22, $FD, $D4, $AF, $86,
    $07, $2E, $55, $7C, $A3, $8A, $F1, $D8, $8C, $A5, $DE, $F7, $28, $01, $7A,
    $53, $BB, $92, $E9, $C0, $1F, $36, $4D, $64, $30, $19, $62, $4B, $94, $BD,
    $C6, $EF, $6E, $47, $3C, $15, $CA, $E3, $98, $B1, $E5, $CC, $B7, $9E, $41,
    $68, $13, $3A, $67, $4E, $35, $1C, $C3, $EA, $91, $B8, $EC, $C5, $BE, $97,
    $48, $61, $1A, $33, $B2, $9B, $E0, $C9, $16, $3F, $44, $6D, $39, $10, $6B,
    $42, $9D, $B4, $CF, $E6, $0E, $27, $5C, $75, $AA, $83, $F8, $D1, $85, $AC,
    $D7, $FE, $21, $08, $73, $5A, $DB, $F2, $89, $A0, $7F, $56, $2D, $04, $50,
    $79, $02, $2B, $F4, $DD, $A6, $8F, $B5, $9C, $E7, $CE, $11, $38, $43, $6A,
    $3E, $17, $6C, $45, $9A, $B3, $C8, $E1, $60, $49, $32, $1B, $C4, $ED, $96,
    $BF, $EB, $C2, $B9, $90, $4F, $66, $1D, $34, $DC, $F5, $8E, $A7, $78, $51,
    $2A, $03, $57, $7E, $05, $2C, $F3, $DA, $A1, $88, $09, $20, $5B, $72, $AD,
    $84, $FF, $D6, $82, $AB, $D0, $F9, $26, $0F, $74, $5D, $00, $2A, $54, $7E,
    $A8, $82, $FC, $D6, $93, $B9, $C7, $ED, $3B, $11, $6F, $45, $E5, $CF, $B1,
    $9B, $4D, $67, $19, $33, $76, $5C, $22, $08, $DE, $F4, $8A, $A0, $09, $23,
    $5D, $77, $A1, $8B, $F5, $DF, $9A, $B0, $CE, $E4, $32, $18, $66, $4C, $EC,
    $C6, $B8, $92, $44, $6E, $10, $3A, $7F, $55, $2B, $01, $D7, $FD, $83, $A9,
    $12, $38, $46, $6C, $BA, $90, $EE, $C4, $81, $AB, $D5, $FF, $29, $03, $7D,
    $57, $F7, $DD, $A3, $89, $5F, $75, $0B, $21, $64, $4E, $30, $1A, $CC, $E6,
    $98, $B2, $1B, $31, $4F, $65, $B3, $99, $E7, $CD, $88, $A2, $DC, $F6, $20,
    $0A, $74, $5E, $FE, $D4, $AA, $80, $56, $7C, $02, $28, $6D, $47, $39, $13,
    $C5, $EF, $91, $BB, $24, $0E, $70, $5A, $8C, $A6, $D8, $F2, $B7, $9D, $E3,
    $C9, $1F, $35, $4B, $61, $C1, $EB, $95, $BF, $69, $43, $3D, $17, $52, $78,
    $06, $2C, $FA, $D0, $AE, $84, $2D, $07, $79, $53, $85, $AF, $D1, $FB, $BE,
    $94, $EA, $C0, $16, $3C, $42, $68, $C8, $E2, $9C, $B6, $60, $4A, $34, $1E,
    $5B, $71, $0F, $25, $F3, $D9, $A7, $8D, $36, $1C, $62, $48, $9E, $B4, $CA,
    $E0, $A5, $8F, $F1, $DB, $0D, $27, $59, $73, $D3, $F9, $87, $AD, $7B, $51,
    $2F, $05, $40, $6A, $14, $3E, $E8, $C2, $BC, $96, $3F, $15, $6B, $41, $97,
    $BD, $C3, $E9, $AC, $86, $F8, $D2, $04, $2E, $50, $7A, $DA, $F0, $8E, $A4,
    $72, $58, $26, $0C, $49, $63, $1D, $37, $E1, $CB, $B5, $9F, $00, $2B, $56,
    $7D, $AC, $87, $FA, $D1, $9B, $B0, $CD, $E6, $37, $1C, $61, $4A, $F5, $DE,
    $A3, $88, $59, $72, $0F, $24, $6E, $45, $38, $13, $C2, $E9, $94, $BF, $29,
    $02, $7F, $54, $85, $AE, $D3, $F8, $B2, $99, $E4, $CF, $1E, $35, $48, $63,
    $DC, $F7, $8A, $A1, $70, $5B, $26, $0D, $47, $6C, $11, $3A, $EB, $C0, $BD,
    $96, $52, $79, $04, $2F, $FE, $D5, $A8, $83, $C9, $E2, $9F, $B4, $65, $4E,
    $33, $18, $A7, $8C, $F1, $DA, $0B, $20, $5D, $76, $3C, $17, $6A, $41, $90,
    $BB, $C6, $ED, $7B, $50, $2D, $06, $D7, $FC, $81, $AA, $E0, $CB, $B6, $9D,
    $4C, $67, $1A, $31, $8E, $A5, $D8, $F3, $22, $09, $74, $5F, $15, $3E, $43,
    $68, $B9, $92, $EF, $C4, $A4, $8F, $F2, $D9, $08, $23, $5E, $75, $3F, $14,
    $69, $42, $93, $B8, $C5, $EE, $51, $7A, $07, $2C, $FD, $D6, $AB, $80, $CA,
    $E1, $9C, $B7, $66, $4D, $30, $1B, $8D, $A6, $DB, $F0, $21, $0A, $77, $5C,
    $16, $3D, $40, $6B, $BA, $91, $EC, $C7, $78, $53, $2E, $05, $D4, $FF, $82,
    $A9, $E3, $C8, $B5, $9E, $4F, $64, $19, $32, $F6, $DD, $A0, $8B, $5A, $71,
    $0C, $27, $6D, $46, $3B, $10, $C1, $EA, $97, $BC, $03, $28, $55, $7E, $AF,
    $84, $F9, $D2, $98, $B3, $CE, $E5, $34, $1F, $62, $49, $DF, $F4, $89, $A2,
    $73, $58, $25, $0E, $44, $6F, $12, $39, $E8, $C3, $BE, $95, $2A, $01, $7C,
    $57, $86, $AD, $D0, $FB, $B1, $9A, $E7, $CC, $1D, $36, $4B, $60, $00, $2C,
    $58, $74, $B0, $9C, $E8, $C4, $A3, $8F, $FB, $D7, $13, $3F, $4B, $67, $85,
    $A9, $DD, $F1, $35, $19, $6D, $41, $26, $0A, $7E, $52, $96, $BA, $CE, $E2,
    $C9, $E5, $91, $BD, $79, $55, $21, $0D, $6A, $46, $32, $1E, $DA, $F6, $82,
    $AE, $4C, $60, $14, $38, $FC, $D0, $A4, $88, $EF, $C3, $B7, $9B, $5F, $73,
    $07, $2B, $51, $7D, $09, $25, $E1, $CD, $B9, $95, $F2, $DE, $AA, $86, $42,
    $6E, $1A, $36, $D4, $F8, $8C, $A0, $64, $48, $3C, $10, $77, $5B, $2F, $03,
    $C7, $EB, $9F, $B3, $98, $B4, $C0, $EC, $28, $04, $70, $5C, $3B, $17, $63,
    $4F, $8B, $A7, $D3, $FF, $1D, $31, $45, $69, $AD, $81, $F5, $D9, $BE, $92,
    $E6, $CA, $0E, $22, $56, $7A, $A2, $8E, $FA, $D6, $12, $3E, $4A, $66, $01,
    $2D, $59, $75, $B1, $9D, $E9, $C5, $27, $0B, $7F, $53, $97, $BB, $CF, $E3,
    $84, $A8, $DC, $F0, $34, $18, $6C, $40, $6B, $47, $33, $1F, $DB, $F7, $83,
    $AF, $C8, $E4, $90, $BC, $78, $54, $20, $0C, $EE, $C2, $B6, $9A, $5E, $72,
    $06, $2A, $4D, $61, $15, $39, $FD, $D1, $A5, $89, $F3, $DF, $AB, $87, $43,
    $6F, $1B, $37, $50, $7C, $08, $24, $E0, $CC, $B8, $94, $76, $5A, $2E, $02,
    $C6, $EA, $9E, $B2, $D5, $F9, $8D, $A1, $65, $49, $3D, $11, $3A, $16, $62,
    $4E, $8A, $A6, $D2, $FE, $99, $B5, $C1, $ED, $29, $05, $71, $5D, $BF, $93,
    $E7, $CB, $0F, $23, $57, $7B, $1C, $30, $44, $68, $AC, $80, $F4, $D8, $00,
    $2D, $5A, $77, $B4, $99, $EE, $C3, $AB, $86, $F1, $DC, $1F, $32, $45, $68,
    $95, $B8, $CF, $E2, $21, $0C, $7B, $56, $3E, $13, $64, $49, $8A, $A7, $D0,
    $FD, $E9, $C4, $B3, $9E, $5D, $70, $07, $2A, $42, $6F, $18, $35, $F6, $DB,
    $AC, $81, $7C, $51, $26, $0B, $C8, $E5, $92, $BF, $D7, $FA, $8D, $A0, $63,
    $4E, $39, $14, $11, $3C, $4B, $66, $A5, $88, $FF, $D2, $BA, $97, $E0, $CD,
    $0E, $23, $54, $79, $84, $A9, $DE, $F3, $30, $1D, $6A, $47, $2F, $02, $75,
    $58, $9B, $B6, $C1, $EC, $F8, $D5, $A2, $8F, $4C, $61, $16, $3B, $53, $7E,
    $09, $24, $E7, $CA, $BD, $90, $6D, $40, $37, $1A, $D9, $F4, $83, $AE, $C6,
    $EB, $9C, $B1, $72, $5F, $28, $05, $22, $0F, $78, $55, $96, $BB, $CC, $E1,
    $89, $A4, $D3, $FE, $3D, $10, $67, $4A, $B7, $9A, $ED, $C0, $03, $2E, $59,
    $74, $1C, $31, $46, $6B, $A8, $85, $F2, $DF, $CB, $E6, $91, $BC, $7F, $52,
    $25, $08, $60, $4D, $3A, $17, $D4, $F9, $8E, $A3, $5E, $73, $04, $29, $EA,
    $C7, $B0, $9D, $F5, $D8, $AF, $82, $41, $6C, $1B, $36, $33, $1E, $69, $44,
    $87, $AA, $DD, $F0, $98, $B5, $C2, $EF, $2C, $01, $76, $5B, $A6, $8B, $FC,
    $D1, $12, $3F, $48, $65, $0D, $20, $57, $7A, $B9, $94, $E3, $CE, $DA, $F7,
    $80, $AD, $6E, $43, $34, $19, $71, $5C, $2B, $06, $C5, $E8, $9F, $B2, $4F,
    $62, $15, $38, $FB, $D6, $A1, $8C, $E4, $C9, $BE, $93, $50, $7D, $0A, $27,
    $00, $2E, $5C, $72, $B8, $96, $E4, $CA, $B3, $9D, $EF, $C1, $0B, $25, $57,
    $79, $A5, $8B, $F9, $D7, $1D, $33, $41, $6F, $16, $38, $4A, $64, $AE, $80,
    $F2, $DC, $89, $A7, $D5, $FB, $31, $1F, $6D, $43, $3A, $14, $66, $48, $82,
    $AC, $DE, $F0, $2C, $02, $70, $5E, $94, $BA, $C8, $E6, $9F, $B1, $C3, $ED,
    $27, $09, $7B, $55, $D1, $FF, $8D, $A3, $69, $47, $35, $1B, $62, $4C, $3E,
    $10, $DA, $F4, $86, $A8, $74, $5A, $28, $06, $CC, $E2, $90, $BE, $C7, $E9,
    $9B, $B5, $7F, $51, $23, $0D, $58, $76, $04, $2A, $E0, $CE, $BC, $92, $EB,
    $C5, $B7, $99, $53, $7D, $0F, $21, $FD, $D3, $A1, $8F, $45, $6B, $19, $37,
    $4E, $60, $12, $3C, $F6, $D8, $AA, $84, $61, $4F, $3D, $13, $D9, $F7, $85,
    $AB, $D2, $FC, $8E, $A0, $6A, $44, $36, $18, $C4, $EA, $98, $B6, $7C, $52,
    $20, $0E, $77, $59, $2B, $05, $CF, $E1, $93, $BD, $E8, $C6, $B4, $9A, $50,
    $7E, $0C, $22, $5B, $75, $07, $29, $E3, $CD, $BF, $91, $4D, $63, $11, $3F,
    $F5, $DB, $A9, $87, $FE, $D0, $A2, $8C, $46, $68, $1A, $34, $B0, $9E, $EC,
    $C2, $08, $26, $54, $7A, $03, $2D, $5F, $71, $BB, $95, $E7, $C9, $15, $3B,
    $49, $67, $AD, $83, $F1, $DF, $A6, $88, $FA, $D4, $1E, $30, $42, $6C, $39,
    $17, $65, $4B, $81, $AF, $DD, $F3, $8A, $A4, $D6, $F8, $32, $1C, $6E, $40,
    $9C, $B2, $C0, $EE, $24, $0A, $78, $56, $2F, $01, $73, $5D, $97, $B9, $CB,
    $E5, $00, $2F, $5E, $71, $BC, $93, $E2, $CD, $BB, $94, $E5, $CA, $07, $28,
    $59, $76, $B5, $9A, $EB, $C4, $09, $26, $57, $78, $0E, $21, $50, $7F, $B2,
    $9D, $EC, $C3, $A9, $86, $F7, $D8, $15, $3A, $4B, $64, $12, $3D, $4C, $63,
    $AE, $81, $F0, $DF, $1C, $33, $42, $6D, $A0, $8F, $FE, $D1, $A7, $88, $F9,
    $D6, $1B, $34, $45, $6A, $91, $BE, $CF, $E0, $2D, $02, $73, $5C, $2A, $05,
    $74, $5B, $96, $B9, $C8, $E7, $24, $0B, $7A, $55, $98, $B7, $C6, $E9, $9F,
    $B0, $C1, $EE, $23, $0C, $7D, $52, $38, $17, $66, $49, $84, $AB, $DA, $F5,
    $83, $AC, $DD, $F2, $3F, $10, $61, $4E, $8D, $A2, $D3, $FC, $31, $1E, $6F,
    $40, $36, $19, $68, $47, $8A, $A5, $D4, $FB, $E1, $CE, $BF, $90, $5D, $72,
    $03, $2C, $5A, $75, $04, $2B, $E6, $C9, $B8, $97, $54, $7B, $0A, $25, $E8,
    $C7, $B6, $99, $EF, $C0, $B1, $9E, $53, $7C, $0D, $22, $48, $67, $16, $39,
    $F4, $DB, $AA, $85, $F3, $DC, $AD, $82, $4F, $60, $11, $3E, $FD, $D2, $A3,
    $8C, $41, $6E, $1F, $30, $46, $69, $18, $37, $FA, $D5, $A4, $8B, $70, $5F,
    $2E, $01, $CC, $E3, $92, $BD, $CB, $E4, $95, $BA, $77, $58, $29, $06, $C5,
    $EA, $9B, $B4, $79, $56, $27, $08, $7E, $51, $20, $0F, $C2, $ED, $9C, $B3,
    $D9, $F6, $87, $A8, $65, $4A, $3B, $14, $62, $4D, $3C, $13, $DE, $F1, $80,
    $AF, $6C, $43, $32, $1D, $D0, $FF, $8E, $A1, $D7, $F8, $89, $A6, $6B, $44,
    $35, $1A, $00, $30, $60, $50, $C0, $F0, $A0, $90, $43, $73, $23, $13, $83,
    $B3, $E3, $D3, $86, $B6, $E6, $D6, $46, $76, $26, $16, $C5, $F5, $A5, $95,
    $05, $35, $65, $55, $CF, $FF, $AF, $9F, $0F, $3F, $6F, $5F, $8C, $BC, $EC,
    $DC, $4C, $7C, $2C, $1C, $49, $79, $29, $19, $89, $B9, $E9, $D9, $0A, $3A,
    $6A, $5A, $CA, $FA, $AA, $9A, $5D, $6D, $3D, $0D, $9D, $AD, $FD, $CD, $1E,
    $2E, $7E, $4E, $DE, $EE, $BE, $8E, $DB, $EB, $BB, $8B, $1B, $2B, $7B, $4B,
    $98, $A8, $F8, $C8, $58, $68, $38, $08, $92, $A2, $F2, $C2, $52, $62, $32,
    $02, $D1, $E1, $B1, $81, $11, $21, $71, $41, $14, $24, $74, $44, $D4, $E4,
    $B4, $84, $57, $67, $37, $07, $97, $A7, $F7, $C7, $BA, $8A, $DA, $EA, $7A,
    $4A, $1A, $2A, $F9, $C9, $99, $A9, $39, $09, $59, $69, $3C, $0C, $5C, $6C,
    $FC, $CC, $9C, $AC, $7F, $4F, $1F, $2F, $BF, $8F, $DF, $EF, $75, $45, $15,
    $25, $B5, $85, $D5, $E5, $36, $06, $56, $66, $F6, $C6, $96, $A6, $F3, $C3,
    $93, $A3, $33, $03, $53, $63, $B0, $80, $D0, $E0, $70, $40, $10, $20, $E7,
    $D7, $87, $B7, $27, $17, $47, $77, $A4, $94, $C4, $F4, $64, $54, $04, $34,
    $61, $51, $01, $31, $A1, $91, $C1, $F1, $22, $12, $42, $72, $E2, $D2, $82,
    $B2, $28, $18, $48, $78, $E8, $D8, $88, $B8, $6B, $5B, $0B, $3B, $AB, $9B,
    $CB, $FB, $AE, $9E, $CE, $FE, $6E, $5E, $0E, $3E, $ED, $DD, $8D, $BD, $2D,
    $1D, $4D, $7D, $00, $31, $62, $53, $C4, $F5, $A6, $97, $4B, $7A, $29, $18,
    $8F, $BE, $ED, $DC, $96, $A7, $F4, $C5, $52, $63, $30, $01, $DD, $EC, $BF,
    $8E, $19, $28, $7B, $4A, $EF, $DE, $8D, $BC, $2B, $1A, $49, $78, $A4, $95,
    $C6, $F7, $60, $51, $02, $33, $79, $48, $1B, $2A, $BD, $8C, $DF, $EE, $32,
    $03, $50, $61, $F6, $C7, $94, $A5, $1D, $2C, $7F, $4E, $D9, $E8, $BB, $8A,
    $56, $67, $34, $05, $92, $A3, $F0, $C1, $8B, $BA, $E9, $D8, $4F, $7E, $2D,
    $1C, $C0, $F1, $A2, $93, $04, $35, $66, $57, $F2, $C3, $90, $A1, $36, $07,
    $54, $65, $B9, $88, $DB, $EA, $7D, $4C, $1F, $2E, $64, $55, $06, $37, $A0,
    $91, $C2, $F3, $2F, $1E, $4D, $7C, $EB, $DA, $89, $B8, $3A, $0B, $58, $69,
    $FE, $CF, $9C, $AD, $71, $40, $13, $22, $B5, $84, $D7, $E6, $AC, $9D, $CE,
    $FF, $68, $59, $0A, $3B, $E7, $D6, $85, $B4, $23, $12, $41, $70, $D5, $E4,
    $B7, $86, $11, $20, $73, $42, $9E, $AF, $FC, $CD, $5A, $6B, $38, $09, $43,
    $72, $21, $10, $87, $B6, $E5, $D4, $08, $39, $6A, $5B, $CC, $FD, $AE, $9F,
    $27, $16, $45, $74, $E3, $D2, $81, $B0, $6C, $5D, $0E, $3F, $A8, $99, $CA,
    $FB, $B1, $80, $D3, $E2, $75, $44, $17, $26, $FA, $CB, $98, $A9, $3E, $0F,
    $5C, $6D, $C8, $F9, $AA, $9B, $0C, $3D, $6E, $5F, $83, $B2, $E1, $D0, $47,
    $76, $25, $14, $5E, $6F, $3C, $0D, $9A, $AB, $F8, $C9, $15, $24, $77, $46,
    $D1, $E0, $B3, $82, $00, $32, $64, $56, $C8, $FA, $AC, $9E, $53, $61, $37,
    $05, $9B, $A9, $FF, $CD, $A6, $94, $C2, $F0, $6E, $5C, $0A, $38, $F5, $C7,
    $91, $A3, $3D, $0F, $59, $6B, $8F, $BD, $EB, $D9, $47, $75, $23, $11, $DC,
    $EE, $B8, $8A, $14, $26, $70, $42, $29, $1B, $4D, $7F, $E1, $D3, $85, $B7,
    $7A, $48, $1E, $2C, $B2, $80, $D6, $E4, $DD, $EF, $B9, $8B, $15, $27, $71,
    $43, $8E, $BC, $EA, $D8, $46, $74, $22, $10, $7B, $49, $1F, $2D, $B3, $81,
    $D7, $E5, $28, $1A, $4C, $7E, $E0, $D2, $84, $B6, $52, $60, $36, $04, $9A,
    $A8, $FE, $CC, $01, $33, $65, $57, $C9, $FB, $AD, $9F, $F4, $C6, $90, $A2,
    $3C, $0E, $58, $6A, $A7, $95, $C3, $F1, $6F, $5D, $0B, $39, $79, $4B, $1D,
    $2F, $B1, $83, $D5, $E7, $2A, $18, $4E, $7C, $E2, $D0, $86, $B4, $DF, $ED,
    $BB, $89, $17, $25, $73, $41, $8C, $BE, $E8, $DA, $44, $76, $20, $12, $F6,
    $C4, $92, $A0, $3E, $0C, $5A, $68, $A5, $97, $C1, $F3, $6D, $5F, $09, $3B,
    $50, $62, $34, $06, $98, $AA, $FC, $CE, $03, $31, $67, $55, $CB, $F9, $AF,
    $9D, $A4, $96, $C0, $F2, $6C, $5E, $08, $3A, $F7, $C5, $93, $A1, $3F, $0D,
    $5B, $69, $02, $30, $66, $54, $CA, $F8, $AE, $9C, $51, $63, $35, $07, $99,
    $AB, $FD, $CF, $2B, $19, $4F, $7D, $E3, $D1, $87, $B5, $78, $4A, $1C, $2E,
    $B0, $82, $D4, $E6, $8D, $BF, $E9, $DB, $45, $77, $21, $13, $DE, $EC, $BA,
    $88, $16, $24, $72, $40, $00, $33, $66, $55, $CC, $FF, $AA, $99, $5B, $68,
    $3D, $0E, $97, $A4, $F1, $C2, $B6, $85, $D0, $E3, $7A, $49, $1C, $2F, $ED,
    $DE, $8B, $B8, $21, $12, $47, $74, $AF, $9C, $C9, $FA, $63, $50, $05, $36,
    $F4, $C7, $92, $A1, $38, $0B, $5E, $6D, $19, $2A, $7F, $4C, $D5, $E6, $B3,
    $80, $42, $71, $24, $17, $8E, $BD, $E8, $DB, $9D, $AE, $FB, $C8, $51, $62,
    $37, $04, $C6, $F5, $A0, $93, $0A, $39, $6C, $5F, $2B, $18, $4D, $7E, $E7,
    $D4, $81, $B2, $70, $43, $16, $25, $BC, $8F, $DA, $E9, $32, $01, $54, $67,
    $FE, $CD, $98, $AB, $69, $5A, $0F, $3C, $A5, $96, $C3, $F0, $84, $B7, $E2,
    $D1, $48, $7B, $2E, $1D, $DF, $EC, $B9, $8A, $13, $20, $75, $46, $F9, $CA,
    $9F, $AC, $35, $06, $53, $60, $A2, $91, $C4, $F7, $6E, $5D, $08, $3B, $4F,
    $7C, $29, $1A, $83, $B0, $E5, $D6, $14, $27, $72, $41, $D8, $EB, $BE, $8D,
    $56, $65, $30, $03, $9A, $A9, $FC, $CF, $0D, $3E, $6B, $58, $C1, $F2, $A7,
    $94, $E0, $D3, $86, $B5, $2C, $1F, $4A, $79, $BB, $88, $DD, $EE, $77, $44,
    $11, $22, $64, $57, $02, $31, $A8, $9B, $CE, $FD, $3F, $0C, $59, $6A, $F3,
    $C0, $95, $A6, $D2, $E1, $B4, $87, $1E, $2D, $78, $4B, $89, $BA, $EF, $DC,
    $45, $76, $23, $10, $CB, $F8, $AD, $9E, $07, $34, $61, $52, $90, $A3, $F6,
    $C5, $5C, $6F, $3A, $09, $7D, $4E, $1B, $28, $B1, $82, $D7, $E4, $26, $15,
    $40, $73, $EA, $D9, $8C, $BF, $00, $34, $68, $5C, $D0, $E4, $B8, $8C, $63,
    $57, $0B, $3F, $B3, $87, $DB, $EF, $C6, $F2, $AE, $9A, $16, $22, $7E, $4A,
    $A5, $91, $CD, $F9, $75, $41, $1D, $29, $4F, $7B, $27, $13, $9F, $AB, $F7,
    $C3, $2C, $18, $44, $70, $FC, $C8, $94, $A0, $89, $BD, $E1, $D5, $59, $6D,
    $31, $05, $EA, $DE, $82, $B6, $3A, $0E, $52, $66, $9E, $AA, $F6, $C2, $4E,
    $7A, $26, $12, $FD, $C9, $95, $A1, $2D, $19, $45, $71, $58, $6C, $30, $04,
    $88, $BC, $E0, $D4, $3B, $0F, $53, $67, $EB, $DF, $83, $B7, $D1, $E5, $B9,
    $8D, $01, $35, $69, $5D, $B2, $86, $DA, $EE, $62, $56, $0A, $3E, $17, $23,
    $7F, $4B, $C7, $F3, $AF, $9B, $74, $40, $1C, $28, $A4, $90, $CC, $F8, $FF,
    $CB, $97, $A3, $2F, $1B, $47, $73, $9C, $A8, $F4, $C0, $4C, $78, $24, $10,
    $39, $0D, $51, $65, $E9, $DD, $81, $B5, $5A, $6E, $32, $06, $8A, $BE, $E2,
    $D6, $B0, $84, $D8, $EC, $60, $54, $08, $3C, $D3, $E7, $BB, $8F, $03, $37,
    $6B, $5F, $76, $42, $1E, $2A, $A6, $92, $CE, $FA, $15, $21, $7D, $49, $C5,
    $F1, $AD, $99, $61, $55, $09, $3D, $B1, $85, $D9, $ED, $02, $36, $6A, $5E,
    $D2, $E6, $BA, $8E, $A7, $93, $CF, $FB, $77, $43, $1F, $2B, $C4, $F0, $AC,
    $98, $14, $20, $7C, $48, $2E, $1A, $46, $72, $FE, $CA, $96, $A2, $4D, $79,
    $25, $11, $9D, $A9, $F5, $C1, $E8, $DC, $80, $B4, $38, $0C, $50, $64, $8B,
    $BF, $E3, $D7, $5B, $6F, $33, $07, $00, $35, $6A, $5F, $D4, $E1, $BE, $8B,
    $6B, $5E, $01, $34, $BF, $8A, $D5, $E0, $D6, $E3, $BC, $89, $02, $37, $68,
    $5D, $BD, $88, $D7, $E2, $69, $5C, $03, $36, $6F, $5A, $05, $30, $BB, $8E,
    $D1, $E4, $04, $31, $6E, $5B, $D0, $E5, $BA, $8F, $B9, $8C, $D3, $E6, $6D,
    $58, $07, $32, $D2, $E7, $B8, $8D, $06, $33, $6C, $59, $DE, $EB, $B4, $81,
    $0A, $3F, $60, $55, $B5, $80, $DF, $EA, $61, $54, $0B, $3E, $08, $3D, $62,
    $57, $DC, $E9, $B6, $83, $63, $56, $09, $3C, $B7, $82, $DD, $E8, $B1, $84,
    $DB, $EE, $65, $50, $0F, $3A, $DA, $EF, $B0, $85, $0E, $3B, $64, $51, $67,
    $52, $0D, $38, $B3, $86, $D9, $EC, $0C, $39, $66, $53, $D8, $ED, $B2, $87,
    $7F, $4A, $15, $20, $AB, $9E, $C1, $F4, $14, $21, $7E, $4B, $C0, $F5, $AA,
    $9F, $A9, $9C, $C3, $F6, $7D, $48, $17, $22, $C2, $F7, $A8, $9D, $16, $23,
    $7C, $49, $10, $25, $7A, $4F, $C4, $F1, $AE, $9B, $7B, $4E, $11, $24, $AF,
    $9A, $C5, $F0, $C6, $F3, $AC, $99, $12, $27, $78, $4D, $AD, $98, $C7, $F2,
    $79, $4C, $13, $26, $A1, $94, $CB, $FE, $75, $40, $1F, $2A, $CA, $FF, $A0,
    $95, $1E, $2B, $74, $41, $77, $42, $1D, $28, $A3, $96, $C9, $FC, $1C, $29,
    $76, $43, $C8, $FD, $A2, $97, $CE, $FB, $A4, $91, $1A, $2F, $70, $45, $A5,
    $90, $CF, $FA, $71, $44, $1B, $2E, $18, $2D, $72, $47, $CC, $F9, $A6, $93,
    $73, $46, $19, $2C, $A7, $92, $CD, $F8, $00, $36, $6C, $5A, $D8, $EE, $B4,
    $82, $73, $45, $1F, $29, $AB, $9D, $C7, $F1, $E6, $D0, $8A, $BC, $3E, $08,
    $52, $64, $95, $A3, $F9, $CF, $4D, $7B, $21, $17, $0F, $39, $63, $55, $D7,
    $E1, $BB, $8D, $7C, $4A, $10, $26, $A4, $92, $C8, $FE, $E9, $DF, $85, $B3,
    $31, $07, $5D, $6B, $9A, $AC, $F6, $C0, $42, $74, $2E, $18, $1E, $28, $72,
    $44, $C6, $F0, $AA, $9C, $6D, $5B, $01, $37, $B5, $83, $D9, $EF, $F8, $CE,
    $94, $A2, $20, $16, $4C, $7A, $8B, $BD, $E7, $D1, $53, $65, $3F, $09, $11,
    $27, $7D, $4B, $C9, $FF, $A5, $93, $62, $54, $0E, $38, $BA, $8C, $D6, $E0,
    $F7, $C1, $9B, $AD, $2F, $19, $43, $75, $84, $B2, $E8, $DE, $5C, $6A, $30,
    $06, $3C, $0A, $50, $66, $E4, $D2, $88, $BE, $4F, $79, $23, $15, $97, $A1,
    $FB, $CD, $DA, $EC, $B6, $80, $02, $34, $6E, $58, $A9, $9F, $C5, $F3, $71,
    $47, $1D, $2B, $33, $05, $5F, $69, $EB, $DD, $87, $B1, $40, $76, $2C, $1A,
    $98, $AE, $F4, $C2, $D5, $E3, $B9, $8F, $0D, $3B, $61, $57, $A6, $90, $CA,
    $FC, $7E, $48, $12, $24, $22, $14, $4E, $78, $FA, $CC, $96, $A0, $51, $67,
    $3D, $0B, $89, $BF, $E5, $D3, $C4, $F2, $A8, $9E, $1C, $2A, $70, $46, $B7,
    $81, $DB, $ED, $6F, $59, $03, $35, $2D, $1B, $41, $77, $F5, $C3, $99, $AF,
    $5E, $68, $32, $04, $86, $B0, $EA, $DC, $CB, $FD, $A7, $91, $13, $25, $7F,
    $49, $B8, $8E, $D4, $E2, $60, $56, $0C, $3A, $00, $37, $6E, $59, $DC, $EB,
    $B2, $85, $7B, $4C, $15, $22, $A7, $90, $C9, $FE, $F6, $C1, $98, $AF, $2A,
    $1D, $44, $73, $8D, $BA, $E3, $D4, $51, $66, $3F, $08, $2F, $18, $41, $76,
    $F3, $C4, $9D, $AA, $54, $63, $3A, $0D, $88, $BF, $E6, $D1, $D9, $EE, $B7,
    $80, $05, $32, $6B, $5C, $A2, $95, $CC, $FB, $7E, $49, $10, $27, $5E, $69,
    $30, $07, $82, $B5, $EC, $DB, $25, $12, $4B, $7C, $F9, $CE, $97, $A0, $A8,
    $9F, $C6, $F1, $74, $43, $1A, $2D, $D3, $E4, $BD, $8A, $0F, $38, $61, $56,
    $71, $46, $1F, $28, $AD, $9A, $C3, $F4, $0A, $3D, $64, $53, $D6, $E1, $B8,
    $8F, $87, $B0, $E9, $DE, $5B, $6C, $35, $02, $FC, $CB, $92, $A5, $20, $17,
    $4E, $79, $BC, $8B, $D2, $E5, $60, $57, $0E, $39, $C7, $F0, $A9, $9E, $1B,
    $2C, $75, $42, $4A, $7D, $24, $13, $96, $A1, $F8, $CF, $31, $06, $5F, $68,
    $ED, $DA, $83, $B4, $93, $A4, $FD, $CA, $4F, $78, $21, $16, $E8, $DF, $86,
    $B1, $34, $03, $5A, $6D, $65, $52, $0B, $3C, $B9, $8E, $D7, $E0, $1E, $29,
    $70, $47, $C2, $F5, $AC, $9B, $E2, $D5, $8C, $BB, $3E, $09, $50, $67, $99,
    $AE, $F7, $C0, $45, $72, $2B, $1C, $14, $23, $7A, $4D, $C8, $FF, $A6, $91,
    $6F, $58, $01, $36, $B3, $84, $DD, $EA, $CD, $FA, $A3, $94, $11, $26, $7F,
    $48, $B6, $81, $D8, $EF, $6A, $5D, $04, $33, $3B, $0C, $55, $62, $E7, $D0,
    $89, $BE, $40, $77, $2E, $19, $9C, $AB, $F2, $C5, $00, $38, $70, $48, $E0,
    $D8, $90, $A8, $03, $3B, $73, $4B, $E3, $DB, $93, $AB, $06, $3E, $76, $4E,
    $E6, $DE, $96, $AE, $05, $3D, $75, $4D, $E5, $DD, $95, $AD, $0C, $34, $7C,
    $44, $EC, $D4, $9C, $A4, $0F, $37, $7F, $47, $EF, $D7, $9F, $A7, $0A, $32,
    $7A, $42, $EA, $D2, $9A, $A2, $09, $31, $79, $41, $E9, $D1, $99, $A1, $18,
    $20, $68, $50, $F8, $C0, $88, $B0, $1B, $23, $6B, $53, $FB, $C3, $8B, $B3,
    $1E, $26, $6E, $56, $FE, $C6, $8E, $B6, $1D, $25, $6D, $55, $FD, $C5, $8D,
    $B5, $14, $2C, $64, $5C, $F4, $CC, $84, $BC, $17, $2F, $67, $5F, $F7, $CF,
    $87, $BF, $12, $2A, $62, $5A, $F2, $CA, $82, $BA, $11, $29, $61, $59, $F1,
    $C9, $81, $B9, $30, $08, $40, $78, $D0, $E8, $A0, $98, $33, $0B, $43, $7B,
    $D3, $EB, $A3, $9B, $36, $0E, $46, $7E, $D6, $EE, $A6, $9E, $35, $0D, $45,
    $7D, $D5, $ED, $A5, $9D, $3C, $04, $4C, $74, $DC, $E4, $AC, $94, $3F, $07,
    $4F, $77, $DF, $E7, $AF, $97, $3A, $02, $4A, $72, $DA, $E2, $AA, $92, $39,
    $01, $49, $71, $D9, $E1, $A9, $91, $28, $10, $58, $60, $C8, $F0, $B8, $80,
    $2B, $13, $5B, $63, $CB, $F3, $BB, $83, $2E, $16, $5E, $66, $CE, $F6, $BE,
    $86, $2D, $15, $5D, $65, $CD, $F5, $BD, $85, $24, $1C, $54, $6C, $C4, $FC,
    $B4, $8C, $27, $1F, $57, $6F, $C7, $FF, $B7, $8F, $22, $1A, $52, $6A, $C2,
    $FA, $B2, $8A, $21, $19, $51, $69, $C1, $F9, $B1, $89, $00, $39, $72, $4B,
    $E4, $DD, $96, $AF, $0B, $32, $79, $40, $EF, $D6, $9D, $A4, $16, $2F, $64,
    $5D, $F2, $CB, $80, $B9, $1D, $24, $6F, $56, $F9, $C0, $8B, $B2, $2C, $15,
    $5E, $67, $C8, $F1, $BA, $83, $27, $1E, $55, $6C, $C3, $FA, $B1, $88, $3A,
    $03, $48, $71, $DE, $E7, $AC, $95, $31, $08, $43, $7A, $D5, $EC, $A7, $9E,
    $58, $61, $2A, $13, $BC, $85, $CE, $F7, $53, $6A, $21, $18, $B7, $8E, $C5,
    $FC, $4E, $77, $3C, $05, $AA, $93, $D8, $E1, $45, $7C, $37, $0E, $A1, $98,
    $D3, $EA, $74, $4D, $06, $3F, $90, $A9, $E2, $DB, $7F, $46, $0D, $34, $9B,
    $A2, $E9, $D0, $62, $5B, $10, $29, $86, $BF, $F4, $CD, $69, $50, $1B, $22,
    $8D, $B4, $FF, $C6, $B0, $89, $C2, $FB, $54, $6D, $26, $1F, $BB, $82, $C9,
    $F0, $5F, $66, $2D, $14, $A6, $9F, $D4, $ED, $42, $7B, $30, $09, $AD, $94,
    $DF, $E6, $49, $70, $3B, $02, $9C, $A5, $EE, $D7, $78, $41, $0A, $33, $97,
    $AE, $E5, $DC, $73, $4A, $01, $38, $8A, $B3, $F8, $C1, $6E, $57, $1C, $25,
    $81, $B8, $F3, $CA, $65, $5C, $17, $2E, $E8, $D1, $9A, $A3, $0C, $35, $7E,
    $47, $E3, $DA, $91, $A8, $07, $3E, $75, $4C, $FE, $C7, $8C, $B5, $1A, $23,
    $68, $51, $F5, $CC, $87, $BE, $11, $28, $63, $5A, $C4, $FD, $B6, $8F, $20,
    $19, $52, $6B, $CF, $F6, $BD, $84, $2B, $12, $59, $60, $D2, $EB, $A0, $99,
    $36, $0F, $44, $7D, $D9, $E0, $AB, $92, $3D, $04, $4F, $76, $00, $3A, $74,
    $4E, $E8, $D2, $9C, $A6, $13, $29, $67, $5D, $FB, $C1, $8F, $B5, $26, $1C,
    $52, $68, $CE, $F4, $BA, $80, $35, $0F, $41, $7B, $DD, $E7, $A9, $93, $4C,
    $76, $38, $02, $A4, $9E, $D0, $EA, $5F, $65, $2B, $11, $B7, $8D, $C3, $F9,
    $6A, $50, $1E, $24, $82, $B8, $F6, $CC, $79, $43, $0D, $37, $91, $AB, $E5,
    $DF, $98, $A2, $EC, $D6, $70, $4A, $04, $3E, $8B, $B1, $FF, $C5, $63, $59,
    $17, $2D, $BE, $84, $CA, $F0, $56, $6C, $22, $18, $AD, $97, $D9, $E3, $45,
    $7F, $31, $0B, $D4, $EE, $A0, $9A, $3C, $06, $48, $72, $C7, $FD, $B3, $89,
    $2F, $15, $5B, $61, $F2, $C8, $86, $BC, $1A, $20, $6E, $54, $E1, $DB, $95,
    $AF, $09, $33, $7D, $47, $F3, $C9, $87, $BD, $1B, $21, $6F, $55, $E0, $DA,
    $94, $AE, $08, $32, $7C, $46, $D5, $EF, $A1, $9B, $3D, $07, $49, $73, $C6,
    $FC, $B2, $88, $2E, $14, $5A, $60, $BF, $85, $CB, $F1, $57, $6D, $23, $19,
    $AC, $96, $D8, $E2, $44, $7E, $30, $0A, $99, $A3, $ED, $D7, $71, $4B, $05,
    $3F, $8A, $B0, $FE, $C4, $62, $58, $16, $2C, $6B, $51, $1F, $25, $83, $B9,
    $F7, $CD, $78, $42, $0C, $36, $90, $AA, $E4, $DE, $4D, $77, $39, $03, $A5,
    $9F, $D1, $EB, $5E, $64, $2A, $10, $B6, $8C, $C2, $F8, $27, $1D, $53, $69,
    $CF, $F5, $BB, $81, $34, $0E, $40, $7A, $DC, $E6, $A8, $92, $01, $3B, $75,
    $4F, $E9, $D3, $9D, $A7, $12, $28, $66, $5C, $FA, $C0, $8E, $B4, $00, $3B,
    $76, $4D, $EC, $D7, $9A, $A1, $1B, $20, $6D, $56, $F7, $CC, $81, $BA, $36,
    $0D, $40, $7B, $DA, $E1, $AC, $97, $2D, $16, $5B, $60, $C1, $FA, $B7, $8C,
    $6C, $57, $1A, $21, $80, $BB, $F6, $CD, $77, $4C, $01, $3A, $9B, $A0, $ED,
    $D6, $5A, $61, $2C, $17, $B6, $8D, $C0, $FB, $41, $7A, $37, $0C, $AD, $96,
    $DB, $E0, $D8, $E3, $AE, $95, $34, $0F, $42, $79, $C3, $F8, $B5, $8E, $2F,
    $14, $59, $62, $EE, $D5, $98, $A3, $02, $39, $74, $4F, $F5, $CE, $83, $B8,
    $19, $22, $6F, $54, $B4, $8F, $C2, $F9, $58, $63, $2E, $15, $AF, $94, $D9,
    $E2, $43, $78, $35, $0E, $82, $B9, $F4, $CF, $6E, $55, $18, $23, $99, $A2,
    $EF, $D4, $75, $4E, $03, $38, $73, $48, $05, $3E, $9F, $A4, $E9, $D2, $68,
    $53, $1E, $25, $84, $BF, $F2, $C9, $45, $7E, $33, $08, $A9, $92, $DF, $E4,
    $5E, $65, $28, $13, $B2, $89, $C4, $FF, $1F, $24, $69, $52, $F3, $C8, $85,
    $BE, $04, $3F, $72, $49, $E8, $D3, $9E, $A5, $29, $12, $5F, $64, $C5, $FE,
    $B3, $88, $32, $09, $44, $7F, $DE, $E5, $A8, $93, $AB, $90, $DD, $E6, $47,
    $7C, $31, $0A, $B0, $8B, $C6, $FD, $5C, $67, $2A, $11, $9D, $A6, $EB, $D0,
    $71, $4A, $07, $3C, $86, $BD, $F0, $CB, $6A, $51, $1C, $27, $C7, $FC, $B1,
    $8A, $2B, $10, $5D, $66, $DC, $E7, $AA, $91, $30, $0B, $46, $7D, $F1, $CA,
    $87, $BC, $1D, $26, $6B, $50, $EA, $D1, $9C, $A7, $06, $3D, $70, $4B, $00,
    $3C, $78, $44, $F0, $CC, $88, $B4, $23, $1F, $5B, $67, $D3, $EF, $AB, $97,
    $46, $7A, $3E, $02, $B6, $8A, $CE, $F2, $65, $59, $1D, $21, $95, $A9, $ED,
    $D1, $8C, $B0, $F4, $C8, $7C, $40, $04, $38, $AF, $93, $D7, $EB, $5F, $63,
    $27, $1B, $CA, $F6, $B2, $8E, $3A, $06, $42, $7E, $E9, $D5, $91, $AD, $19,
    $25, $61, $5D, $DB, $E7, $A3, $9F, $2B, $17, $53, $6F, $F8, $C4, $80, $BC,
    $08, $34, $70, $4C, $9D, $A1, $E5, $D9, $6D, $51, $15, $29, $BE, $82, $C6,
    $FA, $4E, $72, $36, $0A, $57, $6B, $2F, $13, $A7, $9B, $DF, $E3, $74, $48,
    $0C, $30, $84, $B8, $FC, $C0, $11, $2D, $69, $55, $E1, $DD, $99, $A5, $32,
    $0E, $4A, $76, $C2, $FE, $BA, $86, $75, $49, $0D, $31, $85, $B9, $FD, $C1,
    $56, $6A, $2E, $12, $A6, $9A, $DE, $E2, $33, $0F, $4B, $77, $C3, $FF, $BB,
    $87, $10, $2C, $68, $54, $E0, $DC, $98, $A4, $F9, $C5, $81, $BD, $09, $35,
    $71, $4D, $DA, $E6, $A2, $9E, $2A, $16, $52, $6E, $BF, $83, $C7, $FB, $4F,
    $73, $37, $0B, $9C, $A0, $E4, $D8, $6C, $50, $14, $28, $AE, $92, $D6, $EA,
    $5E, $62, $26, $1A, $8D, $B1, $F5, $C9, $7D, $41, $05, $39, $E8, $D4, $90,
    $AC, $18, $24, $60, $5C, $CB, $F7, $B3, $8F, $3B, $07, $43, $7F, $22, $1E,
    $5A, $66, $D2, $EE, $AA, $96, $01, $3D, $79, $45, $F1, $CD, $89, $B5, $64,
    $58, $1C, $20, $94, $A8, $EC, $D0, $47, $7B, $3F, $03, $B7, $8B, $CF, $F3,
    $00, $3D, $7A, $47, $F4, $C9, $8E, $B3, $2B, $16, $51, $6C, $DF, $E2, $A5,
    $98, $56, $6B, $2C, $11, $A2, $9F, $D8, $E5, $7D, $40, $07, $3A, $89, $B4,
    $F3, $CE, $AC, $91, $D6, $EB, $58, $65, $22, $1F, $87, $BA, $FD, $C0, $73,
    $4E, $09, $34, $FA, $C7, $80, $BD, $0E, $33, $74, $49, $D1, $EC, $AB, $96,
    $25, $18, $5F, $62, $9B, $A6, $E1, $DC, $6F, $52, $15, $28, $B0, $8D, $CA,
    $F7, $44, $79, $3E, $03, $CD, $F0, $B7, $8A, $39, $04, $43, $7E, $E6, $DB,
    $9C, $A1, $12, $2F, $68, $55, $37, $0A, $4D, $70, $C3, $FE, $B9, $84, $1C,
    $21, $66, $5B, $E8, $D5, $92, $AF, $61, $5C, $1B, $26, $95, $A8, $EF, $D2,
    $4A, $77, $30, $0D, $BE, $83, $C4, $F9, $F5, $C8, $8F, $B2, $01, $3C, $7B,
    $46, $DE, $E3, $A4, $99, $2A, $17, $50, $6D, $A3, $9E, $D9, $E4, $57, $6A,
    $2D, $10, $88, $B5, $F2, $CF, $7C, $41, $06, $3B, $59, $64, $23, $1E, $AD,
    $90, $D7, $EA, $72, $4F, $08, $35, $86, $BB, $FC, $C1, $0F, $32, $75, $48,
    $FB, $C6, $81, $BC, $24, $19, $5E, $63, $D0, $ED, $AA, $97, $6E, $53, $14,
    $29, $9A, $A7, $E0, $DD, $45, $78, $3F, $02, $B1, $8C, $CB, $F6, $38, $05,
    $42, $7F, $CC, $F1, $B6, $8B, $13, $2E, $69, $54, $E7, $DA, $9D, $A0, $C2,
    $FF, $B8, $85, $36, $0B, $4C, $71, $E9, $D4, $93, $AE, $1D, $20, $67, $5A,
    $94, $A9, $EE, $D3, $60, $5D, $1A, $27, $BF, $82, $C5, $F8, $4B, $76, $31,
    $0C, $00, $3E, $7C, $42, $F8, $C6, $84, $BA, $33, $0D, $4F, $71, $CB, $F5,
    $B7, $89, $66, $58, $1A, $24, $9E, $A0, $E2, $DC, $55, $6B, $29, $17, $AD,
    $93, $D1, $EF, $CC, $F2, $B0, $8E, $34, $0A, $48, $76, $FF, $C1, $83, $BD,
    $07, $39, $7B, $45, $AA, $94, $D6, $E8, $52, $6C, $2E, $10, $99, $A7, $E5,
    $DB, $61, $5F, $1D, $23, $5B, $65, $27, $19, $A3, $9D, $DF, $E1, $68, $56,
    $14, $2A, $90, $AE, $EC, $D2, $3D, $03, $41, $7F, $C5, $FB, $B9, $87, $0E,
    $30, $72, $4C, $F6, $C8, $8A, $B4, $97, $A9, $EB, $D5, $6F, $51, $13, $2D,
    $A4, $9A, $D8, $E6, $5C, $62, $20, $1E, $F1, $CF, $8D, $B3, $09, $37, $75,
    $4B, $C2, $FC, $BE, $80, $3A, $04, $46, $78, $B6, $88, $CA, $F4, $4E, $70,
    $32, $0C, $85, $BB, $F9, $C7, $7D, $43, $01, $3F, $D0, $EE, $AC, $92, $28,
    $16, $54, $6A, $E3, $DD, $9F, $A1, $1B, $25, $67, $59, $7A, $44, $06, $38,
    $82, $BC, $FE, $C0, $49, $77, $35, $0B, $B1, $8F, $CD, $F3, $1C, $22, $60,
    $5E, $E4, $DA, $98, $A6, $2F, $11, $53, $6D, $D7, $E9, $AB, $95, $ED, $D3,
    $91, $AF, $15, $2B, $69, $57, $DE, $E0, $A2, $9C, $26, $18, $5A, $64, $8B,
    $B5, $F7, $C9, $73, $4D, $0F, $31, $B8, $86, $C4, $FA, $40, $7E, $3C, $02,
    $21, $1F, $5D, $63, $D9, $E7, $A5, $9B, $12, $2C, $6E, $50, $EA, $D4, $96,
    $A8, $47, $79, $3B, $05, $BF, $81, $C3, $FD, $74, $4A, $08, $36, $8C, $B2,
    $F0, $CE, $00, $3F, $7E, $41, $FC, $C3, $82, $BD, $3B, $04, $45, $7A, $C7,
    $F8, $B9, $86, $76, $49, $08, $37, $8A, $B5, $F4, $CB, $4D, $72, $33, $0C,
    $B1, $8E, $CF, $F0, $EC, $D3, $92, $AD, $10, $2F, $6E, $51, $D7, $E8, $A9,
    $96, $2B, $14, $55, $6A, $9A, $A5, $E4, $DB, $66, $59, $18, $27, $A1, $9E,
    $DF, $E0, $5D, $62, $23, $1C, $1B, $24, $65, $5A, $E7, $D8, $99, $A6, $20,
    $1F, $5E, $61, $DC, $E3, $A2, $9D, $6D, $52, $13, $2C, $91, $AE, $EF, $D0,
    $56, $69, $28, $17, $AA, $95, $D4, $EB, $F7, $C8, $89, $B6, $0B, $34, $75,
    $4A, $CC, $F3, $B2, $8D, $30, $0F, $4E, $71, $81, $BE, $FF, $C0, $7D, $42,
    $03, $3C, $BA, $85, $C4, $FB, $46, $79, $38, $07, $36, $09, $48, $77, $CA,
    $F5, $B4, $8B, $0D, $32, $73, $4C, $F1, $CE, $8F, $B0, $40, $7F, $3E, $01,
    $BC, $83, $C2, $FD, $7B, $44, $05, $3A, $87, $B8, $F9, $C6, $DA, $E5, $A4,
    $9B, $26, $19, $58, $67, $E1, $DE, $9F, $A0, $1D, $22, $63, $5C, $AC, $93,
    $D2, $ED, $50, $6F, $2E, $11, $97, $A8, $E9, $D6, $6B, $54, $15, $2A, $2D,
    $12, $53, $6C, $D1, $EE, $AF, $90, $16, $29, $68, $57, $EA, $D5, $94, $AB,
    $5B, $64, $25, $1A, $A7, $98, $D9, $E6, $60, $5F, $1E, $21, $9C, $A3, $E2,
    $DD, $C1, $FE, $BF, $80, $3D, $02, $43, $7C, $FA, $C5, $84, $BB, $06, $39,
    $78, $47, $B7, $88, $C9, $F6, $4B, $74, $35, $0A, $8C, $B3, $F2, $CD, $70,
    $4F, $0E, $31, $00, $40, $80, $C0, $C3, $83, $43, $03, $45, $05, $C5, $85,
    $86, $C6, $06, $46, $8A, $CA, $0A, $4A, $49, $09, $C9, $89, $CF, $8F, $4F,
    $0F, $0C, $4C, $8C, $CC, $D7, $97, $57, $17, $14, $54, $94, $D4, $92, $D2,
    $12, $52, $51, $11, $D1, $91, $5D, $1D, $DD, $9D, $9E, $DE, $1E, $5E, $18,
    $58, $98, $D8, $DB, $9B, $5B, $1B, $6D, $2D, $ED, $AD, $AE, $EE, $2E, $6E,
    $28, $68, $A8, $E8, $EB, $AB, $6B, $2B, $E7, $A7, $67, $27, $24, $64, $A4,
    $E4, $A2, $E2, $22, $62, $61, $21, $E1, $A1, $BA, $FA, $3A, $7A, $79, $39,
    $F9, $B9, $FF, $BF, $7F, $3F, $3C, $7C, $BC, $FC, $30, $70, $B0, $F0, $F3,
    $B3, $73, $33, $75, $35, $F5, $B5, $B6, $F6, $36, $76, $DA, $9A, $5A, $1A,
    $19, $59, $99, $D9, $9F, $DF, $1F, $5F, $5C, $1C, $DC, $9C, $50, $10, $D0,
    $90, $93, $D3, $13, $53, $15, $55, $95, $D5, $D6, $96, $56, $16, $0D, $4D,
    $8D, $CD, $CE, $8E, $4E, $0E, $48, $08, $C8, $88, $8B, $CB, $0B, $4B, $87,
    $C7, $07, $47, $44, $04, $C4, $84, $C2, $82, $42, $02, $01, $41, $81, $C1,
    $B7, $F7, $37, $77, $74, $34, $F4, $B4, $F2, $B2, $72, $32, $31, $71, $B1,
    $F1, $3D, $7D, $BD, $FD, $FE, $BE, $7E, $3E, $78, $38, $F8, $B8, $BB, $FB,
    $3B, $7B, $60, $20, $E0, $A0, $A3, $E3, $23, $63, $25, $65, $A5, $E5, $E6,
    $A6, $66, $26, $EA, $AA, $6A, $2A, $29, $69, $A9, $E9, $AF, $EF, $2F, $6F,
    $6C, $2C, $EC, $AC, $00, $41, $82, $C3, $C7, $86, $45, $04, $4D, $0C, $CF,
    $8E, $8A, $CB, $08, $49, $9A, $DB, $18, $59, $5D, $1C, $DF, $9E, $D7, $96,
    $55, $14, $10, $51, $92, $D3, $F7, $B6, $75, $34, $30, $71, $B2, $F3, $BA,
    $FB, $38, $79, $7D, $3C, $FF, $BE, $6D, $2C, $EF, $AE, $AA, $EB, $28, $69,
    $20, $61, $A2, $E3, $E7, $A6, $65, $24, $2D, $6C, $AF, $EE, $EA, $AB, $68,
    $29, $60, $21, $E2, $A3, $A7, $E6, $25, $64, $B7, $F6, $35, $74, $70, $31,
    $F2, $B3, $FA, $BB, $78, $39, $3D, $7C, $BF, $FE, $DA, $9B, $58, $19, $1D,
    $5C, $9F, $DE, $97, $D6, $15, $54, $50, $11, $D2, $93, $40, $01, $C2, $83,
    $87, $C6, $05, $44, $0D, $4C, $8F, $CE, $CA, $8B, $48, $09, $5A, $1B, $D8,
    $99, $9D, $DC, $1F, $5E, $17, $56, $95, $D4, $D0, $91, $52, $13, $C0, $81,
    $42, $03, $07, $46, $85, $C4, $8D, $CC, $0F, $4E, $4A, $0B, $C8, $89, $AD,
    $EC, $2F, $6E, $6A, $2B, $E8, $A9, $E0, $A1, $62, $23, $27, $66, $A5, $E4,
    $37, $76, $B5, $F4, $F0, $B1, $72, $33, $7A, $3B, $F8, $B9, $BD, $FC, $3F,
    $7E, $77, $36, $F5, $B4, $B0, $F1, $32, $73, $3A, $7B, $B8, $F9, $FD, $BC,
    $7F, $3E, $ED, $AC, $6F, $2E, $2A, $6B, $A8, $E9, $A0, $E1, $22, $63, $67,
    $26, $E5, $A4, $80, $C1, $02, $43, $47, $06, $C5, $84, $CD, $8C, $4F, $0E,
    $0A, $4B, $88, $C9, $1A, $5B, $98, $D9, $DD, $9C, $5F, $1E, $57, $16, $D5,
    $94, $90, $D1, $12, $53, $00, $42, $84, $C6, $CB, $89, $4F, $0D, $55, $17,
    $D1, $93, $9E, $DC, $1A, $58, $AA, $E8, $2E, $6C, $61, $23, $E5, $A7, $FF,
    $BD, $7B, $39, $34, $76, $B0, $F2, $97, $D5, $13, $51, $5C, $1E, $D8, $9A,
    $C2, $80, $46, $04, $09, $4B, $8D, $CF, $3D, $7F, $B9, $FB, $F6, $B4, $72,
    $30, $68, $2A, $EC, $AE, $A3, $E1, $27, $65, $ED, $AF, $69, $2B, $26, $64,
    $A2, $E0, $B8, $FA, $3C, $7E, $73, $31, $F7, $B5, $47, $05, $C3, $81, $8C,
    $CE, $08, $4A, $12, $50, $96, $D4, $D9, $9B, $5D, $1F, $7A, $38, $FE, $BC,
    $B1, $F3, $35, $77, $2F, $6D, $AB, $E9, $E4, $A6, $60, $22, $D0, $92, $54,
    $16, $1B, $59, $9F, $DD, $85, $C7, $01, $43, $4E, $0C, $CA, $88, $19, $5B,
    $9D, $DF, $D2, $90, $56, $14, $4C, $0E, $C8, $8A, $87, $C5, $03, $41, $B3,
    $F1, $37, $75, $78, $3A, $FC, $BE, $E6, $A4, $62, $20, $2D, $6F, $A9, $EB,
    $8E, $CC, $0A, $48, $45, $07, $C1, $83, $DB, $99, $5F, $1D, $10, $52, $94,
    $D6, $24, $66, $A0, $E2, $EF, $AD, $6B, $29, $71, $33, $F5, $B7, $BA, $F8,
    $3E, $7C, $F4, $B6, $70, $32, $3F, $7D, $BB, $F9, $A1, $E3, $25, $67, $6A,
    $28, $EE, $AC, $5E, $1C, $DA, $98, $95, $D7, $11, $53, $0B, $49, $8F, $CD,
    $C0, $82, $44, $06, $63, $21, $E7, $A5, $A8, $EA, $2C, $6E, $36, $74, $B2,
    $F0, $FD, $BF, $79, $3B, $C9, $8B, $4D, $0F, $02, $40, $86, $C4, $9C, $DE,
    $18, $5A, $57, $15, $D3, $91, $00, $43, $86, $C5, $CF, $8C, $49, $0A, $5D,
    $1E, $DB, $98, $92, $D1, $14, $57, $BA, $F9, $3C, $7F, $75, $36, $F3, $B0,
    $E7, $A4, $61, $22, $28, $6B, $AE, $ED, $B7, $F4, $31, $72, $78, $3B, $FE,
    $BD, $EA, $A9, $6C, $2F, $25, $66, $A3, $E0, $0D, $4E, $8B, $C8, $C2, $81,
    $44, $07, $50, $13, $D6, $95, $9F, $DC, $19, $5A, $AD, $EE, $2B, $68, $62,
    $21, $E4, $A7, $F0, $B3, $76, $35, $3F, $7C, $B9, $FA, $17, $54, $91, $D2,
    $D8, $9B, $5E, $1D, $4A, $09, $CC, $8F, $85, $C6, $03, $40, $1A, $59, $9C,
    $DF, $D5, $96, $53, $10, $47, $04, $C1, $82, $88, $CB, $0E, $4D, $A0, $E3,
    $26, $65, $6F, $2C, $E9, $AA, $FD, $BE, $7B, $38, $32, $71, $B4, $F7, $99,
    $DA, $1F, $5C, $56, $15, $D0, $93, $C4, $87, $42, $01, $0B, $48, $8D, $CE,
    $23, $60, $A5, $E6, $EC, $AF, $6A, $29, $7E, $3D, $F8, $BB, $B1, $F2, $37,
    $74, $2E, $6D, $A8, $EB, $E1, $A2, $67, $24, $73, $30, $F5, $B6, $BC, $FF,
    $3A, $79, $94, $D7, $12, $51, $5B, $18, $DD, $9E, $C9, $8A, $4F, $0C, $06,
    $45, $80, $C3, $34, $77, $B2, $F1, $FB, $B8, $7D, $3E, $69, $2A, $EF, $AC,
    $A6, $E5, $20, $63, $8E, $CD, $08, $4B, $41, $02, $C7, $84, $D3, $90, $55,
    $16, $1C, $5F, $9A, $D9, $83, $C0, $05, $46, $4C, $0F, $CA, $89, $DE, $9D,
    $58, $1B, $11, $52, $97, $D4, $39, $7A, $BF, $FC, $F6, $B5, $70, $33, $64,
    $27, $E2, $A1, $AB, $E8, $2D, $6E, $00, $44, $88, $CC, $D3, $97, $5B, $1F,
    $65, $21, $ED, $A9, $B6, $F2, $3E, $7A, $CA, $8E, $42, $06, $19, $5D, $91,
    $D5, $AF, $EB, $27, $63, $7C, $38, $F4, $B0, $57, $13, $DF, $9B, $84, $C0,
    $0C, $48, $32, $76, $BA, $FE, $E1, $A5, $69, $2D, $9D, $D9, $15, $51, $4E,
    $0A, $C6, $82, $F8, $BC, $70, $34, $2B, $6F, $A3, $E7, $AE, $EA, $26, $62,
    $7D, $39, $F5, $B1, $CB, $8F, $43, $07, $18, $5C, $90, $D4, $64, $20, $EC,
    $A8, $B7, $F3, $3F, $7B, $01, $45, $89, $CD, $D2, $96, $5A, $1E, $F9, $BD,
    $71, $35, $2A, $6E, $A2, $E6, $9C, $D8, $14, $50, $4F, $0B, $C7, $83, $33,
    $77, $BB, $FF, $E0, $A4, $68, $2C, $56, $12, $DE, $9A, $85, $C1, $0D, $49,
    $9F, $DB, $17, $53, $4C, $08, $C4, $80, $FA, $BE, $72, $36, $29, $6D, $A1,
    $E5, $55, $11, $DD, $99, $86, $C2, $0E, $4A, $30, $74, $B8, $FC, $E3, $A7,
    $6B, $2F, $C8, $8C, $40, $04, $1B, $5F, $93, $D7, $AD, $E9, $25, $61, $7E,
    $3A, $F6, $B2, $02, $46, $8A, $CE, $D1, $95, $59, $1D, $67, $23, $EF, $AB,
    $B4, $F0, $3C, $78, $31, $75, $B9, $FD, $E2, $A6, $6A, $2E, $54, $10, $DC,
    $98, $87, $C3, $0F, $4B, $FB, $BF, $73, $37, $28, $6C, $A0, $E4, $9E, $DA,
    $16, $52, $4D, $09, $C5, $81, $66, $22, $EE, $AA, $B5, $F1, $3D, $79, $03,
    $47, $8B, $CF, $D0, $94, $58, $1C, $AC, $E8, $24, $60, $7F, $3B, $F7, $B3,
    $C9, $8D, $41, $05, $1A, $5E, $92, $D6, $00, $45, $8A, $CF, $D7, $92, $5D,
    $18, $6D, $28, $E7, $A2, $BA, $FF, $30, $75, $DA, $9F, $50, $15, $0D, $48,
    $87, $C2, $B7, $F2, $3D, $78, $60, $25, $EA, $AF, $77, $32, $FD, $B8, $A0,
    $E5, $2A, $6F, $1A, $5F, $90, $D5, $CD, $88, $47, $02, $AD, $E8, $27, $62,
    $7A, $3F, $F0, $B5, $C0, $85, $4A, $0F, $17, $52, $9D, $D8, $EE, $AB, $64,
    $21, $39, $7C, $B3, $F6, $83, $C6, $09, $4C, $54, $11, $DE, $9B, $34, $71,
    $BE, $FB, $E3, $A6, $69, $2C, $59, $1C, $D3, $96, $8E, $CB, $04, $41, $99,
    $DC, $13, $56, $4E, $0B, $C4, $81, $F4, $B1, $7E, $3B, $23, $66, $A9, $EC,
    $43, $06, $C9, $8C, $94, $D1, $1E, $5B, $2E, $6B, $A4, $E1, $F9, $BC, $73,
    $36, $1F, $5A, $95, $D0, $C8, $8D, $42, $07, $72, $37, $F8, $BD, $A5, $E0,
    $2F, $6A, $C5, $80, $4F, $0A, $12, $57, $98, $DD, $A8, $ED, $22, $67, $7F,
    $3A, $F5, $B0, $68, $2D, $E2, $A7, $BF, $FA, $35, $70, $05, $40, $8F, $CA,
    $D2, $97, $58, $1D, $B2, $F7, $38, $7D, $65, $20, $EF, $AA, $DF, $9A, $55,
    $10, $08, $4D, $82, $C7, $F1, $B4, $7B, $3E, $26, $63, $AC, $E9, $9C, $D9,
    $16, $53, $4B, $0E, $C1, $84, $2B, $6E, $A1, $E4, $FC, $B9, $76, $33, $46,
    $03, $CC, $89, $91, $D4, $1B, $5E, $86, $C3, $0C, $49, $51, $14, $DB, $9E,
    $EB, $AE, $61, $24, $3C, $79, $B6, $F3, $5C, $19, $D6, $93, $8B, $CE, $01,
    $44, $31, $74, $BB, $FE, $E6, $A3, $6C, $29, $00, $46, $8C, $CA, $DB, $9D,
    $57, $11, $75, $33, $F9, $BF, $AE, $E8, $22, $64, $EA, $AC, $66, $20, $31,
    $77, $BD, $FB, $9F, $D9, $13, $55, $44, $02, $C8, $8E, $17, $51, $9B, $DD,
    $CC, $8A, $40, $06, $62, $24, $EE, $A8, $B9, $FF, $35, $73, $FD, $BB, $71,
    $37, $26, $60, $AA, $EC, $88, $CE, $04, $42, $53, $15, $DF, $99, $2E, $68,
    $A2, $E4, $F5, $B3, $79, $3F, $5B, $1D, $D7, $91, $80, $C6, $0C, $4A, $C4,
    $82, $48, $0E, $1F, $59, $93, $D5, $B1, $F7, $3D, $7B, $6A, $2C, $E6, $A0,
    $39, $7F, $B5, $F3, $E2, $A4, $6E, $28, $4C, $0A, $C0, $86, $97, $D1, $1B,
    $5D, $D3, $95, $5F, $19, $08, $4E, $84, $C2, $A6, $E0, $2A, $6C, $7D, $3B,
    $F1, $B7, $5C, $1A, $D0, $96, $87, $C1, $0B, $4D, $29, $6F, $A5, $E3, $F2,
    $B4, $7E, $38, $B6, $F0, $3A, $7C, $6D, $2B, $E1, $A7, $C3, $85, $4F, $09,
    $18, $5E, $94, $D2, $4B, $0D, $C7, $81, $90, $D6, $1C, $5A, $3E, $78, $B2,
    $F4, $E5, $A3, $69, $2F, $A1, $E7, $2D, $6B, $7A, $3C, $F6, $B0, $D4, $92,
    $58, $1E, $0F, $49, $83, $C5, $72, $34, $FE, $B8, $A9, $EF, $25, $63, $07,
    $41, $8B, $CD, $DC, $9A, $50, $16, $98, $DE, $14, $52, $43, $05, $CF, $89,
    $ED, $AB, $61, $27, $36, $70, $BA, $FC, $65, $23, $E9, $AF, $BE, $F8, $32,
    $74, $10, $56, $9C, $DA, $CB, $8D, $47, $01, $8F, $C9, $03, $45, $54, $12,
    $D8, $9E, $FA, $BC, $76, $30, $21, $67, $AD, $EB, $00, $47, $8E, $C9, $DF,
    $98, $51, $16, $7D, $3A, $F3, $B4, $A2, $E5, $2C, $6B, $FA, $BD, $74, $33,
    $25, $62, $AB, $EC, $87, $C0, $09, $4E, $58, $1F, $D6, $91, $37, $70, $B9,
    $FE, $E8, $AF, $66, $21, $4A, $0D, $C4, $83, $95, $D2, $1B, $5C, $CD, $8A,
    $43, $04, $12, $55, $9C, $DB, $B0, $F7, $3E, $79, $6F, $28, $E1, $A6, $6E,
    $29, $E0, $A7, $B1, $F6, $3F, $78, $13, $54, $9D, $DA, $CC, $8B, $42, $05,
    $94, $D3, $1A, $5D, $4B, $0C, $C5, $82, $E9, $AE, $67, $20, $36, $71, $B8,
    $FF, $59, $1E, $D7, $90, $86, $C1, $08, $4F, $24, $63, $AA, $ED, $FB, $BC,
    $75, $32, $A3, $E4, $2D, $6A, $7C, $3B, $F2, $B5, $DE, $99, $50, $17, $01,
    $46, $8F, $C8, $DC, $9B, $52, $15, $03, $44, $8D, $CA, $A1, $E6, $2F, $68,
    $7E, $39, $F0, $B7, $26, $61, $A8, $EF, $F9, $BE, $77, $30, $5B, $1C, $D5,
    $92, $84, $C3, $0A, $4D, $EB, $AC, $65, $22, $34, $73, $BA, $FD, $96, $D1,
    $18, $5F, $49, $0E, $C7, $80, $11, $56, $9F, $D8, $CE, $89, $40, $07, $6C,
    $2B, $E2, $A5, $B3, $F4, $3D, $7A, $B2, $F5, $3C, $7B, $6D, $2A, $E3, $A4,
    $CF, $88, $41, $06, $10, $57, $9E, $D9, $48, $0F, $C6, $81, $97, $D0, $19,
    $5E, $35, $72, $BB, $FC, $EA, $AD, $64, $23, $85, $C2, $0B, $4C, $5A, $1D,
    $D4, $93, $F8, $BF, $76, $31, $27, $60, $A9, $EE, $7F, $38, $F1, $B6, $A0,
    $E7, $2E, $69, $02, $45, $8C, $CB, $DD, $9A, $53, $14, $00, $48, $90, $D8,
    $E3, $AB, $73, $3B, $05, $4D, $95, $DD, $E6, $AE, $76, $3E, $0A, $42, $9A,
    $D2, $E9, $A1, $79, $31, $0F, $47, $9F, $D7, $EC, $A4, $7C, $34, $14, $5C,
    $84, $CC, $F7, $BF, $67, $2F, $11, $59, $81, $C9, $F2, $BA, $62, $2A, $1E,
    $56, $8E, $C6, $FD, $B5, $6D, $25, $1B, $53, $8B, $C3, $F8, $B0, $68, $20,
    $28, $60, $B8, $F0, $CB, $83, $5B, $13, $2D, $65, $BD, $F5, $CE, $86, $5E,
    $16, $22, $6A, $B2, $FA, $C1, $89, $51, $19, $27, $6F, $B7, $FF, $C4, $8C,
    $54, $1C, $3C, $74, $AC, $E4, $DF, $97, $4F, $07, $39, $71, $A9, $E1, $DA,
    $92, $4A, $02, $36, $7E, $A6, $EE, $D5, $9D, $45, $0D, $33, $7B, $A3, $EB,
    $D0, $98, $40, $08, $50, $18, $C0, $88, $B3, $FB, $23, $6B, $55, $1D, $C5,
    $8D, $B6, $FE, $26, $6E, $5A, $12, $CA, $82, $B9, $F1, $29, $61, $5F, $17,
    $CF, $87, $BC, $F4, $2C, $64, $44, $0C, $D4, $9C, $A7, $EF, $37, $7F, $41,
    $09, $D1, $99, $A2, $EA, $32, $7A, $4E, $06, $DE, $96, $AD, $E5, $3D, $75,
    $4B, $03, $DB, $93, $A8, $E0, $38, $70, $78, $30, $E8, $A0, $9B, $D3, $0B,
    $43, $7D, $35, $ED, $A5, $9E, $D6, $0E, $46, $72, $3A, $E2, $AA, $91, $D9,
    $01, $49, $77, $3F, $E7, $AF, $94, $DC, $04, $4C, $6C, $24, $FC, $B4, $8F,
    $C7, $1F, $57, $69, $21, $F9, $B1, $8A, $C2, $1A, $52, $66, $2E, $F6, $BE,
    $85, $CD, $15, $5D, $63, $2B, $F3, $BB, $80, $C8, $10, $58, $00, $49, $92,
    $DB, $E7, $AE, $75, $3C, $0D, $44, $9F, $D6, $EA, $A3, $78, $31, $1A, $53,
    $88, $C1, $FD, $B4, $6F, $26, $17, $5E, $85, $CC, $F0, $B9, $62, $2B, $34,
    $7D, $A6, $EF, $D3, $9A, $41, $08, $39, $70, $AB, $E2, $DE, $97, $4C, $05,
    $2E, $67, $BC, $F5, $C9, $80, $5B, $12, $23, $6A, $B1, $F8, $C4, $8D, $56,
    $1F, $68, $21, $FA, $B3, $8F, $C6, $1D, $54, $65, $2C, $F7, $BE, $82, $CB,
    $10, $59, $72, $3B, $E0, $A9, $95, $DC, $07, $4E, $7F, $36, $ED, $A4, $98,
    $D1, $0A, $43, $5C, $15, $CE, $87, $BB, $F2, $29, $60, $51, $18, $C3, $8A,
    $B6, $FF, $24, $6D, $46, $0F, $D4, $9D, $A1, $E8, $33, $7A, $4B, $02, $D9,
    $90, $AC, $E5, $3E, $77, $D0, $99, $42, $0B, $37, $7E, $A5, $EC, $DD, $94,
    $4F, $06, $3A, $73, $A8, $E1, $CA, $83, $58, $11, $2D, $64, $BF, $F6, $C7,
    $8E, $55, $1C, $20, $69, $B2, $FB, $E4, $AD, $76, $3F, $03, $4A, $91, $D8,
    $E9, $A0, $7B, $32, $0E, $47, $9C, $D5, $FE, $B7, $6C, $25, $19, $50, $8B,
    $C2, $F3, $BA, $61, $28, $14, $5D, $86, $CF, $B8, $F1, $2A, $63, $5F, $16,
    $CD, $84, $B5, $FC, $27, $6E, $52, $1B, $C0, $89, $A2, $EB, $30, $79, $45,
    $0C, $D7, $9E, $AF, $E6, $3D, $74, $48, $01, $DA, $93, $8C, $C5, $1E, $57,
    $6B, $22, $F9, $B0, $81, $C8, $13, $5A, $66, $2F, $F4, $BD, $96, $DF, $04,
    $4D, $71, $38, $E3, $AA, $9B, $D2, $09, $40, $7C, $35, $EE, $A7, $00, $4A,
    $94, $DE, $EB, $A1, $7F, $35, $15, $5F, $81, $CB, $FE, $B4, $6A, $20, $2A,
    $60, $BE, $F4, $C1, $8B, $55, $1F, $3F, $75, $AB, $E1, $D4, $9E, $40, $0A,
    $54, $1E, $C0, $8A, $BF, $F5, $2B, $61, $41, $0B, $D5, $9F, $AA, $E0, $3E,
    $74, $7E, $34, $EA, $A0, $95, $DF, $01, $4B, $6B, $21, $FF, $B5, $80, $CA,
    $14, $5E, $A8, $E2, $3C, $76, $43, $09, $D7, $9D, $BD, $F7, $29, $63, $56,
    $1C, $C2, $88, $82, $C8, $16, $5C, $69, $23, $FD, $B7, $97, $DD, $03, $49,
    $7C, $36, $E8, $A2, $FC, $B6, $68, $22, $17, $5D, $83, $C9, $E9, $A3, $7D,
    $37, $02, $48, $96, $DC, $D6, $9C, $42, $08, $3D, $77, $A9, $E3, $C3, $89,
    $57, $1D, $28, $62, $BC, $F6, $93, $D9, $07, $4D, $78, $32, $EC, $A6, $86,
    $CC, $12, $58, $6D, $27, $F9, $B3, $B9, $F3, $2D, $67, $52, $18, $C6, $8C,
    $AC, $E6, $38, $72, $47, $0D, $D3, $99, $C7, $8D, $53, $19, $2C, $66, $B8,
    $F2, $D2, $98, $46, $0C, $39, $73, $AD, $E7, $ED, $A7, $79, $33, $06, $4C,
    $92, $D8, $F8, $B2, $6C, $26, $13, $59, $87, $CD, $3B, $71, $AF, $E5, $D0,
    $9A, $44, $0E, $2E, $64, $BA, $F0, $C5, $8F, $51, $1B, $11, $5B, $85, $CF,
    $FA, $B0, $6E, $24, $04, $4E, $90, $DA, $EF, $A5, $7B, $31, $6F, $25, $FB,
    $B1, $84, $CE, $10, $5A, $7A, $30, $EE, $A4, $91, $DB, $05, $4F, $45, $0F,
    $D1, $9B, $AE, $E4, $3A, $70, $50, $1A, $C4, $8E, $BB, $F1, $2F, $65, $00,
    $4B, $96, $DD, $EF, $A4, $79, $32, $1D, $56, $8B, $C0, $F2, $B9, $64, $2F,
    $3A, $71, $AC, $E7, $D5, $9E, $43, $08, $27, $6C, $B1, $FA, $C8, $83, $5E,
    $15, $74, $3F, $E2, $A9, $9B, $D0, $0D, $46, $69, $22, $FF, $B4, $86, $CD,
    $10, $5B, $4E, $05, $D8, $93, $A1, $EA, $37, $7C, $53, $18, $C5, $8E, $BC,
    $F7, $2A, $61, $E8, $A3, $7E, $35, $07, $4C, $91, $DA, $F5, $BE, $63, $28,
    $1A, $51, $8C, $C7, $D2, $99, $44, $0F, $3D, $76, $AB, $E0, $CF, $84, $59,
    $12, $20, $6B, $B6, $FD, $9C, $D7, $0A, $41, $73, $38, $E5, $AE, $81, $CA,
    $17, $5C, $6E, $25, $F8, $B3, $A6, $ED, $30, $7B, $49, $02, $DF, $94, $BB,
    $F0, $2D, $66, $54, $1F, $C2, $89, $13, $58, $85, $CE, $FC, $B7, $6A, $21,
    $0E, $45, $98, $D3, $E1, $AA, $77, $3C, $29, $62, $BF, $F4, $C6, $8D, $50,
    $1B, $34, $7F, $A2, $E9, $DB, $90, $4D, $06, $67, $2C, $F1, $BA, $88, $C3,
    $1E, $55, $7A, $31, $EC, $A7, $95, $DE, $03, $48, $5D, $16, $CB, $80, $B2,
    $F9, $24, $6F, $40, $0B, $D6, $9D, $AF, $E4, $39, $72, $FB, $B0, $6D, $26,
    $14, $5F, $82, $C9, $E6, $AD, $70, $3B, $09, $42, $9F, $D4, $C1, $8A, $57,
    $1C, $2E, $65, $B8, $F3, $DC, $97, $4A, $01, $33, $78, $A5, $EE, $8F, $C4,
    $19, $52, $60, $2B, $F6, $BD, $92, $D9, $04, $4F, $7D, $36, $EB, $A0, $B5,
    $FE, $23, $68, $5A, $11, $CC, $87, $A8, $E3, $3E, $75, $47, $0C, $D1, $9A,
    $00, $4C, $98, $D4, $F3, $BF, $6B, $27, $25, $69, $BD, $F1, $D6, $9A, $4E,
    $02, $4A, $06, $D2, $9E, $B9, $F5, $21, $6D, $6F, $23, $F7, $BB, $9C, $D0,
    $04, $48, $94, $D8, $0C, $40, $67, $2B, $FF, $B3, $B1, $FD, $29, $65, $42,
    $0E, $DA, $96, $DE, $92, $46, $0A, $2D, $61, $B5, $F9, $FB, $B7, $63, $2F,
    $08, $44, $90, $DC, $EB, $A7, $73, $3F, $18, $54, $80, $CC, $CE, $82, $56,
    $1A, $3D, $71, $A5, $E9, $A1, $ED, $39, $75, $52, $1E, $CA, $86, $84, $C8,
    $1C, $50, $77, $3B, $EF, $A3, $7F, $33, $E7, $AB, $8C, $C0, $14, $58, $5A,
    $16, $C2, $8E, $A9, $E5, $31, $7D, $35, $79, $AD, $E1, $C6, $8A, $5E, $12,
    $10, $5C, $88, $C4, $E3, $AF, $7B, $37, $15, $59, $8D, $C1, $E6, $AA, $7E,
    $32, $30, $7C, $A8, $E4, $C3, $8F, $5B, $17, $5F, $13, $C7, $8B, $AC, $E0,
    $34, $78, $7A, $36, $E2, $AE, $89, $C5, $11, $5D, $81, $CD, $19, $55, $72,
    $3E, $EA, $A6, $A4, $E8, $3C, $70, $57, $1B, $CF, $83, $CB, $87, $53, $1F,
    $38, $74, $A0, $EC, $EE, $A2, $76, $3A, $1D, $51, $85, $C9, $FE, $B2, $66,
    $2A, $0D, $41, $95, $D9, $DB, $97, $43, $0F, $28, $64, $B0, $FC, $B4, $F8,
    $2C, $60, $47, $0B, $DF, $93, $91, $DD, $09, $45, $62, $2E, $FA, $B6, $6A,
    $26, $F2, $BE, $99, $D5, $01, $4D, $4F, $03, $D7, $9B, $BC, $F0, $24, $68,
    $20, $6C, $B8, $F4, $D3, $9F, $4B, $07, $05, $49, $9D, $D1, $F6, $BA, $6E,
    $22, $00, $4D, $9A, $D7, $F7, $BA, $6D, $20, $2D, $60, $B7, $FA, $DA, $97,
    $40, $0D, $5A, $17, $C0, $8D, $AD, $E0, $37, $7A, $77, $3A, $ED, $A0, $80,
    $CD, $1A, $57, $B4, $F9, $2E, $63, $43, $0E, $D9, $94, $99, $D4, $03, $4E,
    $6E, $23, $F4, $B9, $EE, $A3, $74, $39, $19, $54, $83, $CE, $C3, $8E, $59,
    $14, $34, $79, $AE, $E3, $AB, $E6, $31, $7C, $5C, $11, $C6, $8B, $86, $CB,
    $1C, $51, $71, $3C, $EB, $A6, $F1, $BC, $6B, $26, $06, $4B, $9C, $D1, $DC,
    $91, $46, $0B, $2B, $66, $B1, $FC, $1F, $52, $85, $C8, $E8, $A5, $72, $3F,
    $32, $7F, $A8, $E5, $C5, $88, $5F, $12, $45, $08, $DF, $92, $B2, $FF, $28,
    $65, $68, $25, $F2, $BF, $9F, $D2, $05, $48, $95, $D8, $0F, $42, $62, $2F,
    $F8, $B5, $B8, $F5, $22, $6F, $4F, $02, $D5, $98, $CF, $82, $55, $18, $38,
    $75, $A2, $EF, $E2, $AF, $78, $35, $15, $58, $8F, $C2, $21, $6C, $BB, $F6,
    $D6, $9B, $4C, $01, $0C, $41, $96, $DB, $FB, $B6, $61, $2C, $7B, $36, $E1,
    $AC, $8C, $C1, $16, $5B, $56, $1B, $CC, $81, $A1, $EC, $3B, $76, $3E, $73,
    $A4, $E9, $C9, $84, $53, $1E, $13, $5E, $89, $C4, $E4, $A9, $7E, $33, $64,
    $29, $FE, $B3, $93, $DE, $09, $44, $49, $04, $D3, $9E, $BE, $F3, $24, $69,
    $8A, $C7, $10, $5D, $7D, $30, $E7, $AA, $A7, $EA, $3D, $70, $50, $1D, $CA,
    $87, $D0, $9D, $4A, $07, $27, $6A, $BD, $F0, $FD, $B0, $67, $2A, $0A, $47,
    $90, $DD, $00, $4E, $9C, $D2, $FB, $B5, $67, $29, $35, $7B, $A9, $E7, $CE,
    $80, $52, $1C, $6A, $24, $F6, $B8, $91, $DF, $0D, $43, $5F, $11, $C3, $8D,
    $A4, $EA, $38, $76, $D4, $9A, $48, $06, $2F, $61, $B3, $FD, $E1, $AF, $7D,
    $33, $1A, $54, $86, $C8, $BE, $F0, $22, $6C, $45, $0B, $D9, $97, $8B, $C5,
    $17, $59, $70, $3E, $EC, $A2, $6B, $25, $F7, $B9, $90, $DE, $0C, $42, $5E,
    $10, $C2, $8C, $A5, $EB, $39, $77, $01, $4F, $9D, $D3, $FA, $B4, $66, $28,
    $34, $7A, $A8, $E6, $CF, $81, $53, $1D, $BF, $F1, $23, $6D, $44, $0A, $D8,
    $96, $8A, $C4, $16, $58, $71, $3F, $ED, $A3, $D5, $9B, $49, $07, $2E, $60,
    $B2, $FC, $E0, $AE, $7C, $32, $1B, $55, $87, $C9, $D6, $98, $4A, $04, $2D,
    $63, $B1, $FF, $E3, $AD, $7F, $31, $18, $56, $84, $CA, $BC, $F2, $20, $6E,
    $47, $09, $DB, $95, $89, $C7, $15, $5B, $72, $3C, $EE, $A0, $02, $4C, $9E,
    $D0, $F9, $B7, $65, $2B, $37, $79, $AB, $E5, $CC, $82, $50, $1E, $68, $26,
    $F4, $BA, $93, $DD, $0F, $41, $5D, $13, $C1, $8F, $A6, $E8, $3A, $74, $BD,
    $F3, $21, $6F, $46, $08, $DA, $94, $88, $C6, $14, $5A, $73, $3D, $EF, $A1,
    $D7, $99, $4B, $05, $2C, $62, $B0, $FE, $E2, $AC, $7E, $30, $19, $57, $85,
    $CB, $69, $27, $F5, $BB, $92, $DC, $0E, $40, $5C, $12, $C0, $8E, $A7, $E9,
    $3B, $75, $03, $4D, $9F, $D1, $F8, $B6, $64, $2A, $36, $78, $AA, $E4, $CD,
    $83, $51, $1F, $00, $4F, $9E, $D1, $FF, $B0, $61, $2E, $3D, $72, $A3, $EC,
    $C2, $8D, $5C, $13, $7A, $35, $E4, $AB, $85, $CA, $1B, $54, $47, $08, $D9,
    $96, $B8, $F7, $26, $69, $F4, $BB, $6A, $25, $0B, $44, $95, $DA, $C9, $86,
    $57, $18, $36, $79, $A8, $E7, $8E, $C1, $10, $5F, $71, $3E, $EF, $A0, $B3,
    $FC, $2D, $62, $4C, $03, $D2, $9D, $2B, $64, $B5, $FA, $D4, $9B, $4A, $05,
    $16, $59, $88, $C7, $E9, $A6, $77, $38, $51, $1E, $CF, $80, $AE, $E1, $30,
    $7F, $6C, $23, $F2, $BD, $93, $DC, $0D, $42, $DF, $90, $41, $0E, $20, $6F,
    $BE, $F1, $E2, $AD, $7C, $33, $1D, $52, $83, $CC, $A5, $EA, $3B, $74, $5A,
    $15, $C4, $8B, $98, $D7, $06, $49, $67, $28, $F9, $B6, $56, $19, $C8, $87,
    $A9, $E6, $37, $78, $6B, $24, $F5, $BA, $94, $DB, $0A, $45, $2C, $63, $B2,
    $FD, $D3, $9C, $4D, $02, $11, $5E, $8F, $C0, $EE, $A1, $70, $3F, $A2, $ED,
    $3C, $73, $5D, $12, $C3, $8C, $9F, $D0, $01, $4E, $60, $2F, $FE, $B1, $D8,
    $97, $46, $09, $27, $68, $B9, $F6, $E5, $AA, $7B, $34, $1A, $55, $84, $CB,
    $7D, $32, $E3, $AC, $82, $CD, $1C, $53, $40, $0F, $DE, $91, $BF, $F0, $21,
    $6E, $07, $48, $99, $D6, $F8, $B7, $66, $29, $3A, $75, $A4, $EB, $C5, $8A,
    $5B, $14, $89, $C6, $17, $58, $76, $39, $E8, $A7, $B4, $FB, $2A, $65, $4B,
    $04, $D5, $9A, $F3, $BC, $6D, $22, $0C, $43, $92, $DD, $CE, $81, $50, $1F,
    $31, $7E, $AF, $E0, $00, $50, $A0, $F0, $83, $D3, $23, $73, $C5, $95, $65,
    $35, $46, $16, $E6, $B6, $49, $19, $E9, $B9, $CA, $9A, $6A, $3A, $8C, $DC,
    $2C, $7C, $0F, $5F, $AF, $FF, $92, $C2, $32, $62, $11, $41, $B1, $E1, $57,
    $07, $F7, $A7, $D4, $84, $74, $24, $DB, $8B, $7B, $2B, $58, $08, $F8, $A8,
    $1E, $4E, $BE, $EE, $9D, $CD, $3D, $6D, $E7, $B7, $47, $17, $64, $34, $C4,
    $94, $22, $72, $82, $D2, $A1, $F1, $01, $51, $AE, $FE, $0E, $5E, $2D, $7D,
    $8D, $DD, $6B, $3B, $CB, $9B, $E8, $B8, $48, $18, $75, $25, $D5, $85, $F6,
    $A6, $56, $06, $B0, $E0, $10, $40, $33, $63, $93, $C3, $3C, $6C, $9C, $CC,
    $BF, $EF, $1F, $4F, $F9, $A9, $59, $09, $7A, $2A, $DA, $8A, $0D, $5D, $AD,
    $FD, $8E, $DE, $2E, $7E, $C8, $98, $68, $38, $4B, $1B, $EB, $BB, $44, $14,
    $E4, $B4, $C7, $97, $67, $37, $81, $D1, $21, $71, $02, $52, $A2, $F2, $9F,
    $CF, $3F, $6F, $1C, $4C, $BC, $EC, $5A, $0A, $FA, $AA, $D9, $89, $79, $29,
    $D6, $86, $76, $26, $55, $05, $F5, $A5, $13, $43, $B3, $E3, $90, $C0, $30,
    $60, $EA, $BA, $4A, $1A, $69, $39, $C9, $99, $2F, $7F, $8F, $DF, $AC, $FC,
    $0C, $5C, $A3, $F3, $03, $53, $20, $70, $80, $D0, $66, $36, $C6, $96, $E5,
    $B5, $45, $15, $78, $28, $D8, $88, $FB, $AB, $5B, $0B, $BD, $ED, $1D, $4D,
    $3E, $6E, $9E, $CE, $31, $61, $91, $C1, $B2, $E2, $12, $42, $F4, $A4, $54,
    $04, $77, $27, $D7, $87, $00, $51, $A2, $F3, $87, $D6, $25, $74, $CD, $9C,
    $6F, $3E, $4A, $1B, $E8, $B9, $59, $08, $FB, $AA, $DE, $8F, $7C, $2D, $94,
    $C5, $36, $67, $13, $42, $B1, $E0, $B2, $E3, $10, $41, $35, $64, $97, $C6,
    $7F, $2E, $DD, $8C, $F8, $A9, $5A, $0B, $EB, $BA, $49, $18, $6C, $3D, $CE,
    $9F, $26, $77, $84, $D5, $A1, $F0, $03, $52, $A7, $F6, $05, $54, $20, $71,
    $82, $D3, $6A, $3B, $C8, $99, $ED, $BC, $4F, $1E, $FE, $AF, $5C, $0D, $79,
    $28, $DB, $8A, $33, $62, $91, $C0, $B4, $E5, $16, $47, $15, $44, $B7, $E6,
    $92, $C3, $30, $61, $D8, $89, $7A, $2B, $5F, $0E, $FD, $AC, $4C, $1D, $EE,
    $BF, $CB, $9A, $69, $38, $81, $D0, $23, $72, $06, $57, $A4, $F5, $8D, $DC,
    $2F, $7E, $0A, $5B, $A8, $F9, $40, $11, $E2, $B3, $C7, $96, $65, $34, $D4,
    $85, $76, $27, $53, $02, $F1, $A0, $19, $48, $BB, $EA, $9E, $CF, $3C, $6D,
    $3F, $6E, $9D, $CC, $B8, $E9, $1A, $4B, $F2, $A3, $50, $01, $75, $24, $D7,
    $86, $66, $37, $C4, $95, $E1, $B0, $43, $12, $AB, $FA, $09, $58, $2C, $7D,
    $8E, $DF, $2A, $7B, $88, $D9, $AD, $FC, $0F, $5E, $E7, $B6, $45, $14, $60,
    $31, $C2, $93, $73, $22, $D1, $80, $F4, $A5, $56, $07, $BE, $EF, $1C, $4D,
    $39, $68, $9B, $CA, $98, $C9, $3A, $6B, $1F, $4E, $BD, $EC, $55, $04, $F7,
    $A6, $D2, $83, $70, $21, $C1, $90, $63, $32, $46, $17, $E4, $B5, $0C, $5D,
    $AE, $FF, $8B, $DA, $29, $78, $00, $52, $A4, $F6, $8B, $D9, $2F, $7D, $D5,
    $87, $71, $23, $5E, $0C, $FA, $A8, $69, $3B, $CD, $9F, $E2, $B0, $46, $14,
    $BC, $EE, $18, $4A, $37, $65, $93, $C1, $D2, $80, $76, $24, $59, $0B, $FD,
    $AF, $07, $55, $A3, $F1, $8C, $DE, $28, $7A, $BB, $E9, $1F, $4D, $30, $62,
    $94, $C6, $6E, $3C, $CA, $98, $E5, $B7, $41, $13, $67, $35, $C3, $91, $EC,
    $BE, $48, $1A, $B2, $E0, $16, $44, $39, $6B, $9D, $CF, $0E, $5C, $AA, $F8,
    $85, $D7, $21, $73, $DB, $89, $7F, $2D, $50, $02, $F4, $A6, $B5, $E7, $11,
    $43, $3E, $6C, $9A, $C8, $60, $32, $C4, $96, $EB, $B9, $4F, $1D, $DC, $8E,
    $78, $2A, $57, $05, $F3, $A1, $09, $5B, $AD, $FF, $82, $D0, $26, $74, $CE,
    $9C, $6A, $38, $45, $17, $E1, $B3, $1B, $49, $BF, $ED, $90, $C2, $34, $66,
    $A7, $F5, $03, $51, $2C, $7E, $88, $DA, $72, $20, $D6, $84, $F9, $AB, $5D,
    $0F, $1C, $4E, $B8, $EA, $97, $C5, $33, $61, $C9, $9B, $6D, $3F, $42, $10,
    $E6, $B4, $75, $27, $D1, $83, $FE, $AC, $5A, $08, $A0, $F2, $04, $56, $2B,
    $79, $8F, $DD, $A9, $FB, $0D, $5F, $22, $70, $86, $D4, $7C, $2E, $D8, $8A,
    $F7, $A5, $53, $01, $C0, $92, $64, $36, $4B, $19, $EF, $BD, $15, $47, $B1,
    $E3, $9E, $CC, $3A, $68, $7B, $29, $DF, $8D, $F0, $A2, $54, $06, $AE, $FC,
    $0A, $58, $25, $77, $81, $D3, $12, $40, $B6, $E4, $99, $CB, $3D, $6F, $C7,
    $95, $63, $31, $4C, $1E, $E8, $BA, $00, $53, $A6, $F5, $8F, $DC, $29, $7A,
    $DD, $8E, $7B, $28, $52, $01, $F4, $A7, $79, $2A, $DF, $8C, $F6, $A5, $50,
    $03, $A4, $F7, $02, $51, $2B, $78, $8D, $DE, $F2, $A1, $54, $07, $7D, $2E,
    $DB, $88, $2F, $7C, $89, $DA, $A0, $F3, $06, $55, $8B, $D8, $2D, $7E, $04,
    $57, $A2, $F1, $56, $05, $F0, $A3, $D9, $8A, $7F, $2C, $27, $74, $81, $D2,
    $A8, $FB, $0E, $5D, $FA, $A9, $5C, $0F, $75, $26, $D3, $80, $5E, $0D, $F8,
    $AB, $D1, $82, $77, $24, $83, $D0, $25, $76, $0C, $5F, $AA, $F9, $D5, $86,
    $73, $20, $5A, $09, $FC, $AF, $08, $5B, $AE, $FD, $87, $D4, $21, $72, $AC,
    $FF, $0A, $59, $23, $70, $85, $D6, $71, $22, $D7, $84, $FE, $AD, $58, $0B,
    $4E, $1D, $E8, $BB, $C1, $92, $67, $34, $93, $C0, $35, $66, $1C, $4F, $BA,
    $E9, $37, $64, $91, $C2, $B8, $EB, $1E, $4D, $EA, $B9, $4C, $1F, $65, $36,
    $C3, $90, $BC, $EF, $1A, $49, $33, $60, $95, $C6, $61, $32, $C7, $94, $EE,
    $BD, $48, $1B, $C5, $96, $63, $30, $4A, $19, $EC, $BF, $18, $4B, $BE, $ED,
    $97, $C4, $31, $62, $69, $3A, $CF, $9C, $E6, $B5, $40, $13, $B4, $E7, $12,
    $41, $3B, $68, $9D, $CE, $10, $43, $B6, $E5, $9F, $CC, $39, $6A, $CD, $9E,
    $6B, $38, $42, $11, $E4, $B7, $9B, $C8, $3D, $6E, $14, $47, $B2, $E1, $46,
    $15, $E0, $B3, $C9, $9A, $6F, $3C, $E2, $B1, $44, $17, $6D, $3E, $CB, $98,
    $3F, $6C, $99, $CA, $B0, $E3, $16, $45, $00, $54, $A8, $FC, $93, $C7, $3B,
    $6F, $E5, $B1, $4D, $19, $76, $22, $DE, $8A, $09, $5D, $A1, $F5, $9A, $CE,
    $32, $66, $EC, $B8, $44, $10, $7F, $2B, $D7, $83, $12, $46, $BA, $EE, $81,
    $D5, $29, $7D, $F7, $A3, $5F, $0B, $64, $30, $CC, $98, $1B, $4F, $B3, $E7,
    $88, $DC, $20, $74, $FE, $AA, $56, $02, $6D, $39, $C5, $91, $24, $70, $8C,
    $D8, $B7, $E3, $1F, $4B, $C1, $95, $69, $3D, $52, $06, $FA, $AE, $2D, $79,
    $85, $D1, $BE, $EA, $16, $42, $C8, $9C, $60, $34, $5B, $0F, $F3, $A7, $36,
    $62, $9E, $CA, $A5, $F1, $0D, $59, $D3, $87, $7B, $2F, $40, $14, $E8, $BC,
    $3F, $6B, $97, $C3, $AC, $F8, $04, $50, $DA, $8E, $72, $26, $49, $1D, $E1,
    $B5, $48, $1C, $E0, $B4, $DB, $8F, $73, $27, $AD, $F9, $05, $51, $3E, $6A,
    $96, $C2, $41, $15, $E9, $BD, $D2, $86, $7A, $2E, $A4, $F0, $0C, $58, $37,
    $63, $9F, $CB, $5A, $0E, $F2, $A6, $C9, $9D, $61, $35, $BF, $EB, $17, $43,
    $2C, $78, $84, $D0, $53, $07, $FB, $AF, $C0, $94, $68, $3C, $B6, $E2, $1E,
    $4A, $25, $71, $8D, $D9, $6C, $38, $C4, $90, $FF, $AB, $57, $03, $89, $DD,
    $21, $75, $1A, $4E, $B2, $E6, $65, $31, $CD, $99, $F6, $A2, $5E, $0A, $80,
    $D4, $28, $7C, $13, $47, $BB, $EF, $7E, $2A, $D6, $82, $ED, $B9, $45, $11,
    $9B, $CF, $33, $67, $08, $5C, $A0, $F4, $77, $23, $DF, $8B, $E4, $B0, $4C,
    $18, $92, $C6, $3A, $6E, $01, $55, $A9, $FD, $00, $55, $AA, $FF, $97, $C2,
    $3D, $68, $ED, $B8, $47, $12, $7A, $2F, $D0, $85, $19, $4C, $B3, $E6, $8E,
    $DB, $24, $71, $F4, $A1, $5E, $0B, $63, $36, $C9, $9C, $32, $67, $98, $CD,
    $A5, $F0, $0F, $5A, $DF, $8A, $75, $20, $48, $1D, $E2, $B7, $2B, $7E, $81,
    $D4, $BC, $E9, $16, $43, $C6, $93, $6C, $39, $51, $04, $FB, $AE, $64, $31,
    $CE, $9B, $F3, $A6, $59, $0C, $89, $DC, $23, $76, $1E, $4B, $B4, $E1, $7D,
    $28, $D7, $82, $EA, $BF, $40, $15, $90, $C5, $3A, $6F, $07, $52, $AD, $F8,
    $56, $03, $FC, $A9, $C1, $94, $6B, $3E, $BB, $EE, $11, $44, $2C, $79, $86,
    $D3, $4F, $1A, $E5, $B0, $D8, $8D, $72, $27, $A2, $F7, $08, $5D, $35, $60,
    $9F, $CA, $C8, $9D, $62, $37, $5F, $0A, $F5, $A0, $25, $70, $8F, $DA, $B2,
    $E7, $18, $4D, $D1, $84, $7B, $2E, $46, $13, $EC, $B9, $3C, $69, $96, $C3,
    $AB, $FE, $01, $54, $FA, $AF, $50, $05, $6D, $38, $C7, $92, $17, $42, $BD,
    $E8, $80, $D5, $2A, $7F, $E3, $B6, $49, $1C, $74, $21, $DE, $8B, $0E, $5B,
    $A4, $F1, $99, $CC, $33, $66, $AC, $F9, $06, $53, $3B, $6E, $91, $C4, $41,
    $14, $EB, $BE, $D6, $83, $7C, $29, $B5, $E0, $1F, $4A, $22, $77, $88, $DD,
    $58, $0D, $F2, $A7, $CF, $9A, $65, $30, $9E, $CB, $34, $61, $09, $5C, $A3,
    $F6, $73, $26, $D9, $8C, $E4, $B1, $4E, $1B, $87, $D2, $2D, $78, $10, $45,
    $BA, $EF, $6A, $3F, $C0, $95, $FD, $A8, $57, $02, $00, $56, $AC, $FA, $9B,
    $CD, $37, $61, $F5, $A3, $59, $0F, $6E, $38, $C2, $94, $29, $7F, $85, $D3,
    $B2, $E4, $1E, $48, $DC, $8A, $70, $26, $47, $11, $EB, $BD, $52, $04, $FE,
    $A8, $C9, $9F, $65, $33, $A7, $F1, $0B, $5D, $3C, $6A, $90, $C6, $7B, $2D,
    $D7, $81, $E0, $B6, $4C, $1A, $8E, $D8, $22, $74, $15, $43, $B9, $EF, $A4,
    $F2, $08, $5E, $3F, $69, $93, $C5, $51, $07, $FD, $AB, $CA, $9C, $66, $30,
    $8D, $DB, $21, $77, $16, $40, $BA, $EC, $78, $2E, $D4, $82, $E3, $B5, $4F,
    $19, $F6, $A0, $5A, $0C, $6D, $3B, $C1, $97, $03, $55, $AF, $F9, $98, $CE,
    $34, $62, $DF, $89, $73, $25, $44, $12, $E8, $BE, $2A, $7C, $86, $D0, $B1,
    $E7, $1D, $4B, $8B, $DD, $27, $71, $10, $46, $BC, $EA, $7E, $28, $D2, $84,
    $E5, $B3, $49, $1F, $A2, $F4, $0E, $58, $39, $6F, $95, $C3, $57, $01, $FB,
    $AD, $CC, $9A, $60, $36, $D9, $8F, $75, $23, $42, $14, $EE, $B8, $2C, $7A,
    $80, $D6, $B7, $E1, $1B, $4D, $F0, $A6, $5C, $0A, $6B, $3D, $C7, $91, $05,
    $53, $A9, $FF, $9E, $C8, $32, $64, $2F, $79, $83, $D5, $B4, $E2, $18, $4E,
    $DA, $8C, $76, $20, $41, $17, $ED, $BB, $06, $50, $AA, $FC, $9D, $CB, $31,
    $67, $F3, $A5, $5F, $09, $68, $3E, $C4, $92, $7D, $2B, $D1, $87, $E6, $B0,
    $4A, $1C, $88, $DE, $24, $72, $13, $45, $BF, $E9, $54, $02, $F8, $AE, $CF,
    $99, $63, $35, $A1, $F7, $0D, $5B, $3A, $6C, $96, $C0, $00, $57, $AE, $F9,
    $9F, $C8, $31, $66, $FD, $AA, $53, $04, $62, $35, $CC, $9B, $39, $6E, $97,
    $C0, $A6, $F1, $08, $5F, $C4, $93, $6A, $3D, $5B, $0C, $F5, $A2, $72, $25,
    $DC, $8B, $ED, $BA, $43, $14, $8F, $D8, $21, $76, $10, $47, $BE, $E9, $4B,
    $1C, $E5, $B2, $D4, $83, $7A, $2D, $B6, $E1, $18, $4F, $29, $7E, $87, $D0,
    $E4, $B3, $4A, $1D, $7B, $2C, $D5, $82, $19, $4E, $B7, $E0, $86, $D1, $28,
    $7F, $DD, $8A, $73, $24, $42, $15, $EC, $BB, $20, $77, $8E, $D9, $BF, $E8,
    $11, $46, $96, $C1, $38, $6F, $09, $5E, $A7, $F0, $6B, $3C, $C5, $92, $F4,
    $A3, $5A, $0D, $AF, $F8, $01, $56, $30, $67, $9E, $C9, $52, $05, $FC, $AB,
    $CD, $9A, $63, $34, $0B, $5C, $A5, $F2, $94, $C3, $3A, $6D, $F6, $A1, $58,
    $0F, $69, $3E, $C7, $90, $32, $65, $9C, $CB, $AD, $FA, $03, $54, $CF, $98,
    $61, $36, $50, $07, $FE, $A9, $79, $2E, $D7, $80, $E6, $B1, $48, $1F, $84,
    $D3, $2A, $7D, $1B, $4C, $B5, $E2, $40, $17, $EE, $B9, $DF, $88, $71, $26,
    $BD, $EA, $13, $44, $22, $75, $8C, $DB, $EF, $B8, $41, $16, $70, $27, $DE,
    $89, $12, $45, $BC, $EB, $8D, $DA, $23, $74, $D6, $81, $78, $2F, $49, $1E,
    $E7, $B0, $2B, $7C, $85, $D2, $B4, $E3, $1A, $4D, $9D, $CA, $33, $64, $02,
    $55, $AC, $FB, $60, $37, $CE, $99, $FF, $A8, $51, $06, $A4, $F3, $0A, $5D,
    $3B, $6C, $95, $C2, $59, $0E, $F7, $A0, $C6, $91, $68, $3F, $00, $58, $B0,
    $E8, $A3, $FB, $13, $4B, $85, $DD, $35, $6D, $26, $7E, $96, $CE, $C9, $91,
    $79, $21, $6A, $32, $DA, $82, $4C, $14, $FC, $A4, $EF, $B7, $5F, $07, $51,
    $09, $E1, $B9, $F2, $AA, $42, $1A, $D4, $8C, $64, $3C, $77, $2F, $C7, $9F,
    $98, $C0, $28, $70, $3B, $63, $8B, $D3, $1D, $45, $AD, $F5, $BE, $E6, $0E,
    $56, $A2, $FA, $12, $4A, $01, $59, $B1, $E9, $27, $7F, $97, $CF, $84, $DC,
    $34, $6C, $6B, $33, $DB, $83, $C8, $90, $78, $20, $EE, $B6, $5E, $06, $4D,
    $15, $FD, $A5, $F3, $AB, $43, $1B, $50, $08, $E0, $B8, $76, $2E, $C6, $9E,
    $D5, $8D, $65, $3D, $3A, $62, $8A, $D2, $99, $C1, $29, $71, $BF, $E7, $0F,
    $57, $1C, $44, $AC, $F4, $87, $DF, $37, $6F, $24, $7C, $94, $CC, $02, $5A,
    $B2, $EA, $A1, $F9, $11, $49, $4E, $16, $FE, $A6, $ED, $B5, $5D, $05, $CB,
    $93, $7B, $23, $68, $30, $D8, $80, $D6, $8E, $66, $3E, $75, $2D, $C5, $9D,
    $53, $0B, $E3, $BB, $F0, $A8, $40, $18, $1F, $47, $AF, $F7, $BC, $E4, $0C,
    $54, $9A, $C2, $2A, $72, $39, $61, $89, $D1, $25, $7D, $95, $CD, $86, $DE,
    $36, $6E, $A0, $F8, $10, $48, $03, $5B, $B3, $EB, $EC, $B4, $5C, $04, $4F,
    $17, $FF, $A7, $69, $31, $D9, $81, $CA, $92, $7A, $22, $74, $2C, $C4, $9C,
    $D7, $8F, $67, $3F, $F1, $A9, $41, $19, $52, $0A, $E2, $BA, $BD, $E5, $0D,
    $55, $1E, $46, $AE, $F6, $38, $60, $88, $D0, $9B, $C3, $2B, $73, $00, $59,
    $B2, $EB, $A7, $FE, $15, $4C, $8D, $D4, $3F, $66, $2A, $73, $98, $C1, $D9,
    $80, $6B, $32, $7E, $27, $CC, $95, $54, $0D, $E6, $BF, $F3, $AA, $41, $18,
    $71, $28, $C3, $9A, $D6, $8F, $64, $3D, $FC, $A5, $4E, $17, $5B, $02, $E9,
    $B0, $A8, $F1, $1A, $43, $0F, $56, $BD, $E4, $25, $7C, $97, $CE, $82, $DB,
    $30, $69, $E2, $BB, $50, $09, $45, $1C, $F7, $AE, $6F, $36, $DD, $84, $C8,
    $91, $7A, $23, $3B, $62, $89, $D0, $9C, $C5, $2E, $77, $B6, $EF, $04, $5D,
    $11, $48, $A3, $FA, $93, $CA, $21, $78, $34, $6D, $86, $DF, $1E, $47, $AC,
    $F5, $B9, $E0, $0B, $52, $4A, $13, $F8, $A1, $ED, $B4, $5F, $06, $C7, $9E,
    $75, $2C, $60, $39, $D2, $8B, $07, $5E, $B5, $EC, $A0, $F9, $12, $4B, $8A,
    $D3, $38, $61, $2D, $74, $9F, $C6, $DE, $87, $6C, $35, $79, $20, $CB, $92,
    $53, $0A, $E1, $B8, $F4, $AD, $46, $1F, $76, $2F, $C4, $9D, $D1, $88, $63,
    $3A, $FB, $A2, $49, $10, $5C, $05, $EE, $B7, $AF, $F6, $1D, $44, $08, $51,
    $BA, $E3, $22, $7B, $90, $C9, $85, $DC, $37, $6E, $E5, $BC, $57, $0E, $42,
    $1B, $F0, $A9, $68, $31, $DA, $83, $CF, $96, $7D, $24, $3C, $65, $8E, $D7,
    $9B, $C2, $29, $70, $B1, $E8, $03, $5A, $16, $4F, $A4, $FD, $94, $CD, $26,
    $7F, $33, $6A, $81, $D8, $19, $40, $AB, $F2, $BE, $E7, $0C, $55, $4D, $14,
    $FF, $A6, $EA, $B3, $58, $01, $C0, $99, $72, $2B, $67, $3E, $D5, $8C, $00,
    $5A, $B4, $EE, $AB, $F1, $1F, $45, $95, $CF, $21, $7B, $3E, $64, $8A, $D0,
    $E9, $B3, $5D, $07, $42, $18, $F6, $AC, $7C, $26, $C8, $92, $D7, $8D, $63,
    $39, $11, $4B, $A5, $FF, $BA, $E0, $0E, $54, $84, $DE, $30, $6A, $2F, $75,
    $9B, $C1, $F8, $A2, $4C, $16, $53, $09, $E7, $BD, $6D, $37, $D9, $83, $C6,
    $9C, $72, $28, $22, $78, $96, $CC, $89, $D3, $3D, $67, $B7, $ED, $03, $59,
    $1C, $46, $A8, $F2, $CB, $91, $7F, $25, $60, $3A, $D4, $8E, $5E, $04, $EA,
    $B0, $F5, $AF, $41, $1B, $33, $69, $87, $DD, $98, $C2, $2C, $76, $A6, $FC,
    $12, $48, $0D, $57, $B9, $E3, $DA, $80, $6E, $34, $71, $2B, $C5, $9F, $4F,
    $15, $FB, $A1, $E4, $BE, $50, $0A, $44, $1E, $F0, $AA, $EF, $B5, $5B, $01,
    $D1, $8B, $65, $3F, $7A, $20, $CE, $94, $AD, $F7, $19, $43, $06, $5C, $B2,
    $E8, $38, $62, $8C, $D6, $93, $C9, $27, $7D, $55, $0F, $E1, $BB, $FE, $A4,
    $4A, $10, $C0, $9A, $74, $2E, $6B, $31, $DF, $85, $BC, $E6, $08, $52, $17,
    $4D, $A3, $F9, $29, $73, $9D, $C7, $82, $D8, $36, $6C, $66, $3C, $D2, $88,
    $CD, $97, $79, $23, $F3, $A9, $47, $1D, $58, $02, $EC, $B6, $8F, $D5, $3B,
    $61, $24, $7E, $90, $CA, $1A, $40, $AE, $F4, $B1, $EB, $05, $5F, $77, $2D,
    $C3, $99, $DC, $86, $68, $32, $E2, $B8, $56, $0C, $49, $13, $FD, $A7, $9E,
    $C4, $2A, $70, $35, $6F, $81, $DB, $0B, $51, $BF, $E5, $A0, $FA, $14, $4E,
    $00, $5B, $B6, $ED, $AF, $F4, $19, $42, $9D, $C6, $2B, $70, $32, $69, $84,
    $DF, $F9, $A2, $4F, $14, $56, $0D, $E0, $BB, $64, $3F, $D2, $89, $CB, $90,
    $7D, $26, $31, $6A, $87, $DC, $9E, $C5, $28, $73, $AC, $F7, $1A, $41, $03,
    $58, $B5, $EE, $C8, $93, $7E, $25, $67, $3C, $D1, $8A, $55, $0E, $E3, $B8,
    $FA, $A1, $4C, $17, $62, $39, $D4, $8F, $CD, $96, $7B, $20, $FF, $A4, $49,
    $12, $50, $0B, $E6, $BD, $9B, $C0, $2D, $76, $34, $6F, $82, $D9, $06, $5D,
    $B0, $EB, $A9, $F2, $1F, $44, $53, $08, $E5, $BE, $FC, $A7, $4A, $11, $CE,
    $95, $78, $23, $61, $3A, $D7, $8C, $AA, $F1, $1C, $47, $05, $5E, $B3, $E8,
    $37, $6C, $81, $DA, $98, $C3, $2E, $75, $C4, $9F, $72, $29, $6B, $30, $DD,
    $86, $59, $02, $EF, $B4, $F6, $AD, $40, $1B, $3D, $66, $8B, $D0, $92, $C9,
    $24, $7F, $A0, $FB, $16, $4D, $0F, $54, $B9, $E2, $F5, $AE, $43, $18, $5A,
    $01, $EC, $B7, $68, $33, $DE, $85, $C7, $9C, $71, $2A, $0C, $57, $BA, $E1,
    $A3, $F8, $15, $4E, $91, $CA, $27, $7C, $3E, $65, $88, $D3, $A6, $FD, $10,
    $4B, $09, $52, $BF, $E4, $3B, $60, $8D, $D6, $94, $CF, $22, $79, $5F, $04,
    $E9, $B2, $F0, $AB, $46, $1D, $C2, $99, $74, $2F, $6D, $36, $DB, $80, $97,
    $CC, $21, $7A, $38, $63, $8E, $D5, $0A, $51, $BC, $E7, $A5, $FE, $13, $48,
    $6E, $35, $D8, $83, $C1, $9A, $77, $2C, $F3, $A8, $45, $1E, $5C, $07, $EA,
    $B1, $00, $5C, $B8, $E4, $B3, $EF, $0B, $57, $A5, $F9, $1D, $41, $16, $4A,
    $AE, $F2, $89, $D5, $31, $6D, $3A, $66, $82, $DE, $2C, $70, $94, $C8, $9F,
    $C3, $27, $7B, $D1, $8D, $69, $35, $62, $3E, $DA, $86, $74, $28, $CC, $90,
    $C7, $9B, $7F, $23, $58, $04, $E0, $BC, $EB, $B7, $53, $0F, $FD, $A1, $45,
    $19, $4E, $12, $F6, $AA, $61, $3D, $D9, $85, $D2, $8E, $6A, $36, $C4, $98,
    $7C, $20, $77, $2B, $CF, $93, $E8, $B4, $50, $0C, $5B, $07, $E3, $BF, $4D,
    $11, $F5, $A9, $FE, $A2, $46, $1A, $B0, $EC, $08, $54, $03, $5F, $BB, $E7,
    $15, $49, $AD, $F1, $A6, $FA, $1E, $42, $39, $65, $81, $DD, $8A, $D6, $32,
    $6E, $9C, $C0, $24, $78, $2F, $73, $97, $CB, $C2, $9E, $7A, $26, $71, $2D,
    $C9, $95, $67, $3B, $DF, $83, $D4, $88, $6C, $30, $4B, $17, $F3, $AF, $F8,
    $A4, $40, $1C, $EE, $B2, $56, $0A, $5D, $01, $E5, $B9, $13, $4F, $AB, $F7,
    $A0, $FC, $18, $44, $B6, $EA, $0E, $52, $05, $59, $BD, $E1, $9A, $C6, $22,
    $7E, $29, $75, $91, $CD, $3F, $63, $87, $DB, $8C, $D0, $34, $68, $A3, $FF,
    $1B, $47, $10, $4C, $A8, $F4, $06, $5A, $BE, $E2, $B5, $E9, $0D, $51, $2A,
    $76, $92, $CE, $99, $C5, $21, $7D, $8F, $D3, $37, $6B, $3C, $60, $84, $D8,
    $72, $2E, $CA, $96, $C1, $9D, $79, $25, $D7, $8B, $6F, $33, $64, $38, $DC,
    $80, $FB, $A7, $43, $1F, $48, $14, $F0, $AC, $5E, $02, $E6, $BA, $ED, $B1,
    $55, $09, $00, $5D, $BA, $E7, $B7, $EA, $0D, $50, $AD, $F0, $17, $4A, $1A,
    $47, $A0, $FD, $99, $C4, $23, $7E, $2E, $73, $94, $C9, $34, $69, $8E, $D3,
    $83, $DE, $39, $64, $F1, $AC, $4B, $16, $46, $1B, $FC, $A1, $5C, $01, $E6,
    $BB, $EB, $B6, $51, $0C, $68, $35, $D2, $8F, $DF, $82, $65, $38, $C5, $98,
    $7F, $22, $72, $2F, $C8, $95, $21, $7C, $9B, $C6, $96, $CB, $2C, $71, $8C,
    $D1, $36, $6B, $3B, $66, $81, $DC, $B8, $E5, $02, $5F, $0F, $52, $B5, $E8,
    $15, $48, $AF, $F2, $A2, $FF, $18, $45, $D0, $8D, $6A, $37, $67, $3A, $DD,
    $80, $7D, $20, $C7, $9A, $CA, $97, $70, $2D, $49, $14, $F3, $AE, $FE, $A3,
    $44, $19, $E4, $B9, $5E, $03, $53, $0E, $E9, $B4, $42, $1F, $F8, $A5, $F5,
    $A8, $4F, $12, $EF, $B2, $55, $08, $58, $05, $E2, $BF, $DB, $86, $61, $3C,
    $6C, $31, $D6, $8B, $76, $2B, $CC, $91, $C1, $9C, $7B, $26, $B3, $EE, $09,
    $54, $04, $59, $BE, $E3, $1E, $43, $A4, $F9, $A9, $F4, $13, $4E, $2A, $77,
    $90, $CD, $9D, $C0, $27, $7A, $87, $DA, $3D, $60, $30, $6D, $8A, $D7, $63,
    $3E, $D9, $84, $D4, $89, $6E, $33, $CE, $93, $74, $29, $79, $24, $C3, $9E,
    $FA, $A7, $40, $1D, $4D, $10, $F7, $AA, $57, $0A, $ED, $B0, $E0, $BD, $5A,
    $07, $92, $CF, $28, $75, $25, $78, $9F, $C2, $3F, $62, $85, $D8, $88, $D5,
    $32, $6F, $0B, $56, $B1, $EC, $BC, $E1, $06, $5B, $A6, $FB, $1C, $41, $11,
    $4C, $AB, $F6, $00, $5E, $BC, $E2, $BB, $E5, $07, $59, $B5, $EB, $09, $57,
    $0E, $50, $B2, $EC, $A9, $F7, $15, $4B, $12, $4C, $AE, $F0, $1C, $42, $A0,
    $FE, $A7, $F9, $1B, $45, $91, $CF, $2D, $73, $2A, $74, $96, $C8, $24, $7A,
    $98, $C6, $9F, $C1, $23, $7D, $38, $66, $84, $DA, $83, $DD, $3F, $61, $8D,
    $D3, $31, $6F, $36, $68, $8A, $D4, $E1, $BF, $5D, $03, $5A, $04, $E6, $B8,
    $54, $0A, $E8, $B6, $EF, $B1, $53, $0D, $48, $16, $F4, $AA, $F3, $AD, $4F,
    $11, $FD, $A3, $41, $1F, $46, $18, $FA, $A4, $70, $2E, $CC, $92, $CB, $95,
    $77, $29, $C5, $9B, $79, $27, $7E, $20, $C2, $9C, $D9, $87, $65, $3B, $62,
    $3C, $DE, $80, $6C, $32, $D0, $8E, $D7, $89, $6B, $35, $01, $5F, $BD, $E3,
    $BA, $E4, $06, $58, $B4, $EA, $08, $56, $0F, $51, $B3, $ED, $A8, $F6, $14,
    $4A, $13, $4D, $AF, $F1, $1D, $43, $A1, $FF, $A6, $F8, $1A, $44, $90, $CE,
    $2C, $72, $2B, $75, $97, $C9, $25, $7B, $99, $C7, $9E, $C0, $22, $7C, $39,
    $67, $85, $DB, $82, $DC, $3E, $60, $8C, $D2, $30, $6E, $37, $69, $8B, $D5,
    $E0, $BE, $5C, $02, $5B, $05, $E7, $B9, $55, $0B, $E9, $B7, $EE, $B0, $52,
    $0C, $49, $17, $F5, $AB, $F2, $AC, $4E, $10, $FC, $A2, $40, $1E, $47, $19,
    $FB, $A5, $71, $2F, $CD, $93, $CA, $94, $76, $28, $C4, $9A, $78, $26, $7F,
    $21, $C3, $9D, $D8, $86, $64, $3A, $63, $3D, $DF, $81, $6D, $33, $D1, $8F,
    $D6, $88, $6A, $34, $00, $5F, $BE, $E1, $BF, $E0, $01, $5E, $BD, $E2, $03,
    $5C, $02, $5D, $BC, $E3, $B9, $E6, $07, $58, $06, $59, $B8, $E7, $04, $5B,
    $BA, $E5, $BB, $E4, $05, $5A, $B1, $EE, $0F, $50, $0E, $51, $B0, $EF, $0C,
    $53, $B2, $ED, $B3, $EC, $0D, $52, $08, $57, $B6, $E9, $B7, $E8, $09, $56,
    $B5, $EA, $0B, $54, $0A, $55, $B4, $EB, $A1, $FE, $1F, $40, $1E, $41, $A0,
    $FF, $1C, $43, $A2, $FD, $A3, $FC, $1D, $42, $18, $47, $A6, $F9, $A7, $F8,
    $19, $46, $A5, $FA, $1B, $44, $1A, $45, $A4, $FB, $10, $4F, $AE, $F1, $AF,
    $F0, $11, $4E, $AD, $F2, $13, $4C, $12, $4D, $AC, $F3, $A9, $F6, $17, $48,
    $16, $49, $A8, $F7, $14, $4B, $AA, $F5, $AB, $F4, $15, $4A, $81, $DE, $3F,
    $60, $3E, $61, $80, $DF, $3C, $63, $82, $DD, $83, $DC, $3D, $62, $38, $67,
    $86, $D9, $87, $D8, $39, $66, $85, $DA, $3B, $64, $3A, $65, $84, $DB, $30,
    $6F, $8E, $D1, $8F, $D0, $31, $6E, $8D, $D2, $33, $6C, $32, $6D, $8C, $D3,
    $89, $D6, $37, $68, $36, $69, $88, $D7, $34, $6B, $8A, $D5, $8B, $D4, $35,
    $6A, $20, $7F, $9E, $C1, $9F, $C0, $21, $7E, $9D, $C2, $23, $7C, $22, $7D,
    $9C, $C3, $99, $C6, $27, $78, $26, $79, $98, $C7, $24, $7B, $9A, $C5, $9B,
    $C4, $25, $7A, $91, $CE, $2F, $70, $2E, $71, $90, $CF, $2C, $73, $92, $CD,
    $93, $CC, $2D, $72, $28, $77, $96, $C9, $97, $C8, $29, $76, $95, $CA, $2B,
    $74, $2A, $75, $94, $CB, $00, $60, $C0, $A0, $43, $23, $83, $E3, $86, $E6,
    $46, $26, $C5, $A5, $05, $65, $CF, $AF, $0F, $6F, $8C, $EC, $4C, $2C, $49,
    $29, $89, $E9, $0A, $6A, $CA, $AA, $5D, $3D, $9D, $FD, $1E, $7E, $DE, $BE,
    $DB, $BB, $1B, $7B, $98, $F8, $58, $38, $92, $F2, $52, $32, $D1, $B1, $11,
    $71, $14, $74, $D4, $B4, $57, $37, $97, $F7, $BA, $DA, $7A, $1A, $F9, $99,
    $39, $59, $3C, $5C, $FC, $9C, $7F, $1F, $BF, $DF, $75, $15, $B5, $D5, $36,
    $56, $F6, $96, $F3, $93, $33, $53, $B0, $D0, $70, $10, $E7, $87, $27, $47,
    $A4, $C4, $64, $04, $61, $01, $A1, $C1, $22, $42, $E2, $82, $28, $48, $E8,
    $88, $6B, $0B, $AB, $CB, $AE, $CE, $6E, $0E, $ED, $8D, $2D, $4D, $B7, $D7,
    $77, $17, $F4, $94, $34, $54, $31, $51, $F1, $91, $72, $12, $B2, $D2, $78,
    $18, $B8, $D8, $3B, $5B, $FB, $9B, $FE, $9E, $3E, $5E, $BD, $DD, $7D, $1D,
    $EA, $8A, $2A, $4A, $A9, $C9, $69, $09, $6C, $0C, $AC, $CC, $2F, $4F, $EF,
    $8F, $25, $45, $E5, $85, $66, $06, $A6, $C6, $A3, $C3, $63, $03, $E0, $80,
    $20, $40, $0D, $6D, $CD, $AD, $4E, $2E, $8E, $EE, $8B, $EB, $4B, $2B, $C8,
    $A8, $08, $68, $C2, $A2, $02, $62, $81, $E1, $41, $21, $44, $24, $84, $E4,
    $07, $67, $C7, $A7, $50, $30, $90, $F0, $13, $73, $D3, $B3, $D6, $B6, $16,
    $76, $95, $F5, $55, $35, $9F, $FF, $5F, $3F, $DC, $BC, $1C, $7C, $19, $79,
    $D9, $B9, $5A, $3A, $9A, $FA, $00, $61, $C2, $A3, $47, $26, $85, $E4, $8E,
    $EF, $4C, $2D, $C9, $A8, $0B, $6A, $DF, $BE, $1D, $7C, $98, $F9, $5A, $3B,
    $51, $30, $93, $F2, $16, $77, $D4, $B5, $7D, $1C, $BF, $DE, $3A, $5B, $F8,
    $99, $F3, $92, $31, $50, $B4, $D5, $76, $17, $A2, $C3, $60, $01, $E5, $84,
    $27, $46, $2C, $4D, $EE, $8F, $6B, $0A, $A9, $C8, $FA, $9B, $38, $59, $BD,
    $DC, $7F, $1E, $74, $15, $B6, $D7, $33, $52, $F1, $90, $25, $44, $E7, $86,
    $62, $03, $A0, $C1, $AB, $CA, $69, $08, $EC, $8D, $2E, $4F, $87, $E6, $45,
    $24, $C0, $A1, $02, $63, $09, $68, $CB, $AA, $4E, $2F, $8C, $ED, $58, $39,
    $9A, $FB, $1F, $7E, $DD, $BC, $D6, $B7, $14, $75, $91, $F0, $53, $32, $37,
    $56, $F5, $94, $70, $11, $B2, $D3, $B9, $D8, $7B, $1A, $FE, $9F, $3C, $5D,
    $E8, $89, $2A, $4B, $AF, $CE, $6D, $0C, $66, $07, $A4, $C5, $21, $40, $E3,
    $82, $4A, $2B, $88, $E9, $0D, $6C, $CF, $AE, $C4, $A5, $06, $67, $83, $E2,
    $41, $20, $95, $F4, $57, $36, $D2, $B3, $10, $71, $1B, $7A, $D9, $B8, $5C,
    $3D, $9E, $FF, $CD, $AC, $0F, $6E, $8A, $EB, $48, $29, $43, $22, $81, $E0,
    $04, $65, $C6, $A7, $12, $73, $D0, $B1, $55, $34, $97, $F6, $9C, $FD, $5E,
    $3F, $DB, $BA, $19, $78, $B0, $D1, $72, $13, $F7, $96, $35, $54, $3E, $5F,
    $FC, $9D, $79, $18, $BB, $DA, $6F, $0E, $AD, $CC, $28, $49, $EA, $8B, $E1,
    $80, $23, $42, $A6, $C7, $64, $05, $00, $62, $C4, $A6, $4B, $29, $8F, $ED,
    $96, $F4, $52, $30, $DD, $BF, $19, $7B, $EF, $8D, $2B, $49, $A4, $C6, $60,
    $02, $79, $1B, $BD, $DF, $32, $50, $F6, $94, $1D, $7F, $D9, $BB, $56, $34,
    $92, $F0, $8B, $E9, $4F, $2D, $C0, $A2, $04, $66, $F2, $90, $36, $54, $B9,
    $DB, $7D, $1F, $64, $06, $A0, $C2, $2F, $4D, $EB, $89, $3A, $58, $FE, $9C,
    $71, $13, $B5, $D7, $AC, $CE, $68, $0A, $E7, $85, $23, $41, $D5, $B7, $11,
    $73, $9E, $FC, $5A, $38, $43, $21, $87, $E5, $08, $6A, $CC, $AE, $27, $45,
    $E3, $81, $6C, $0E, $A8, $CA, $B1, $D3, $75, $17, $FA, $98, $3E, $5C, $C8,
    $AA, $0C, $6E, $83, $E1, $47, $25, $5E, $3C, $9A, $F8, $15, $77, $D1, $B3,
    $74, $16, $B0, $D2, $3F, $5D, $FB, $99, $E2, $80, $26, $44, $A9, $CB, $6D,
    $0F, $9B, $F9, $5F, $3D, $D0, $B2, $14, $76, $0D, $6F, $C9, $AB, $46, $24,
    $82, $E0, $69, $0B, $AD, $CF, $22, $40, $E6, $84, $FF, $9D, $3B, $59, $B4,
    $D6, $70, $12, $86, $E4, $42, $20, $CD, $AF, $09, $6B, $10, $72, $D4, $B6,
    $5B, $39, $9F, $FD, $4E, $2C, $8A, $E8, $05, $67, $C1, $A3, $D8, $BA, $1C,
    $7E, $93, $F1, $57, $35, $A1, $C3, $65, $07, $EA, $88, $2E, $4C, $37, $55,
    $F3, $91, $7C, $1E, $B8, $DA, $53, $31, $97, $F5, $18, $7A, $DC, $BE, $C5,
    $A7, $01, $63, $8E, $EC, $4A, $28, $BC, $DE, $78, $1A, $F7, $95, $33, $51,
    $2A, $48, $EE, $8C, $61, $03, $A5, $C7, $00, $63, $C6, $A5, $4F, $2C, $89,
    $EA, $9E, $FD, $58, $3B, $D1, $B2, $17, $74, $FF, $9C, $39, $5A, $B0, $D3,
    $76, $15, $61, $02, $A7, $C4, $2E, $4D, $E8, $8B, $3D, $5E, $FB, $98, $72,
    $11, $B4, $D7, $A3, $C0, $65, $06, $EC, $8F, $2A, $49, $C2, $A1, $04, $67,
    $8D, $EE, $4B, $28, $5C, $3F, $9A, $F9, $13, $70, $D5, $B6, $7A, $19, $BC,
    $DF, $35, $56, $F3, $90, $E4, $87, $22, $41, $AB, $C8, $6D, $0E, $85, $E6,
    $43, $20, $CA, $A9, $0C, $6F, $1B, $78, $DD, $BE, $54, $37, $92, $F1, $47,
    $24, $81, $E2, $08, $6B, $CE, $AD, $D9, $BA, $1F, $7C, $96, $F5, $50, $33,
    $B8, $DB, $7E, $1D, $F7, $94, $31, $52, $26, $45, $E0, $83, $69, $0A, $AF,
    $CC, $F4, $97, $32, $51, $BB, $D8, $7D, $1E, $6A, $09, $AC, $CF, $25, $46,
    $E3, $80, $0B, $68, $CD, $AE, $44, $27, $82, $E1, $95, $F6, $53, $30, $DA,
    $B9, $1C, $7F, $C9, $AA, $0F, $6C, $86, $E5, $40, $23, $57, $34, $91, $F2,
    $18, $7B, $DE, $BD, $36, $55, $F0, $93, $79, $1A, $BF, $DC, $A8, $CB, $6E,
    $0D, $E7, $84, $21, $42, $8E, $ED, $48, $2B, $C1, $A2, $07, $64, $10, $73,
    $D6, $B5, $5F, $3C, $99, $FA, $71, $12, $B7, $D4, $3E, $5D, $F8, $9B, $EF,
    $8C, $29, $4A, $A0, $C3, $66, $05, $B3, $D0, $75, $16, $FC, $9F, $3A, $59,
    $2D, $4E, $EB, $88, $62, $01, $A4, $C7, $4C, $2F, $8A, $E9, $03, $60, $C5,
    $A6, $D2, $B1, $14, $77, $9D, $FE, $5B, $38, $00, $64, $C8, $AC, $53, $37,
    $9B, $FF, $A6, $C2, $6E, $0A, $F5, $91, $3D, $59, $8F, $EB, $47, $23, $DC,
    $B8, $14, $70, $29, $4D, $E1, $85, $7A, $1E, $B2, $D6, $DD, $B9, $15, $71,
    $8E, $EA, $46, $22, $7B, $1F, $B3, $D7, $28, $4C, $E0, $84, $52, $36, $9A,
    $FE, $01, $65, $C9, $AD, $F4, $90, $3C, $58, $A7, $C3, $6F, $0B, $79, $1D,
    $B1, $D5, $2A, $4E, $E2, $86, $DF, $BB, $17, $73, $8C, $E8, $44, $20, $F6,
    $92, $3E, $5A, $A5, $C1, $6D, $09, $50, $34, $98, $FC, $03, $67, $CB, $AF,
    $A4, $C0, $6C, $08, $F7, $93, $3F, $5B, $02, $66, $CA, $AE, $51, $35, $99,
    $FD, $2B, $4F, $E3, $87, $78, $1C, $B0, $D4, $8D, $E9, $45, $21, $DE, $BA,
    $16, $72, $F2, $96, $3A, $5E, $A1, $C5, $69, $0D, $54, $30, $9C, $F8, $07,
    $63, $CF, $AB, $7D, $19, $B5, $D1, $2E, $4A, $E6, $82, $DB, $BF, $13, $77,
    $88, $EC, $40, $24, $2F, $4B, $E7, $83, $7C, $18, $B4, $D0, $89, $ED, $41,
    $25, $DA, $BE, $12, $76, $A0, $C4, $68, $0C, $F3, $97, $3B, $5F, $06, $62,
    $CE, $AA, $55, $31, $9D, $F9, $8B, $EF, $43, $27, $D8, $BC, $10, $74, $2D,
    $49, $E5, $81, $7E, $1A, $B6, $D2, $04, $60, $CC, $A8, $57, $33, $9F, $FB,
    $A2, $C6, $6A, $0E, $F1, $95, $39, $5D, $56, $32, $9E, $FA, $05, $61, $CD,
    $A9, $F0, $94, $38, $5C, $A3, $C7, $6B, $0F, $D9, $BD, $11, $75, $8A, $EE,
    $42, $26, $7F, $1B, $B7, $D3, $2C, $48, $E4, $80, $00, $65, $CA, $AF, $57,
    $32, $9D, $F8, $AE, $CB, $64, $01, $F9, $9C, $33, $56, $9F, $FA, $55, $30,
    $C8, $AD, $02, $67, $31, $54, $FB, $9E, $66, $03, $AC, $C9, $FD, $98, $37,
    $52, $AA, $CF, $60, $05, $53, $36, $99, $FC, $04, $61, $CE, $AB, $62, $07,
    $A8, $CD, $35, $50, $FF, $9A, $CC, $A9, $06, $63, $9B, $FE, $51, $34, $39,
    $5C, $F3, $96, $6E, $0B, $A4, $C1, $97, $F2, $5D, $38, $C0, $A5, $0A, $6F,
    $A6, $C3, $6C, $09, $F1, $94, $3B, $5E, $08, $6D, $C2, $A7, $5F, $3A, $95,
    $F0, $C4, $A1, $0E, $6B, $93, $F6, $59, $3C, $6A, $0F, $A0, $C5, $3D, $58,
    $F7, $92, $5B, $3E, $91, $F4, $0C, $69, $C6, $A3, $F5, $90, $3F, $5A, $A2,
    $C7, $68, $0D, $72, $17, $B8, $DD, $25, $40, $EF, $8A, $DC, $B9, $16, $73,
    $8B, $EE, $41, $24, $ED, $88, $27, $42, $BA, $DF, $70, $15, $43, $26, $89,
    $EC, $14, $71, $DE, $BB, $8F, $EA, $45, $20, $D8, $BD, $12, $77, $21, $44,
    $EB, $8E, $76, $13, $BC, $D9, $10, $75, $DA, $BF, $47, $22, $8D, $E8, $BE,
    $DB, $74, $11, $E9, $8C, $23, $46, $4B, $2E, $81, $E4, $1C, $79, $D6, $B3,
    $E5, $80, $2F, $4A, $B2, $D7, $78, $1D, $D4, $B1, $1E, $7B, $83, $E6, $49,
    $2C, $7A, $1F, $B0, $D5, $2D, $48, $E7, $82, $B6, $D3, $7C, $19, $E1, $84,
    $2B, $4E, $18, $7D, $D2, $B7, $4F, $2A, $85, $E0, $29, $4C, $E3, $86, $7E,
    $1B, $B4, $D1, $87, $E2, $4D, $28, $D0, $B5, $1A, $7F, $00, $66, $CC, $AA,
    $5B, $3D, $97, $F1, $B6, $D0, $7A, $1C, $ED, $8B, $21, $47, $AF, $C9, $63,
    $05, $F4, $92, $38, $5E, $19, $7F, $D5, $B3, $42, $24, $8E, $E8, $9D, $FB,
    $51, $37, $C6, $A0, $0A, $6C, $2B, $4D, $E7, $81, $70, $16, $BC, $DA, $32,
    $54, $FE, $98, $69, $0F, $A5, $C3, $84, $E2, $48, $2E, $DF, $B9, $13, $75,
    $F9, $9F, $35, $53, $A2, $C4, $6E, $08, $4F, $29, $83, $E5, $14, $72, $D8,
    $BE, $56, $30, $9A, $FC, $0D, $6B, $C1, $A7, $E0, $86, $2C, $4A, $BB, $DD,
    $77, $11, $64, $02, $A8, $CE, $3F, $59, $F3, $95, $D2, $B4, $1E, $78, $89,
    $EF, $45, $23, $CB, $AD, $07, $61, $90, $F6, $5C, $3A, $7D, $1B, $B1, $D7,
    $26, $40, $EA, $8C, $31, $57, $FD, $9B, $6A, $0C, $A6, $C0, $87, $E1, $4B,
    $2D, $DC, $BA, $10, $76, $9E, $F8, $52, $34, $C5, $A3, $09, $6F, $28, $4E,
    $E4, $82, $73, $15, $BF, $D9, $AC, $CA, $60, $06, $F7, $91, $3B, $5D, $1A,
    $7C, $D6, $B0, $41, $27, $8D, $EB, $03, $65, $CF, $A9, $58, $3E, $94, $F2,
    $B5, $D3, $79, $1F, $EE, $88, $22, $44, $C8, $AE, $04, $62, $93, $F5, $5F,
    $39, $7E, $18, $B2, $D4, $25, $43, $E9, $8F, $67, $01, $AB, $CD, $3C, $5A,
    $F0, $96, $D1, $B7, $1D, $7B, $8A, $EC, $46, $20, $55, $33, $99, $FF, $0E,
    $68, $C2, $A4, $E3, $85, $2F, $49, $B8, $DE, $74, $12, $FA, $9C, $36, $50,
    $A1, $C7, $6D, $0B, $4C, $2A, $80, $E6, $17, $71, $DB, $BD, $00, $67, $CE,
    $A9, $5F, $38, $91, $F6, $BE, $D9, $70, $17, $E1, $86, $2F, $48, $BF, $D8,
    $71, $16, $E0, $87, $2E, $49, $01, $66, $CF, $A8, $5E, $39, $90, $F7, $BD,
    $DA, $73, $14, $E2, $85, $2C, $4B, $03, $64, $CD, $AA, $5C, $3B, $92, $F5,
    $02, $65, $CC, $AB, $5D, $3A, $93, $F4, $BC, $DB, $72, $15, $E3, $84, $2D,
    $4A, $B9, $DE, $77, $10, $E6, $81, $28, $4F, $07, $60, $C9, $AE, $58, $3F,
    $96, $F1, $06, $61, $C8, $AF, $59, $3E, $97, $F0, $B8, $DF, $76, $11, $E7,
    $80, $29, $4E, $04, $63, $CA, $AD, $5B, $3C, $95, $F2, $BA, $DD, $74, $13,
    $E5, $82, $2B, $4C, $BB, $DC, $75, $12, $E4, $83, $2A, $4D, $05, $62, $CB,
    $AC, $5A, $3D, $94, $F3, $B1, $D6, $7F, $18, $EE, $89, $20, $47, $0F, $68,
    $C1, $A6, $50, $37, $9E, $F9, $0E, $69, $C0, $A7, $51, $36, $9F, $F8, $B0,
    $D7, $7E, $19, $EF, $88, $21, $46, $0C, $6B, $C2, $A5, $53, $34, $9D, $FA,
    $B2, $D5, $7C, $1B, $ED, $8A, $23, $44, $B3, $D4, $7D, $1A, $EC, $8B, $22,
    $45, $0D, $6A, $C3, $A4, $52, $35, $9C, $FB, $08, $6F, $C6, $A1, $57, $30,
    $99, $FE, $B6, $D1, $78, $1F, $E9, $8E, $27, $40, $B7, $D0, $79, $1E, $E8,
    $8F, $26, $41, $09, $6E, $C7, $A0, $56, $31, $98, $FF, $B5, $D2, $7B, $1C,
    $EA, $8D, $24, $43, $0B, $6C, $C5, $A2, $54, $33, $9A, $FD, $0A, $6D, $C4,
    $A3, $55, $32, $9B, $FC, $B4, $D3, $7A, $1D, $EB, $8C, $25, $42, $00, $68,
    $D0, $B8, $63, $0B, $B3, $DB, $C6, $AE, $16, $7E, $A5, $CD, $75, $1D, $4F,
    $27, $9F, $F7, $2C, $44, $FC, $94, $89, $E1, $59, $31, $EA, $82, $3A, $52,
    $9E, $F6, $4E, $26, $FD, $95, $2D, $45, $58, $30, $88, $E0, $3B, $53, $EB,
    $83, $D1, $B9, $01, $69, $B2, $DA, $62, $0A, $17, $7F, $C7, $AF, $74, $1C,
    $A4, $CC, $FF, $97, $2F, $47, $9C, $F4, $4C, $24, $39, $51, $E9, $81, $5A,
    $32, $8A, $E2, $B0, $D8, $60, $08, $D3, $BB, $03, $6B, $76, $1E, $A6, $CE,
    $15, $7D, $C5, $AD, $61, $09, $B1, $D9, $02, $6A, $D2, $BA, $A7, $CF, $77,
    $1F, $C4, $AC, $14, $7C, $2E, $46, $FE, $96, $4D, $25, $9D, $F5, $E8, $80,
    $38, $50, $8B, $E3, $5B, $33, $3D, $55, $ED, $85, $5E, $36, $8E, $E6, $FB,
    $93, $2B, $43, $98, $F0, $48, $20, $72, $1A, $A2, $CA, $11, $79, $C1, $A9,
    $B4, $DC, $64, $0C, $D7, $BF, $07, $6F, $A3, $CB, $73, $1B, $C0, $A8, $10,
    $78, $65, $0D, $B5, $DD, $06, $6E, $D6, $BE, $EC, $84, $3C, $54, $8F, $E7,
    $5F, $37, $2A, $42, $FA, $92, $49, $21, $99, $F1, $C2, $AA, $12, $7A, $A1,
    $C9, $71, $19, $04, $6C, $D4, $BC, $67, $0F, $B7, $DF, $8D, $E5, $5D, $35,
    $EE, $86, $3E, $56, $4B, $23, $9B, $F3, $28, $40, $F8, $90, $5C, $34, $8C,
    $E4, $3F, $57, $EF, $87, $9A, $F2, $4A, $22, $F9, $91, $29, $41, $13, $7B,
    $C3, $AB, $70, $18, $A0, $C8, $D5, $BD, $05, $6D, $B6, $DE, $66, $0E, $00,
    $69, $D2, $BB, $67, $0E, $B5, $DC, $CE, $A7, $1C, $75, $A9, $C0, $7B, $12,
    $5F, $36, $8D, $E4, $38, $51, $EA, $83, $91, $F8, $43, $2A, $F6, $9F, $24,
    $4D, $BE, $D7, $6C, $05, $D9, $B0, $0B, $62, $70, $19, $A2, $CB, $17, $7E,
    $C5, $AC, $E1, $88, $33, $5A, $86, $EF, $54, $3D, $2F, $46, $FD, $94, $48,
    $21, $9A, $F3, $BF, $D6, $6D, $04, $D8, $B1, $0A, $63, $71, $18, $A3, $CA,
    $16, $7F, $C4, $AD, $E0, $89, $32, $5B, $87, $EE, $55, $3C, $2E, $47, $FC,
    $95, $49, $20, $9B, $F2, $01, $68, $D3, $BA, $66, $0F, $B4, $DD, $CF, $A6,
    $1D, $74, $A8, $C1, $7A, $13, $5E, $37, $8C, $E5, $39, $50, $EB, $82, $90,
    $F9, $42, $2B, $F7, $9E, $25, $4C, $BD, $D4, $6F, $06, $DA, $B3, $08, $61,
    $73, $1A, $A1, $C8, $14, $7D, $C6, $AF, $E2, $8B, $30, $59, $85, $EC, $57,
    $3E, $2C, $45, $FE, $97, $4B, $22, $99, $F0, $03, $6A, $D1, $B8, $64, $0D,
    $B6, $DF, $CD, $A4, $1F, $76, $AA, $C3, $78, $11, $5C, $35, $8E, $E7, $3B,
    $52, $E9, $80, $92, $FB, $40, $29, $F5, $9C, $27, $4E, $02, $6B, $D0, $B9,
    $65, $0C, $B7, $DE, $CC, $A5, $1E, $77, $AB, $C2, $79, $10, $5D, $34, $8F,
    $E6, $3A, $53, $E8, $81, $93, $FA, $41, $28, $F4, $9D, $26, $4F, $BC, $D5,
    $6E, $07, $DB, $B2, $09, $60, $72, $1B, $A0, $C9, $15, $7C, $C7, $AE, $E3,
    $8A, $31, $58, $84, $ED, $56, $3F, $2D, $44, $FF, $96, $4A, $23, $98, $F1,
    $00, $6A, $D4, $BE, $6B, $01, $BF, $D5, $D6, $BC, $02, $68, $BD, $D7, $69,
    $03, $6F, $05, $BB, $D1, $04, $6E, $D0, $BA, $B9, $D3, $6D, $07, $D2, $B8,
    $06, $6C, $DE, $B4, $0A, $60, $B5, $DF, $61, $0B, $08, $62, $DC, $B6, $63,
    $09, $B7, $DD, $B1, $DB, $65, $0F, $DA, $B0, $0E, $64, $67, $0D, $B3, $D9,
    $0C, $66, $D8, $B2, $7F, $15, $AB, $C1, $14, $7E, $C0, $AA, $A9, $C3, $7D,
    $17, $C2, $A8, $16, $7C, $10, $7A, $C4, $AE, $7B, $11, $AF, $C5, $C6, $AC,
    $12, $78, $AD, $C7, $79, $13, $A1, $CB, $75, $1F, $CA, $A0, $1E, $74, $77,
    $1D, $A3, $C9, $1C, $76, $C8, $A2, $CE, $A4, $1A, $70, $A5, $CF, $71, $1B,
    $18, $72, $CC, $A6, $73, $19, $A7, $CD, $FE, $94, $2A, $40, $95, $FF, $41,
    $2B, $28, $42, $FC, $96, $43, $29, $97, $FD, $91, $FB, $45, $2F, $FA, $90,
    $2E, $44, $47, $2D, $93, $F9, $2C, $46, $F8, $92, $20, $4A, $F4, $9E, $4B,
    $21, $9F, $F5, $F6, $9C, $22, $48, $9D, $F7, $49, $23, $4F, $25, $9B, $F1,
    $24, $4E, $F0, $9A, $99, $F3, $4D, $27, $F2, $98, $26, $4C, $81, $EB, $55,
    $3F, $EA, $80, $3E, $54, $57, $3D, $83, $E9, $3C, $56, $E8, $82, $EE, $84,
    $3A, $50, $85, $EF, $51, $3B, $38, $52, $EC, $86, $53, $39, $87, $ED, $5F,
    $35, $8B, $E1, $34, $5E, $E0, $8A, $89, $E3, $5D, $37, $E2, $88, $36, $5C,
    $30, $5A, $E4, $8E, $5B, $31, $8F, $E5, $E6, $8C, $32, $58, $8D, $E7, $59,
    $33, $00, $6B, $D6, $BD, $6F, $04, $B9, $D2, $DE, $B5, $08, $63, $B1, $DA,
    $67, $0C, $7F, $14, $A9, $C2, $10, $7B, $C6, $AD, $A1, $CA, $77, $1C, $CE,
    $A5, $18, $73, $FE, $95, $28, $43, $91, $FA, $47, $2C, $20, $4B, $F6, $9D,
    $4F, $24, $99, $F2, $81, $EA, $57, $3C, $EE, $85, $38, $53, $5F, $34, $89,
    $E2, $30, $5B, $E6, $8D, $3F, $54, $E9, $82, $50, $3B, $86, $ED, $E1, $8A,
    $37, $5C, $8E, $E5, $58, $33, $40, $2B, $96, $FD, $2F, $44, $F9, $92, $9E,
    $F5, $48, $23, $F1, $9A, $27, $4C, $C1, $AA, $17, $7C, $AE, $C5, $78, $13,
    $1F, $74, $C9, $A2, $70, $1B, $A6, $CD, $BE, $D5, $68, $03, $D1, $BA, $07,
    $6C, $60, $0B, $B6, $DD, $0F, $64, $D9, $B2, $7E, $15, $A8, $C3, $11, $7A,
    $C7, $AC, $A0, $CB, $76, $1D, $CF, $A4, $19, $72, $01, $6A, $D7, $BC, $6E,
    $05, $B8, $D3, $DF, $B4, $09, $62, $B0, $DB, $66, $0D, $80, $EB, $56, $3D,
    $EF, $84, $39, $52, $5E, $35, $88, $E3, $31, $5A, $E7, $8C, $FF, $94, $29,
    $42, $90, $FB, $46, $2D, $21, $4A, $F7, $9C, $4E, $25, $98, $F3, $41, $2A,
    $97, $FC, $2E, $45, $F8, $93, $9F, $F4, $49, $22, $F0, $9B, $26, $4D, $3E,
    $55, $E8, $83, $51, $3A, $87, $EC, $E0, $8B, $36, $5D, $8F, $E4, $59, $32,
    $BF, $D4, $69, $02, $D0, $BB, $06, $6D, $61, $0A, $B7, $DC, $0E, $65, $D8,
    $B3, $C0, $AB, $16, $7D, $AF, $C4, $79, $12, $1E, $75, $C8, $A3, $71, $1A,
    $A7, $CC, $00, $6C, $D8, $B4, $73, $1F, $AB, $C7, $E6, $8A, $3E, $52, $95,
    $F9, $4D, $21, $0F, $63, $D7, $BB, $7C, $10, $A4, $C8, $E9, $85, $31, $5D,
    $9A, $F6, $42, $2E, $1E, $72, $C6, $AA, $6D, $01, $B5, $D9, $F8, $94, $20,
    $4C, $8B, $E7, $53, $3F, $11, $7D, $C9, $A5, $62, $0E, $BA, $D6, $F7, $9B,
    $2F, $43, $84, $E8, $5C, $30, $3C, $50, $E4, $88, $4F, $23, $97, $FB, $DA,
    $B6, $02, $6E, $A9, $C5, $71, $1D, $33, $5F, $EB, $87, $40, $2C, $98, $F4,
    $D5, $B9, $0D, $61, $A6, $CA, $7E, $12, $22, $4E, $FA, $96, $51, $3D, $89,
    $E5, $C4, $A8, $1C, $70, $B7, $DB, $6F, $03, $2D, $41, $F5, $99, $5E, $32,
    $86, $EA, $CB, $A7, $13, $7F, $B8, $D4, $60, $0C, $78, $14, $A0, $CC, $0B,
    $67, $D3, $BF, $9E, $F2, $46, $2A, $ED, $81, $35, $59, $77, $1B, $AF, $C3,
    $04, $68, $DC, $B0, $91, $FD, $49, $25, $E2, $8E, $3A, $56, $66, $0A, $BE,
    $D2, $15, $79, $CD, $A1, $80, $EC, $58, $34, $F3, $9F, $2B, $47, $69, $05,
    $B1, $DD, $1A, $76, $C2, $AE, $8F, $E3, $57, $3B, $FC, $90, $24, $48, $44,
    $28, $9C, $F0, $37, $5B, $EF, $83, $A2, $CE, $7A, $16, $D1, $BD, $09, $65,
    $4B, $27, $93, $FF, $38, $54, $E0, $8C, $AD, $C1, $75, $19, $DE, $B2, $06,
    $6A, $5A, $36, $82, $EE, $29, $45, $F1, $9D, $BC, $D0, $64, $08, $CF, $A3,
    $17, $7B, $55, $39, $8D, $E1, $26, $4A, $FE, $92, $B3, $DF, $6B, $07, $C0,
    $AC, $18, $74, $00, $6D, $DA, $B7, $77, $1A, $AD, $C0, $EE, $83, $34, $59,
    $99, $F4, $43, $2E, $1F, $72, $C5, $A8, $68, $05, $B2, $DF, $F1, $9C, $2B,
    $46, $86, $EB, $5C, $31, $3E, $53, $E4, $89, $49, $24, $93, $FE, $D0, $BD,
    $0A, $67, $A7, $CA, $7D, $10, $21, $4C, $FB, $96, $56, $3B, $8C, $E1, $CF,
    $A2, $15, $78, $B8, $D5, $62, $0F, $7C, $11, $A6, $CB, $0B, $66, $D1, $BC,
    $92, $FF, $48, $25, $E5, $88, $3F, $52, $63, $0E, $B9, $D4, $14, $79, $CE,
    $A3, $8D, $E0, $57, $3A, $FA, $97, $20, $4D, $42, $2F, $98, $F5, $35, $58,
    $EF, $82, $AC, $C1, $76, $1B, $DB, $B6, $01, $6C, $5D, $30, $87, $EA, $2A,
    $47, $F0, $9D, $B3, $DE, $69, $04, $C4, $A9, $1E, $73, $F8, $95, $22, $4F,
    $8F, $E2, $55, $38, $16, $7B, $CC, $A1, $61, $0C, $BB, $D6, $E7, $8A, $3D,
    $50, $90, $FD, $4A, $27, $09, $64, $D3, $BE, $7E, $13, $A4, $C9, $C6, $AB,
    $1C, $71, $B1, $DC, $6B, $06, $28, $45, $F2, $9F, $5F, $32, $85, $E8, $D9,
    $B4, $03, $6E, $AE, $C3, $74, $19, $37, $5A, $ED, $80, $40, $2D, $9A, $F7,
    $84, $E9, $5E, $33, $F3, $9E, $29, $44, $6A, $07, $B0, $DD, $1D, $70, $C7,
    $AA, $9B, $F6, $41, $2C, $EC, $81, $36, $5B, $75, $18, $AF, $C2, $02, $6F,
    $D8, $B5, $BA, $D7, $60, $0D, $CD, $A0, $17, $7A, $54, $39, $8E, $E3, $23,
    $4E, $F9, $94, $A5, $C8, $7F, $12, $D2, $BF, $08, $65, $4B, $26, $91, $FC,
    $3C, $51, $E6, $8B, $00, $6E, $DC, $B2, $7B, $15, $A7, $C9, $F6, $98, $2A,
    $44, $8D, $E3, $51, $3F, $2F, $41, $F3, $9D, $54, $3A, $88, $E6, $D9, $B7,
    $05, $6B, $A2, $CC, $7E, $10, $5E, $30, $82, $EC, $25, $4B, $F9, $97, $A8,
    $C6, $74, $1A, $D3, $BD, $0F, $61, $71, $1F, $AD, $C3, $0A, $64, $D6, $B8,
    $87, $E9, $5B, $35, $FC, $92, $20, $4E, $BC, $D2, $60, $0E, $C7, $A9, $1B,
    $75, $4A, $24, $96, $F8, $31, $5F, $ED, $83, $93, $FD, $4F, $21, $E8, $86,
    $34, $5A, $65, $0B, $B9, $D7, $1E, $70, $C2, $AC, $E2, $8C, $3E, $50, $99,
    $F7, $45, $2B, $14, $7A, $C8, $A6, $6F, $01, $B3, $DD, $CD, $A3, $11, $7F,
    $B6, $D8, $6A, $04, $3B, $55, $E7, $89, $40, $2E, $9C, $F2, $BB, $D5, $67,
    $09, $C0, $AE, $1C, $72, $4D, $23, $91, $FF, $36, $58, $EA, $84, $94, $FA,
    $48, $26, $EF, $81, $33, $5D, $62, $0C, $BE, $D0, $19, $77, $C5, $AB, $E5,
    $8B, $39, $57, $9E, $F0, $42, $2C, $13, $7D, $CF, $A1, $68, $06, $B4, $DA,
    $CA, $A4, $16, $78, $B1, $DF, $6D, $03, $3C, $52, $E0, $8E, $47, $29, $9B,
    $F5, $07, $69, $DB, $B5, $7C, $12, $A0, $CE, $F1, $9F, $2D, $43, $8A, $E4,
    $56, $38, $28, $46, $F4, $9A, $53, $3D, $8F, $E1, $DE, $B0, $02, $6C, $A5,
    $CB, $79, $17, $59, $37, $85, $EB, $22, $4C, $FE, $90, $AF, $C1, $73, $1D,
    $D4, $BA, $08, $66, $76, $18, $AA, $C4, $0D, $63, $D1, $BF, $80, $EE, $5C,
    $32, $FB, $95, $27, $49, $00, $6F, $DE, $B1, $7F, $10, $A1, $CE, $FE, $91,
    $20, $4F, $81, $EE, $5F, $30, $3F, $50, $E1, $8E, $40, $2F, $9E, $F1, $C1,
    $AE, $1F, $70, $BE, $D1, $60, $0F, $7E, $11, $A0, $CF, $01, $6E, $DF, $B0,
    $80, $EF, $5E, $31, $FF, $90, $21, $4E, $41, $2E, $9F, $F0, $3E, $51, $E0,
    $8F, $BF, $D0, $61, $0E, $C0, $AF, $1E, $71, $FC, $93, $22, $4D, $83, $EC,
    $5D, $32, $02, $6D, $DC, $B3, $7D, $12, $A3, $CC, $C3, $AC, $1D, $72, $BC,
    $D3, $62, $0D, $3D, $52, $E3, $8C, $42, $2D, $9C, $F3, $82, $ED, $5C, $33,
    $FD, $92, $23, $4C, $7C, $13, $A2, $CD, $03, $6C, $DD, $B2, $BD, $D2, $63,
    $0C, $C2, $AD, $1C, $73, $43, $2C, $9D, $F2, $3C, $53, $E2, $8D, $3B, $54,
    $E5, $8A, $44, $2B, $9A, $F5, $C5, $AA, $1B, $74, $BA, $D5, $64, $0B, $04,
    $6B, $DA, $B5, $7B, $14, $A5, $CA, $FA, $95, $24, $4B, $85, $EA, $5B, $34,
    $45, $2A, $9B, $F4, $3A, $55, $E4, $8B, $BB, $D4, $65, $0A, $C4, $AB, $1A,
    $75, $7A, $15, $A4, $CB, $05, $6A, $DB, $B4, $84, $EB, $5A, $35, $FB, $94,
    $25, $4A, $C7, $A8, $19, $76, $B8, $D7, $66, $09, $39, $56, $E7, $88, $46,
    $29, $98, $F7, $F8, $97, $26, $49, $87, $E8, $59, $36, $06, $69, $D8, $B7,
    $79, $16, $A7, $C8, $B9, $D6, $67, $08, $C6, $A9, $18, $77, $47, $28, $99,
    $F6, $38, $57, $E6, $89, $86, $E9, $58, $37, $F9, $96, $27, $48, $78, $17,
    $A6, $C9, $07, $68, $D9, $B6, $00, $70, $E0, $90, $03, $73, $E3, $93, $06,
    $76, $E6, $96, $05, $75, $E5, $95, $0C, $7C, $EC, $9C, $0F, $7F, $EF, $9F,
    $0A, $7A, $EA, $9A, $09, $79, $E9, $99, $18, $68, $F8, $88, $1B, $6B, $FB,
    $8B, $1E, $6E, $FE, $8E, $1D, $6D, $FD, $8D, $14, $64, $F4, $84, $17, $67,
    $F7, $87, $12, $62, $F2, $82, $11, $61, $F1, $81, $30, $40, $D0, $A0, $33,
    $43, $D3, $A3, $36, $46, $D6, $A6, $35, $45, $D5, $A5, $3C, $4C, $DC, $AC,
    $3F, $4F, $DF, $AF, $3A, $4A, $DA, $AA, $39, $49, $D9, $A9, $28, $58, $C8,
    $B8, $2B, $5B, $CB, $BB, $2E, $5E, $CE, $BE, $2D, $5D, $CD, $BD, $24, $54,
    $C4, $B4, $27, $57, $C7, $B7, $22, $52, $C2, $B2, $21, $51, $C1, $B1, $60,
    $10, $80, $F0, $63, $13, $83, $F3, $66, $16, $86, $F6, $65, $15, $85, $F5,
    $6C, $1C, $8C, $FC, $6F, $1F, $8F, $FF, $6A, $1A, $8A, $FA, $69, $19, $89,
    $F9, $78, $08, $98, $E8, $7B, $0B, $9B, $EB, $7E, $0E, $9E, $EE, $7D, $0D,
    $9D, $ED, $74, $04, $94, $E4, $77, $07, $97, $E7, $72, $02, $92, $E2, $71,
    $01, $91, $E1, $50, $20, $B0, $C0, $53, $23, $B3, $C3, $56, $26, $B6, $C6,
    $55, $25, $B5, $C5, $5C, $2C, $BC, $CC, $5F, $2F, $BF, $CF, $5A, $2A, $BA,
    $CA, $59, $29, $B9, $C9, $48, $38, $A8, $D8, $4B, $3B, $AB, $DB, $4E, $3E,
    $AE, $DE, $4D, $3D, $AD, $DD, $44, $34, $A4, $D4, $47, $37, $A7, $D7, $42,
    $32, $A2, $D2, $41, $31, $A1, $D1, $00, $71, $E2, $93, $07, $76, $E5, $94,
    $0E, $7F, $EC, $9D, $09, $78, $EB, $9A, $1C, $6D, $FE, $8F, $1B, $6A, $F9,
    $88, $12, $63, $F0, $81, $15, $64, $F7, $86, $38, $49, $DA, $AB, $3F, $4E,
    $DD, $AC, $36, $47, $D4, $A5, $31, $40, $D3, $A2, $24, $55, $C6, $B7, $23,
    $52, $C1, $B0, $2A, $5B, $C8, $B9, $2D, $5C, $CF, $BE, $70, $01, $92, $E3,
    $77, $06, $95, $E4, $7E, $0F, $9C, $ED, $79, $08, $9B, $EA, $6C, $1D, $8E,
    $FF, $6B, $1A, $89, $F8, $62, $13, $80, $F1, $65, $14, $87, $F6, $48, $39,
    $AA, $DB, $4F, $3E, $AD, $DC, $46, $37, $A4, $D5, $41, $30, $A3, $D2, $54,
    $25, $B6, $C7, $53, $22, $B1, $C0, $5A, $2B, $B8, $C9, $5D, $2C, $BF, $CE,
    $E0, $91, $02, $73, $E7, $96, $05, $74, $EE, $9F, $0C, $7D, $E9, $98, $0B,
    $7A, $FC, $8D, $1E, $6F, $FB, $8A, $19, $68, $F2, $83, $10, $61, $F5, $84,
    $17, $66, $D8, $A9, $3A, $4B, $DF, $AE, $3D, $4C, $D6, $A7, $34, $45, $D1,
    $A0, $33, $42, $C4, $B5, $26, $57, $C3, $B2, $21, $50, $CA, $BB, $28, $59,
    $CD, $BC, $2F, $5E, $90, $E1, $72, $03, $97, $E6, $75, $04, $9E, $EF, $7C,
    $0D, $99, $E8, $7B, $0A, $8C, $FD, $6E, $1F, $8B, $FA, $69, $18, $82, $F3,
    $60, $11, $85, $F4, $67, $16, $A8, $D9, $4A, $3B, $AF, $DE, $4D, $3C, $A6,
    $D7, $44, $35, $A1, $D0, $43, $32, $B4, $C5, $56, $27, $B3, $C2, $51, $20,
    $BA, $CB, $58, $29, $BD, $CC, $5F, $2E, $00, $72, $E4, $96, $0B, $79, $EF,
    $9D, $16, $64, $F2, $80, $1D, $6F, $F9, $8B, $2C, $5E, $C8, $BA, $27, $55,
    $C3, $B1, $3A, $48, $DE, $AC, $31, $43, $D5, $A7, $58, $2A, $BC, $CE, $53,
    $21, $B7, $C5, $4E, $3C, $AA, $D8, $45, $37, $A1, $D3, $74, $06, $90, $E2,
    $7F, $0D, $9B, $E9, $62, $10, $86, $F4, $69, $1B, $8D, $FF, $B0, $C2, $54,
    $26, $BB, $C9, $5F, $2D, $A6, $D4, $42, $30, $AD, $DF, $49, $3B, $9C, $EE,
    $78, $0A, $97, $E5, $73, $01, $8A, $F8, $6E, $1C, $81, $F3, $65, $17, $E8,
    $9A, $0C, $7E, $E3, $91, $07, $75, $FE, $8C, $1A, $68, $F5, $87, $11, $63,
    $C4, $B6, $20, $52, $CF, $BD, $2B, $59, $D2, $A0, $36, $44, $D9, $AB, $3D,
    $4F, $A3, $D1, $47, $35, $A8, $DA, $4C, $3E, $B5, $C7, $51, $23, $BE, $CC,
    $5A, $28, $8F, $FD, $6B, $19, $84, $F6, $60, $12, $99, $EB, $7D, $0F, $92,
    $E0, $76, $04, $FB, $89, $1F, $6D, $F0, $82, $14, $66, $ED, $9F, $09, $7B,
    $E6, $94, $02, $70, $D7, $A5, $33, $41, $DC, $AE, $38, $4A, $C1, $B3, $25,
    $57, $CA, $B8, $2E, $5C, $13, $61, $F7, $85, $18, $6A, $FC, $8E, $05, $77,
    $E1, $93, $0E, $7C, $EA, $98, $3F, $4D, $DB, $A9, $34, $46, $D0, $A2, $29,
    $5B, $CD, $BF, $22, $50, $C6, $B4, $4B, $39, $AF, $DD, $40, $32, $A4, $D6,
    $5D, $2F, $B9, $CB, $56, $24, $B2, $C0, $67, $15, $83, $F1, $6C, $1E, $88,
    $FA, $71, $03, $95, $E7, $7A, $08, $9E, $EC, $00, $73, $E6, $95, $0F, $7C,
    $E9, $9A, $1E, $6D, $F8, $8B, $11, $62, $F7, $84, $3C, $4F, $DA, $A9, $33,
    $40, $D5, $A6, $22, $51, $C4, $B7, $2D, $5E, $CB, $B8, $78, $0B, $9E, $ED,
    $77, $04, $91, $E2, $66, $15, $80, $F3, $69, $1A, $8F, $FC, $44, $37, $A2,
    $D1, $4B, $38, $AD, $DE, $5A, $29, $BC, $CF, $55, $26, $B3, $C0, $F0, $83,
    $16, $65, $FF, $8C, $19, $6A, $EE, $9D, $08, $7B, $E1, $92, $07, $74, $CC,
    $BF, $2A, $59, $C3, $B0, $25, $56, $D2, $A1, $34, $47, $DD, $AE, $3B, $48,
    $88, $FB, $6E, $1D, $87, $F4, $61, $12, $96, $E5, $70, $03, $99, $EA, $7F,
    $0C, $B4, $C7, $52, $21, $BB, $C8, $5D, $2E, $AA, $D9, $4C, $3F, $A5, $D6,
    $43, $30, $23, $50, $C5, $B6, $2C, $5F, $CA, $B9, $3D, $4E, $DB, $A8, $32,
    $41, $D4, $A7, $1F, $6C, $F9, $8A, $10, $63, $F6, $85, $01, $72, $E7, $94,
    $0E, $7D, $E8, $9B, $5B, $28, $BD, $CE, $54, $27, $B2, $C1, $45, $36, $A3,
    $D0, $4A, $39, $AC, $DF, $67, $14, $81, $F2, $68, $1B, $8E, $FD, $79, $0A,
    $9F, $EC, $76, $05, $90, $E3, $D3, $A0, $35, $46, $DC, $AF, $3A, $49, $CD,
    $BE, $2B, $58, $C2, $B1, $24, $57, $EF, $9C, $09, $7A, $E0, $93, $06, $75,
    $F1, $82, $17, $64, $FE, $8D, $18, $6B, $AB, $D8, $4D, $3E, $A4, $D7, $42,
    $31, $B5, $C6, $53, $20, $BA, $C9, $5C, $2F, $97, $E4, $71, $02, $98, $EB,
    $7E, $0D, $89, $FA, $6F, $1C, $86, $F5, $60, $13, $00, $74, $E8, $9C, $13,
    $67, $FB, $8F, $26, $52, $CE, $BA, $35, $41, $DD, $A9, $4C, $38, $A4, $D0,
    $5F, $2B, $B7, $C3, $6A, $1E, $82, $F6, $79, $0D, $91, $E5, $98, $EC, $70,
    $04, $8B, $FF, $63, $17, $BE, $CA, $56, $22, $AD, $D9, $45, $31, $D4, $A0,
    $3C, $48, $C7, $B3, $2F, $5B, $F2, $86, $1A, $6E, $E1, $95, $09, $7D, $F3,
    $87, $1B, $6F, $E0, $94, $08, $7C, $D5, $A1, $3D, $49, $C6, $B2, $2E, $5A,
    $BF, $CB, $57, $23, $AC, $D8, $44, $30, $99, $ED, $71, $05, $8A, $FE, $62,
    $16, $6B, $1F, $83, $F7, $78, $0C, $90, $E4, $4D, $39, $A5, $D1, $5E, $2A,
    $B6, $C2, $27, $53, $CF, $BB, $34, $40, $DC, $A8, $01, $75, $E9, $9D, $12,
    $66, $FA, $8E, $25, $51, $CD, $B9, $36, $42, $DE, $AA, $03, $77, $EB, $9F,
    $10, $64, $F8, $8C, $69, $1D, $81, $F5, $7A, $0E, $92, $E6, $4F, $3B, $A7,
    $D3, $5C, $28, $B4, $C0, $BD, $C9, $55, $21, $AE, $DA, $46, $32, $9B, $EF,
    $73, $07, $88, $FC, $60, $14, $F1, $85, $19, $6D, $E2, $96, $0A, $7E, $D7,
    $A3, $3F, $4B, $C4, $B0, $2C, $58, $D6, $A2, $3E, $4A, $C5, $B1, $2D, $59,
    $F0, $84, $18, $6C, $E3, $97, $0B, $7F, $9A, $EE, $72, $06, $89, $FD, $61,
    $15, $BC, $C8, $54, $20, $AF, $DB, $47, $33, $4E, $3A, $A6, $D2, $5D, $29,
    $B5, $C1, $68, $1C, $80, $F4, $7B, $0F, $93, $E7, $02, $76, $EA, $9E, $11,
    $65, $F9, $8D, $24, $50, $CC, $B8, $37, $43, $DF, $AB, $00, $75, $EA, $9F,
    $17, $62, $FD, $88, $2E, $5B, $C4, $B1, $39, $4C, $D3, $A6, $5C, $29, $B6,
    $C3, $4B, $3E, $A1, $D4, $72, $07, $98, $ED, $65, $10, $8F, $FA, $B8, $CD,
    $52, $27, $AF, $DA, $45, $30, $96, $E3, $7C, $09, $81, $F4, $6B, $1E, $E4,
    $91, $0E, $7B, $F3, $86, $19, $6C, $CA, $BF, $20, $55, $DD, $A8, $37, $42,
    $B3, $C6, $59, $2C, $A4, $D1, $4E, $3B, $9D, $E8, $77, $02, $8A, $FF, $60,
    $15, $EF, $9A, $05, $70, $F8, $8D, $12, $67, $C1, $B4, $2B, $5E, $D6, $A3,
    $3C, $49, $0B, $7E, $E1, $94, $1C, $69, $F6, $83, $25, $50, $CF, $BA, $32,
    $47, $D8, $AD, $57, $22, $BD, $C8, $40, $35, $AA, $DF, $79, $0C, $93, $E6,
    $6E, $1B, $84, $F1, $A5, $D0, $4F, $3A, $B2, $C7, $58, $2D, $8B, $FE, $61,
    $14, $9C, $E9, $76, $03, $F9, $8C, $13, $66, $EE, $9B, $04, $71, $D7, $A2,
    $3D, $48, $C0, $B5, $2A, $5F, $1D, $68, $F7, $82, $0A, $7F, $E0, $95, $33,
    $46, $D9, $AC, $24, $51, $CE, $BB, $41, $34, $AB, $DE, $56, $23, $BC, $C9,
    $6F, $1A, $85, $F0, $78, $0D, $92, $E7, $16, $63, $FC, $89, $01, $74, $EB,
    $9E, $38, $4D, $D2, $A7, $2F, $5A, $C5, $B0, $4A, $3F, $A0, $D5, $5D, $28,
    $B7, $C2, $64, $11, $8E, $FB, $73, $06, $99, $EC, $AE, $DB, $44, $31, $B9,
    $CC, $53, $26, $80, $F5, $6A, $1F, $97, $E2, $7D, $08, $F2, $87, $18, $6D,
    $E5, $90, $0F, $7A, $DC, $A9, $36, $43, $CB, $BE, $21, $54, $00, $76, $EC,
    $9A, $1B, $6D, $F7, $81, $36, $40, $DA, $AC, $2D, $5B, $C1, $B7, $6C, $1A,
    $80, $F6, $77, $01, $9B, $ED, $5A, $2C, $B6, $C0, $41, $37, $AD, $DB, $D8,
    $AE, $34, $42, $C3, $B5, $2F, $59, $EE, $98, $02, $74, $F5, $83, $19, $6F,
    $B4, $C2, $58, $2E, $AF, $D9, $43, $35, $82, $F4, $6E, $18, $99, $EF, $75,
    $03, $73, $05, $9F, $E9, $68, $1E, $84, $F2, $45, $33, $A9, $DF, $5E, $28,
    $B2, $C4, $1F, $69, $F3, $85, $04, $72, $E8, $9E, $29, $5F, $C5, $B3, $32,
    $44, $DE, $A8, $AB, $DD, $47, $31, $B0, $C6, $5C, $2A, $9D, $EB, $71, $07,
    $86, $F0, $6A, $1C, $C7, $B1, $2B, $5D, $DC, $AA, $30, $46, $F1, $87, $1D,
    $6B, $EA, $9C, $06, $70, $E6, $90, $0A, $7C, $FD, $8B, $11, $67, $D0, $A6,
    $3C, $4A, $CB, $BD, $27, $51, $8A, $FC, $66, $10, $91, $E7, $7D, $0B, $BC,
    $CA, $50, $26, $A7, $D1, $4B, $3D, $3E, $48, $D2, $A4, $25, $53, $C9, $BF,
    $08, $7E, $E4, $92, $13, $65, $FF, $89, $52, $24, $BE, $C8, $49, $3F, $A5,
    $D3, $64, $12, $88, $FE, $7F, $09, $93, $E5, $95, $E3, $79, $0F, $8E, $F8,
    $62, $14, $A3, $D5, $4F, $39, $B8, $CE, $54, $22, $F9, $8F, $15, $63, $E2,
    $94, $0E, $78, $CF, $B9, $23, $55, $D4, $A2, $38, $4E, $4D, $3B, $A1, $D7,
    $56, $20, $BA, $CC, $7B, $0D, $97, $E1, $60, $16, $8C, $FA, $21, $57, $CD,
    $BB, $3A, $4C, $D6, $A0, $17, $61, $FB, $8D, $0C, $7A, $E0, $96, $00, $77,
    $EE, $99, $1F, $68, $F1, $86, $3E, $49, $D0, $A7, $21, $56, $CF, $B8, $7C,
    $0B, $92, $E5, $63, $14, $8D, $FA, $42, $35, $AC, $DB, $5D, $2A, $B3, $C4,
    $F8, $8F, $16, $61, $E7, $90, $09, $7E, $C6, $B1, $28, $5F, $D9, $AE, $37,
    $40, $84, $F3, $6A, $1D, $9B, $EC, $75, $02, $BA, $CD, $54, $23, $A5, $D2,
    $4B, $3C, $33, $44, $DD, $AA, $2C, $5B, $C2, $B5, $0D, $7A, $E3, $94, $12,
    $65, $FC, $8B, $4F, $38, $A1, $D6, $50, $27, $BE, $C9, $71, $06, $9F, $E8,
    $6E, $19, $80, $F7, $CB, $BC, $25, $52, $D4, $A3, $3A, $4D, $F5, $82, $1B,
    $6C, $EA, $9D, $04, $73, $B7, $C0, $59, $2E, $A8, $DF, $46, $31, $89, $FE,
    $67, $10, $96, $E1, $78, $0F, $66, $11, $88, $FF, $79, $0E, $97, $E0, $58,
    $2F, $B6, $C1, $47, $30, $A9, $DE, $1A, $6D, $F4, $83, $05, $72, $EB, $9C,
    $24, $53, $CA, $BD, $3B, $4C, $D5, $A2, $9E, $E9, $70, $07, $81, $F6, $6F,
    $18, $A0, $D7, $4E, $39, $BF, $C8, $51, $26, $E2, $95, $0C, $7B, $FD, $8A,
    $13, $64, $DC, $AB, $32, $45, $C3, $B4, $2D, $5A, $55, $22, $BB, $CC, $4A,
    $3D, $A4, $D3, $6B, $1C, $85, $F2, $74, $03, $9A, $ED, $29, $5E, $C7, $B0,
    $36, $41, $D8, $AF, $17, $60, $F9, $8E, $08, $7F, $E6, $91, $AD, $DA, $43,
    $34, $B2, $C5, $5C, $2B, $93, $E4, $7D, $0A, $8C, $FB, $62, $15, $D1, $A6,
    $3F, $48, $CE, $B9, $20, $57, $EF, $98, $01, $76, $F0, $87, $1E, $69, $00,
    $78, $F0, $88, $23, $5B, $D3, $AB, $46, $3E, $B6, $CE, $65, $1D, $95, $ED,
    $8C, $F4, $7C, $04, $AF, $D7, $5F, $27, $CA, $B2, $3A, $42, $E9, $91, $19,
    $61, $DB, $A3, $2B, $53, $F8, $80, $08, $70, $9D, $E5, $6D, $15, $BE, $C6,
    $4E, $36, $57, $2F, $A7, $DF, $74, $0C, $84, $FC, $11, $69, $E1, $99, $32,
    $4A, $C2, $BA, $75, $0D, $85, $FD, $56, $2E, $A6, $DE, $33, $4B, $C3, $BB,
    $10, $68, $E0, $98, $F9, $81, $09, $71, $DA, $A2, $2A, $52, $BF, $C7, $4F,
    $37, $9C, $E4, $6C, $14, $AE, $D6, $5E, $26, $8D, $F5, $7D, $05, $E8, $90,
    $18, $60, $CB, $B3, $3B, $43, $22, $5A, $D2, $AA, $01, $79, $F1, $89, $64,
    $1C, $94, $EC, $47, $3F, $B7, $CF, $EA, $92, $1A, $62, $C9, $B1, $39, $41,
    $AC, $D4, $5C, $24, $8F, $F7, $7F, $07, $66, $1E, $96, $EE, $45, $3D, $B5,
    $CD, $20, $58, $D0, $A8, $03, $7B, $F3, $8B, $31, $49, $C1, $B9, $12, $6A,
    $E2, $9A, $77, $0F, $87, $FF, $54, $2C, $A4, $DC, $BD, $C5, $4D, $35, $9E,
    $E6, $6E, $16, $FB, $83, $0B, $73, $D8, $A0, $28, $50, $9F, $E7, $6F, $17,
    $BC, $C4, $4C, $34, $D9, $A1, $29, $51, $FA, $82, $0A, $72, $13, $6B, $E3,
    $9B, $30, $48, $C0, $B8, $55, $2D, $A5, $DD, $76, $0E, $86, $FE, $44, $3C,
    $B4, $CC, $67, $1F, $97, $EF, $02, $7A, $F2, $8A, $21, $59, $D1, $A9, $C8,
    $B0, $38, $40, $EB, $93, $1B, $63, $8E, $F6, $7E, $06, $AD, $D5, $5D, $25,
    $00, $79, $F2, $8B, $27, $5E, $D5, $AC, $4E, $37, $BC, $C5, $69, $10, $9B,
    $E2, $9C, $E5, $6E, $17, $BB, $C2, $49, $30, $D2, $AB, $20, $59, $F5, $8C,
    $07, $7E, $FB, $82, $09, $70, $DC, $A5, $2E, $57, $B5, $CC, $47, $3E, $92,
    $EB, $60, $19, $67, $1E, $95, $EC, $40, $39, $B2, $CB, $29, $50, $DB, $A2,
    $0E, $77, $FC, $85, $35, $4C, $C7, $BE, $12, $6B, $E0, $99, $7B, $02, $89,
    $F0, $5C, $25, $AE, $D7, $A9, $D0, $5B, $22, $8E, $F7, $7C, $05, $E7, $9E,
    $15, $6C, $C0, $B9, $32, $4B, $CE, $B7, $3C, $45, $E9, $90, $1B, $62, $80,
    $F9, $72, $0B, $A7, $DE, $55, $2C, $52, $2B, $A0, $D9, $75, $0C, $87, $FE,
    $1C, $65, $EE, $97, $3B, $42, $C9, $B0, $6A, $13, $98, $E1, $4D, $34, $BF,
    $C6, $24, $5D, $D6, $AF, $03, $7A, $F1, $88, $F6, $8F, $04, $7D, $D1, $A8,
    $23, $5A, $B8, $C1, $4A, $33, $9F, $E6, $6D, $14, $91, $E8, $63, $1A, $B6,
    $CF, $44, $3D, $DF, $A6, $2D, $54, $F8, $81, $0A, $73, $0D, $74, $FF, $86,
    $2A, $53, $D8, $A1, $43, $3A, $B1, $C8, $64, $1D, $96, $EF, $5F, $26, $AD,
    $D4, $78, $01, $8A, $F3, $11, $68, $E3, $9A, $36, $4F, $C4, $BD, $C3, $BA,
    $31, $48, $E4, $9D, $16, $6F, $8D, $F4, $7F, $06, $AA, $D3, $58, $21, $A4,
    $DD, $56, $2F, $83, $FA, $71, $08, $EA, $93, $18, $61, $CD, $B4, $3F, $46,
    $38, $41, $CA, $B3, $1F, $66, $ED, $94, $76, $0F, $84, $FD, $51, $28, $A3,
    $DA, $00, $7A, $F4, $8E, $2B, $51, $DF, $A5, $56, $2C, $A2, $D8, $7D, $07,
    $89, $F3, $AC, $D6, $58, $22, $87, $FD, $73, $09, $FA, $80, $0E, $74, $D1,
    $AB, $25, $5F, $9B, $E1, $6F, $15, $B0, $CA, $44, $3E, $CD, $B7, $39, $43,
    $E6, $9C, $12, $68, $37, $4D, $C3, $B9, $1C, $66, $E8, $92, $61, $1B, $95,
    $EF, $4A, $30, $BE, $C4, $F5, $8F, $01, $7B, $DE, $A4, $2A, $50, $A3, $D9,
    $57, $2D, $88, $F2, $7C, $06, $59, $23, $AD, $D7, $72, $08, $86, $FC, $0F,
    $75, $FB, $81, $24, $5E, $D0, $AA, $6E, $14, $9A, $E0, $45, $3F, $B1, $CB,
    $38, $42, $CC, $B6, $13, $69, $E7, $9D, $C2, $B8, $36, $4C, $E9, $93, $1D,
    $67, $94, $EE, $60, $1A, $BF, $C5, $4B, $31, $29, $53, $DD, $A7, $02, $78,
    $F6, $8C, $7F, $05, $8B, $F1, $54, $2E, $A0, $DA, $85, $FF, $71, $0B, $AE,
    $D4, $5A, $20, $D3, $A9, $27, $5D, $F8, $82, $0C, $76, $B2, $C8, $46, $3C,
    $99, $E3, $6D, $17, $E4, $9E, $10, $6A, $CF, $B5, $3B, $41, $1E, $64, $EA,
    $90, $35, $4F, $C1, $BB, $48, $32, $BC, $C6, $63, $19, $97, $ED, $DC, $A6,
    $28, $52, $F7, $8D, $03, $79, $8A, $F0, $7E, $04, $A1, $DB, $55, $2F, $70,
    $0A, $84, $FE, $5B, $21, $AF, $D5, $26, $5C, $D2, $A8, $0D, $77, $F9, $83,
    $47, $3D, $B3, $C9, $6C, $16, $98, $E2, $11, $6B, $E5, $9F, $3A, $40, $CE,
    $B4, $EB, $91, $1F, $65, $C0, $BA, $34, $4E, $BD, $C7, $49, $33, $96, $EC,
    $62, $18, $00, $7B, $F6, $8D, $2F, $54, $D9, $A2, $5E, $25, $A8, $D3, $71,
    $0A, $87, $FC, $BC, $C7, $4A, $31, $93, $E8, $65, $1E, $E2, $99, $14, $6F,
    $CD, $B6, $3B, $40, $BB, $C0, $4D, $36, $94, $EF, $62, $19, $E5, $9E, $13,
    $68, $CA, $B1, $3C, $47, $07, $7C, $F1, $8A, $28, $53, $DE, $A5, $59, $22,
    $AF, $D4, $76, $0D, $80, $FB, $B5, $CE, $43, $38, $9A, $E1, $6C, $17, $EB,
    $90, $1D, $66, $C4, $BF, $32, $49, $09, $72, $FF, $84, $26, $5D, $D0, $AB,
    $57, $2C, $A1, $DA, $78, $03, $8E, $F5, $0E, $75, $F8, $83, $21, $5A, $D7,
    $AC, $50, $2B, $A6, $DD, $7F, $04, $89, $F2, $B2, $C9, $44, $3F, $9D, $E6,
    $6B, $10, $EC, $97, $1A, $61, $C3, $B8, $35, $4E, $A9, $D2, $5F, $24, $86,
    $FD, $70, $0B, $F7, $8C, $01, $7A, $D8, $A3, $2E, $55, $15, $6E, $E3, $98,
    $3A, $41, $CC, $B7, $4B, $30, $BD, $C6, $64, $1F, $92, $E9, $12, $69, $E4,
    $9F, $3D, $46, $CB, $B0, $4C, $37, $BA, $C1, $63, $18, $95, $EE, $AE, $D5,
    $58, $23, $81, $FA, $77, $0C, $F0, $8B, $06, $7D, $DF, $A4, $29, $52, $1C,
    $67, $EA, $91, $33, $48, $C5, $BE, $42, $39, $B4, $CF, $6D, $16, $9B, $E0,
    $A0, $DB, $56, $2D, $8F, $F4, $79, $02, $FE, $85, $08, $73, $D1, $AA, $27,
    $5C, $A7, $DC, $51, $2A, $88, $F3, $7E, $05, $F9, $82, $0F, $74, $D6, $AD,
    $20, $5B, $1B, $60, $ED, $96, $34, $4F, $C2, $B9, $45, $3E, $B3, $C8, $6A,
    $11, $9C, $E7, $00, $7C, $F8, $84, $33, $4F, $CB, $B7, $66, $1A, $9E, $E2,
    $55, $29, $AD, $D1, $CC, $B0, $34, $48, $FF, $83, $07, $7B, $AA, $D6, $52,
    $2E, $99, $E5, $61, $1D, $5B, $27, $A3, $DF, $68, $14, $90, $EC, $3D, $41,
    $C5, $B9, $0E, $72, $F6, $8A, $97, $EB, $6F, $13, $A4, $D8, $5C, $20, $F1,
    $8D, $09, $75, $C2, $BE, $3A, $46, $B6, $CA, $4E, $32, $85, $F9, $7D, $01,
    $D0, $AC, $28, $54, $E3, $9F, $1B, $67, $7A, $06, $82, $FE, $49, $35, $B1,
    $CD, $1C, $60, $E4, $98, $2F, $53, $D7, $AB, $ED, $91, $15, $69, $DE, $A2,
    $26, $5A, $8B, $F7, $73, $0F, $B8, $C4, $40, $3C, $21, $5D, $D9, $A5, $12,
    $6E, $EA, $96, $47, $3B, $BF, $C3, $74, $08, $8C, $F0, $AF, $D3, $57, $2B,
    $9C, $E0, $64, $18, $C9, $B5, $31, $4D, $FA, $86, $02, $7E, $63, $1F, $9B,
    $E7, $50, $2C, $A8, $D4, $05, $79, $FD, $81, $36, $4A, $CE, $B2, $F4, $88,
    $0C, $70, $C7, $BB, $3F, $43, $92, $EE, $6A, $16, $A1, $DD, $59, $25, $38,
    $44, $C0, $BC, $0B, $77, $F3, $8F, $5E, $22, $A6, $DA, $6D, $11, $95, $E9,
    $19, $65, $E1, $9D, $2A, $56, $D2, $AE, $7F, $03, $87, $FB, $4C, $30, $B4,
    $C8, $D5, $A9, $2D, $51, $E6, $9A, $1E, $62, $B3, $CF, $4B, $37, $80, $FC,
    $78, $04, $42, $3E, $BA, $C6, $71, $0D, $89, $F5, $24, $58, $DC, $A0, $17,
    $6B, $EF, $93, $8E, $F2, $76, $0A, $BD, $C1, $45, $39, $E8, $94, $10, $6C,
    $DB, $A7, $23, $5F, $00, $7D, $FA, $87, $37, $4A, $CD, $B0, $6E, $13, $94,
    $E9, $59, $24, $A3, $DE, $DC, $A1, $26, $5B, $EB, $96, $11, $6C, $B2, $CF,
    $48, $35, $85, $F8, $7F, $02, $7B, $06, $81, $FC, $4C, $31, $B6, $CB, $15,
    $68, $EF, $92, $22, $5F, $D8, $A5, $A7, $DA, $5D, $20, $90, $ED, $6A, $17,
    $C9, $B4, $33, $4E, $FE, $83, $04, $79, $F6, $8B, $0C, $71, $C1, $BC, $3B,
    $46, $98, $E5, $62, $1F, $AF, $D2, $55, $28, $2A, $57, $D0, $AD, $1D, $60,
    $E7, $9A, $44, $39, $BE, $C3, $73, $0E, $89, $F4, $8D, $F0, $77, $0A, $BA,
    $C7, $40, $3D, $E3, $9E, $19, $64, $D4, $A9, $2E, $53, $51, $2C, $AB, $D6,
    $66, $1B, $9C, $E1, $3F, $42, $C5, $B8, $08, $75, $F2, $8F, $2F, $52, $D5,
    $A8, $18, $65, $E2, $9F, $41, $3C, $BB, $C6, $76, $0B, $8C, $F1, $F3, $8E,
    $09, $74, $C4, $B9, $3E, $43, $9D, $E0, $67, $1A, $AA, $D7, $50, $2D, $54,
    $29, $AE, $D3, $63, $1E, $99, $E4, $3A, $47, $C0, $BD, $0D, $70, $F7, $8A,
    $88, $F5, $72, $0F, $BF, $C2, $45, $38, $E6, $9B, $1C, $61, $D1, $AC, $2B,
    $56, $D9, $A4, $23, $5E, $EE, $93, $14, $69, $B7, $CA, $4D, $30, $80, $FD,
    $7A, $07, $05, $78, $FF, $82, $32, $4F, $C8, $B5, $6B, $16, $91, $EC, $5C,
    $21, $A6, $DB, $A2, $DF, $58, $25, $95, $E8, $6F, $12, $CC, $B1, $36, $4B,
    $FB, $86, $01, $7C, $7E, $03, $84, $F9, $49, $34, $B3, $CE, $10, $6D, $EA,
    $97, $27, $5A, $DD, $A0, $00, $7E, $FC, $82, $3B, $45, $C7, $B9, $76, $08,
    $8A, $F4, $4D, $33, $B1, $CF, $EC, $92, $10, $6E, $D7, $A9, $2B, $55, $9A,
    $E4, $66, $18, $A1, $DF, $5D, $23, $1B, $65, $E7, $99, $20, $5E, $DC, $A2,
    $6D, $13, $91, $EF, $56, $28, $AA, $D4, $F7, $89, $0B, $75, $CC, $B2, $30,
    $4E, $81, $FF, $7D, $03, $BA, $C4, $46, $38, $36, $48, $CA, $B4, $0D, $73,
    $F1, $8F, $40, $3E, $BC, $C2, $7B, $05, $87, $F9, $DA, $A4, $26, $58, $E1,
    $9F, $1D, $63, $AC, $D2, $50, $2E, $97, $E9, $6B, $15, $2D, $53, $D1, $AF,
    $16, $68, $EA, $94, $5B, $25, $A7, $D9, $60, $1E, $9C, $E2, $C1, $BF, $3D,
    $43, $FA, $84, $06, $78, $B7, $C9, $4B, $35, $8C, $F2, $70, $0E, $6C, $12,
    $90, $EE, $57, $29, $AB, $D5, $1A, $64, $E6, $98, $21, $5F, $DD, $A3, $80,
    $FE, $7C, $02, $BB, $C5, $47, $39, $F6, $88, $0A, $74, $CD, $B3, $31, $4F,
    $77, $09, $8B, $F5, $4C, $32, $B0, $CE, $01, $7F, $FD, $83, $3A, $44, $C6,
    $B8, $9B, $E5, $67, $19, $A0, $DE, $5C, $22, $ED, $93, $11, $6F, $D6, $A8,
    $2A, $54, $5A, $24, $A6, $D8, $61, $1F, $9D, $E3, $2C, $52, $D0, $AE, $17,
    $69, $EB, $95, $B6, $C8, $4A, $34, $8D, $F3, $71, $0F, $C0, $BE, $3C, $42,
    $FB, $85, $07, $79, $41, $3F, $BD, $C3, $7A, $04, $86, $F8, $37, $49, $CB,
    $B5, $0C, $72, $F0, $8E, $AD, $D3, $51, $2F, $96, $E8, $6A, $14, $DB, $A5,
    $27, $59, $E0, $9E, $1C, $62, $00, $7F, $FE, $81, $3F, $40, $C1, $BE, $7E,
    $01, $80, $FF, $41, $3E, $BF, $C0, $FC, $83, $02, $7D, $C3, $BC, $3D, $42,
    $82, $FD, $7C, $03, $BD, $C2, $43, $3C, $3B, $44, $C5, $BA, $04, $7B, $FA,
    $85, $45, $3A, $BB, $C4, $7A, $05, $84, $FB, $C7, $B8, $39, $46, $F8, $87,
    $06, $79, $B9, $C6, $47, $38, $86, $F9, $78, $07, $76, $09, $88, $F7, $49,
    $36, $B7, $C8, $08, $77, $F6, $89, $37, $48, $C9, $B6, $8A, $F5, $74, $0B,
    $B5, $CA, $4B, $34, $F4, $8B, $0A, $75, $CB, $B4, $35, $4A, $4D, $32, $B3,
    $CC, $72, $0D, $8C, $F3, $33, $4C, $CD, $B2, $0C, $73, $F2, $8D, $B1, $CE,
    $4F, $30, $8E, $F1, $70, $0F, $CF, $B0, $31, $4E, $F0, $8F, $0E, $71, $EC,
    $93, $12, $6D, $D3, $AC, $2D, $52, $92, $ED, $6C, $13, $AD, $D2, $53, $2C,
    $10, $6F, $EE, $91, $2F, $50, $D1, $AE, $6E, $11, $90, $EF, $51, $2E, $AF,
    $D0, $D7, $A8, $29, $56, $E8, $97, $16, $69, $A9, $D6, $57, $28, $96, $E9,
    $68, $17, $2B, $54, $D5, $AA, $14, $6B, $EA, $95, $55, $2A, $AB, $D4, $6A,
    $15, $94, $EB, $9A, $E5, $64, $1B, $A5, $DA, $5B, $24, $E4, $9B, $1A, $65,
    $DB, $A4, $25, $5A, $66, $19, $98, $E7, $59, $26, $A7, $D8, $18, $67, $E6,
    $99, $27, $58, $D9, $A6, $A1, $DE, $5F, $20, $9E, $E1, $60, $1F, $DF, $A0,
    $21, $5E, $E0, $9F, $1E, $61, $5D, $22, $A3, $DC, $62, $1D, $9C, $E3, $23,
    $5C, $DD, $A2, $1C, $63, $E2, $9D, $00, $80, $C3, $43, $45, $C5, $86, $06,
    $8A, $0A, $49, $C9, $CF, $4F, $0C, $8C, $D7, $57, $14, $94, $92, $12, $51,
    $D1, $5D, $DD, $9E, $1E, $18, $98, $DB, $5B, $6D, $ED, $AE, $2E, $28, $A8,
    $EB, $6B, $E7, $67, $24, $A4, $A2, $22, $61, $E1, $BA, $3A, $79, $F9, $FF,
    $7F, $3C, $BC, $30, $B0, $F3, $73, $75, $F5, $B6, $36, $DA, $5A, $19, $99,
    $9F, $1F, $5C, $DC, $50, $D0, $93, $13, $15, $95, $D6, $56, $0D, $8D, $CE,
    $4E, $48, $C8, $8B, $0B, $87, $07, $44, $C4, $C2, $42, $01, $81, $B7, $37,
    $74, $F4, $F2, $72, $31, $B1, $3D, $BD, $FE, $7E, $78, $F8, $BB, $3B, $60,
    $E0, $A3, $23, $25, $A5, $E6, $66, $EA, $6A, $29, $A9, $AF, $2F, $6C, $EC,
    $77, $F7, $B4, $34, $32, $B2, $F1, $71, $FD, $7D, $3E, $BE, $B8, $38, $7B,
    $FB, $A0, $20, $63, $E3, $E5, $65, $26, $A6, $2A, $AA, $E9, $69, $6F, $EF,
    $AC, $2C, $1A, $9A, $D9, $59, $5F, $DF, $9C, $1C, $90, $10, $53, $D3, $D5,
    $55, $16, $96, $CD, $4D, $0E, $8E, $88, $08, $4B, $CB, $47, $C7, $84, $04,
    $02, $82, $C1, $41, $AD, $2D, $6E, $EE, $E8, $68, $2B, $AB, $27, $A7, $E4,
    $64, $62, $E2, $A1, $21, $7A, $FA, $B9, $39, $3F, $BF, $FC, $7C, $F0, $70,
    $33, $B3, $B5, $35, $76, $F6, $C0, $40, $03, $83, $85, $05, $46, $C6, $4A,
    $CA, $89, $09, $0F, $8F, $CC, $4C, $17, $97, $D4, $54, $52, $D2, $91, $11,
    $9D, $1D, $5E, $DE, $D8, $58, $1B, $9B, $00, $81, $C1, $40, $41, $C0, $80,
    $01, $82, $03, $43, $C2, $C3, $42, $02, $83, $C7, $46, $06, $87, $86, $07,
    $47, $C6, $45, $C4, $84, $05, $04, $85, $C5, $44, $4D, $CC, $8C, $0D, $0C,
    $8D, $CD, $4C, $CF, $4E, $0E, $8F, $8E, $0F, $4F, $CE, $8A, $0B, $4B, $CA,
    $CB, $4A, $0A, $8B, $08, $89, $C9, $48, $49, $C8, $88, $09, $9A, $1B, $5B,
    $DA, $DB, $5A, $1A, $9B, $18, $99, $D9, $58, $59, $D8, $98, $19, $5D, $DC,
    $9C, $1D, $1C, $9D, $DD, $5C, $DF, $5E, $1E, $9F, $9E, $1F, $5F, $DE, $D7,
    $56, $16, $97, $96, $17, $57, $D6, $55, $D4, $94, $15, $14, $95, $D5, $54,
    $10, $91, $D1, $50, $51, $D0, $90, $11, $92, $13, $53, $D2, $D3, $52, $12,
    $93, $F7, $76, $36, $B7, $B6, $37, $77, $F6, $75, $F4, $B4, $35, $34, $B5,
    $F5, $74, $30, $B1, $F1, $70, $71, $F0, $B0, $31, $B2, $33, $73, $F2, $F3,
    $72, $32, $B3, $BA, $3B, $7B, $FA, $FB, $7A, $3A, $BB, $38, $B9, $F9, $78,
    $79, $F8, $B8, $39, $7D, $FC, $BC, $3D, $3C, $BD, $FD, $7C, $FF, $7E, $3E,
    $BF, $BE, $3F, $7F, $FE, $6D, $EC, $AC, $2D, $2C, $AD, $ED, $6C, $EF, $6E,
    $2E, $AF, $AE, $2F, $6F, $EE, $AA, $2B, $6B, $EA, $EB, $6A, $2A, $AB, $28,
    $A9, $E9, $68, $69, $E8, $A8, $29, $20, $A1, $E1, $60, $61, $E0, $A0, $21,
    $A2, $23, $63, $E2, $E3, $62, $22, $A3, $E7, $66, $26, $A7, $A6, $27, $67,
    $E6, $65, $E4, $A4, $25, $24, $A5, $E5, $64, $00, $82, $C7, $45, $4D, $CF,
    $8A, $08, $9A, $18, $5D, $DF, $D7, $55, $10, $92, $F7, $75, $30, $B2, $BA,
    $38, $7D, $FF, $6D, $EF, $AA, $28, $20, $A2, $E7, $65, $2D, $AF, $EA, $68,
    $60, $E2, $A7, $25, $B7, $35, $70, $F2, $FA, $78, $3D, $BF, $DA, $58, $1D,
    $9F, $97, $15, $50, $D2, $40, $C2, $87, $05, $0D, $8F, $CA, $48, $5A, $D8,
    $9D, $1F, $17, $95, $D0, $52, $C0, $42, $07, $85, $8D, $0F, $4A, $C8, $AD,
    $2F, $6A, $E8, $E0, $62, $27, $A5, $37, $B5, $F0, $72, $7A, $F8, $BD, $3F,
    $77, $F5, $B0, $32, $3A, $B8, $FD, $7F, $ED, $6F, $2A, $A8, $A0, $22, $67,
    $E5, $80, $02, $47, $C5, $CD, $4F, $0A, $88, $1A, $98, $DD, $5F, $57, $D5,
    $90, $12, $B4, $36, $73, $F1, $F9, $7B, $3E, $BC, $2E, $AC, $E9, $6B, $63,
    $E1, $A4, $26, $43, $C1, $84, $06, $0E, $8C, $C9, $4B, $D9, $5B, $1E, $9C,
    $94, $16, $53, $D1, $99, $1B, $5E, $DC, $D4, $56, $13, $91, $03, $81, $C4,
    $46, $4E, $CC, $89, $0B, $6E, $EC, $A9, $2B, $23, $A1, $E4, $66, $F4, $76,
    $33, $B1, $B9, $3B, $7E, $FC, $EE, $6C, $29, $AB, $A3, $21, $64, $E6, $74,
    $F6, $B3, $31, $39, $BB, $FE, $7C, $19, $9B, $DE, $5C, $54, $D6, $93, $11,
    $83, $01, $44, $C6, $CE, $4C, $09, $8B, $C3, $41, $04, $86, $8E, $0C, $49,
    $CB, $59, $DB, $9E, $1C, $14, $96, $D3, $51, $34, $B6, $F3, $71, $79, $FB,
    $BE, $3C, $AE, $2C, $69, $EB, $E3, $61, $24, $A6, $00, $83, $C5, $46, $49,
    $CA, $8C, $0F, $92, $11, $57, $D4, $DB, $58, $1E, $9D, $E7, $64, $22, $A1,
    $AE, $2D, $6B, $E8, $75, $F6, $B0, $33, $3C, $BF, $F9, $7A, $0D, $8E, $C8,
    $4B, $44, $C7, $81, $02, $9F, $1C, $5A, $D9, $D6, $55, $13, $90, $EA, $69,
    $2F, $AC, $A3, $20, $66, $E5, $78, $FB, $BD, $3E, $31, $B2, $F4, $77, $1A,
    $99, $DF, $5C, $53, $D0, $96, $15, $88, $0B, $4D, $CE, $C1, $42, $04, $87,
    $FD, $7E, $38, $BB, $B4, $37, $71, $F2, $6F, $EC, $AA, $29, $26, $A5, $E3,
    $60, $17, $94, $D2, $51, $5E, $DD, $9B, $18, $85, $06, $40, $C3, $CC, $4F,
    $09, $8A, $F0, $73, $35, $B6, $B9, $3A, $7C, $FF, $62, $E1, $A7, $24, $2B,
    $A8, $EE, $6D, $34, $B7, $F1, $72, $7D, $FE, $B8, $3B, $A6, $25, $63, $E0,
    $EF, $6C, $2A, $A9, $D3, $50, $16, $95, $9A, $19, $5F, $DC, $41, $C2, $84,
    $07, $08, $8B, $CD, $4E, $39, $BA, $FC, $7F, $70, $F3, $B5, $36, $AB, $28,
    $6E, $ED, $E2, $61, $27, $A4, $DE, $5D, $1B, $98, $97, $14, $52, $D1, $4C,
    $CF, $89, $0A, $05, $86, $C0, $43, $2E, $AD, $EB, $68, $67, $E4, $A2, $21,
    $BC, $3F, $79, $FA, $F5, $76, $30, $B3, $C9, $4A, $0C, $8F, $80, $03, $45,
    $C6, $5B, $D8, $9E, $1D, $12, $91, $D7, $54, $23, $A0, $E6, $65, $6A, $E9,
    $AF, $2C, $B1, $32, $74, $F7, $F8, $7B, $3D, $BE, $C4, $47, $01, $82, $8D,
    $0E, $48, $CB, $56, $D5, $93, $10, $1F, $9C, $DA, $59, $00, $84, $CB, $4F,
    $55, $D1, $9E, $1A, $AA, $2E, $61, $E5, $FF, $7B, $34, $B0, $97, $13, $5C,
    $D8, $C2, $46, $09, $8D, $3D, $B9, $F6, $72, $68, $EC, $A3, $27, $ED, $69,
    $26, $A2, $B8, $3C, $73, $F7, $47, $C3, $8C, $08, $12, $96, $D9, $5D, $7A,
    $FE, $B1, $35, $2F, $AB, $E4, $60, $D0, $54, $1B, $9F, $85, $01, $4E, $CA,
    $19, $9D, $D2, $56, $4C, $C8, $87, $03, $B3, $37, $78, $FC, $E6, $62, $2D,
    $A9, $8E, $0A, $45, $C1, $DB, $5F, $10, $94, $24, $A0, $EF, $6B, $71, $F5,
    $BA, $3E, $F4, $70, $3F, $BB, $A1, $25, $6A, $EE, $5E, $DA, $95, $11, $0B,
    $8F, $C0, $44, $63, $E7, $A8, $2C, $36, $B2, $FD, $79, $C9, $4D, $02, $86,
    $9C, $18, $57, $D3, $32, $B6, $F9, $7D, $67, $E3, $AC, $28, $98, $1C, $53,
    $D7, $CD, $49, $06, $82, $A5, $21, $6E, $EA, $F0, $74, $3B, $BF, $0F, $8B,
    $C4, $40, $5A, $DE, $91, $15, $DF, $5B, $14, $90, $8A, $0E, $41, $C5, $75,
    $F1, $BE, $3A, $20, $A4, $EB, $6F, $48, $CC, $83, $07, $1D, $99, $D6, $52,
    $E2, $66, $29, $AD, $B7, $33, $7C, $F8, $2B, $AF, $E0, $64, $7E, $FA, $B5,
    $31, $81, $05, $4A, $CE, $D4, $50, $1F, $9B, $BC, $38, $77, $F3, $E9, $6D,
    $22, $A6, $16, $92, $DD, $59, $43, $C7, $88, $0C, $C6, $42, $0D, $89, $93,
    $17, $58, $DC, $6C, $E8, $A7, $23, $39, $BD, $F2, $76, $51, $D5, $9A, $1E,
    $04, $80, $CF, $4B, $FB, $7F, $30, $B4, $AE, $2A, $65, $E1, $00, $85, $C9,
    $4C, $51, $D4, $98, $1D, $A2, $27, $6B, $EE, $F3, $76, $3A, $BF, $87, $02,
    $4E, $CB, $D6, $53, $1F, $9A, $25, $A0, $EC, $69, $74, $F1, $BD, $38, $CD,
    $48, $04, $81, $9C, $19, $55, $D0, $6F, $EA, $A6, $23, $3E, $BB, $F7, $72,
    $4A, $CF, $83, $06, $1B, $9E, $D2, $57, $E8, $6D, $21, $A4, $B9, $3C, $70,
    $F5, $59, $DC, $90, $15, $08, $8D, $C1, $44, $FB, $7E, $32, $B7, $AA, $2F,
    $63, $E6, $DE, $5B, $17, $92, $8F, $0A, $46, $C3, $7C, $F9, $B5, $30, $2D,
    $A8, $E4, $61, $94, $11, $5D, $D8, $C5, $40, $0C, $89, $36, $B3, $FF, $7A,
    $67, $E2, $AE, $2B, $13, $96, $DA, $5F, $42, $C7, $8B, $0E, $B1, $34, $78,
    $FD, $E0, $65, $29, $AC, $B2, $37, $7B, $FE, $E3, $66, $2A, $AF, $10, $95,
    $D9, $5C, $41, $C4, $88, $0D, $35, $B0, $FC, $79, $64, $E1, $AD, $28, $97,
    $12, $5E, $DB, $C6, $43, $0F, $8A, $7F, $FA, $B6, $33, $2E, $AB, $E7, $62,
    $DD, $58, $14, $91, $8C, $09, $45, $C0, $F8, $7D, $31, $B4, $A9, $2C, $60,
    $E5, $5A, $DF, $93, $16, $0B, $8E, $C2, $47, $EB, $6E, $22, $A7, $BA, $3F,
    $73, $F6, $49, $CC, $80, $05, $18, $9D, $D1, $54, $6C, $E9, $A5, $20, $3D,
    $B8, $F4, $71, $CE, $4B, $07, $82, $9F, $1A, $56, $D3, $26, $A3, $EF, $6A,
    $77, $F2, $BE, $3B, $84, $01, $4D, $C8, $D5, $50, $1C, $99, $A1, $24, $68,
    $ED, $F0, $75, $39, $BC, $03, $86, $CA, $4F, $52, $D7, $9B, $1E, $00, $86,
    $CF, $49, $5D, $DB, $92, $14, $BA, $3C, $75, $F3, $E7, $61, $28, $AE, $B7,
    $31, $78, $FE, $EA, $6C, $25, $A3, $0D, $8B, $C2, $44, $50, $D6, $9F, $19,
    $AD, $2B, $62, $E4, $F0, $76, $3F, $B9, $17, $91, $D8, $5E, $4A, $CC, $85,
    $03, $1A, $9C, $D5, $53, $47, $C1, $88, $0E, $A0, $26, $6F, $E9, $FD, $7B,
    $32, $B4, $99, $1F, $56, $D0, $C4, $42, $0B, $8D, $23, $A5, $EC, $6A, $7E,
    $F8, $B1, $37, $2E, $A8, $E1, $67, $73, $F5, $BC, $3A, $94, $12, $5B, $DD,
    $C9, $4F, $06, $80, $34, $B2, $FB, $7D, $69, $EF, $A6, $20, $8E, $08, $41,
    $C7, $D3, $55, $1C, $9A, $83, $05, $4C, $CA, $DE, $58, $11, $97, $39, $BF,
    $F6, $70, $64, $E2, $AB, $2D, $F1, $77, $3E, $B8, $AC, $2A, $63, $E5, $4B,
    $CD, $84, $02, $16, $90, $D9, $5F, $46, $C0, $89, $0F, $1B, $9D, $D4, $52,
    $FC, $7A, $33, $B5, $A1, $27, $6E, $E8, $5C, $DA, $93, $15, $01, $87, $CE,
    $48, $E6, $60, $29, $AF, $BB, $3D, $74, $F2, $EB, $6D, $24, $A2, $B6, $30,
    $79, $FF, $51, $D7, $9E, $18, $0C, $8A, $C3, $45, $68, $EE, $A7, $21, $35,
    $B3, $FA, $7C, $D2, $54, $1D, $9B, $8F, $09, $40, $C6, $DF, $59, $10, $96,
    $82, $04, $4D, $CB, $65, $E3, $AA, $2C, $38, $BE, $F7, $71, $C5, $43, $0A,
    $8C, $98, $1E, $57, $D1, $7F, $F9, $B0, $36, $22, $A4, $ED, $6B, $72, $F4,
    $BD, $3B, $2F, $A9, $E0, $66, $C8, $4E, $07, $81, $95, $13, $5A, $DC, $00,
    $87, $CD, $4A, $59, $DE, $94, $13, $B2, $35, $7F, $F8, $EB, $6C, $26, $A1,
    $A7, $20, $6A, $ED, $FE, $79, $33, $B4, $15, $92, $D8, $5F, $4C, $CB, $81,
    $06, $8D, $0A, $40, $C7, $D4, $53, $19, $9E, $3F, $B8, $F2, $75, $66, $E1,
    $AB, $2C, $2A, $AD, $E7, $60, $73, $F4, $BE, $39, $98, $1F, $55, $D2, $C1,
    $46, $0C, $8B, $D9, $5E, $14, $93, $80, $07, $4D, $CA, $6B, $EC, $A6, $21,
    $32, $B5, $FF, $78, $7E, $F9, $B3, $34, $27, $A0, $EA, $6D, $CC, $4B, $01,
    $86, $95, $12, $58, $DF, $54, $D3, $99, $1E, $0D, $8A, $C0, $47, $E6, $61,
    $2B, $AC, $BF, $38, $72, $F5, $F3, $74, $3E, $B9, $AA, $2D, $67, $E0, $41,
    $C6, $8C, $0B, $18, $9F, $D5, $52, $71, $F6, $BC, $3B, $28, $AF, $E5, $62,
    $C3, $44, $0E, $89, $9A, $1D, $57, $D0, $D6, $51, $1B, $9C, $8F, $08, $42,
    $C5, $64, $E3, $A9, $2E, $3D, $BA, $F0, $77, $FC, $7B, $31, $B6, $A5, $22,
    $68, $EF, $4E, $C9, $83, $04, $17, $90, $DA, $5D, $5B, $DC, $96, $11, $02,
    $85, $CF, $48, $E9, $6E, $24, $A3, $B0, $37, $7D, $FA, $A8, $2F, $65, $E2,
    $F1, $76, $3C, $BB, $1A, $9D, $D7, $50, $43, $C4, $8E, $09, $0F, $88, $C2,
    $45, $56, $D1, $9B, $1C, $BD, $3A, $70, $F7, $E4, $63, $29, $AE, $25, $A2,
    $E8, $6F, $7C, $FB, $B1, $36, $97, $10, $5A, $DD, $CE, $49, $03, $84, $82,
    $05, $4F, $C8, $DB, $5C, $16, $91, $30, $B7, $FD, $7A, $69, $EE, $A4, $23,
    $00, $88, $D3, $5B, $65, $ED, $B6, $3E, $CA, $42, $19, $91, $AF, $27, $7C,
    $F4, $57, $DF, $84, $0C, $32, $BA, $E1, $69, $9D, $15, $4E, $C6, $F8, $70,
    $2B, $A3, $AE, $26, $7D, $F5, $CB, $43, $18, $90, $64, $EC, $B7, $3F, $01,
    $89, $D2, $5A, $F9, $71, $2A, $A2, $9C, $14, $4F, $C7, $33, $BB, $E0, $68,
    $56, $DE, $85, $0D, $9F, $17, $4C, $C4, $FA, $72, $29, $A1, $55, $DD, $86,
    $0E, $30, $B8, $E3, $6B, $C8, $40, $1B, $93, $AD, $25, $7E, $F6, $02, $8A,
    $D1, $59, $67, $EF, $B4, $3C, $31, $B9, $E2, $6A, $54, $DC, $87, $0F, $FB,
    $73, $28, $A0, $9E, $16, $4D, $C5, $66, $EE, $B5, $3D, $03, $8B, $D0, $58,
    $AC, $24, $7F, $F7, $C9, $41, $1A, $92, $FD, $75, $2E, $A6, $98, $10, $4B,
    $C3, $37, $BF, $E4, $6C, $52, $DA, $81, $09, $AA, $22, $79, $F1, $CF, $47,
    $1C, $94, $60, $E8, $B3, $3B, $05, $8D, $D6, $5E, $53, $DB, $80, $08, $36,
    $BE, $E5, $6D, $99, $11, $4A, $C2, $FC, $74, $2F, $A7, $04, $8C, $D7, $5F,
    $61, $E9, $B2, $3A, $CE, $46, $1D, $95, $AB, $23, $78, $F0, $62, $EA, $B1,
    $39, $07, $8F, $D4, $5C, $A8, $20, $7B, $F3, $CD, $45, $1E, $96, $35, $BD,
    $E6, $6E, $50, $D8, $83, $0B, $FF, $77, $2C, $A4, $9A, $12, $49, $C1, $CC,
    $44, $1F, $97, $A9, $21, $7A, $F2, $06, $8E, $D5, $5D, $63, $EB, $B0, $38,
    $9B, $13, $48, $C0, $FE, $76, $2D, $A5, $51, $D9, $82, $0A, $34, $BC, $E7,
    $6F, $00, $89, $D1, $58, $61, $E8, $B0, $39, $C2, $4B, $13, $9A, $A3, $2A,
    $72, $FB, $47, $CE, $96, $1F, $26, $AF, $F7, $7E, $85, $0C, $54, $DD, $E4,
    $6D, $35, $BC, $8E, $07, $5F, $D6, $EF, $66, $3E, $B7, $4C, $C5, $9D, $14,
    $2D, $A4, $FC, $75, $C9, $40, $18, $91, $A8, $21, $79, $F0, $0B, $82, $DA,
    $53, $6A, $E3, $BB, $32, $DF, $56, $0E, $87, $BE, $37, $6F, $E6, $1D, $94,
    $CC, $45, $7C, $F5, $AD, $24, $98, $11, $49, $C0, $F9, $70, $28, $A1, $5A,
    $D3, $8B, $02, $3B, $B2, $EA, $63, $51, $D8, $80, $09, $30, $B9, $E1, $68,
    $93, $1A, $42, $CB, $F2, $7B, $23, $AA, $16, $9F, $C7, $4E, $77, $FE, $A6,
    $2F, $D4, $5D, $05, $8C, $B5, $3C, $64, $ED, $7D, $F4, $AC, $25, $1C, $95,
    $CD, $44, $BF, $36, $6E, $E7, $DE, $57, $0F, $86, $3A, $B3, $EB, $62, $5B,
    $D2, $8A, $03, $F8, $71, $29, $A0, $99, $10, $48, $C1, $F3, $7A, $22, $AB,
    $92, $1B, $43, $CA, $31, $B8, $E0, $69, $50, $D9, $81, $08, $B4, $3D, $65,
    $EC, $D5, $5C, $04, $8D, $76, $FF, $A7, $2E, $17, $9E, $C6, $4F, $A2, $2B,
    $73, $FA, $C3, $4A, $12, $9B, $60, $E9, $B1, $38, $01, $88, $D0, $59, $E5,
    $6C, $34, $BD, $84, $0D, $55, $DC, $27, $AE, $F6, $7F, $46, $CF, $97, $1E,
    $2C, $A5, $FD, $74, $4D, $C4, $9C, $15, $EE, $67, $3F, $B6, $8F, $06, $5E,
    $D7, $6B, $E2, $BA, $33, $0A, $83, $DB, $52, $A9, $20, $78, $F1, $C8, $41,
    $19, $90, $00, $8A, $D7, $5D, $6D, $E7, $BA, $30, $DA, $50, $0D, $87, $B7,
    $3D, $60, $EA, $77, $FD, $A0, $2A, $1A, $90, $CD, $47, $AD, $27, $7A, $F0,
    $C0, $4A, $17, $9D, $EE, $64, $39, $B3, $83, $09, $54, $DE, $34, $BE, $E3,
    $69, $59, $D3, $8E, $04, $99, $13, $4E, $C4, $F4, $7E, $23, $A9, $43, $C9,
    $94, $1E, $2E, $A4, $F9, $73, $1F, $95, $C8, $42, $72, $F8, $A5, $2F, $C5,
    $4F, $12, $98, $A8, $22, $7F, $F5, $68, $E2, $BF, $35, $05, $8F, $D2, $58,
    $B2, $38, $65, $EF, $DF, $55, $08, $82, $F1, $7B, $26, $AC, $9C, $16, $4B,
    $C1, $2B, $A1, $FC, $76, $46, $CC, $91, $1B, $86, $0C, $51, $DB, $EB, $61,
    $3C, $B6, $5C, $D6, $8B, $01, $31, $BB, $E6, $6C, $3E, $B4, $E9, $63, $53,
    $D9, $84, $0E, $E4, $6E, $33, $B9, $89, $03, $5E, $D4, $49, $C3, $9E, $14,
    $24, $AE, $F3, $79, $93, $19, $44, $CE, $FE, $74, $29, $A3, $D0, $5A, $07,
    $8D, $BD, $37, $6A, $E0, $0A, $80, $DD, $57, $67, $ED, $B0, $3A, $A7, $2D,
    $70, $FA, $CA, $40, $1D, $97, $7D, $F7, $AA, $20, $10, $9A, $C7, $4D, $21,
    $AB, $F6, $7C, $4C, $C6, $9B, $11, $FB, $71, $2C, $A6, $96, $1C, $41, $CB,
    $56, $DC, $81, $0B, $3B, $B1, $EC, $66, $8C, $06, $5B, $D1, $E1, $6B, $36,
    $BC, $CF, $45, $18, $92, $A2, $28, $75, $FF, $15, $9F, $C2, $48, $78, $F2,
    $AF, $25, $B8, $32, $6F, $E5, $D5, $5F, $02, $88, $62, $E8, $B5, $3F, $0F,
    $85, $D8, $52, $00, $8B, $D5, $5E, $69, $E2, $BC, $37, $D2, $59, $07, $8C,
    $BB, $30, $6E, $E5, $67, $EC, $B2, $39, $0E, $85, $DB, $50, $B5, $3E, $60,
    $EB, $DC, $57, $09, $82, $CE, $45, $1B, $90, $A7, $2C, $72, $F9, $1C, $97,
    $C9, $42, $75, $FE, $A0, $2B, $A9, $22, $7C, $F7, $C0, $4B, $15, $9E, $7B,
    $F0, $AE, $25, $12, $99, $C7, $4C, $5F, $D4, $8A, $01, $36, $BD, $E3, $68,
    $8D, $06, $58, $D3, $E4, $6F, $31, $BA, $38, $B3, $ED, $66, $51, $DA, $84,
    $0F, $EA, $61, $3F, $B4, $83, $08, $56, $DD, $91, $1A, $44, $CF, $F8, $73,
    $2D, $A6, $43, $C8, $96, $1D, $2A, $A1, $FF, $74, $F6, $7D, $23, $A8, $9F,
    $14, $4A, $C1, $24, $AF, $F1, $7A, $4D, $C6, $98, $13, $BE, $35, $6B, $E0,
    $D7, $5C, $02, $89, $6C, $E7, $B9, $32, $05, $8E, $D0, $5B, $D9, $52, $0C,
    $87, $B0, $3B, $65, $EE, $0B, $80, $DE, $55, $62, $E9, $B7, $3C, $70, $FB,
    $A5, $2E, $19, $92, $CC, $47, $A2, $29, $77, $FC, $CB, $40, $1E, $95, $17,
    $9C, $C2, $49, $7E, $F5, $AB, $20, $C5, $4E, $10, $9B, $AC, $27, $79, $F2,
    $E1, $6A, $34, $BF, $88, $03, $5D, $D6, $33, $B8, $E6, $6D, $5A, $D1, $8F,
    $04, $86, $0D, $53, $D8, $EF, $64, $3A, $B1, $54, $DF, $81, $0A, $3D, $B6,
    $E8, $63, $2F, $A4, $FA, $71, $46, $CD, $93, $18, $FD, $76, $28, $A3, $94,
    $1F, $41, $CA, $48, $C3, $9D, $16, $21, $AA, $F4, $7F, $9A, $11, $4F, $C4,
    $F3, $78, $26, $AD, $00, $8C, $DB, $57, $75, $F9, $AE, $22, $EA, $66, $31,
    $BD, $9F, $13, $44, $C8, $17, $9B, $CC, $40, $62, $EE, $B9, $35, $FD, $71,
    $26, $AA, $88, $04, $53, $DF, $2E, $A2, $F5, $79, $5B, $D7, $80, $0C, $C4,
    $48, $1F, $93, $B1, $3D, $6A, $E6, $39, $B5, $E2, $6E, $4C, $C0, $97, $1B,
    $D3, $5F, $08, $84, $A6, $2A, $7D, $F1, $5C, $D0, $87, $0B, $29, $A5, $F2,
    $7E, $B6, $3A, $6D, $E1, $C3, $4F, $18, $94, $4B, $C7, $90, $1C, $3E, $B2,
    $E5, $69, $A1, $2D, $7A, $F6, $D4, $58, $0F, $83, $72, $FE, $A9, $25, $07,
    $8B, $DC, $50, $98, $14, $43, $CF, $ED, $61, $36, $BA, $65, $E9, $BE, $32,
    $10, $9C, $CB, $47, $8F, $03, $54, $D8, $FA, $76, $21, $AD, $B8, $34, $63,
    $EF, $CD, $41, $16, $9A, $52, $DE, $89, $05, $27, $AB, $FC, $70, $AF, $23,
    $74, $F8, $DA, $56, $01, $8D, $45, $C9, $9E, $12, $30, $BC, $EB, $67, $96,
    $1A, $4D, $C1, $E3, $6F, $38, $B4, $7C, $F0, $A7, $2B, $09, $85, $D2, $5E,
    $81, $0D, $5A, $D6, $F4, $78, $2F, $A3, $6B, $E7, $B0, $3C, $1E, $92, $C5,
    $49, $E4, $68, $3F, $B3, $91, $1D, $4A, $C6, $0E, $82, $D5, $59, $7B, $F7,
    $A0, $2C, $F3, $7F, $28, $A4, $86, $0A, $5D, $D1, $19, $95, $C2, $4E, $6C,
    $E0, $B7, $3B, $CA, $46, $11, $9D, $BF, $33, $64, $E8, $20, $AC, $FB, $77,
    $55, $D9, $8E, $02, $DD, $51, $06, $8A, $A8, $24, $73, $FF, $37, $BB, $EC,
    $60, $42, $CE, $99, $15, $00, $8D, $D9, $54, $71, $FC, $A8, $25, $E2, $6F,
    $3B, $B6, $93, $1E, $4A, $C7, $07, $8A, $DE, $53, $76, $FB, $AF, $22, $E5,
    $68, $3C, $B1, $94, $19, $4D, $C0, $0E, $83, $D7, $5A, $7F, $F2, $A6, $2B,
    $EC, $61, $35, $B8, $9D, $10, $44, $C9, $09, $84, $D0, $5D, $78, $F5, $A1,
    $2C, $EB, $66, $32, $BF, $9A, $17, $43, $CE, $1C, $91, $C5, $48, $6D, $E0,
    $B4, $39, $FE, $73, $27, $AA, $8F, $02, $56, $DB, $1B, $96, $C2, $4F, $6A,
    $E7, $B3, $3E, $F9, $74, $20, $AD, $88, $05, $51, $DC, $12, $9F, $CB, $46,
    $63, $EE, $BA, $37, $F0, $7D, $29, $A4, $81, $0C, $58, $D5, $15, $98, $CC,
    $41, $64, $E9, $BD, $30, $F7, $7A, $2E, $A3, $86, $0B, $5F, $D2, $38, $B5,
    $E1, $6C, $49, $C4, $90, $1D, $DA, $57, $03, $8E, $AB, $26, $72, $FF, $3F,
    $B2, $E6, $6B, $4E, $C3, $97, $1A, $DD, $50, $04, $89, $AC, $21, $75, $F8,
    $36, $BB, $EF, $62, $47, $CA, $9E, $13, $D4, $59, $0D, $80, $A5, $28, $7C,
    $F1, $31, $BC, $E8, $65, $40, $CD, $99, $14, $D3, $5E, $0A, $87, $A2, $2F,
    $7B, $F6, $24, $A9, $FD, $70, $55, $D8, $8C, $01, $C6, $4B, $1F, $92, $B7,
    $3A, $6E, $E3, $23, $AE, $FA, $77, $52, $DF, $8B, $06, $C1, $4C, $18, $95,
    $B0, $3D, $69, $E4, $2A, $A7, $F3, $7E, $5B, $D6, $82, $0F, $C8, $45, $11,
    $9C, $B9, $34, $60, $ED, $2D, $A0, $F4, $79, $5C, $D1, $85, $08, $CF, $42,
    $16, $9B, $BE, $33, $67, $EA, $00, $8E, $DF, $51, $7D, $F3, $A2, $2C, $FA,
    $74, $25, $AB, $87, $09, $58, $D6, $37, $B9, $E8, $66, $4A, $C4, $95, $1B,
    $CD, $43, $12, $9C, $B0, $3E, $6F, $E1, $6E, $E0, $B1, $3F, $13, $9D, $CC,
    $42, $94, $1A, $4B, $C5, $E9, $67, $36, $B8, $59, $D7, $86, $08, $24, $AA,
    $FB, $75, $A3, $2D, $7C, $F2, $DE, $50, $01, $8F, $DC, $52, $03, $8D, $A1,
    $2F, $7E, $F0, $26, $A8, $F9, $77, $5B, $D5, $84, $0A, $EB, $65, $34, $BA,
    $96, $18, $49, $C7, $11, $9F, $CE, $40, $6C, $E2, $B3, $3D, $B2, $3C, $6D,
    $E3, $CF, $41, $10, $9E, $48, $C6, $97, $19, $35, $BB, $EA, $64, $85, $0B,
    $5A, $D4, $F8, $76, $27, $A9, $7F, $F1, $A0, $2E, $02, $8C, $DD, $53, $7B,
    $F5, $A4, $2A, $06, $88, $D9, $57, $81, $0F, $5E, $D0, $FC, $72, $23, $AD,
    $4C, $C2, $93, $1D, $31, $BF, $EE, $60, $B6, $38, $69, $E7, $CB, $45, $14,
    $9A, $15, $9B, $CA, $44, $68, $E6, $B7, $39, $EF, $61, $30, $BE, $92, $1C,
    $4D, $C3, $22, $AC, $FD, $73, $5F, $D1, $80, $0E, $D8, $56, $07, $89, $A5,
    $2B, $7A, $F4, $A7, $29, $78, $F6, $DA, $54, $05, $8B, $5D, $D3, $82, $0C,
    $20, $AE, $FF, $71, $90, $1E, $4F, $C1, $ED, $63, $32, $BC, $6A, $E4, $B5,
    $3B, $17, $99, $C8, $46, $C9, $47, $16, $98, $B4, $3A, $6B, $E5, $33, $BD,
    $EC, $62, $4E, $C0, $91, $1F, $FE, $70, $21, $AF, $83, $0D, $5C, $D2, $04,
    $8A, $DB, $55, $79, $F7, $A6, $28, $00, $8F, $DD, $52, $79, $F6, $A4, $2B,
    $F2, $7D, $2F, $A0, $8B, $04, $56, $D9, $27, $A8, $FA, $75, $5E, $D1, $83,
    $0C, $D5, $5A, $08, $87, $AC, $23, $71, $FE, $4E, $C1, $93, $1C, $37, $B8,
    $EA, $65, $BC, $33, $61, $EE, $C5, $4A, $18, $97, $69, $E6, $B4, $3B, $10,
    $9F, $CD, $42, $9B, $14, $46, $C9, $E2, $6D, $3F, $B0, $9C, $13, $41, $CE,
    $E5, $6A, $38, $B7, $6E, $E1, $B3, $3C, $17, $98, $CA, $45, $BB, $34, $66,
    $E9, $C2, $4D, $1F, $90, $49, $C6, $94, $1B, $30, $BF, $ED, $62, $D2, $5D,
    $0F, $80, $AB, $24, $76, $F9, $20, $AF, $FD, $72, $59, $D6, $84, $0B, $F5,
    $7A, $28, $A7, $8C, $03, $51, $DE, $07, $88, $DA, $55, $7E, $F1, $A3, $2C,
    $FB, $74, $26, $A9, $82, $0D, $5F, $D0, $09, $86, $D4, $5B, $70, $FF, $AD,
    $22, $DC, $53, $01, $8E, $A5, $2A, $78, $F7, $2E, $A1, $F3, $7C, $57, $D8,
    $8A, $05, $B5, $3A, $68, $E7, $CC, $43, $11, $9E, $47, $C8, $9A, $15, $3E,
    $B1, $E3, $6C, $92, $1D, $4F, $C0, $EB, $64, $36, $B9, $60, $EF, $BD, $32,
    $19, $96, $C4, $4B, $67, $E8, $BA, $35, $1E, $91, $C3, $4C, $95, $1A, $48,
    $C7, $EC, $63, $31, $BE, $40, $CF, $9D, $12, $39, $B6, $E4, $6B, $B2, $3D,
    $6F, $E0, $CB, $44, $16, $99, $29, $A6, $F4, $7B, $50, $DF, $8D, $02, $DB,
    $54, $06, $89, $A2, $2D, $7F, $F0, $0E, $81, $D3, $5C, $77, $F8, $AA, $25,
    $FC, $73, $21, $AE, $85, $0A, $58, $D7, $00, $90, $E3, $73, $05, $95, $E6,
    $76, $0A, $9A, $E9, $79, $0F, $9F, $EC, $7C, $14, $84, $F7, $67, $11, $81,
    $F2, $62, $1E, $8E, $FD, $6D, $1B, $8B, $F8, $68, $28, $B8, $CB, $5B, $2D,
    $BD, $CE, $5E, $22, $B2, $C1, $51, $27, $B7, $C4, $54, $3C, $AC, $DF, $4F,
    $39, $A9, $DA, $4A, $36, $A6, $D5, $45, $33, $A3, $D0, $40, $50, $C0, $B3,
    $23, $55, $C5, $B6, $26, $5A, $CA, $B9, $29, $5F, $CF, $BC, $2C, $44, $D4,
    $A7, $37, $41, $D1, $A2, $32, $4E, $DE, $AD, $3D, $4B, $DB, $A8, $38, $78,
    $E8, $9B, $0B, $7D, $ED, $9E, $0E, $72, $E2, $91, $01, $77, $E7, $94, $04,
    $6C, $FC, $8F, $1F, $69, $F9, $8A, $1A, $66, $F6, $85, $15, $63, $F3, $80,
    $10, $A0, $30, $43, $D3, $A5, $35, $46, $D6, $AA, $3A, $49, $D9, $AF, $3F,
    $4C, $DC, $B4, $24, $57, $C7, $B1, $21, $52, $C2, $BE, $2E, $5D, $CD, $BB,
    $2B, $58, $C8, $88, $18, $6B, $FB, $8D, $1D, $6E, $FE, $82, $12, $61, $F1,
    $87, $17, $64, $F4, $9C, $0C, $7F, $EF, $99, $09, $7A, $EA, $96, $06, $75,
    $E5, $93, $03, $70, $E0, $F0, $60, $13, $83, $F5, $65, $16, $86, $FA, $6A,
    $19, $89, $FF, $6F, $1C, $8C, $E4, $74, $07, $97, $E1, $71, $02, $92, $EE,
    $7E, $0D, $9D, $EB, $7B, $08, $98, $D8, $48, $3B, $AB, $DD, $4D, $3E, $AE,
    $D2, $42, $31, $A1, $D7, $47, $34, $A4, $CC, $5C, $2F, $BF, $C9, $59, $2A,
    $BA, $C6, $56, $25, $B5, $C3, $53, $20, $B0, $00, $91, $E1, $70, $01, $90,
    $E0, $71, $02, $93, $E3, $72, $03, $92, $E2, $73, $04, $95, $E5, $74, $05,
    $94, $E4, $75, $06, $97, $E7, $76, $07, $96, $E6, $77, $08, $99, $E9, $78,
    $09, $98, $E8, $79, $0A, $9B, $EB, $7A, $0B, $9A, $EA, $7B, $0C, $9D, $ED,
    $7C, $0D, $9C, $EC, $7D, $0E, $9F, $EF, $7E, $0F, $9E, $EE, $7F, $10, $81,
    $F1, $60, $11, $80, $F0, $61, $12, $83, $F3, $62, $13, $82, $F2, $63, $14,
    $85, $F5, $64, $15, $84, $F4, $65, $16, $87, $F7, $66, $17, $86, $F6, $67,
    $18, $89, $F9, $68, $19, $88, $F8, $69, $1A, $8B, $FB, $6A, $1B, $8A, $FA,
    $6B, $1C, $8D, $FD, $6C, $1D, $8C, $FC, $6D, $1E, $8F, $FF, $6E, $1F, $8E,
    $FE, $6F, $20, $B1, $C1, $50, $21, $B0, $C0, $51, $22, $B3, $C3, $52, $23,
    $B2, $C2, $53, $24, $B5, $C5, $54, $25, $B4, $C4, $55, $26, $B7, $C7, $56,
    $27, $B6, $C6, $57, $28, $B9, $C9, $58, $29, $B8, $C8, $59, $2A, $BB, $CB,
    $5A, $2B, $BA, $CA, $5B, $2C, $BD, $CD, $5C, $2D, $BC, $CC, $5D, $2E, $BF,
    $CF, $5E, $2F, $BE, $CE, $5F, $30, $A1, $D1, $40, $31, $A0, $D0, $41, $32,
    $A3, $D3, $42, $33, $A2, $D2, $43, $34, $A5, $D5, $44, $35, $A4, $D4, $45,
    $36, $A7, $D7, $46, $37, $A6, $D6, $47, $38, $A9, $D9, $48, $39, $A8, $D8,
    $49, $3A, $AB, $DB, $4A, $3B, $AA, $DA, $4B, $3C, $AD, $DD, $4C, $3D, $AC,
    $DC, $4D, $3E, $AF, $DF, $4E, $3F, $AE, $DE, $4F, $00, $92, $E7, $75, $0D,
    $9F, $EA, $78, $1A, $88, $FD, $6F, $17, $85, $F0, $62, $34, $A6, $D3, $41,
    $39, $AB, $DE, $4C, $2E, $BC, $C9, $5B, $23, $B1, $C4, $56, $68, $FA, $8F,
    $1D, $65, $F7, $82, $10, $72, $E0, $95, $07, $7F, $ED, $98, $0A, $5C, $CE,
    $BB, $29, $51, $C3, $B6, $24, $46, $D4, $A1, $33, $4B, $D9, $AC, $3E, $D0,
    $42, $37, $A5, $DD, $4F, $3A, $A8, $CA, $58, $2D, $BF, $C7, $55, $20, $B2,
    $E4, $76, $03, $91, $E9, $7B, $0E, $9C, $FE, $6C, $19, $8B, $F3, $61, $14,
    $86, $B8, $2A, $5F, $CD, $B5, $27, $52, $C0, $A2, $30, $45, $D7, $AF, $3D,
    $48, $DA, $8C, $1E, $6B, $F9, $81, $13, $66, $F4, $96, $04, $71, $E3, $9B,
    $09, $7C, $EE, $63, $F1, $84, $16, $6E, $FC, $89, $1B, $79, $EB, $9E, $0C,
    $74, $E6, $93, $01, $57, $C5, $B0, $22, $5A, $C8, $BD, $2F, $4D, $DF, $AA,
    $38, $40, $D2, $A7, $35, $0B, $99, $EC, $7E, $06, $94, $E1, $73, $11, $83,
    $F6, $64, $1C, $8E, $FB, $69, $3F, $AD, $D8, $4A, $32, $A0, $D5, $47, $25,
    $B7, $C2, $50, $28, $BA, $CF, $5D, $B3, $21, $54, $C6, $BE, $2C, $59, $CB,
    $A9, $3B, $4E, $DC, $A4, $36, $43, $D1, $87, $15, $60, $F2, $8A, $18, $6D,
    $FF, $9D, $0F, $7A, $E8, $90, $02, $77, $E5, $DB, $49, $3C, $AE, $D6, $44,
    $31, $A3, $C1, $53, $26, $B4, $CC, $5E, $2B, $B9, $EF, $7D, $08, $9A, $E2,
    $70, $05, $97, $F5, $67, $12, $80, $F8, $6A, $1F, $8D, $00, $93, $E5, $76,
    $09, $9A, $EC, $7F, $12, $81, $F7, $64, $1B, $88, $FE, $6D, $24, $B7, $C1,
    $52, $2D, $BE, $C8, $5B, $36, $A5, $D3, $40, $3F, $AC, $DA, $49, $48, $DB,
    $AD, $3E, $41, $D2, $A4, $37, $5A, $C9, $BF, $2C, $53, $C0, $B6, $25, $6C,
    $FF, $89, $1A, $65, $F6, $80, $13, $7E, $ED, $9B, $08, $77, $E4, $92, $01,
    $90, $03, $75, $E6, $99, $0A, $7C, $EF, $82, $11, $67, $F4, $8B, $18, $6E,
    $FD, $B4, $27, $51, $C2, $BD, $2E, $58, $CB, $A6, $35, $43, $D0, $AF, $3C,
    $4A, $D9, $D8, $4B, $3D, $AE, $D1, $42, $34, $A7, $CA, $59, $2F, $BC, $C3,
    $50, $26, $B5, $FC, $6F, $19, $8A, $F5, $66, $10, $83, $EE, $7D, $0B, $98,
    $E7, $74, $02, $91, $E3, $70, $06, $95, $EA, $79, $0F, $9C, $F1, $62, $14,
    $87, $F8, $6B, $1D, $8E, $C7, $54, $22, $B1, $CE, $5D, $2B, $B8, $D5, $46,
    $30, $A3, $DC, $4F, $39, $AA, $AB, $38, $4E, $DD, $A2, $31, $47, $D4, $B9,
    $2A, $5C, $CF, $B0, $23, $55, $C6, $8F, $1C, $6A, $F9, $86, $15, $63, $F0,
    $9D, $0E, $78, $EB, $94, $07, $71, $E2, $73, $E0, $96, $05, $7A, $E9, $9F,
    $0C, $61, $F2, $84, $17, $68, $FB, $8D, $1E, $57, $C4, $B2, $21, $5E, $CD,
    $BB, $28, $45, $D6, $A0, $33, $4C, $DF, $A9, $3A, $3B, $A8, $DE, $4D, $32,
    $A1, $D7, $44, $29, $BA, $CC, $5F, $20, $B3, $C5, $56, $1F, $8C, $FA, $69,
    $16, $85, $F3, $60, $0D, $9E, $E8, $7B, $04, $97, $E1, $72, $00, $94, $EB,
    $7F, $15, $81, $FE, $6A, $2A, $BE, $C1, $55, $3F, $AB, $D4, $40, $54, $C0,
    $BF, $2B, $41, $D5, $AA, $3E, $7E, $EA, $95, $01, $6B, $FF, $80, $14, $A8,
    $3C, $43, $D7, $BD, $29, $56, $C2, $82, $16, $69, $FD, $97, $03, $7C, $E8,
    $FC, $68, $17, $83, $E9, $7D, $02, $96, $D6, $42, $3D, $A9, $C3, $57, $28,
    $BC, $93, $07, $78, $EC, $86, $12, $6D, $F9, $B9, $2D, $52, $C6, $AC, $38,
    $47, $D3, $C7, $53, $2C, $B8, $D2, $46, $39, $AD, $ED, $79, $06, $92, $F8,
    $6C, $13, $87, $3B, $AF, $D0, $44, $2E, $BA, $C5, $51, $11, $85, $FA, $6E,
    $04, $90, $EF, $7B, $6F, $FB, $84, $10, $7A, $EE, $91, $05, $45, $D1, $AE,
    $3A, $50, $C4, $BB, $2F, $E5, $71, $0E, $9A, $F0, $64, $1B, $8F, $CF, $5B,
    $24, $B0, $DA, $4E, $31, $A5, $B1, $25, $5A, $CE, $A4, $30, $4F, $DB, $9B,
    $0F, $70, $E4, $8E, $1A, $65, $F1, $4D, $D9, $A6, $32, $58, $CC, $B3, $27,
    $67, $F3, $8C, $18, $72, $E6, $99, $0D, $19, $8D, $F2, $66, $0C, $98, $E7,
    $73, $33, $A7, $D8, $4C, $26, $B2, $CD, $59, $76, $E2, $9D, $09, $63, $F7,
    $88, $1C, $5C, $C8, $B7, $23, $49, $DD, $A2, $36, $22, $B6, $C9, $5D, $37,
    $A3, $DC, $48, $08, $9C, $E3, $77, $1D, $89, $F6, $62, $DE, $4A, $35, $A1,
    $CB, $5F, $20, $B4, $F4, $60, $1F, $8B, $E1, $75, $0A, $9E, $8A, $1E, $61,
    $F5, $9F, $0B, $74, $E0, $A0, $34, $4B, $DF, $B5, $21, $5E, $CA, $00, $95,
    $E9, $7C, $11, $84, $F8, $6D, $22, $B7, $CB, $5E, $33, $A6, $DA, $4F, $44,
    $D1, $AD, $38, $55, $C0, $BC, $29, $66, $F3, $8F, $1A, $77, $E2, $9E, $0B,
    $88, $1D, $61, $F4, $99, $0C, $70, $E5, $AA, $3F, $43, $D6, $BB, $2E, $52,
    $C7, $CC, $59, $25, $B0, $DD, $48, $34, $A1, $EE, $7B, $07, $92, $FF, $6A,
    $16, $83, $D3, $46, $3A, $AF, $C2, $57, $2B, $BE, $F1, $64, $18, $8D, $E0,
    $75, $09, $9C, $97, $02, $7E, $EB, $86, $13, $6F, $FA, $B5, $20, $5C, $C9,
    $A4, $31, $4D, $D8, $5B, $CE, $B2, $27, $4A, $DF, $A3, $36, $79, $EC, $90,
    $05, $68, $FD, $81, $14, $1F, $8A, $F6, $63, $0E, $9B, $E7, $72, $3D, $A8,
    $D4, $41, $2C, $B9, $C5, $50, $65, $F0, $8C, $19, $74, $E1, $9D, $08, $47,
    $D2, $AE, $3B, $56, $C3, $BF, $2A, $21, $B4, $C8, $5D, $30, $A5, $D9, $4C,
    $03, $96, $EA, $7F, $12, $87, $FB, $6E, $ED, $78, $04, $91, $FC, $69, $15,
    $80, $CF, $5A, $26, $B3, $DE, $4B, $37, $A2, $A9, $3C, $40, $D5, $B8, $2D,
    $51, $C4, $8B, $1E, $62, $F7, $9A, $0F, $73, $E6, $B6, $23, $5F, $CA, $A7,
    $32, $4E, $DB, $94, $01, $7D, $E8, $85, $10, $6C, $F9, $F2, $67, $1B, $8E,
    $E3, $76, $0A, $9F, $D0, $45, $39, $AC, $C1, $54, $28, $BD, $3E, $AB, $D7,
    $42, $2F, $BA, $C6, $53, $1C, $89, $F5, $60, $0D, $98, $E4, $71, $7A, $EF,
    $93, $06, $6B, $FE, $82, $17, $58, $CD, $B1, $24, $49, $DC, $A0, $35, $00,
    $96, $EF, $79, $1D, $8B, $F2, $64, $3A, $AC, $D5, $43, $27, $B1, $C8, $5E,
    $74, $E2, $9B, $0D, $69, $FF, $86, $10, $4E, $D8, $A1, $37, $53, $C5, $BC,
    $2A, $E8, $7E, $07, $91, $F5, $63, $1A, $8C, $D2, $44, $3D, $AB, $CF, $59,
    $20, $B6, $9C, $0A, $73, $E5, $81, $17, $6E, $F8, $A6, $30, $49, $DF, $BB,
    $2D, $54, $C2, $13, $85, $FC, $6A, $0E, $98, $E1, $77, $29, $BF, $C6, $50,
    $34, $A2, $DB, $4D, $67, $F1, $88, $1E, $7A, $EC, $95, $03, $5D, $CB, $B2,
    $24, $40, $D6, $AF, $39, $FB, $6D, $14, $82, $E6, $70, $09, $9F, $C1, $57,
    $2E, $B8, $DC, $4A, $33, $A5, $8F, $19, $60, $F6, $92, $04, $7D, $EB, $B5,
    $23, $5A, $CC, $A8, $3E, $47, $D1, $26, $B0, $C9, $5F, $3B, $AD, $D4, $42,
    $1C, $8A, $F3, $65, $01, $97, $EE, $78, $52, $C4, $BD, $2B, $4F, $D9, $A0,
    $36, $68, $FE, $87, $11, $75, $E3, $9A, $0C, $CE, $58, $21, $B7, $D3, $45,
    $3C, $AA, $F4, $62, $1B, $8D, $E9, $7F, $06, $90, $BA, $2C, $55, $C3, $A7,
    $31, $48, $DE, $80, $16, $6F, $F9, $9D, $0B, $72, $E4, $35, $A3, $DA, $4C,
    $28, $BE, $C7, $51, $0F, $99, $E0, $76, $12, $84, $FD, $6B, $41, $D7, $AE,
    $38, $5C, $CA, $B3, $25, $7B, $ED, $94, $02, $66, $F0, $89, $1F, $DD, $4B,
    $32, $A4, $C0, $56, $2F, $B9, $E7, $71, $08, $9E, $FA, $6C, $15, $83, $A9,
    $3F, $46, $D0, $B4, $22, $5B, $CD, $93, $05, $7C, $EA, $8E, $18, $61, $F7,
    $00, $97, $ED, $7A, $19, $8E, $F4, $63, $32, $A5, $DF, $48, $2B, $BC, $C6,
    $51, $64, $F3, $89, $1E, $7D, $EA, $90, $07, $56, $C1, $BB, $2C, $4F, $D8,
    $A2, $35, $C8, $5F, $25, $B2, $D1, $46, $3C, $AB, $FA, $6D, $17, $80, $E3,
    $74, $0E, $99, $AC, $3B, $41, $D6, $B5, $22, $58, $CF, $9E, $09, $73, $E4,
    $87, $10, $6A, $FD, $53, $C4, $BE, $29, $4A, $DD, $A7, $30, $61, $F6, $8C,
    $1B, $78, $EF, $95, $02, $37, $A0, $DA, $4D, $2E, $B9, $C3, $54, $05, $92,
    $E8, $7F, $1C, $8B, $F1, $66, $9B, $0C, $76, $E1, $82, $15, $6F, $F8, $A9,
    $3E, $44, $D3, $B0, $27, $5D, $CA, $FF, $68, $12, $85, $E6, $71, $0B, $9C,
    $CD, $5A, $20, $B7, $D4, $43, $39, $AE, $A6, $31, $4B, $DC, $BF, $28, $52,
    $C5, $94, $03, $79, $EE, $8D, $1A, $60, $F7, $C2, $55, $2F, $B8, $DB, $4C,
    $36, $A1, $F0, $67, $1D, $8A, $E9, $7E, $04, $93, $6E, $F9, $83, $14, $77,
    $E0, $9A, $0D, $5C, $CB, $B1, $26, $45, $D2, $A8, $3F, $0A, $9D, $E7, $70,
    $13, $84, $FE, $69, $38, $AF, $D5, $42, $21, $B6, $CC, $5B, $F5, $62, $18,
    $8F, $EC, $7B, $01, $96, $C7, $50, $2A, $BD, $DE, $49, $33, $A4, $91, $06,
    $7C, $EB, $88, $1F, $65, $F2, $A3, $34, $4E, $D9, $BA, $2D, $57, $C0, $3D,
    $AA, $D0, $47, $24, $B3, $C9, $5E, $0F, $98, $E2, $75, $16, $81, $FB, $6C,
    $59, $CE, $B4, $23, $40, $D7, $AD, $3A, $6B, $FC, $86, $11, $72, $E5, $9F,
    $08, $00, $98, $F3, $6B, $25, $BD, $D6, $4E, $4A, $D2, $B9, $21, $6F, $F7,
    $9C, $04, $94, $0C, $67, $FF, $B1, $29, $42, $DA, $DE, $46, $2D, $B5, $FB,
    $63, $08, $90, $EB, $73, $18, $80, $CE, $56, $3D, $A5, $A1, $39, $52, $CA,
    $84, $1C, $77, $EF, $7F, $E7, $8C, $14, $5A, $C2, $A9, $31, $35, $AD, $C6,
    $5E, $10, $88, $E3, $7B, $15, $8D, $E6, $7E, $30, $A8, $C3, $5B, $5F, $C7,
    $AC, $34, $7A, $E2, $89, $11, $81, $19, $72, $EA, $A4, $3C, $57, $CF, $CB,
    $53, $38, $A0, $EE, $76, $1D, $85, $FE, $66, $0D, $95, $DB, $43, $28, $B0,
    $B4, $2C, $47, $DF, $91, $09, $62, $FA, $6A, $F2, $99, $01, $4F, $D7, $BC,
    $24, $20, $B8, $D3, $4B, $05, $9D, $F6, $6E, $2A, $B2, $D9, $41, $0F, $97,
    $FC, $64, $60, $F8, $93, $0B, $45, $DD, $B6, $2E, $BE, $26, $4D, $D5, $9B,
    $03, $68, $F0, $F4, $6C, $07, $9F, $D1, $49, $22, $BA, $C1, $59, $32, $AA,
    $E4, $7C, $17, $8F, $8B, $13, $78, $E0, $AE, $36, $5D, $C5, $55, $CD, $A6,
    $3E, $70, $E8, $83, $1B, $1F, $87, $EC, $74, $3A, $A2, $C9, $51, $3F, $A7,
    $CC, $54, $1A, $82, $E9, $71, $75, $ED, $86, $1E, $50, $C8, $A3, $3B, $AB,
    $33, $58, $C0, $8E, $16, $7D, $E5, $E1, $79, $12, $8A, $C4, $5C, $37, $AF,
    $D4, $4C, $27, $BF, $F1, $69, $02, $9A, $9E, $06, $6D, $F5, $BB, $23, $48,
    $D0, $40, $D8, $B3, $2B, $65, $FD, $96, $0E, $0A, $92, $F9, $61, $2F, $B7,
    $DC, $44, $00, $99, $F1, $68, $21, $B8, $D0, $49, $42, $DB, $B3, $2A, $63,
    $FA, $92, $0B, $84, $1D, $75, $EC, $A5, $3C, $54, $CD, $C6, $5F, $37, $AE,
    $E7, $7E, $16, $8F, $CB, $52, $3A, $A3, $EA, $73, $1B, $82, $89, $10, $78,
    $E1, $A8, $31, $59, $C0, $4F, $D6, $BE, $27, $6E, $F7, $9F, $06, $0D, $94,
    $FC, $65, $2C, $B5, $DD, $44, $55, $CC, $A4, $3D, $74, $ED, $85, $1C, $17,
    $8E, $E6, $7F, $36, $AF, $C7, $5E, $D1, $48, $20, $B9, $F0, $69, $01, $98,
    $93, $0A, $62, $FB, $B2, $2B, $43, $DA, $9E, $07, $6F, $F6, $BF, $26, $4E,
    $D7, $DC, $45, $2D, $B4, $FD, $64, $0C, $95, $1A, $83, $EB, $72, $3B, $A2,
    $CA, $53, $58, $C1, $A9, $30, $79, $E0, $88, $11, $AA, $33, $5B, $C2, $8B,
    $12, $7A, $E3, $E8, $71, $19, $80, $C9, $50, $38, $A1, $2E, $B7, $DF, $46,
    $0F, $96, $FE, $67, $6C, $F5, $9D, $04, $4D, $D4, $BC, $25, $61, $F8, $90,
    $09, $40, $D9, $B1, $28, $23, $BA, $D2, $4B, $02, $9B, $F3, $6A, $E5, $7C,
    $14, $8D, $C4, $5D, $35, $AC, $A7, $3E, $56, $CF, $86, $1F, $77, $EE, $FF,
    $66, $0E, $97, $DE, $47, $2F, $B6, $BD, $24, $4C, $D5, $9C, $05, $6D, $F4,
    $7B, $E2, $8A, $13, $5A, $C3, $AB, $32, $39, $A0, $C8, $51, $18, $81, $E9,
    $70, $34, $AD, $C5, $5C, $15, $8C, $E4, $7D, $76, $EF, $87, $1E, $57, $CE,
    $A6, $3F, $B0, $29, $41, $D8, $91, $08, $60, $F9, $F2, $6B, $03, $9A, $D3,
    $4A, $22, $BB, $00, $9A, $F7, $6D, $2D, $B7, $DA, $40, $5A, $C0, $AD, $37,
    $77, $ED, $80, $1A, $B4, $2E, $43, $D9, $99, $03, $6E, $F4, $EE, $74, $19,
    $83, $C3, $59, $34, $AE, $AB, $31, $5C, $C6, $86, $1C, $71, $EB, $F1, $6B,
    $06, $9C, $DC, $46, $2B, $B1, $1F, $85, $E8, $72, $32, $A8, $C5, $5F, $45,
    $DF, $B2, $28, $68, $F2, $9F, $05, $95, $0F, $62, $F8, $B8, $22, $4F, $D5,
    $CF, $55, $38, $A2, $E2, $78, $15, $8F, $21, $BB, $D6, $4C, $0C, $96, $FB,
    $61, $7B, $E1, $8C, $16, $56, $CC, $A1, $3B, $3E, $A4, $C9, $53, $13, $89,
    $E4, $7E, $64, $FE, $93, $09, $49, $D3, $BE, $24, $8A, $10, $7D, $E7, $A7,
    $3D, $50, $CA, $D0, $4A, $27, $BD, $FD, $67, $0A, $90, $E9, $73, $1E, $84,
    $C4, $5E, $33, $A9, $B3, $29, $44, $DE, $9E, $04, $69, $F3, $5D, $C7, $AA,
    $30, $70, $EA, $87, $1D, $07, $9D, $F0, $6A, $2A, $B0, $DD, $47, $42, $D8,
    $B5, $2F, $6F, $F5, $98, $02, $18, $82, $EF, $75, $35, $AF, $C2, $58, $F6,
    $6C, $01, $9B, $DB, $41, $2C, $B6, $AC, $36, $5B, $C1, $81, $1B, $76, $EC,
    $7C, $E6, $8B, $11, $51, $CB, $A6, $3C, $26, $BC, $D1, $4B, $0B, $91, $FC,
    $66, $C8, $52, $3F, $A5, $E5, $7F, $12, $88, $92, $08, $65, $FF, $BF, $25,
    $48, $D2, $D7, $4D, $20, $BA, $FA, $60, $0D, $97, $8D, $17, $7A, $E0, $A0,
    $3A, $57, $CD, $63, $F9, $94, $0E, $4E, $D4, $B9, $23, $39, $A3, $CE, $54,
    $14, $8E, $E3, $79, $00, $9B, $F5, $6E, $29, $B2, $DC, $47, $52, $C9, $A7,
    $3C, $7B, $E0, $8E, $15, $A4, $3F, $51, $CA, $8D, $16, $78, $E3, $F6, $6D,
    $03, $98, $DF, $44, $2A, $B1, $8B, $10, $7E, $E5, $A2, $39, $57, $CC, $D9,
    $42, $2C, $B7, $F0, $6B, $05, $9E, $2F, $B4, $DA, $41, $06, $9D, $F3, $68,
    $7D, $E6, $88, $13, $54, $CF, $A1, $3A, $D5, $4E, $20, $BB, $FC, $67, $09,
    $92, $87, $1C, $72, $E9, $AE, $35, $5B, $C0, $71, $EA, $84, $1F, $58, $C3,
    $AD, $36, $23, $B8, $D6, $4D, $0A, $91, $FF, $64, $5E, $C5, $AB, $30, $77,
    $EC, $82, $19, $0C, $97, $F9, $62, $25, $BE, $D0, $4B, $FA, $61, $0F, $94,
    $D3, $48, $26, $BD, $A8, $33, $5D, $C6, $81, $1A, $74, $EF, $69, $F2, $9C,
    $07, $40, $DB, $B5, $2E, $3B, $A0, $CE, $55, $12, $89, $E7, $7C, $CD, $56,
    $38, $A3, $E4, $7F, $11, $8A, $9F, $04, $6A, $F1, $B6, $2D, $43, $D8, $E2,
    $79, $17, $8C, $CB, $50, $3E, $A5, $B0, $2B, $45, $DE, $99, $02, $6C, $F7,
    $46, $DD, $B3, $28, $6F, $F4, $9A, $01, $14, $8F, $E1, $7A, $3D, $A6, $C8,
    $53, $BC, $27, $49, $D2, $95, $0E, $60, $FB, $EE, $75, $1B, $80, $C7, $5C,
    $32, $A9, $18, $83, $ED, $76, $31, $AA, $C4, $5F, $4A, $D1, $BF, $24, $63,
    $F8, $96, $0D, $37, $AC, $C2, $59, $1E, $85, $EB, $70, $65, $FE, $90, $0B,
    $4C, $D7, $B9, $22, $93, $08, $66, $FD, $BA, $21, $4F, $D4, $C1, $5A, $34,
    $AF, $E8, $73, $1D, $86, $00, $9C, $FB, $67, $35, $A9, $CE, $52, $6A, $F6,
    $91, $0D, $5F, $C3, $A4, $38, $D4, $48, $2F, $B3, $E1, $7D, $1A, $86, $BE,
    $22, $45, $D9, $8B, $17, $70, $EC, $6B, $F7, $90, $0C, $5E, $C2, $A5, $39,
    $01, $9D, $FA, $66, $34, $A8, $CF, $53, $BF, $23, $44, $D8, $8A, $16, $71,
    $ED, $D5, $49, $2E, $B2, $E0, $7C, $1B, $87, $D6, $4A, $2D, $B1, $E3, $7F,
    $18, $84, $BC, $20, $47, $DB, $89, $15, $72, $EE, $02, $9E, $F9, $65, $37,
    $AB, $CC, $50, $68, $F4, $93, $0F, $5D, $C1, $A6, $3A, $BD, $21, $46, $DA,
    $88, $14, $73, $EF, $D7, $4B, $2C, $B0, $E2, $7E, $19, $85, $69, $F5, $92,
    $0E, $5C, $C0, $A7, $3B, $03, $9F, $F8, $64, $36, $AA, $CD, $51, $6F, $F3,
    $94, $08, $5A, $C6, $A1, $3D, $05, $99, $FE, $62, $30, $AC, $CB, $57, $BB,
    $27, $40, $DC, $8E, $12, $75, $E9, $D1, $4D, $2A, $B6, $E4, $78, $1F, $83,
    $04, $98, $FF, $63, $31, $AD, $CA, $56, $6E, $F2, $95, $09, $5B, $C7, $A0,
    $3C, $D0, $4C, $2B, $B7, $E5, $79, $1E, $82, $BA, $26, $41, $DD, $8F, $13,
    $74, $E8, $B9, $25, $42, $DE, $8C, $10, $77, $EB, $D3, $4F, $28, $B4, $E6,
    $7A, $1D, $81, $6D, $F1, $96, $0A, $58, $C4, $A3, $3F, $07, $9B, $FC, $60,
    $32, $AE, $C9, $55, $D2, $4E, $29, $B5, $E7, $7B, $1C, $80, $B8, $24, $43,
    $DF, $8D, $11, $76, $EA, $06, $9A, $FD, $61, $33, $AF, $C8, $54, $6C, $F0,
    $97, $0B, $59, $C5, $A2, $3E, $00, $9D, $F9, $64, $31, $AC, $C8, $55, $62,
    $FF, $9B, $06, $53, $CE, $AA, $37, $C4, $59, $3D, $A0, $F5, $68, $0C, $91,
    $A6, $3B, $5F, $C2, $97, $0A, $6E, $F3, $4B, $D6, $B2, $2F, $7A, $E7, $83,
    $1E, $29, $B4, $D0, $4D, $18, $85, $E1, $7C, $8F, $12, $76, $EB, $BE, $23,
    $47, $DA, $ED, $70, $14, $89, $DC, $41, $25, $B8, $96, $0B, $6F, $F2, $A7,
    $3A, $5E, $C3, $F4, $69, $0D, $90, $C5, $58, $3C, $A1, $52, $CF, $AB, $36,
    $63, $FE, $9A, $07, $30, $AD, $C9, $54, $01, $9C, $F8, $65, $DD, $40, $24,
    $B9, $EC, $71, $15, $88, $BF, $22, $46, $DB, $8E, $13, $77, $EA, $19, $84,
    $E0, $7D, $28, $B5, $D1, $4C, $7B, $E6, $82, $1F, $4A, $D7, $B3, $2E, $EF,
    $72, $16, $8B, $DE, $43, $27, $BA, $8D, $10, $74, $E9, $BC, $21, $45, $D8,
    $2B, $B6, $D2, $4F, $1A, $87, $E3, $7E, $49, $D4, $B0, $2D, $78, $E5, $81,
    $1C, $A4, $39, $5D, $C0, $95, $08, $6C, $F1, $C6, $5B, $3F, $A2, $F7, $6A,
    $0E, $93, $60, $FD, $99, $04, $51, $CC, $A8, $35, $02, $9F, $FB, $66, $33,
    $AE, $CA, $57, $79, $E4, $80, $1D, $48, $D5, $B1, $2C, $1B, $86, $E2, $7F,
    $2A, $B7, $D3, $4E, $BD, $20, $44, $D9, $8C, $11, $75, $E8, $DF, $42, $26,
    $BB, $EE, $73, $17, $8A, $32, $AF, $CB, $56, $03, $9E, $FA, $67, $50, $CD,
    $A9, $34, $61, $FC, $98, $05, $F6, $6B, $0F, $92, $C7, $5A, $3E, $A3, $94,
    $09, $6D, $F0, $A5, $38, $5C, $C1, $00, $9E, $FF, $61, $3D, $A3, $C2, $5C,
    $7A, $E4, $85, $1B, $47, $D9, $B8, $26, $F4, $6A, $0B, $95, $C9, $57, $36,
    $A8, $8E, $10, $71, $EF, $B3, $2D, $4C, $D2, $2B, $B5, $D4, $4A, $16, $88,
    $E9, $77, $51, $CF, $AE, $30, $6C, $F2, $93, $0D, $DF, $41, $20, $BE, $E2,
    $7C, $1D, $83, $A5, $3B, $5A, $C4, $98, $06, $67, $F9, $56, $C8, $A9, $37,
    $6B, $F5, $94, $0A, $2C, $B2, $D3, $4D, $11, $8F, $EE, $70, $A2, $3C, $5D,
    $C3, $9F, $01, $60, $FE, $D8, $46, $27, $B9, $E5, $7B, $1A, $84, $7D, $E3,
    $82, $1C, $40, $DE, $BF, $21, $07, $99, $F8, $66, $3A, $A4, $C5, $5B, $89,
    $17, $76, $E8, $B4, $2A, $4B, $D5, $F3, $6D, $0C, $92, $CE, $50, $31, $AF,
    $AC, $32, $53, $CD, $91, $0F, $6E, $F0, $D6, $48, $29, $B7, $EB, $75, $14,
    $8A, $58, $C6, $A7, $39, $65, $FB, $9A, $04, $22, $BC, $DD, $43, $1F, $81,
    $E0, $7E, $87, $19, $78, $E6, $BA, $24, $45, $DB, $FD, $63, $02, $9C, $C0,
    $5E, $3F, $A1, $73, $ED, $8C, $12, $4E, $D0, $B1, $2F, $09, $97, $F6, $68,
    $34, $AA, $CB, $55, $FA, $64, $05, $9B, $C7, $59, $38, $A6, $80, $1E, $7F,
    $E1, $BD, $23, $42, $DC, $0E, $90, $F1, $6F, $33, $AD, $CC, $52, $74, $EA,
    $8B, $15, $49, $D7, $B6, $28, $D1, $4F, $2E, $B0, $EC, $72, $13, $8D, $AB,
    $35, $54, $CA, $96, $08, $69, $F7, $25, $BB, $DA, $44, $18, $86, $E7, $79,
    $5F, $C1, $A0, $3E, $62, $FC, $9D, $03, $00, $9F, $FD, $62, $39, $A6, $C4,
    $5B, $72, $ED, $8F, $10, $4B, $D4, $B6, $29, $E4, $7B, $19, $86, $DD, $42,
    $20, $BF, $96, $09, $6B, $F4, $AF, $30, $52, $CD, $0B, $94, $F6, $69, $32,
    $AD, $CF, $50, $79, $E6, $84, $1B, $40, $DF, $BD, $22, $EF, $70, $12, $8D,
    $D6, $49, $2B, $B4, $9D, $02, $60, $FF, $A4, $3B, $59, $C6, $16, $89, $EB,
    $74, $2F, $B0, $D2, $4D, $64, $FB, $99, $06, $5D, $C2, $A0, $3F, $F2, $6D,
    $0F, $90, $CB, $54, $36, $A9, $80, $1F, $7D, $E2, $B9, $26, $44, $DB, $1D,
    $82, $E0, $7F, $24, $BB, $D9, $46, $6F, $F0, $92, $0D, $56, $C9, $AB, $34,
    $F9, $66, $04, $9B, $C0, $5F, $3D, $A2, $8B, $14, $76, $E9, $B2, $2D, $4F,
    $D0, $2C, $B3, $D1, $4E, $15, $8A, $E8, $77, $5E, $C1, $A3, $3C, $67, $F8,
    $9A, $05, $C8, $57, $35, $AA, $F1, $6E, $0C, $93, $BA, $25, $47, $D8, $83,
    $1C, $7E, $E1, $27, $B8, $DA, $45, $1E, $81, $E3, $7C, $55, $CA, $A8, $37,
    $6C, $F3, $91, $0E, $C3, $5C, $3E, $A1, $FA, $65, $07, $98, $B1, $2E, $4C,
    $D3, $88, $17, $75, $EA, $3A, $A5, $C7, $58, $03, $9C, $FE, $61, $48, $D7,
    $B5, $2A, $71, $EE, $8C, $13, $DE, $41, $23, $BC, $E7, $78, $1A, $85, $AC,
    $33, $51, $CE, $95, $0A, $68, $F7, $31, $AE, $CC, $53, $08, $97, $F5, $6A,
    $43, $DC, $BE, $21, $7A, $E5, $87, $18, $D5, $4A, $28, $B7, $EC, $73, $11,
    $8E, $A7, $38, $5A, $C5, $9E, $01, $63, $FC, $00, $A0, $83, $23, $C5, $65,
    $46, $E6, $49, $E9, $CA, $6A, $8C, $2C, $0F, $AF, $92, $32, $11, $B1, $57,
    $F7, $D4, $74, $DB, $7B, $58, $F8, $1E, $BE, $9D, $3D, $E7, $47, $64, $C4,
    $22, $82, $A1, $01, $AE, $0E, $2D, $8D, $6B, $CB, $E8, $48, $75, $D5, $F6,
    $56, $B0, $10, $33, $93, $3C, $9C, $BF, $1F, $F9, $59, $7A, $DA, $0D, $AD,
    $8E, $2E, $C8, $68, $4B, $EB, $44, $E4, $C7, $67, $81, $21, $02, $A2, $9F,
    $3F, $1C, $BC, $5A, $FA, $D9, $79, $D6, $76, $55, $F5, $13, $B3, $90, $30,
    $EA, $4A, $69, $C9, $2F, $8F, $AC, $0C, $A3, $03, $20, $80, $66, $C6, $E5,
    $45, $78, $D8, $FB, $5B, $BD, $1D, $3E, $9E, $31, $91, $B2, $12, $F4, $54,
    $77, $D7, $1A, $BA, $99, $39, $DF, $7F, $5C, $FC, $53, $F3, $D0, $70, $96,
    $36, $15, $B5, $88, $28, $0B, $AB, $4D, $ED, $CE, $6E, $C1, $61, $42, $E2,
    $04, $A4, $87, $27, $FD, $5D, $7E, $DE, $38, $98, $BB, $1B, $B4, $14, $37,
    $97, $71, $D1, $F2, $52, $6F, $CF, $EC, $4C, $AA, $0A, $29, $89, $26, $86,
    $A5, $05, $E3, $43, $60, $C0, $17, $B7, $94, $34, $D2, $72, $51, $F1, $5E,
    $FE, $DD, $7D, $9B, $3B, $18, $B8, $85, $25, $06, $A6, $40, $E0, $C3, $63,
    $CC, $6C, $4F, $EF, $09, $A9, $8A, $2A, $F0, $50, $73, $D3, $35, $95, $B6,
    $16, $B9, $19, $3A, $9A, $7C, $DC, $FF, $5F, $62, $C2, $E1, $41, $A7, $07,
    $24, $84, $2B, $8B, $A8, $08, $EE, $4E, $6D, $CD, $00, $A1, $81, $20, $C1,
    $60, $40, $E1, $41, $E0, $C0, $61, $80, $21, $01, $A0, $82, $23, $03, $A2,
    $43, $E2, $C2, $63, $C3, $62, $42, $E3, $02, $A3, $83, $22, $C7, $66, $46,
    $E7, $06, $A7, $87, $26, $86, $27, $07, $A6, $47, $E6, $C6, $67, $45, $E4,
    $C4, $65, $84, $25, $05, $A4, $04, $A5, $85, $24, $C5, $64, $44, $E5, $4D,
    $EC, $CC, $6D, $8C, $2D, $0D, $AC, $0C, $AD, $8D, $2C, $CD, $6C, $4C, $ED,
    $CF, $6E, $4E, $EF, $0E, $AF, $8F, $2E, $8E, $2F, $0F, $AE, $4F, $EE, $CE,
    $6F, $8A, $2B, $0B, $AA, $4B, $EA, $CA, $6B, $CB, $6A, $4A, $EB, $0A, $AB,
    $8B, $2A, $08, $A9, $89, $28, $C9, $68, $48, $E9, $49, $E8, $C8, $69, $88,
    $29, $09, $A8, $9A, $3B, $1B, $BA, $5B, $FA, $DA, $7B, $DB, $7A, $5A, $FB,
    $1A, $BB, $9B, $3A, $18, $B9, $99, $38, $D9, $78, $58, $F9, $59, $F8, $D8,
    $79, $98, $39, $19, $B8, $5D, $FC, $DC, $7D, $9C, $3D, $1D, $BC, $1C, $BD,
    $9D, $3C, $DD, $7C, $5C, $FD, $DF, $7E, $5E, $FF, $1E, $BF, $9F, $3E, $9E,
    $3F, $1F, $BE, $5F, $FE, $DE, $7F, $D7, $76, $56, $F7, $16, $B7, $97, $36,
    $96, $37, $17, $B6, $57, $F6, $D6, $77, $55, $F4, $D4, $75, $94, $35, $15,
    $B4, $14, $B5, $95, $34, $D5, $74, $54, $F5, $10, $B1, $91, $30, $D1, $70,
    $50, $F1, $51, $F0, $D0, $71, $90, $31, $11, $B0, $92, $33, $13, $B2, $53,
    $F2, $D2, $73, $D3, $72, $52, $F3, $12, $B3, $93, $32, $00, $A2, $87, $25,
    $CD, $6F, $4A, $E8, $59, $FB, $DE, $7C, $94, $36, $13, $B1, $B2, $10, $35,
    $97, $7F, $DD, $F8, $5A, $EB, $49, $6C, $CE, $26, $84, $A1, $03, $A7, $05,
    $20, $82, $6A, $C8, $ED, $4F, $FE, $5C, $79, $DB, $33, $91, $B4, $16, $15,
    $B7, $92, $30, $D8, $7A, $5F, $FD, $4C, $EE, $CB, $69, $81, $23, $06, $A4,
    $8D, $2F, $0A, $A8, $40, $E2, $C7, $65, $D4, $76, $53, $F1, $19, $BB, $9E,
    $3C, $3F, $9D, $B8, $1A, $F2, $50, $75, $D7, $66, $C4, $E1, $43, $AB, $09,
    $2C, $8E, $2A, $88, $AD, $0F, $E7, $45, $60, $C2, $73, $D1, $F4, $56, $BE,
    $1C, $39, $9B, $98, $3A, $1F, $BD, $55, $F7, $D2, $70, $C1, $63, $46, $E4,
    $0C, $AE, $8B, $29, $D9, $7B, $5E, $FC, $14, $B6, $93, $31, $80, $22, $07,
    $A5, $4D, $EF, $CA, $68, $6B, $C9, $EC, $4E, $A6, $04, $21, $83, $32, $90,
    $B5, $17, $FF, $5D, $78, $DA, $7E, $DC, $F9, $5B, $B3, $11, $34, $96, $27,
    $85, $A0, $02, $EA, $48, $6D, $CF, $CC, $6E, $4B, $E9, $01, $A3, $86, $24,
    $95, $37, $12, $B0, $58, $FA, $DF, $7D, $54, $F6, $D3, $71, $99, $3B, $1E,
    $BC, $0D, $AF, $8A, $28, $C0, $62, $47, $E5, $E6, $44, $61, $C3, $2B, $89,
    $AC, $0E, $BF, $1D, $38, $9A, $72, $D0, $F5, $57, $F3, $51, $74, $D6, $3E,
    $9C, $B9, $1B, $AA, $08, $2D, $8F, $67, $C5, $E0, $42, $41, $E3, $C6, $64,
    $8C, $2E, $0B, $A9, $18, $BA, $9F, $3D, $D5, $77, $52, $F0, $00, $A3, $85,
    $26, $C9, $6A, $4C, $EF, $51, $F2, $D4, $77, $98, $3B, $1D, $BE, $A2, $01,
    $27, $84, $6B, $C8, $EE, $4D, $F3, $50, $76, $D5, $3A, $99, $BF, $1C, $87,
    $24, $02, $A1, $4E, $ED, $CB, $68, $D6, $75, $53, $F0, $1F, $BC, $9A, $39,
    $25, $86, $A0, $03, $EC, $4F, $69, $CA, $74, $D7, $F1, $52, $BD, $1E, $38,
    $9B, $CD, $6E, $48, $EB, $04, $A7, $81, $22, $9C, $3F, $19, $BA, $55, $F6,
    $D0, $73, $6F, $CC, $EA, $49, $A6, $05, $23, $80, $3E, $9D, $BB, $18, $F7,
    $54, $72, $D1, $4A, $E9, $CF, $6C, $83, $20, $06, $A5, $1B, $B8, $9E, $3D,
    $D2, $71, $57, $F4, $E8, $4B, $6D, $CE, $21, $82, $A4, $07, $B9, $1A, $3C,
    $9F, $70, $D3, $F5, $56, $59, $FA, $DC, $7F, $90, $33, $15, $B6, $08, $AB,
    $8D, $2E, $C1, $62, $44, $E7, $FB, $58, $7E, $DD, $32, $91, $B7, $14, $AA,
    $09, $2F, $8C, $63, $C0, $E6, $45, $DE, $7D, $5B, $F8, $17, $B4, $92, $31,
    $8F, $2C, $0A, $A9, $46, $E5, $C3, $60, $7C, $DF, $F9, $5A, $B5, $16, $30,
    $93, $2D, $8E, $A8, $0B, $E4, $47, $61, $C2, $94, $37, $11, $B2, $5D, $FE,
    $D8, $7B, $C5, $66, $40, $E3, $0C, $AF, $89, $2A, $36, $95, $B3, $10, $FF,
    $5C, $7A, $D9, $67, $C4, $E2, $41, $AE, $0D, $2B, $88, $13, $B0, $96, $35,
    $DA, $79, $5F, $FC, $42, $E1, $C7, $64, $8B, $28, $0E, $AD, $B1, $12, $34,
    $97, $78, $DB, $FD, $5E, $E0, $43, $65, $C6, $29, $8A, $AC, $0F, $00, $A4,
    $8B, $2F, $D5, $71, $5E, $FA, $69, $CD, $E2, $46, $BC, $18, $37, $93, $D2,
    $76, $59, $FD, $07, $A3, $8C, $28, $BB, $1F, $30, $94, $6E, $CA, $E5, $41,
    $67, $C3, $EC, $48, $B2, $16, $39, $9D, $0E, $AA, $85, $21, $DB, $7F, $50,
    $F4, $B5, $11, $3E, $9A, $60, $C4, $EB, $4F, $DC, $78, $57, $F3, $09, $AD,
    $82, $26, $CE, $6A, $45, $E1, $1B, $BF, $90, $34, $A7, $03, $2C, $88, $72,
    $D6, $F9, $5D, $1C, $B8, $97, $33, $C9, $6D, $42, $E6, $75, $D1, $FE, $5A,
    $A0, $04, $2B, $8F, $A9, $0D, $22, $86, $7C, $D8, $F7, $53, $C0, $64, $4B,
    $EF, $15, $B1, $9E, $3A, $7B, $DF, $F0, $54, $AE, $0A, $25, $81, $12, $B6,
    $99, $3D, $C7, $63, $4C, $E8, $5F, $FB, $D4, $70, $8A, $2E, $01, $A5, $36,
    $92, $BD, $19, $E3, $47, $68, $CC, $8D, $29, $06, $A2, $58, $FC, $D3, $77,
    $E4, $40, $6F, $CB, $31, $95, $BA, $1E, $38, $9C, $B3, $17, $ED, $49, $66,
    $C2, $51, $F5, $DA, $7E, $84, $20, $0F, $AB, $EA, $4E, $61, $C5, $3F, $9B,
    $B4, $10, $83, $27, $08, $AC, $56, $F2, $DD, $79, $91, $35, $1A, $BE, $44,
    $E0, $CF, $6B, $F8, $5C, $73, $D7, $2D, $89, $A6, $02, $43, $E7, $C8, $6C,
    $96, $32, $1D, $B9, $2A, $8E, $A1, $05, $FF, $5B, $74, $D0, $F6, $52, $7D,
    $D9, $23, $87, $A8, $0C, $9F, $3B, $14, $B0, $4A, $EE, $C1, $65, $24, $80,
    $AF, $0B, $F1, $55, $7A, $DE, $4D, $E9, $C6, $62, $98, $3C, $13, $B7, $00,
    $A5, $89, $2C, $D1, $74, $58, $FD, $61, $C4, $E8, $4D, $B0, $15, $39, $9C,
    $C2, $67, $4B, $EE, $13, $B6, $9A, $3F, $A3, $06, $2A, $8F, $72, $D7, $FB,
    $5E, $47, $E2, $CE, $6B, $96, $33, $1F, $BA, $26, $83, $AF, $0A, $F7, $52,
    $7E, $DB, $85, $20, $0C, $A9, $54, $F1, $DD, $78, $E4, $41, $6D, $C8, $35,
    $90, $BC, $19, $8E, $2B, $07, $A2, $5F, $FA, $D6, $73, $EF, $4A, $66, $C3,
    $3E, $9B, $B7, $12, $4C, $E9, $C5, $60, $9D, $38, $14, $B1, $2D, $88, $A4,
    $01, $FC, $59, $75, $D0, $C9, $6C, $40, $E5, $18, $BD, $91, $34, $A8, $0D,
    $21, $84, $79, $DC, $F0, $55, $0B, $AE, $82, $27, $DA, $7F, $53, $F6, $6A,
    $CF, $E3, $46, $BB, $1E, $32, $97, $DF, $7A, $56, $F3, $0E, $AB, $87, $22,
    $BE, $1B, $37, $92, $6F, $CA, $E6, $43, $1D, $B8, $94, $31, $CC, $69, $45,
    $E0, $7C, $D9, $F5, $50, $AD, $08, $24, $81, $98, $3D, $11, $B4, $49, $EC,
    $C0, $65, $F9, $5C, $70, $D5, $28, $8D, $A1, $04, $5A, $FF, $D3, $76, $8B,
    $2E, $02, $A7, $3B, $9E, $B2, $17, $EA, $4F, $63, $C6, $51, $F4, $D8, $7D,
    $80, $25, $09, $AC, $30, $95, $B9, $1C, $E1, $44, $68, $CD, $93, $36, $1A,
    $BF, $42, $E7, $CB, $6E, $F2, $57, $7B, $DE, $23, $86, $AA, $0F, $16, $B3,
    $9F, $3A, $C7, $62, $4E, $EB, $77, $D2, $FE, $5B, $A6, $03, $2F, $8A, $D4,
    $71, $5D, $F8, $05, $A0, $8C, $29, $B5, $10, $3C, $99, $64, $C1, $ED, $48,
    $00, $A6, $8F, $29, $DD, $7B, $52, $F4, $79, $DF, $F6, $50, $A4, $02, $2B,
    $8D, $F2, $54, $7D, $DB, $2F, $89, $A0, $06, $8B, $2D, $04, $A2, $56, $F0,
    $D9, $7F, $27, $81, $A8, $0E, $FA, $5C, $75, $D3, $5E, $F8, $D1, $77, $83,
    $25, $0C, $AA, $D5, $73, $5A, $FC, $08, $AE, $87, $21, $AC, $0A, $23, $85,
    $71, $D7, $FE, $58, $4E, $E8, $C1, $67, $93, $35, $1C, $BA, $37, $91, $B8,
    $1E, $EA, $4C, $65, $C3, $BC, $1A, $33, $95, $61, $C7, $EE, $48, $C5, $63,
    $4A, $EC, $18, $BE, $97, $31, $69, $CF, $E6, $40, $B4, $12, $3B, $9D, $10,
    $B6, $9F, $39, $CD, $6B, $42, $E4, $9B, $3D, $14, $B2, $46, $E0, $C9, $6F,
    $E2, $44, $6D, $CB, $3F, $99, $B0, $16, $9C, $3A, $13, $B5, $41, $E7, $CE,
    $68, $E5, $43, $6A, $CC, $38, $9E, $B7, $11, $6E, $C8, $E1, $47, $B3, $15,
    $3C, $9A, $17, $B1, $98, $3E, $CA, $6C, $45, $E3, $BB, $1D, $34, $92, $66,
    $C0, $E9, $4F, $C2, $64, $4D, $EB, $1F, $B9, $90, $36, $49, $EF, $C6, $60,
    $94, $32, $1B, $BD, $30, $96, $BF, $19, $ED, $4B, $62, $C4, $D2, $74, $5D,
    $FB, $0F, $A9, $80, $26, $AB, $0D, $24, $82, $76, $D0, $F9, $5F, $20, $86,
    $AF, $09, $FD, $5B, $72, $D4, $59, $FF, $D6, $70, $84, $22, $0B, $AD, $F5,
    $53, $7A, $DC, $28, $8E, $A7, $01, $8C, $2A, $03, $A5, $51, $F7, $DE, $78,
    $07, $A1, $88, $2E, $DA, $7C, $55, $F3, $7E, $D8, $F1, $57, $A3, $05, $2C,
    $8A, $00, $A7, $8D, $2A, $D9, $7E, $54, $F3, $71, $D6, $FC, $5B, $A8, $0F,
    $25, $82, $E2, $45, $6F, $C8, $3B, $9C, $B6, $11, $93, $34, $1E, $B9, $4A,
    $ED, $C7, $60, $07, $A0, $8A, $2D, $DE, $79, $53, $F4, $76, $D1, $FB, $5C,
    $AF, $08, $22, $85, $E5, $42, $68, $CF, $3C, $9B, $B1, $16, $94, $33, $19,
    $BE, $4D, $EA, $C0, $67, $0E, $A9, $83, $24, $D7, $70, $5A, $FD, $7F, $D8,
    $F2, $55, $A6, $01, $2B, $8C, $EC, $4B, $61, $C6, $35, $92, $B8, $1F, $9D,
    $3A, $10, $B7, $44, $E3, $C9, $6E, $09, $AE, $84, $23, $D0, $77, $5D, $FA,
    $78, $DF, $F5, $52, $A1, $06, $2C, $8B, $EB, $4C, $66, $C1, $32, $95, $BF,
    $18, $9A, $3D, $17, $B0, $43, $E4, $CE, $69, $1C, $BB, $91, $36, $C5, $62,
    $48, $EF, $6D, $CA, $E0, $47, $B4, $13, $39, $9E, $FE, $59, $73, $D4, $27,
    $80, $AA, $0D, $8F, $28, $02, $A5, $56, $F1, $DB, $7C, $1B, $BC, $96, $31,
    $C2, $65, $4F, $E8, $6A, $CD, $E7, $40, $B3, $14, $3E, $99, $F9, $5E, $74,
    $D3, $20, $87, $AD, $0A, $88, $2F, $05, $A2, $51, $F6, $DC, $7B, $12, $B5,
    $9F, $38, $CB, $6C, $46, $E1, $63, $C4, $EE, $49, $BA, $1D, $37, $90, $F0,
    $57, $7D, $DA, $29, $8E, $A4, $03, $81, $26, $0C, $AB, $58, $FF, $D5, $72,
    $15, $B2, $98, $3F, $CC, $6B, $41, $E6, $64, $C3, $E9, $4E, $BD, $1A, $30,
    $97, $F7, $50, $7A, $DD, $2E, $89, $A3, $04, $86, $21, $0B, $AC, $5F, $F8,
    $D2, $75, $00, $A8, $93, $3B, $E5, $4D, $76, $DE, $09, $A1, $9A, $32, $EC,
    $44, $7F, $D7, $12, $BA, $81, $29, $F7, $5F, $64, $CC, $1B, $B3, $88, $20,
    $FE, $56, $6D, $C5, $24, $8C, $B7, $1F, $C1, $69, $52, $FA, $2D, $85, $BE,
    $16, $C8, $60, $5B, $F3, $36, $9E, $A5, $0D, $D3, $7B, $40, $E8, $3F, $97,
    $AC, $04, $DA, $72, $49, $E1, $48, $E0, $DB, $73, $AD, $05, $3E, $96, $41,
    $E9, $D2, $7A, $A4, $0C, $37, $9F, $5A, $F2, $C9, $61, $BF, $17, $2C, $84,
    $53, $FB, $C0, $68, $B6, $1E, $25, $8D, $6C, $C4, $FF, $57, $89, $21, $1A,
    $B2, $65, $CD, $F6, $5E, $80, $28, $13, $BB, $7E, $D6, $ED, $45, $9B, $33,
    $08, $A0, $77, $DF, $E4, $4C, $92, $3A, $01, $A9, $90, $38, $03, $AB, $75,
    $DD, $E6, $4E, $99, $31, $0A, $A2, $7C, $D4, $EF, $47, $82, $2A, $11, $B9,
    $67, $CF, $F4, $5C, $8B, $23, $18, $B0, $6E, $C6, $FD, $55, $B4, $1C, $27,
    $8F, $51, $F9, $C2, $6A, $BD, $15, $2E, $86, $58, $F0, $CB, $63, $A6, $0E,
    $35, $9D, $43, $EB, $D0, $78, $AF, $07, $3C, $94, $4A, $E2, $D9, $71, $D8,
    $70, $4B, $E3, $3D, $95, $AE, $06, $D1, $79, $42, $EA, $34, $9C, $A7, $0F,
    $CA, $62, $59, $F1, $2F, $87, $BC, $14, $C3, $6B, $50, $F8, $26, $8E, $B5,
    $1D, $FC, $54, $6F, $C7, $19, $B1, $8A, $22, $F5, $5D, $66, $CE, $10, $B8,
    $83, $2B, $EE, $46, $7D, $D5, $0B, $A3, $98, $30, $E7, $4F, $74, $DC, $02,
    $AA, $91, $39, $00, $A9, $91, $38, $E1, $48, $70, $D9, $01, $A8, $90, $39,
    $E0, $49, $71, $D8, $02, $AB, $93, $3A, $E3, $4A, $72, $DB, $03, $AA, $92,
    $3B, $E2, $4B, $73, $DA, $04, $AD, $95, $3C, $E5, $4C, $74, $DD, $05, $AC,
    $94, $3D, $E4, $4D, $75, $DC, $06, $AF, $97, $3E, $E7, $4E, $76, $DF, $07,
    $AE, $96, $3F, $E6, $4F, $77, $DE, $08, $A1, $99, $30, $E9, $40, $78, $D1,
    $09, $A0, $98, $31, $E8, $41, $79, $D0, $0A, $A3, $9B, $32, $EB, $42, $7A,
    $D3, $0B, $A2, $9A, $33, $EA, $43, $7B, $D2, $0C, $A5, $9D, $34, $ED, $44,
    $7C, $D5, $0D, $A4, $9C, $35, $EC, $45, $7D, $D4, $0E, $A7, $9F, $36, $EF,
    $46, $7E, $D7, $0F, $A6, $9E, $37, $EE, $47, $7F, $D6, $10, $B9, $81, $28,
    $F1, $58, $60, $C9, $11, $B8, $80, $29, $F0, $59, $61, $C8, $12, $BB, $83,
    $2A, $F3, $5A, $62, $CB, $13, $BA, $82, $2B, $F2, $5B, $63, $CA, $14, $BD,
    $85, $2C, $F5, $5C, $64, $CD, $15, $BC, $84, $2D, $F4, $5D, $65, $CC, $16,
    $BF, $87, $2E, $F7, $5E, $66, $CF, $17, $BE, $86, $2F, $F6, $5F, $67, $CE,
    $18, $B1, $89, $20, $F9, $50, $68, $C1, $19, $B0, $88, $21, $F8, $51, $69,
    $C0, $1A, $B3, $8B, $22, $FB, $52, $6A, $C3, $1B, $B2, $8A, $23, $FA, $53,
    $6B, $C2, $1C, $B5, $8D, $24, $FD, $54, $6C, $C5, $1D, $B4, $8C, $25, $FC,
    $55, $6D, $C4, $1E, $B7, $8F, $26, $FF, $56, $6E, $C7, $1F, $B6, $8E, $27,
    $FE, $57, $6F, $C6, $00, $AA, $97, $3D, $ED, $47, $7A, $D0, $19, $B3, $8E,
    $24, $F4, $5E, $63, $C9, $32, $98, $A5, $0F, $DF, $75, $48, $E2, $2B, $81,
    $BC, $16, $C6, $6C, $51, $FB, $64, $CE, $F3, $59, $89, $23, $1E, $B4, $7D,
    $D7, $EA, $40, $90, $3A, $07, $AD, $56, $FC, $C1, $6B, $BB, $11, $2C, $86,
    $4F, $E5, $D8, $72, $A2, $08, $35, $9F, $C8, $62, $5F, $F5, $25, $8F, $B2,
    $18, $D1, $7B, $46, $EC, $3C, $96, $AB, $01, $FA, $50, $6D, $C7, $17, $BD,
    $80, $2A, $E3, $49, $74, $DE, $0E, $A4, $99, $33, $AC, $06, $3B, $91, $41,
    $EB, $D6, $7C, $B5, $1F, $22, $88, $58, $F2, $CF, $65, $9E, $34, $09, $A3,
    $73, $D9, $E4, $4E, $87, $2D, $10, $BA, $6A, $C0, $FD, $57, $53, $F9, $C4,
    $6E, $BE, $14, $29, $83, $4A, $E0, $DD, $77, $A7, $0D, $30, $9A, $61, $CB,
    $F6, $5C, $8C, $26, $1B, $B1, $78, $D2, $EF, $45, $95, $3F, $02, $A8, $37,
    $9D, $A0, $0A, $DA, $70, $4D, $E7, $2E, $84, $B9, $13, $C3, $69, $54, $FE,
    $05, $AF, $92, $38, $E8, $42, $7F, $D5, $1C, $B6, $8B, $21, $F1, $5B, $66,
    $CC, $9B, $31, $0C, $A6, $76, $DC, $E1, $4B, $82, $28, $15, $BF, $6F, $C5,
    $F8, $52, $A9, $03, $3E, $94, $44, $EE, $D3, $79, $B0, $1A, $27, $8D, $5D,
    $F7, $CA, $60, $FF, $55, $68, $C2, $12, $B8, $85, $2F, $E6, $4C, $71, $DB,
    $0B, $A1, $9C, $36, $CD, $67, $5A, $F0, $20, $8A, $B7, $1D, $D4, $7E, $43,
    $E9, $39, $93, $AE, $04, $00, $AB, $95, $3E, $E9, $42, $7C, $D7, $11, $BA,
    $84, $2F, $F8, $53, $6D, $C6, $22, $89, $B7, $1C, $CB, $60, $5E, $F5, $33,
    $98, $A6, $0D, $DA, $71, $4F, $E4, $44, $EF, $D1, $7A, $AD, $06, $38, $93,
    $55, $FE, $C0, $6B, $BC, $17, $29, $82, $66, $CD, $F3, $58, $8F, $24, $1A,
    $B1, $77, $DC, $E2, $49, $9E, $35, $0B, $A0, $88, $23, $1D, $B6, $61, $CA,
    $F4, $5F, $99, $32, $0C, $A7, $70, $DB, $E5, $4E, $AA, $01, $3F, $94, $43,
    $E8, $D6, $7D, $BB, $10, $2E, $85, $52, $F9, $C7, $6C, $CC, $67, $59, $F2,
    $25, $8E, $B0, $1B, $DD, $76, $48, $E3, $34, $9F, $A1, $0A, $EE, $45, $7B,
    $D0, $07, $AC, $92, $39, $FF, $54, $6A, $C1, $16, $BD, $83, $28, $D3, $78,
    $46, $ED, $3A, $91, $AF, $04, $C2, $69, $57, $FC, $2B, $80, $BE, $15, $F1,
    $5A, $64, $CF, $18, $B3, $8D, $26, $E0, $4B, $75, $DE, $09, $A2, $9C, $37,
    $97, $3C, $02, $A9, $7E, $D5, $EB, $40, $86, $2D, $13, $B8, $6F, $C4, $FA,
    $51, $B5, $1E, $20, $8B, $5C, $F7, $C9, $62, $A4, $0F, $31, $9A, $4D, $E6,
    $D8, $73, $5B, $F0, $CE, $65, $B2, $19, $27, $8C, $4A, $E1, $DF, $74, $A3,
    $08, $36, $9D, $79, $D2, $EC, $47, $90, $3B, $05, $AE, $68, $C3, $FD, $56,
    $81, $2A, $14, $BF, $1F, $B4, $8A, $21, $F6, $5D, $63, $C8, $0E, $A5, $9B,
    $30, $E7, $4C, $72, $D9, $3D, $96, $A8, $03, $D4, $7F, $41, $EA, $2C, $87,
    $B9, $12, $C5, $6E, $50, $FB, $00, $AC, $9B, $37, $F5, $59, $6E, $C2, $29,
    $85, $B2, $1E, $DC, $70, $47, $EB, $52, $FE, $C9, $65, $A7, $0B, $3C, $90,
    $7B, $D7, $E0, $4C, $8E, $22, $15, $B9, $A4, $08, $3F, $93, $51, $FD, $CA,
    $66, $8D, $21, $16, $BA, $78, $D4, $E3, $4F, $F6, $5A, $6D, $C1, $03, $AF,
    $98, $34, $DF, $73, $44, $E8, $2A, $86, $B1, $1D, $8B, $27, $10, $BC, $7E,
    $D2, $E5, $49, $A2, $0E, $39, $95, $57, $FB, $CC, $60, $D9, $75, $42, $EE,
    $2C, $80, $B7, $1B, $F0, $5C, $6B, $C7, $05, $A9, $9E, $32, $2F, $83, $B4,
    $18, $DA, $76, $41, $ED, $06, $AA, $9D, $31, $F3, $5F, $68, $C4, $7D, $D1,
    $E6, $4A, $88, $24, $13, $BF, $54, $F8, $CF, $63, $A1, $0D, $3A, $96, $D5,
    $79, $4E, $E2, $20, $8C, $BB, $17, $FC, $50, $67, $CB, $09, $A5, $92, $3E,
    $87, $2B, $1C, $B0, $72, $DE, $E9, $45, $AE, $02, $35, $99, $5B, $F7, $C0,
    $6C, $71, $DD, $EA, $46, $84, $28, $1F, $B3, $58, $F4, $C3, $6F, $AD, $01,
    $36, $9A, $23, $8F, $B8, $14, $D6, $7A, $4D, $E1, $0A, $A6, $91, $3D, $FF,
    $53, $64, $C8, $5E, $F2, $C5, $69, $AB, $07, $30, $9C, $77, $DB, $EC, $40,
    $82, $2E, $19, $B5, $0C, $A0, $97, $3B, $F9, $55, $62, $CE, $25, $89, $BE,
    $12, $D0, $7C, $4B, $E7, $FA, $56, $61, $CD, $0F, $A3, $94, $38, $D3, $7F,
    $48, $E4, $26, $8A, $BD, $11, $A8, $04, $33, $9F, $5D, $F1, $C6, $6A, $81,
    $2D, $1A, $B6, $74, $D8, $EF, $43, $00, $AD, $99, $34, $F1, $5C, $68, $C5,
    $21, $8C, $B8, $15, $D0, $7D, $49, $E4, $42, $EF, $DB, $76, $B3, $1E, $2A,
    $87, $63, $CE, $FA, $57, $92, $3F, $0B, $A6, $84, $29, $1D, $B0, $75, $D8,
    $EC, $41, $A5, $08, $3C, $91, $54, $F9, $CD, $60, $C6, $6B, $5F, $F2, $37,
    $9A, $AE, $03, $E7, $4A, $7E, $D3, $16, $BB, $8F, $22, $CB, $66, $52, $FF,
    $3A, $97, $A3, $0E, $EA, $47, $73, $DE, $1B, $B6, $82, $2F, $89, $24, $10,
    $BD, $78, $D5, $E1, $4C, $A8, $05, $31, $9C, $59, $F4, $C0, $6D, $4F, $E2,
    $D6, $7B, $BE, $13, $27, $8A, $6E, $C3, $F7, $5A, $9F, $32, $06, $AB, $0D,
    $A0, $94, $39, $FC, $51, $65, $C8, $2C, $81, $B5, $18, $DD, $70, $44, $E9,
    $55, $F8, $CC, $61, $A4, $09, $3D, $90, $74, $D9, $ED, $40, $85, $28, $1C,
    $B1, $17, $BA, $8E, $23, $E6, $4B, $7F, $D2, $36, $9B, $AF, $02, $C7, $6A,
    $5E, $F3, $D1, $7C, $48, $E5, $20, $8D, $B9, $14, $F0, $5D, $69, $C4, $01,
    $AC, $98, $35, $93, $3E, $0A, $A7, $62, $CF, $FB, $56, $B2, $1F, $2B, $86,
    $43, $EE, $DA, $77, $9E, $33, $07, $AA, $6F, $C2, $F6, $5B, $BF, $12, $26,
    $8B, $4E, $E3, $D7, $7A, $DC, $71, $45, $E8, $2D, $80, $B4, $19, $FD, $50,
    $64, $C9, $0C, $A1, $95, $38, $1A, $B7, $83, $2E, $EB, $46, $72, $DF, $3B,
    $96, $A2, $0F, $CA, $67, $53, $FE, $58, $F5, $C1, $6C, $A9, $04, $30, $9D,
    $79, $D4, $E0, $4D, $88, $25, $11, $BC, $00, $AE, $9F, $31, $FD, $53, $62,
    $CC, $39, $97, $A6, $08, $C4, $6A, $5B, $F5, $72, $DC, $ED, $43, $8F, $21,
    $10, $BE, $4B, $E5, $D4, $7A, $B6, $18, $29, $87, $E4, $4A, $7B, $D5, $19,
    $B7, $86, $28, $DD, $73, $42, $EC, $20, $8E, $BF, $11, $96, $38, $09, $A7,
    $6B, $C5, $F4, $5A, $AF, $01, $30, $9E, $52, $FC, $CD, $63, $0B, $A5, $94,
    $3A, $F6, $58, $69, $C7, $32, $9C, $AD, $03, $CF, $61, $50, $FE, $79, $D7,
    $E6, $48, $84, $2A, $1B, $B5, $40, $EE, $DF, $71, $BD, $13, $22, $8C, $EF,
    $41, $70, $DE, $12, $BC, $8D, $23, $D6, $78, $49, $E7, $2B, $85, $B4, $1A,
    $9D, $33, $02, $AC, $60, $CE, $FF, $51, $A4, $0A, $3B, $95, $59, $F7, $C6,
    $68, $16, $B8, $89, $27, $EB, $45, $74, $DA, $2F, $81, $B0, $1E, $D2, $7C,
    $4D, $E3, $64, $CA, $FB, $55, $99, $37, $06, $A8, $5D, $F3, $C2, $6C, $A0,
    $0E, $3F, $91, $F2, $5C, $6D, $C3, $0F, $A1, $90, $3E, $CB, $65, $54, $FA,
    $36, $98, $A9, $07, $80, $2E, $1F, $B1, $7D, $D3, $E2, $4C, $B9, $17, $26,
    $88, $44, $EA, $DB, $75, $1D, $B3, $82, $2C, $E0, $4E, $7F, $D1, $24, $8A,
    $BB, $15, $D9, $77, $46, $E8, $6F, $C1, $F0, $5E, $92, $3C, $0D, $A3, $56,
    $F8, $C9, $67, $AB, $05, $34, $9A, $F9, $57, $66, $C8, $04, $AA, $9B, $35,
    $C0, $6E, $5F, $F1, $3D, $93, $A2, $0C, $8B, $25, $14, $BA, $76, $D8, $E9,
    $47, $B2, $1C, $2D, $83, $4F, $E1, $D0, $7E, $00, $AF, $9D, $32, $F9, $56,
    $64, $CB, $31, $9E, $AC, $03, $C8, $67, $55, $FA, $62, $CD, $FF, $50, $9B,
    $34, $06, $A9, $53, $FC, $CE, $61, $AA, $05, $37, $98, $C4, $6B, $59, $F6,
    $3D, $92, $A0, $0F, $F5, $5A, $68, $C7, $0C, $A3, $91, $3E, $A6, $09, $3B,
    $94, $5F, $F0, $C2, $6D, $97, $38, $0A, $A5, $6E, $C1, $F3, $5C, $4B, $E4,
    $D6, $79, $B2, $1D, $2F, $80, $7A, $D5, $E7, $48, $83, $2C, $1E, $B1, $29,
    $86, $B4, $1B, $D0, $7F, $4D, $E2, $18, $B7, $85, $2A, $E1, $4E, $7C, $D3,
    $8F, $20, $12, $BD, $76, $D9, $EB, $44, $BE, $11, $23, $8C, $47, $E8, $DA,
    $75, $ED, $42, $70, $DF, $14, $BB, $89, $26, $DC, $73, $41, $EE, $25, $8A,
    $B8, $17, $96, $39, $0B, $A4, $6F, $C0, $F2, $5D, $A7, $08, $3A, $95, $5E,
    $F1, $C3, $6C, $F4, $5B, $69, $C6, $0D, $A2, $90, $3F, $C5, $6A, $58, $F7,
    $3C, $93, $A1, $0E, $52, $FD, $CF, $60, $AB, $04, $36, $99, $63, $CC, $FE,
    $51, $9A, $35, $07, $A8, $30, $9F, $AD, $02, $C9, $66, $54, $FB, $01, $AE,
    $9C, $33, $F8, $57, $65, $CA, $DD, $72, $40, $EF, $24, $8B, $B9, $16, $EC,
    $43, $71, $DE, $15, $BA, $88, $27, $BF, $10, $22, $8D, $46, $E9, $DB, $74,
    $8E, $21, $13, $BC, $77, $D8, $EA, $45, $19, $B6, $84, $2B, $E0, $4F, $7D,
    $D2, $28, $87, $B5, $1A, $D1, $7E, $4C, $E3, $7B, $D4, $E6, $49, $82, $2D,
    $1F, $B0, $4A, $E5, $D7, $78, $B3, $1C, $2E, $81, $00, $B0, $A3, $13, $85,
    $35, $26, $96, $C9, $79, $6A, $DA, $4C, $FC, $EF, $5F, $51, $E1, $F2, $42,
    $D4, $64, $77, $C7, $98, $28, $3B, $8B, $1D, $AD, $BE, $0E, $A2, $12, $01,
    $B1, $27, $97, $84, $34, $6B, $DB, $C8, $78, $EE, $5E, $4D, $FD, $F3, $43,
    $50, $E0, $76, $C6, $D5, $65, $3A, $8A, $99, $29, $BF, $0F, $1C, $AC, $87,
    $37, $24, $94, $02, $B2, $A1, $11, $4E, $FE, $ED, $5D, $CB, $7B, $68, $D8,
    $D6, $66, $75, $C5, $53, $E3, $F0, $40, $1F, $AF, $BC, $0C, $9A, $2A, $39,
    $89, $25, $95, $86, $36, $A0, $10, $03, $B3, $EC, $5C, $4F, $FF, $69, $D9,
    $CA, $7A, $74, $C4, $D7, $67, $F1, $41, $52, $E2, $BD, $0D, $1E, $AE, $38,
    $88, $9B, $2B, $CD, $7D, $6E, $DE, $48, $F8, $EB, $5B, $04, $B4, $A7, $17,
    $81, $31, $22, $92, $9C, $2C, $3F, $8F, $19, $A9, $BA, $0A, $55, $E5, $F6,
    $46, $D0, $60, $73, $C3, $6F, $DF, $CC, $7C, $EA, $5A, $49, $F9, $A6, $16,
    $05, $B5, $23, $93, $80, $30, $3E, $8E, $9D, $2D, $BB, $0B, $18, $A8, $F7,
    $47, $54, $E4, $72, $C2, $D1, $61, $4A, $FA, $E9, $59, $CF, $7F, $6C, $DC,
    $83, $33, $20, $90, $06, $B6, $A5, $15, $1B, $AB, $B8, $08, $9E, $2E, $3D,
    $8D, $D2, $62, $71, $C1, $57, $E7, $F4, $44, $E8, $58, $4B, $FB, $6D, $DD,
    $CE, $7E, $21, $91, $82, $32, $A4, $14, $07, $B7, $B9, $09, $1A, $AA, $3C,
    $8C, $9F, $2F, $70, $C0, $D3, $63, $F5, $45, $56, $E6, $00, $B1, $A1, $10,
    $81, $30, $20, $91, $C1, $70, $60, $D1, $40, $F1, $E1, $50, $41, $F0, $E0,
    $51, $C0, $71, $61, $D0, $80, $31, $21, $90, $01, $B0, $A0, $11, $82, $33,
    $23, $92, $03, $B2, $A2, $13, $43, $F2, $E2, $53, $C2, $73, $63, $D2, $C3,
    $72, $62, $D3, $42, $F3, $E3, $52, $02, $B3, $A3, $12, $83, $32, $22, $93,
    $C7, $76, $66, $D7, $46, $F7, $E7, $56, $06, $B7, $A7, $16, $87, $36, $26,
    $97, $86, $37, $27, $96, $07, $B6, $A6, $17, $47, $F6, $E6, $57, $C6, $77,
    $67, $D6, $45, $F4, $E4, $55, $C4, $75, $65, $D4, $84, $35, $25, $94, $05,
    $B4, $A4, $15, $04, $B5, $A5, $14, $85, $34, $24, $95, $C5, $74, $64, $D5,
    $44, $F5, $E5, $54, $4D, $FC, $EC, $5D, $CC, $7D, $6D, $DC, $8C, $3D, $2D,
    $9C, $0D, $BC, $AC, $1D, $0C, $BD, $AD, $1C, $8D, $3C, $2C, $9D, $CD, $7C,
    $6C, $DD, $4C, $FD, $ED, $5C, $CF, $7E, $6E, $DF, $4E, $FF, $EF, $5E, $0E,
    $BF, $AF, $1E, $8F, $3E, $2E, $9F, $8E, $3F, $2F, $9E, $0F, $BE, $AE, $1F,
    $4F, $FE, $EE, $5F, $CE, $7F, $6F, $DE, $8A, $3B, $2B, $9A, $0B, $BA, $AA,
    $1B, $4B, $FA, $EA, $5B, $CA, $7B, $6B, $DA, $CB, $7A, $6A, $DB, $4A, $FB,
    $EB, $5A, $0A, $BB, $AB, $1A, $8B, $3A, $2A, $9B, $08, $B9, $A9, $18, $89,
    $38, $28, $99, $C9, $78, $68, $D9, $48, $F9, $E9, $58, $49, $F8, $E8, $59,
    $C8, $79, $69, $D8, $88, $39, $29, $98, $09, $B8, $A8, $19, $00, $B2, $A7,
    $15, $8D, $3F, $2A, $98, $D9, $6B, $7E, $CC, $54, $E6, $F3, $41, $71, $C3,
    $D6, $64, $FC, $4E, $5B, $E9, $A8, $1A, $0F, $BD, $25, $97, $82, $30, $E2,
    $50, $45, $F7, $6F, $DD, $C8, $7A, $3B, $89, $9C, $2E, $B6, $04, $11, $A3,
    $93, $21, $34, $86, $1E, $AC, $B9, $0B, $4A, $F8, $ED, $5F, $C7, $75, $60,
    $D2, $07, $B5, $A0, $12, $8A, $38, $2D, $9F, $DE, $6C, $79, $CB, $53, $E1,
    $F4, $46, $76, $C4, $D1, $63, $FB, $49, $5C, $EE, $AF, $1D, $08, $BA, $22,
    $90, $85, $37, $E5, $57, $42, $F0, $68, $DA, $CF, $7D, $3C, $8E, $9B, $29,
    $B1, $03, $16, $A4, $94, $26, $33, $81, $19, $AB, $BE, $0C, $4D, $FF, $EA,
    $58, $C0, $72, $67, $D5, $0E, $BC, $A9, $1B, $83, $31, $24, $96, $D7, $65,
    $70, $C2, $5A, $E8, $FD, $4F, $7F, $CD, $D8, $6A, $F2, $40, $55, $E7, $A6,
    $14, $01, $B3, $2B, $99, $8C, $3E, $EC, $5E, $4B, $F9, $61, $D3, $C6, $74,
    $35, $87, $92, $20, $B8, $0A, $1F, $AD, $9D, $2F, $3A, $88, $10, $A2, $B7,
    $05, $44, $F6, $E3, $51, $C9, $7B, $6E, $DC, $09, $BB, $AE, $1C, $84, $36,
    $23, $91, $D0, $62, $77, $C5, $5D, $EF, $FA, $48, $78, $CA, $DF, $6D, $F5,
    $47, $52, $E0, $A1, $13, $06, $B4, $2C, $9E, $8B, $39, $EB, $59, $4C, $FE,
    $66, $D4, $C1, $73, $32, $80, $95, $27, $BF, $0D, $18, $AA, $9A, $28, $3D,
    $8F, $17, $A5, $B0, $02, $43, $F1, $E4, $56, $CE, $7C, $69, $DB, $00, $B3,
    $A5, $16, $89, $3A, $2C, $9F, $D1, $62, $74, $C7, $58, $EB, $FD, $4E, $61,
    $D2, $C4, $77, $E8, $5B, $4D, $FE, $B0, $03, $15, $A6, $39, $8A, $9C, $2F,
    $C2, $71, $67, $D4, $4B, $F8, $EE, $5D, $13, $A0, $B6, $05, $9A, $29, $3F,
    $8C, $A3, $10, $06, $B5, $2A, $99, $8F, $3C, $72, $C1, $D7, $64, $FB, $48,
    $5E, $ED, $47, $F4, $E2, $51, $CE, $7D, $6B, $D8, $96, $25, $33, $80, $1F,
    $AC, $BA, $09, $26, $95, $83, $30, $AF, $1C, $0A, $B9, $F7, $44, $52, $E1,
    $7E, $CD, $DB, $68, $85, $36, $20, $93, $0C, $BF, $A9, $1A, $54, $E7, $F1,
    $42, $DD, $6E, $78, $CB, $E4, $57, $41, $F2, $6D, $DE, $C8, $7B, $35, $86,
    $90, $23, $BC, $0F, $19, $AA, $8E, $3D, $2B, $98, $07, $B4, $A2, $11, $5F,
    $EC, $FA, $49, $D6, $65, $73, $C0, $EF, $5C, $4A, $F9, $66, $D5, $C3, $70,
    $3E, $8D, $9B, $28, $B7, $04, $12, $A1, $4C, $FF, $E9, $5A, $C5, $76, $60,
    $D3, $9D, $2E, $38, $8B, $14, $A7, $B1, $02, $2D, $9E, $88, $3B, $A4, $17,
    $01, $B2, $FC, $4F, $59, $EA, $75, $C6, $D0, $63, $C9, $7A, $6C, $DF, $40,
    $F3, $E5, $56, $18, $AB, $BD, $0E, $91, $22, $34, $87, $A8, $1B, $0D, $BE,
    $21, $92, $84, $37, $79, $CA, $DC, $6F, $F0, $43, $55, $E6, $0B, $B8, $AE,
    $1D, $82, $31, $27, $94, $DA, $69, $7F, $CC, $53, $E0, $F6, $45, $6A, $D9,
    $CF, $7C, $E3, $50, $46, $F5, $BB, $08, $1E, $AD, $32, $81, $97, $24, $00,
    $B4, $AB, $1F, $95, $21, $3E, $8A, $E9, $5D, $42, $F6, $7C, $C8, $D7, $63,
    $11, $A5, $BA, $0E, $84, $30, $2F, $9B, $F8, $4C, $53, $E7, $6D, $D9, $C6,
    $72, $22, $96, $89, $3D, $B7, $03, $1C, $A8, $CB, $7F, $60, $D4, $5E, $EA,
    $F5, $41, $33, $87, $98, $2C, $A6, $12, $0D, $B9, $DA, $6E, $71, $C5, $4F,
    $FB, $E4, $50, $44, $F0, $EF, $5B, $D1, $65, $7A, $CE, $AD, $19, $06, $B2,
    $38, $8C, $93, $27, $55, $E1, $FE, $4A, $C0, $74, $6B, $DF, $BC, $08, $17,
    $A3, $29, $9D, $82, $36, $66, $D2, $CD, $79, $F3, $47, $58, $EC, $8F, $3B,
    $24, $90, $1A, $AE, $B1, $05, $77, $C3, $DC, $68, $E2, $56, $49, $FD, $9E,
    $2A, $35, $81, $0B, $BF, $A0, $14, $88, $3C, $23, $97, $1D, $A9, $B6, $02,
    $61, $D5, $CA, $7E, $F4, $40, $5F, $EB, $99, $2D, $32, $86, $0C, $B8, $A7,
    $13, $70, $C4, $DB, $6F, $E5, $51, $4E, $FA, $AA, $1E, $01, $B5, $3F, $8B,
    $94, $20, $43, $F7, $E8, $5C, $D6, $62, $7D, $C9, $BB, $0F, $10, $A4, $2E,
    $9A, $85, $31, $52, $E6, $F9, $4D, $C7, $73, $6C, $D8, $CC, $78, $67, $D3,
    $59, $ED, $F2, $46, $25, $91, $8E, $3A, $B0, $04, $1B, $AF, $DD, $69, $76,
    $C2, $48, $FC, $E3, $57, $34, $80, $9F, $2B, $A1, $15, $0A, $BE, $EE, $5A,
    $45, $F1, $7B, $CF, $D0, $64, $07, $B3, $AC, $18, $92, $26, $39, $8D, $FF,
    $4B, $54, $E0, $6A, $DE, $C1, $75, $16, $A2, $BD, $09, $83, $37, $28, $9C,
    $00, $B5, $A9, $1C, $91, $24, $38, $8D, $E1, $54, $48, $FD, $70, $C5, $D9,
    $6C, $01, $B4, $A8, $1D, $90, $25, $39, $8C, $E0, $55, $49, $FC, $71, $C4,
    $D8, $6D, $02, $B7, $AB, $1E, $93, $26, $3A, $8F, $E3, $56, $4A, $FF, $72,
    $C7, $DB, $6E, $03, $B6, $AA, $1F, $92, $27, $3B, $8E, $E2, $57, $4B, $FE,
    $73, $C6, $DA, $6F, $04, $B1, $AD, $18, $95, $20, $3C, $89, $E5, $50, $4C,
    $F9, $74, $C1, $DD, $68, $05, $B0, $AC, $19, $94, $21, $3D, $88, $E4, $51,
    $4D, $F8, $75, $C0, $DC, $69, $06, $B3, $AF, $1A, $97, $22, $3E, $8B, $E7,
    $52, $4E, $FB, $76, $C3, $DF, $6A, $07, $B2, $AE, $1B, $96, $23, $3F, $8A,
    $E6, $53, $4F, $FA, $77, $C2, $DE, $6B, $08, $BD, $A1, $14, $99, $2C, $30,
    $85, $E9, $5C, $40, $F5, $78, $CD, $D1, $64, $09, $BC, $A0, $15, $98, $2D,
    $31, $84, $E8, $5D, $41, $F4, $79, $CC, $D0, $65, $0A, $BF, $A3, $16, $9B,
    $2E, $32, $87, $EB, $5E, $42, $F7, $7A, $CF, $D3, $66, $0B, $BE, $A2, $17,
    $9A, $2F, $33, $86, $EA, $5F, $43, $F6, $7B, $CE, $D2, $67, $0C, $B9, $A5,
    $10, $9D, $28, $34, $81, $ED, $58, $44, $F1, $7C, $C9, $D5, $60, $0D, $B8,
    $A4, $11, $9C, $29, $35, $80, $EC, $59, $45, $F0, $7D, $C8, $D4, $61, $0E,
    $BB, $A7, $12, $9F, $2A, $36, $83, $EF, $5A, $46, $F3, $7E, $CB, $D7, $62,
    $0F, $BA, $A6, $13, $9E, $2B, $37, $82, $EE, $5B, $47, $F2, $7F, $CA, $D6,
    $63, $00, $B6, $AF, $19, $9D, $2B, $32, $84, $F9, $4F, $56, $E0, $64, $D2,
    $CB, $7D, $31, $87, $9E, $28, $AC, $1A, $03, $B5, $C8, $7E, $67, $D1, $55,
    $E3, $FA, $4C, $62, $D4, $CD, $7B, $FF, $49, $50, $E6, $9B, $2D, $34, $82,
    $06, $B0, $A9, $1F, $53, $E5, $FC, $4A, $CE, $78, $61, $D7, $AA, $1C, $05,
    $B3, $37, $81, $98, $2E, $C4, $72, $6B, $DD, $59, $EF, $F6, $40, $3D, $8B,
    $92, $24, $A0, $16, $0F, $B9, $F5, $43, $5A, $EC, $68, $DE, $C7, $71, $0C,
    $BA, $A3, $15, $91, $27, $3E, $88, $A6, $10, $09, $BF, $3B, $8D, $94, $22,
    $5F, $E9, $F0, $46, $C2, $74, $6D, $DB, $97, $21, $38, $8E, $0A, $BC, $A5,
    $13, $6E, $D8, $C1, $77, $F3, $45, $5C, $EA, $4B, $FD, $E4, $52, $D6, $60,
    $79, $CF, $B2, $04, $1D, $AB, $2F, $99, $80, $36, $7A, $CC, $D5, $63, $E7,
    $51, $48, $FE, $83, $35, $2C, $9A, $1E, $A8, $B1, $07, $29, $9F, $86, $30,
    $B4, $02, $1B, $AD, $D0, $66, $7F, $C9, $4D, $FB, $E2, $54, $18, $AE, $B7,
    $01, $85, $33, $2A, $9C, $E1, $57, $4E, $F8, $7C, $CA, $D3, $65, $8F, $39,
    $20, $96, $12, $A4, $BD, $0B, $76, $C0, $D9, $6F, $EB, $5D, $44, $F2, $BE,
    $08, $11, $A7, $23, $95, $8C, $3A, $47, $F1, $E8, $5E, $DA, $6C, $75, $C3,
    $ED, $5B, $42, $F4, $70, $C6, $DF, $69, $14, $A2, $BB, $0D, $89, $3F, $26,
    $90, $DC, $6A, $73, $C5, $41, $F7, $EE, $58, $25, $93, $8A, $3C, $B8, $0E,
    $17, $A1, $00, $B7, $AD, $1A, $99, $2E, $34, $83, $F1, $46, $5C, $EB, $68,
    $DF, $C5, $72, $21, $96, $8C, $3B, $B8, $0F, $15, $A2, $D0, $67, $7D, $CA,
    $49, $FE, $E4, $53, $42, $F5, $EF, $58, $DB, $6C, $76, $C1, $B3, $04, $1E,
    $A9, $2A, $9D, $87, $30, $63, $D4, $CE, $79, $FA, $4D, $57, $E0, $92, $25,
    $3F, $88, $0B, $BC, $A6, $11, $84, $33, $29, $9E, $1D, $AA, $B0, $07, $75,
    $C2, $D8, $6F, $EC, $5B, $41, $F6, $A5, $12, $08, $BF, $3C, $8B, $91, $26,
    $54, $E3, $F9, $4E, $CD, $7A, $60, $D7, $C6, $71, $6B, $DC, $5F, $E8, $F2,
    $45, $37, $80, $9A, $2D, $AE, $19, $03, $B4, $E7, $50, $4A, $FD, $7E, $C9,
    $D3, $64, $16, $A1, $BB, $0C, $8F, $38, $22, $95, $CB, $7C, $66, $D1, $52,
    $E5, $FF, $48, $3A, $8D, $97, $20, $A3, $14, $0E, $B9, $EA, $5D, $47, $F0,
    $73, $C4, $DE, $69, $1B, $AC, $B6, $01, $82, $35, $2F, $98, $89, $3E, $24,
    $93, $10, $A7, $BD, $0A, $78, $CF, $D5, $62, $E1, $56, $4C, $FB, $A8, $1F,
    $05, $B2, $31, $86, $9C, $2B, $59, $EE, $F4, $43, $C0, $77, $6D, $DA, $4F,
    $F8, $E2, $55, $D6, $61, $7B, $CC, $BE, $09, $13, $A4, $27, $90, $8A, $3D,
    $6E, $D9, $C3, $74, $F7, $40, $5A, $ED, $9F, $28, $32, $85, $06, $B1, $AB,
    $1C, $0D, $BA, $A0, $17, $94, $23, $39, $8E, $FC, $4B, $51, $E6, $65, $D2,
    $C8, $7F, $2C, $9B, $81, $36, $B5, $02, $18, $AF, $DD, $6A, $70, $C7, $44,
    $F3, $E9, $5E, $00, $B8, $B3, $0B, $A5, $1D, $16, $AE, $89, $31, $3A, $82,
    $2C, $94, $9F, $27, $D1, $69, $62, $DA, $74, $CC, $C7, $7F, $58, $E0, $EB,
    $53, $FD, $45, $4E, $F6, $61, $D9, $D2, $6A, $C4, $7C, $77, $CF, $E8, $50,
    $5B, $E3, $4D, $F5, $FE, $46, $B0, $08, $03, $BB, $15, $AD, $A6, $1E, $39,
    $81, $8A, $32, $9C, $24, $2F, $97, $C2, $7A, $71, $C9, $67, $DF, $D4, $6C,
    $4B, $F3, $F8, $40, $EE, $56, $5D, $E5, $13, $AB, $A0, $18, $B6, $0E, $05,
    $BD, $9A, $22, $29, $91, $3F, $87, $8C, $34, $A3, $1B, $10, $A8, $06, $BE,
    $B5, $0D, $2A, $92, $99, $21, $8F, $37, $3C, $84, $72, $CA, $C1, $79, $D7,
    $6F, $64, $DC, $FB, $43, $48, $F0, $5E, $E6, $ED, $55, $47, $FF, $F4, $4C,
    $E2, $5A, $51, $E9, $CE, $76, $7D, $C5, $6B, $D3, $D8, $60, $96, $2E, $25,
    $9D, $33, $8B, $80, $38, $1F, $A7, $AC, $14, $BA, $02, $09, $B1, $26, $9E,
    $95, $2D, $83, $3B, $30, $88, $AF, $17, $1C, $A4, $0A, $B2, $B9, $01, $F7,
    $4F, $44, $FC, $52, $EA, $E1, $59, $7E, $C6, $CD, $75, $DB, $63, $68, $D0,
    $85, $3D, $36, $8E, $20, $98, $93, $2B, $0C, $B4, $BF, $07, $A9, $11, $1A,
    $A2, $54, $EC, $E7, $5F, $F1, $49, $42, $FA, $DD, $65, $6E, $D6, $78, $C0,
    $CB, $73, $E4, $5C, $57, $EF, $41, $F9, $F2, $4A, $6D, $D5, $DE, $66, $C8,
    $70, $7B, $C3, $35, $8D, $86, $3E, $90, $28, $23, $9B, $BC, $04, $0F, $B7,
    $19, $A1, $AA, $12, $00, $B9, $B1, $08, $A1, $18, $10, $A9, $81, $38, $30,
    $89, $20, $99, $91, $28, $C1, $78, $70, $C9, $60, $D9, $D1, $68, $40, $F9,
    $F1, $48, $E1, $58, $50, $E9, $41, $F8, $F0, $49, $E0, $59, $51, $E8, $C0,
    $79, $71, $C8, $61, $D8, $D0, $69, $80, $39, $31, $88, $21, $98, $90, $29,
    $01, $B8, $B0, $09, $A0, $19, $11, $A8, $82, $3B, $33, $8A, $23, $9A, $92,
    $2B, $03, $BA, $B2, $0B, $A2, $1B, $13, $AA, $43, $FA, $F2, $4B, $E2, $5B,
    $53, $EA, $C2, $7B, $73, $CA, $63, $DA, $D2, $6B, $C3, $7A, $72, $CB, $62,
    $DB, $D3, $6A, $42, $FB, $F3, $4A, $E3, $5A, $52, $EB, $02, $BB, $B3, $0A,
    $A3, $1A, $12, $AB, $83, $3A, $32, $8B, $22, $9B, $93, $2A, $C7, $7E, $76,
    $CF, $66, $DF, $D7, $6E, $46, $FF, $F7, $4E, $E7, $5E, $56, $EF, $06, $BF,
    $B7, $0E, $A7, $1E, $16, $AF, $87, $3E, $36, $8F, $26, $9F, $97, $2E, $86,
    $3F, $37, $8E, $27, $9E, $96, $2F, $07, $BE, $B6, $0F, $A6, $1F, $17, $AE,
    $47, $FE, $F6, $4F, $E6, $5F, $57, $EE, $C6, $7F, $77, $CE, $67, $DE, $D6,
    $6F, $45, $FC, $F4, $4D, $E4, $5D, $55, $EC, $C4, $7D, $75, $CC, $65, $DC,
    $D4, $6D, $84, $3D, $35, $8C, $25, $9C, $94, $2D, $05, $BC, $B4, $0D, $A4,
    $1D, $15, $AC, $04, $BD, $B5, $0C, $A5, $1C, $14, $AD, $85, $3C, $34, $8D,
    $24, $9D, $95, $2C, $C5, $7C, $74, $CD, $64, $DD, $D5, $6C, $44, $FD, $F5,
    $4C, $E5, $5C, $54, $ED, $00, $BA, $B7, $0D, $AD, $17, $1A, $A0, $99, $23,
    $2E, $94, $34, $8E, $83, $39, $F1, $4B, $46, $FC, $5C, $E6, $EB, $51, $68,
    $D2, $DF, $65, $C5, $7F, $72, $C8, $21, $9B, $96, $2C, $8C, $36, $3B, $81,
    $B8, $02, $0F, $B5, $15, $AF, $A2, $18, $D0, $6A, $67, $DD, $7D, $C7, $CA,
    $70, $49, $F3, $FE, $44, $E4, $5E, $53, $E9, $42, $F8, $F5, $4F, $EF, $55,
    $58, $E2, $DB, $61, $6C, $D6, $76, $CC, $C1, $7B, $B3, $09, $04, $BE, $1E,
    $A4, $A9, $13, $2A, $90, $9D, $27, $87, $3D, $30, $8A, $63, $D9, $D4, $6E,
    $CE, $74, $79, $C3, $FA, $40, $4D, $F7, $57, $ED, $E0, $5A, $92, $28, $25,
    $9F, $3F, $85, $88, $32, $0B, $B1, $BC, $06, $A6, $1C, $11, $AB, $84, $3E,
    $33, $89, $29, $93, $9E, $24, $1D, $A7, $AA, $10, $B0, $0A, $07, $BD, $75,
    $CF, $C2, $78, $D8, $62, $6F, $D5, $EC, $56, $5B, $E1, $41, $FB, $F6, $4C,
    $A5, $1F, $12, $A8, $08, $B2, $BF, $05, $3C, $86, $8B, $31, $91, $2B, $26,
    $9C, $54, $EE, $E3, $59, $F9, $43, $4E, $F4, $CD, $77, $7A, $C0, $60, $DA,
    $D7, $6D, $C6, $7C, $71, $CB, $6B, $D1, $DC, $66, $5F, $E5, $E8, $52, $F2,
    $48, $45, $FF, $37, $8D, $80, $3A, $9A, $20, $2D, $97, $AE, $14, $19, $A3,
    $03, $B9, $B4, $0E, $E7, $5D, $50, $EA, $4A, $F0, $FD, $47, $7E, $C4, $C9,
    $73, $D3, $69, $64, $DE, $16, $AC, $A1, $1B, $BB, $01, $0C, $B6, $8F, $35,
    $38, $82, $22, $98, $95, $2F, $00, $BB, $B5, $0E, $A9, $12, $1C, $A7, $91,
    $2A, $24, $9F, $38, $83, $8D, $36, $E1, $5A, $54, $EF, $48, $F3, $FD, $46,
    $70, $CB, $C5, $7E, $D9, $62, $6C, $D7, $01, $BA, $B4, $0F, $A8, $13, $1D,
    $A6, $90, $2B, $25, $9E, $39, $82, $8C, $37, $E0, $5B, $55, $EE, $49, $F2,
    $FC, $47, $71, $CA, $C4, $7F, $D8, $63, $6D, $D6, $02, $B9, $B7, $0C, $AB,
    $10, $1E, $A5, $93, $28, $26, $9D, $3A, $81, $8F, $34, $E3, $58, $56, $ED,
    $4A, $F1, $FF, $44, $72, $C9, $C7, $7C, $DB, $60, $6E, $D5, $03, $B8, $B6,
    $0D, $AA, $11, $1F, $A4, $92, $29, $27, $9C, $3B, $80, $8E, $35, $E2, $59,
    $57, $EC, $4B, $F0, $FE, $45, $73, $C8, $C6, $7D, $DA, $61, $6F, $D4, $04,
    $BF, $B1, $0A, $AD, $16, $18, $A3, $95, $2E, $20, $9B, $3C, $87, $89, $32,
    $E5, $5E, $50, $EB, $4C, $F7, $F9, $42, $74, $CF, $C1, $7A, $DD, $66, $68,
    $D3, $05, $BE, $B0, $0B, $AC, $17, $19, $A2, $94, $2F, $21, $9A, $3D, $86,
    $88, $33, $E4, $5F, $51, $EA, $4D, $F6, $F8, $43, $75, $CE, $C0, $7B, $DC,
    $67, $69, $D2, $06, $BD, $B3, $08, $AF, $14, $1A, $A1, $97, $2C, $22, $99,
    $3E, $85, $8B, $30, $E7, $5C, $52, $E9, $4E, $F5, $FB, $40, $76, $CD, $C3,
    $78, $DF, $64, $6A, $D1, $07, $BC, $B2, $09, $AE, $15, $1B, $A0, $96, $2D,
    $23, $98, $3F, $84, $8A, $31, $E6, $5D, $53, $E8, $4F, $F4, $FA, $41, $77,
    $CC, $C2, $79, $DE, $65, $6B, $D0, $00, $BC, $BB, $07, $B5, $09, $0E, $B2,
    $A9, $15, $12, $AE, $1C, $A0, $A7, $1B, $91, $2D, $2A, $96, $24, $98, $9F,
    $23, $38, $84, $83, $3F, $8D, $31, $36, $8A, $E1, $5D, $5A, $E6, $54, $E8,
    $EF, $53, $48, $F4, $F3, $4F, $FD, $41, $46, $FA, $70, $CC, $CB, $77, $C5,
    $79, $7E, $C2, $D9, $65, $62, $DE, $6C, $D0, $D7, $6B, $01, $BD, $BA, $06,
    $B4, $08, $0F, $B3, $A8, $14, $13, $AF, $1D, $A1, $A6, $1A, $90, $2C, $2B,
    $97, $25, $99, $9E, $22, $39, $85, $82, $3E, $8C, $30, $37, $8B, $E0, $5C,
    $5B, $E7, $55, $E9, $EE, $52, $49, $F5, $F2, $4E, $FC, $40, $47, $FB, $71,
    $CD, $CA, $76, $C4, $78, $7F, $C3, $D8, $64, $63, $DF, $6D, $D1, $D6, $6A,
    $02, $BE, $B9, $05, $B7, $0B, $0C, $B0, $AB, $17, $10, $AC, $1E, $A2, $A5,
    $19, $93, $2F, $28, $94, $26, $9A, $9D, $21, $3A, $86, $81, $3D, $8F, $33,
    $34, $88, $E3, $5F, $58, $E4, $56, $EA, $ED, $51, $4A, $F6, $F1, $4D, $FF,
    $43, $44, $F8, $72, $CE, $C9, $75, $C7, $7B, $7C, $C0, $DB, $67, $60, $DC,
    $6E, $D2, $D5, $69, $03, $BF, $B8, $04, $B6, $0A, $0D, $B1, $AA, $16, $11,
    $AD, $1F, $A3, $A4, $18, $92, $2E, $29, $95, $27, $9B, $9C, $20, $3B, $87,
    $80, $3C, $8E, $32, $35, $89, $E2, $5E, $59, $E5, $57, $EB, $EC, $50, $4B,
    $F7, $F0, $4C, $FE, $42, $45, $F9, $73, $CF, $C8, $74, $C6, $7A, $7D, $C1,
    $DA, $66, $61, $DD, $6F, $D3, $D4, $68, $00, $BD, $B9, $04, $B1, $0C, $08,
    $B5, $A1, $1C, $18, $A5, $10, $AD, $A9, $14, $81, $3C, $38, $85, $30, $8D,
    $89, $34, $20, $9D, $99, $24, $91, $2C, $28, $95, $C1, $7C, $78, $C5, $70,
    $CD, $C9, $74, $60, $DD, $D9, $64, $D1, $6C, $68, $D5, $40, $FD, $F9, $44,
    $F1, $4C, $48, $F5, $E1, $5C, $58, $E5, $50, $ED, $E9, $54, $41, $FC, $F8,
    $45, $F0, $4D, $49, $F4, $E0, $5D, $59, $E4, $51, $EC, $E8, $55, $C0, $7D,
    $79, $C4, $71, $CC, $C8, $75, $61, $DC, $D8, $65, $D0, $6D, $69, $D4, $80,
    $3D, $39, $84, $31, $8C, $88, $35, $21, $9C, $98, $25, $90, $2D, $29, $94,
    $01, $BC, $B8, $05, $B0, $0D, $09, $B4, $A0, $1D, $19, $A4, $11, $AC, $A8,
    $15, $82, $3F, $3B, $86, $33, $8E, $8A, $37, $23, $9E, $9A, $27, $92, $2F,
    $2B, $96, $03, $BE, $BA, $07, $B2, $0F, $0B, $B6, $A2, $1F, $1B, $A6, $13,
    $AE, $AA, $17, $43, $FE, $FA, $47, $F2, $4F, $4B, $F6, $E2, $5F, $5B, $E6,
    $53, $EE, $EA, $57, $C2, $7F, $7B, $C6, $73, $CE, $CA, $77, $63, $DE, $DA,
    $67, $D2, $6F, $6B, $D6, $C3, $7E, $7A, $C7, $72, $CF, $CB, $76, $62, $DF,
    $DB, $66, $D3, $6E, $6A, $D7, $42, $FF, $FB, $46, $F3, $4E, $4A, $F7, $E3,
    $5E, $5A, $E7, $52, $EF, $EB, $56, $02, $BF, $BB, $06, $B3, $0E, $0A, $B7,
    $A3, $1E, $1A, $A7, $12, $AF, $AB, $16, $83, $3E, $3A, $87, $32, $8F, $8B,
    $36, $22, $9F, $9B, $26, $93, $2E, $2A, $97, $00, $BE, $BF, $01, $BD, $03,
    $02, $BC, $B9, $07, $06, $B8, $04, $BA, $BB, $05, $B1, $0F, $0E, $B0, $0C,
    $B2, $B3, $0D, $08, $B6, $B7, $09, $B5, $0B, $0A, $B4, $A1, $1F, $1E, $A0,
    $1C, $A2, $A3, $1D, $18, $A6, $A7, $19, $A5, $1B, $1A, $A4, $10, $AE, $AF,
    $11, $AD, $13, $12, $AC, $A9, $17, $16, $A8, $14, $AA, $AB, $15, $81, $3F,
    $3E, $80, $3C, $82, $83, $3D, $38, $86, $87, $39, $85, $3B, $3A, $84, $30,
    $8E, $8F, $31, $8D, $33, $32, $8C, $89, $37, $36, $88, $34, $8A, $8B, $35,
    $20, $9E, $9F, $21, $9D, $23, $22, $9C, $99, $27, $26, $98, $24, $9A, $9B,
    $25, $91, $2F, $2E, $90, $2C, $92, $93, $2D, $28, $96, $97, $29, $95, $2B,
    $2A, $94, $C1, $7F, $7E, $C0, $7C, $C2, $C3, $7D, $78, $C6, $C7, $79, $C5,
    $7B, $7A, $C4, $70, $CE, $CF, $71, $CD, $73, $72, $CC, $C9, $77, $76, $C8,
    $74, $CA, $CB, $75, $60, $DE, $DF, $61, $DD, $63, $62, $DC, $D9, $67, $66,
    $D8, $64, $DA, $DB, $65, $D1, $6F, $6E, $D0, $6C, $D2, $D3, $6D, $68, $D6,
    $D7, $69, $D5, $6B, $6A, $D4, $40, $FE, $FF, $41, $FD, $43, $42, $FC, $F9,
    $47, $46, $F8, $44, $FA, $FB, $45, $F1, $4F, $4E, $F0, $4C, $F2, $F3, $4D,
    $48, $F6, $F7, $49, $F5, $4B, $4A, $F4, $E1, $5F, $5E, $E0, $5C, $E2, $E3,
    $5D, $58, $E6, $E7, $59, $E5, $5B, $5A, $E4, $50, $EE, $EF, $51, $ED, $53,
    $52, $EC, $E9, $57, $56, $E8, $54, $EA, $EB, $55, $00, $BF, $BD, $02, $B9,
    $06, $04, $BB, $B1, $0E, $0C, $B3, $08, $B7, $B5, $0A, $A1, $1E, $1C, $A3,
    $18, $A7, $A5, $1A, $10, $AF, $AD, $12, $A9, $16, $14, $AB, $81, $3E, $3C,
    $83, $38, $87, $85, $3A, $30, $8F, $8D, $32, $89, $36, $34, $8B, $20, $9F,
    $9D, $22, $99, $26, $24, $9B, $91, $2E, $2C, $93, $28, $97, $95, $2A, $C1,
    $7E, $7C, $C3, $78, $C7, $C5, $7A, $70, $CF, $CD, $72, $C9, $76, $74, $CB,
    $60, $DF, $DD, $62, $D9, $66, $64, $DB, $D1, $6E, $6C, $D3, $68, $D7, $D5,
    $6A, $40, $FF, $FD, $42, $F9, $46, $44, $FB, $F1, $4E, $4C, $F3, $48, $F7,
    $F5, $4A, $E1, $5E, $5C, $E3, $58, $E7, $E5, $5A, $50, $EF, $ED, $52, $E9,
    $56, $54, $EB, $41, $FE, $FC, $43, $F8, $47, $45, $FA, $F0, $4F, $4D, $F2,
    $49, $F6, $F4, $4B, $E0, $5F, $5D, $E2, $59, $E6, $E4, $5B, $51, $EE, $EC,
    $53, $E8, $57, $55, $EA, $C0, $7F, $7D, $C2, $79, $C6, $C4, $7B, $71, $CE,
    $CC, $73, $C8, $77, $75, $CA, $61, $DE, $DC, $63, $D8, $67, $65, $DA, $D0,
    $6F, $6D, $D2, $69, $D6, $D4, $6B, $80, $3F, $3D, $82, $39, $86, $84, $3B,
    $31, $8E, $8C, $33, $88, $37, $35, $8A, $21, $9E, $9C, $23, $98, $27, $25,
    $9A, $90, $2F, $2D, $92, $29, $96, $94, $2B, $01, $BE, $BC, $03, $B8, $07,
    $05, $BA, $B0, $0F, $0D, $B2, $09, $B6, $B4, $0B, $A0, $1F, $1D, $A2, $19,
    $A6, $A4, $1B, $11, $AE, $AC, $13, $A8, $17, $15, $AA, $00, $C0, $43, $83,
    $86, $46, $C5, $05, $CF, $0F, $8C, $4C, $49, $89, $0A, $CA, $5D, $9D, $1E,
    $DE, $DB, $1B, $98, $58, $92, $52, $D1, $11, $14, $D4, $57, $97, $BA, $7A,
    $F9, $39, $3C, $FC, $7F, $BF, $75, $B5, $36, $F6, $F3, $33, $B0, $70, $E7,
    $27, $A4, $64, $61, $A1, $22, $E2, $28, $E8, $6B, $AB, $AE, $6E, $ED, $2D,
    $B7, $77, $F4, $34, $31, $F1, $72, $B2, $78, $B8, $3B, $FB, $FE, $3E, $BD,
    $7D, $EA, $2A, $A9, $69, $6C, $AC, $2F, $EF, $25, $E5, $66, $A6, $A3, $63,
    $E0, $20, $0D, $CD, $4E, $8E, $8B, $4B, $C8, $08, $C2, $02, $81, $41, $44,
    $84, $07, $C7, $50, $90, $13, $D3, $D6, $16, $95, $55, $9F, $5F, $DC, $1C,
    $19, $D9, $5A, $9A, $AD, $6D, $EE, $2E, $2B, $EB, $68, $A8, $62, $A2, $21,
    $E1, $E4, $24, $A7, $67, $F0, $30, $B3, $73, $76, $B6, $35, $F5, $3F, $FF,
    $7C, $BC, $B9, $79, $FA, $3A, $17, $D7, $54, $94, $91, $51, $D2, $12, $D8,
    $18, $9B, $5B, $5E, $9E, $1D, $DD, $4A, $8A, $09, $C9, $CC, $0C, $8F, $4F,
    $85, $45, $C6, $06, $03, $C3, $40, $80, $1A, $DA, $59, $99, $9C, $5C, $DF,
    $1F, $D5, $15, $96, $56, $53, $93, $10, $D0, $47, $87, $04, $C4, $C1, $01,
    $82, $42, $88, $48, $CB, $0B, $0E, $CE, $4D, $8D, $A0, $60, $E3, $23, $26,
    $E6, $65, $A5, $6F, $AF, $2C, $EC, $E9, $29, $AA, $6A, $FD, $3D, $BE, $7E,
    $7B, $BB, $38, $F8, $32, $F2, $71, $B1, $B4, $74, $F7, $37, $00, $C1, $41,
    $80, $82, $43, $C3, $02, $C7, $06, $86, $47, $45, $84, $04, $C5, $4D, $8C,
    $0C, $CD, $CF, $0E, $8E, $4F, $8A, $4B, $CB, $0A, $08, $C9, $49, $88, $9A,
    $5B, $DB, $1A, $18, $D9, $59, $98, $5D, $9C, $1C, $DD, $DF, $1E, $9E, $5F,
    $D7, $16, $96, $57, $55, $94, $14, $D5, $10, $D1, $51, $90, $92, $53, $D3,
    $12, $F7, $36, $B6, $77, $75, $B4, $34, $F5, $30, $F1, $71, $B0, $B2, $73,
    $F3, $32, $BA, $7B, $FB, $3A, $38, $F9, $79, $B8, $7D, $BC, $3C, $FD, $FF,
    $3E, $BE, $7F, $6D, $AC, $2C, $ED, $EF, $2E, $AE, $6F, $AA, $6B, $EB, $2A,
    $28, $E9, $69, $A8, $20, $E1, $61, $A0, $A2, $63, $E3, $22, $E7, $26, $A6,
    $67, $65, $A4, $24, $E5, $2D, $EC, $6C, $AD, $AF, $6E, $EE, $2F, $EA, $2B,
    $AB, $6A, $68, $A9, $29, $E8, $60, $A1, $21, $E0, $E2, $23, $A3, $62, $A7,
    $66, $E6, $27, $25, $E4, $64, $A5, $B7, $76, $F6, $37, $35, $F4, $74, $B5,
    $70, $B1, $31, $F0, $F2, $33, $B3, $72, $FA, $3B, $BB, $7A, $78, $B9, $39,
    $F8, $3D, $FC, $7C, $BD, $BF, $7E, $FE, $3F, $DA, $1B, $9B, $5A, $58, $99,
    $19, $D8, $1D, $DC, $5C, $9D, $9F, $5E, $DE, $1F, $97, $56, $D6, $17, $15,
    $D4, $54, $95, $50, $91, $11, $D0, $D2, $13, $93, $52, $40, $81, $01, $C0,
    $C2, $03, $83, $42, $87, $46, $C6, $07, $05, $C4, $44, $85, $0D, $CC, $4C,
    $8D, $8F, $4E, $CE, $0F, $CA, $0B, $8B, $4A, $48, $89, $09, $C8, $00, $C2,
    $47, $85, $8E, $4C, $C9, $0B, $DF, $1D, $98, $5A, $51, $93, $16, $D4, $7D,
    $BF, $3A, $F8, $F3, $31, $B4, $76, $A2, $60, $E5, $27, $2C, $EE, $6B, $A9,
    $FA, $38, $BD, $7F, $74, $B6, $33, $F1, $25, $E7, $62, $A0, $AB, $69, $EC,
    $2E, $87, $45, $C0, $02, $09, $CB, $4E, $8C, $58, $9A, $1F, $DD, $D6, $14,
    $91, $53, $37, $F5, $70, $B2, $B9, $7B, $FE, $3C, $E8, $2A, $AF, $6D, $66,
    $A4, $21, $E3, $4A, $88, $0D, $CF, $C4, $06, $83, $41, $95, $57, $D2, $10,
    $1B, $D9, $5C, $9E, $CD, $0F, $8A, $48, $43, $81, $04, $C6, $12, $D0, $55,
    $97, $9C, $5E, $DB, $19, $B0, $72, $F7, $35, $3E, $FC, $79, $BB, $6F, $AD,
    $28, $EA, $E1, $23, $A6, $64, $6E, $AC, $29, $EB, $E0, $22, $A7, $65, $B1,
    $73, $F6, $34, $3F, $FD, $78, $BA, $13, $D1, $54, $96, $9D, $5F, $DA, $18,
    $CC, $0E, $8B, $49, $42, $80, $05, $C7, $94, $56, $D3, $11, $1A, $D8, $5D,
    $9F, $4B, $89, $0C, $CE, $C5, $07, $82, $40, $E9, $2B, $AE, $6C, $67, $A5,
    $20, $E2, $36, $F4, $71, $B3, $B8, $7A, $FF, $3D, $59, $9B, $1E, $DC, $D7,
    $15, $90, $52, $86, $44, $C1, $03, $08, $CA, $4F, $8D, $24, $E6, $63, $A1,
    $AA, $68, $ED, $2F, $FB, $39, $BC, $7E, $75, $B7, $32, $F0, $A3, $61, $E4,
    $26, $2D, $EF, $6A, $A8, $7C, $BE, $3B, $F9, $F2, $30, $B5, $77, $DE, $1C,
    $99, $5B, $50, $92, $17, $D5, $01, $C3, $46, $84, $8F, $4D, $C8, $0A, $00,
    $C3, $45, $86, $8A, $49, $CF, $0C, $D7, $14, $92, $51, $5D, $9E, $18, $DB,
    $6D, $AE, $28, $EB, $E7, $24, $A2, $61, $BA, $79, $FF, $3C, $30, $F3, $75,
    $B6, $DA, $19, $9F, $5C, $50, $93, $15, $D6, $0D, $CE, $48, $8B, $87, $44,
    $C2, $01, $B7, $74, $F2, $31, $3D, $FE, $78, $BB, $60, $A3, $25, $E6, $EA,
    $29, $AF, $6C, $77, $B4, $32, $F1, $FD, $3E, $B8, $7B, $A0, $63, $E5, $26,
    $2A, $E9, $6F, $AC, $1A, $D9, $5F, $9C, $90, $53, $D5, $16, $CD, $0E, $88,
    $4B, $47, $84, $02, $C1, $AD, $6E, $E8, $2B, $27, $E4, $62, $A1, $7A, $B9,
    $3F, $FC, $F0, $33, $B5, $76, $C0, $03, $85, $46, $4A, $89, $0F, $CC, $17,
    $D4, $52, $91, $9D, $5E, $D8, $1B, $EE, $2D, $AB, $68, $64, $A7, $21, $E2,
    $39, $FA, $7C, $BF, $B3, $70, $F6, $35, $83, $40, $C6, $05, $09, $CA, $4C,
    $8F, $54, $97, $11, $D2, $DE, $1D, $9B, $58, $34, $F7, $71, $B2, $BE, $7D,
    $FB, $38, $E3, $20, $A6, $65, $69, $AA, $2C, $EF, $59, $9A, $1C, $DF, $D3,
    $10, $96, $55, $8E, $4D, $CB, $08, $04, $C7, $41, $82, $99, $5A, $DC, $1F,
    $13, $D0, $56, $95, $4E, $8D, $0B, $C8, $C4, $07, $81, $42, $F4, $37, $B1,
    $72, $7E, $BD, $3B, $F8, $23, $E0, $66, $A5, $A9, $6A, $EC, $2F, $43, $80,
    $06, $C5, $C9, $0A, $8C, $4F, $94, $57, $D1, $12, $1E, $DD, $5B, $98, $2E,
    $ED, $6B, $A8, $A4, $67, $E1, $22, $F9, $3A, $BC, $7F, $73, $B0, $36, $F5,
    $00, $C4, $4B, $8F, $96, $52, $DD, $19, $EF, $2B, $A4, $60, $79, $BD, $32,
    $F6, $1D, $D9, $56, $92, $8B, $4F, $C0, $04, $F2, $36, $B9, $7D, $64, $A0,
    $2F, $EB, $3A, $FE, $71, $B5, $AC, $68, $E7, $23, $D5, $11, $9E, $5A, $43,
    $87, $08, $CC, $27, $E3, $6C, $A8, $B1, $75, $FA, $3E, $C8, $0C, $83, $47,
    $5E, $9A, $15, $D1, $74, $B0, $3F, $FB, $E2, $26, $A9, $6D, $9B, $5F, $D0,
    $14, $0D, $C9, $46, $82, $69, $AD, $22, $E6, $FF, $3B, $B4, $70, $86, $42,
    $CD, $09, $10, $D4, $5B, $9F, $4E, $8A, $05, $C1, $D8, $1C, $93, $57, $A1,
    $65, $EA, $2E, $37, $F3, $7C, $B8, $53, $97, $18, $DC, $C5, $01, $8E, $4A,
    $BC, $78, $F7, $33, $2A, $EE, $61, $A5, $E8, $2C, $A3, $67, $7E, $BA, $35,
    $F1, $07, $C3, $4C, $88, $91, $55, $DA, $1E, $F5, $31, $BE, $7A, $63, $A7,
    $28, $EC, $1A, $DE, $51, $95, $8C, $48, $C7, $03, $D2, $16, $99, $5D, $44,
    $80, $0F, $CB, $3D, $F9, $76, $B2, $AB, $6F, $E0, $24, $CF, $0B, $84, $40,
    $59, $9D, $12, $D6, $20, $E4, $6B, $AF, $B6, $72, $FD, $39, $9C, $58, $D7,
    $13, $0A, $CE, $41, $85, $73, $B7, $38, $FC, $E5, $21, $AE, $6A, $81, $45,
    $CA, $0E, $17, $D3, $5C, $98, $6E, $AA, $25, $E1, $F8, $3C, $B3, $77, $A6,
    $62, $ED, $29, $30, $F4, $7B, $BF, $49, $8D, $02, $C6, $DF, $1B, $94, $50,
    $BB, $7F, $F0, $34, $2D, $E9, $66, $A2, $54, $90, $1F, $DB, $C2, $06, $89,
    $4D, $00, $C5, $49, $8C, $92, $57, $DB, $1E, $E7, $22, $AE, $6B, $75, $B0,
    $3C, $F9, $0D, $C8, $44, $81, $9F, $5A, $D6, $13, $EA, $2F, $A3, $66, $78,
    $BD, $31, $F4, $1A, $DF, $53, $96, $88, $4D, $C1, $04, $FD, $38, $B4, $71,
    $6F, $AA, $26, $E3, $17, $D2, $5E, $9B, $85, $40, $CC, $09, $F0, $35, $B9,
    $7C, $62, $A7, $2B, $EE, $34, $F1, $7D, $B8, $A6, $63, $EF, $2A, $D3, $16,
    $9A, $5F, $41, $84, $08, $CD, $39, $FC, $70, $B5, $AB, $6E, $E2, $27, $DE,
    $1B, $97, $52, $4C, $89, $05, $C0, $2E, $EB, $67, $A2, $BC, $79, $F5, $30,
    $C9, $0C, $80, $45, $5B, $9E, $12, $D7, $23, $E6, $6A, $AF, $B1, $74, $F8,
    $3D, $C4, $01, $8D, $48, $56, $93, $1F, $DA, $68, $AD, $21, $E4, $FA, $3F,
    $B3, $76, $8F, $4A, $C6, $03, $1D, $D8, $54, $91, $65, $A0, $2C, $E9, $F7,
    $32, $BE, $7B, $82, $47, $CB, $0E, $10, $D5, $59, $9C, $72, $B7, $3B, $FE,
    $E0, $25, $A9, $6C, $95, $50, $DC, $19, $07, $C2, $4E, $8B, $7F, $BA, $36,
    $F3, $ED, $28, $A4, $61, $98, $5D, $D1, $14, $0A, $CF, $43, $86, $5C, $99,
    $15, $D0, $CE, $0B, $87, $42, $BB, $7E, $F2, $37, $29, $EC, $60, $A5, $51,
    $94, $18, $DD, $C3, $06, $8A, $4F, $B6, $73, $FF, $3A, $24, $E1, $6D, $A8,
    $46, $83, $0F, $CA, $D4, $11, $9D, $58, $A1, $64, $E8, $2D, $33, $F6, $7A,
    $BF, $4B, $8E, $02, $C7, $D9, $1C, $90, $55, $AC, $69, $E5, $20, $3E, $FB,
    $77, $B2, $00, $C6, $4F, $89, $9E, $58, $D1, $17, $FF, $39, $B0, $76, $61,
    $A7, $2E, $E8, $3D, $FB, $72, $B4, $A3, $65, $EC, $2A, $C2, $04, $8D, $4B,
    $5C, $9A, $13, $D5, $7A, $BC, $35, $F3, $E4, $22, $AB, $6D, $85, $43, $CA,
    $0C, $1B, $DD, $54, $92, $47, $81, $08, $CE, $D9, $1F, $96, $50, $B8, $7E,
    $F7, $31, $26, $E0, $69, $AF, $F4, $32, $BB, $7D, $6A, $AC, $25, $E3, $0B,
    $CD, $44, $82, $95, $53, $DA, $1C, $C9, $0F, $86, $40, $57, $91, $18, $DE,
    $36, $F0, $79, $BF, $A8, $6E, $E7, $21, $8E, $48, $C1, $07, $10, $D6, $5F,
    $99, $71, $B7, $3E, $F8, $EF, $29, $A0, $66, $B3, $75, $FC, $3A, $2D, $EB,
    $62, $A4, $4C, $8A, $03, $C5, $D2, $14, $9D, $5B, $2B, $ED, $64, $A2, $B5,
    $73, $FA, $3C, $D4, $12, $9B, $5D, $4A, $8C, $05, $C3, $16, $D0, $59, $9F,
    $88, $4E, $C7, $01, $E9, $2F, $A6, $60, $77, $B1, $38, $FE, $51, $97, $1E,
    $D8, $CF, $09, $80, $46, $AE, $68, $E1, $27, $30, $F6, $7F, $B9, $6C, $AA,
    $23, $E5, $F2, $34, $BD, $7B, $93, $55, $DC, $1A, $0D, $CB, $42, $84, $DF,
    $19, $90, $56, $41, $87, $0E, $C8, $20, $E6, $6F, $A9, $BE, $78, $F1, $37,
    $E2, $24, $AD, $6B, $7C, $BA, $33, $F5, $1D, $DB, $52, $94, $83, $45, $CC,
    $0A, $A5, $63, $EA, $2C, $3B, $FD, $74, $B2, $5A, $9C, $15, $D3, $C4, $02,
    $8B, $4D, $98, $5E, $D7, $11, $06, $C0, $49, $8F, $67, $A1, $28, $EE, $F9,
    $3F, $B6, $70, $00, $C7, $4D, $8A, $9A, $5D, $D7, $10, $F7, $30, $BA, $7D,
    $6D, $AA, $20, $E7, $2D, $EA, $60, $A7, $B7, $70, $FA, $3D, $DA, $1D, $97,
    $50, $40, $87, $0D, $CA, $5A, $9D, $17, $D0, $C0, $07, $8D, $4A, $AD, $6A,
    $E0, $27, $37, $F0, $7A, $BD, $77, $B0, $3A, $FD, $ED, $2A, $A0, $67, $80,
    $47, $CD, $0A, $1A, $DD, $57, $90, $B4, $73, $F9, $3E, $2E, $E9, $63, $A4,
    $43, $84, $0E, $C9, $D9, $1E, $94, $53, $99, $5E, $D4, $13, $03, $C4, $4E,
    $89, $6E, $A9, $23, $E4, $F4, $33, $B9, $7E, $EE, $29, $A3, $64, $74, $B3,
    $39, $FE, $19, $DE, $54, $93, $83, $44, $CE, $09, $C3, $04, $8E, $49, $59,
    $9E, $14, $D3, $34, $F3, $79, $BE, $AE, $69, $E3, $24, $AB, $6C, $E6, $21,
    $31, $F6, $7C, $BB, $5C, $9B, $11, $D6, $C6, $01, $8B, $4C, $86, $41, $CB,
    $0C, $1C, $DB, $51, $96, $71, $B6, $3C, $FB, $EB, $2C, $A6, $61, $F1, $36,
    $BC, $7B, $6B, $AC, $26, $E1, $06, $C1, $4B, $8C, $9C, $5B, $D1, $16, $DC,
    $1B, $91, $56, $46, $81, $0B, $CC, $2B, $EC, $66, $A1, $B1, $76, $FC, $3B,
    $1F, $D8, $52, $95, $85, $42, $C8, $0F, $E8, $2F, $A5, $62, $72, $B5, $3F,
    $F8, $32, $F5, $7F, $B8, $A8, $6F, $E5, $22, $C5, $02, $88, $4F, $5F, $98,
    $12, $D5, $45, $82, $08, $CF, $DF, $18, $92, $55, $B2, $75, $FF, $38, $28,
    $EF, $65, $A2, $68, $AF, $25, $E2, $F2, $35, $BF, $78, $9F, $58, $D2, $15,
    $05, $C2, $48, $8F, $00, $C8, $53, $9B, $A6, $6E, $F5, $3D, $8F, $47, $DC,
    $14, $29, $E1, $7A, $B2, $DD, $15, $8E, $46, $7B, $B3, $28, $E0, $52, $9A,
    $01, $C9, $F4, $3C, $A7, $6F, $79, $B1, $2A, $E2, $DF, $17, $8C, $44, $F6,
    $3E, $A5, $6D, $50, $98, $03, $CB, $A4, $6C, $F7, $3F, $02, $CA, $51, $99,
    $2B, $E3, $78, $B0, $8D, $45, $DE, $16, $F2, $3A, $A1, $69, $54, $9C, $07,
    $CF, $7D, $B5, $2E, $E6, $DB, $13, $88, $40, $2F, $E7, $7C, $B4, $89, $41,
    $DA, $12, $A0, $68, $F3, $3B, $06, $CE, $55, $9D, $8B, $43, $D8, $10, $2D,
    $E5, $7E, $B6, $04, $CC, $57, $9F, $A2, $6A, $F1, $39, $56, $9E, $05, $CD,
    $F0, $38, $A3, $6B, $D9, $11, $8A, $42, $7F, $B7, $2C, $E4, $27, $EF, $74,
    $BC, $81, $49, $D2, $1A, $A8, $60, $FB, $33, $0E, $C6, $5D, $95, $FA, $32,
    $A9, $61, $5C, $94, $0F, $C7, $75, $BD, $26, $EE, $D3, $1B, $80, $48, $5E,
    $96, $0D, $C5, $F8, $30, $AB, $63, $D1, $19, $82, $4A, $77, $BF, $24, $EC,
    $83, $4B, $D0, $18, $25, $ED, $76, $BE, $0C, $C4, $5F, $97, $AA, $62, $F9,
    $31, $D5, $1D, $86, $4E, $73, $BB, $20, $E8, $5A, $92, $09, $C1, $FC, $34,
    $AF, $67, $08, $C0, $5B, $93, $AE, $66, $FD, $35, $87, $4F, $D4, $1C, $21,
    $E9, $72, $BA, $AC, $64, $FF, $37, $0A, $C2, $59, $91, $23, $EB, $70, $B8,
    $85, $4D, $D6, $1E, $71, $B9, $22, $EA, $D7, $1F, $84, $4C, $FE, $36, $AD,
    $65, $58, $90, $0B, $C3, $00, $C9, $51, $98, $A2, $6B, $F3, $3A, $87, $4E,
    $D6, $1F, $25, $EC, $74, $BD, $CD, $04, $9C, $55, $6F, $A6, $3E, $F7, $4A,
    $83, $1B, $D2, $E8, $21, $B9, $70, $59, $90, $08, $C1, $FB, $32, $AA, $63,
    $DE, $17, $8F, $46, $7C, $B5, $2D, $E4, $94, $5D, $C5, $0C, $36, $FF, $67,
    $AE, $13, $DA, $42, $8B, $B1, $78, $E0, $29, $B2, $7B, $E3, $2A, $10, $D9,
    $41, $88, $35, $FC, $64, $AD, $97, $5E, $C6, $0F, $7F, $B6, $2E, $E7, $DD,
    $14, $8C, $45, $F8, $31, $A9, $60, $5A, $93, $0B, $C2, $EB, $22, $BA, $73,
    $49, $80, $18, $D1, $6C, $A5, $3D, $F4, $CE, $07, $9F, $56, $26, $EF, $77,
    $BE, $84, $4D, $D5, $1C, $A1, $68, $F0, $39, $03, $CA, $52, $9B, $A7, $6E,
    $F6, $3F, $05, $CC, $54, $9D, $20, $E9, $71, $B8, $82, $4B, $D3, $1A, $6A,
    $A3, $3B, $F2, $C8, $01, $99, $50, $ED, $24, $BC, $75, $4F, $86, $1E, $D7,
    $FE, $37, $AF, $66, $5C, $95, $0D, $C4, $79, $B0, $28, $E1, $DB, $12, $8A,
    $43, $33, $FA, $62, $AB, $91, $58, $C0, $09, $B4, $7D, $E5, $2C, $16, $DF,
    $47, $8E, $15, $DC, $44, $8D, $B7, $7E, $E6, $2F, $92, $5B, $C3, $0A, $30,
    $F9, $61, $A8, $D8, $11, $89, $40, $7A, $B3, $2B, $E2, $5F, $96, $0E, $C7,
    $FD, $34, $AC, $65, $4C, $85, $1D, $D4, $EE, $27, $BF, $76, $CB, $02, $9A,
    $53, $69, $A0, $38, $F1, $81, $48, $D0, $19, $23, $EA, $72, $BB, $06, $CF,
    $57, $9E, $A4, $6D, $F5, $3C, $00, $CA, $57, $9D, $AE, $64, $F9, $33, $9F,
    $55, $C8, $02, $31, $FB, $66, $AC, $FD, $37, $AA, $60, $53, $99, $04, $CE,
    $62, $A8, $35, $FF, $CC, $06, $9B, $51, $39, $F3, $6E, $A4, $97, $5D, $C0,
    $0A, $A6, $6C, $F1, $3B, $08, $C2, $5F, $95, $C4, $0E, $93, $59, $6A, $A0,
    $3D, $F7, $5B, $91, $0C, $C6, $F5, $3F, $A2, $68, $72, $B8, $25, $EF, $DC,
    $16, $8B, $41, $ED, $27, $BA, $70, $43, $89, $14, $DE, $8F, $45, $D8, $12,
    $21, $EB, $76, $BC, $10, $DA, $47, $8D, $BE, $74, $E9, $23, $4B, $81, $1C,
    $D6, $E5, $2F, $B2, $78, $D4, $1E, $83, $49, $7A, $B0, $2D, $E7, $B6, $7C,
    $E1, $2B, $18, $D2, $4F, $85, $29, $E3, $7E, $B4, $87, $4D, $D0, $1A, $E4,
    $2E, $B3, $79, $4A, $80, $1D, $D7, $7B, $B1, $2C, $E6, $D5, $1F, $82, $48,
    $19, $D3, $4E, $84, $B7, $7D, $E0, $2A, $86, $4C, $D1, $1B, $28, $E2, $7F,
    $B5, $DD, $17, $8A, $40, $73, $B9, $24, $EE, $42, $88, $15, $DF, $EC, $26,
    $BB, $71, $20, $EA, $77, $BD, $8E, $44, $D9, $13, $BF, $75, $E8, $22, $11,
    $DB, $46, $8C, $96, $5C, $C1, $0B, $38, $F2, $6F, $A5, $09, $C3, $5E, $94,
    $A7, $6D, $F0, $3A, $6B, $A1, $3C, $F6, $C5, $0F, $92, $58, $F4, $3E, $A3,
    $69, $5A, $90, $0D, $C7, $AF, $65, $F8, $32, $01, $CB, $56, $9C, $30, $FA,
    $67, $AD, $9E, $54, $C9, $03, $52, $98, $05, $CF, $FC, $36, $AB, $61, $CD,
    $07, $9A, $50, $63, $A9, $34, $FE, $00, $CB, $55, $9E, $AA, $61, $FF, $34,
    $97, $5C, $C2, $09, $3D, $F6, $68, $A3, $ED, $26, $B8, $73, $47, $8C, $12,
    $D9, $7A, $B1, $2F, $E4, $D0, $1B, $85, $4E, $19, $D2, $4C, $87, $B3, $78,
    $E6, $2D, $8E, $45, $DB, $10, $24, $EF, $71, $BA, $F4, $3F, $A1, $6A, $5E,
    $95, $0B, $C0, $63, $A8, $36, $FD, $C9, $02, $9C, $57, $32, $F9, $67, $AC,
    $98, $53, $CD, $06, $A5, $6E, $F0, $3B, $0F, $C4, $5A, $91, $DF, $14, $8A,
    $41, $75, $BE, $20, $EB, $48, $83, $1D, $D6, $E2, $29, $B7, $7C, $2B, $E0,
    $7E, $B5, $81, $4A, $D4, $1F, $BC, $77, $E9, $22, $16, $DD, $43, $88, $C6,
    $0D, $93, $58, $6C, $A7, $39, $F2, $51, $9A, $04, $CF, $FB, $30, $AE, $65,
    $64, $AF, $31, $FA, $CE, $05, $9B, $50, $F3, $38, $A6, $6D, $59, $92, $0C,
    $C7, $89, $42, $DC, $17, $23, $E8, $76, $BD, $1E, $D5, $4B, $80, $B4, $7F,
    $E1, $2A, $7D, $B6, $28, $E3, $D7, $1C, $82, $49, $EA, $21, $BF, $74, $40,
    $8B, $15, $DE, $90, $5B, $C5, $0E, $3A, $F1, $6F, $A4, $07, $CC, $52, $99,
    $AD, $66, $F8, $33, $56, $9D, $03, $C8, $FC, $37, $A9, $62, $C1, $0A, $94,
    $5F, $6B, $A0, $3E, $F5, $BB, $70, $EE, $25, $11, $DA, $44, $8F, $2C, $E7,
    $79, $B2, $86, $4D, $D3, $18, $4F, $84, $1A, $D1, $E5, $2E, $B0, $7B, $D8,
    $13, $8D, $46, $72, $B9, $27, $EC, $A2, $69, $F7, $3C, $08, $C3, $5D, $96,
    $35, $FE, $60, $AB, $9F, $54, $CA, $01, $00, $CC, $5B, $97, $B6, $7A, $ED,
    $21, $AF, $63, $F4, $38, $19, $D5, $42, $8E, $9D, $51, $C6, $0A, $2B, $E7,
    $70, $BC, $32, $FE, $69, $A5, $84, $48, $DF, $13, $F9, $35, $A2, $6E, $4F,
    $83, $14, $D8, $56, $9A, $0D, $C1, $E0, $2C, $BB, $77, $64, $A8, $3F, $F3,
    $D2, $1E, $89, $45, $CB, $07, $90, $5C, $7D, $B1, $26, $EA, $31, $FD, $6A,
    $A6, $87, $4B, $DC, $10, $9E, $52, $C5, $09, $28, $E4, $73, $BF, $AC, $60,
    $F7, $3B, $1A, $D6, $41, $8D, $03, $CF, $58, $94, $B5, $79, $EE, $22, $C8,
    $04, $93, $5F, $7E, $B2, $25, $E9, $67, $AB, $3C, $F0, $D1, $1D, $8A, $46,
    $55, $99, $0E, $C2, $E3, $2F, $B8, $74, $FA, $36, $A1, $6D, $4C, $80, $17,
    $DB, $62, $AE, $39, $F5, $D4, $18, $8F, $43, $CD, $01, $96, $5A, $7B, $B7,
    $20, $EC, $FF, $33, $A4, $68, $49, $85, $12, $DE, $50, $9C, $0B, $C7, $E6,
    $2A, $BD, $71, $9B, $57, $C0, $0C, $2D, $E1, $76, $BA, $34, $F8, $6F, $A3,
    $82, $4E, $D9, $15, $06, $CA, $5D, $91, $B0, $7C, $EB, $27, $A9, $65, $F2,
    $3E, $1F, $D3, $44, $88, $53, $9F, $08, $C4, $E5, $29, $BE, $72, $FC, $30,
    $A7, $6B, $4A, $86, $11, $DD, $CE, $02, $95, $59, $78, $B4, $23, $EF, $61,
    $AD, $3A, $F6, $D7, $1B, $8C, $40, $AA, $66, $F1, $3D, $1C, $D0, $47, $8B,
    $05, $C9, $5E, $92, $B3, $7F, $E8, $24, $37, $FB, $6C, $A0, $81, $4D, $DA,
    $16, $98, $54, $C3, $0F, $2E, $E2, $75, $B9, $00, $CD, $59, $94, $B2, $7F,
    $EB, $26, $A7, $6A, $FE, $33, $15, $D8, $4C, $81, $8D, $40, $D4, $19, $3F,
    $F2, $66, $AB, $2A, $E7, $73, $BE, $98, $55, $C1, $0C, $D9, $14, $80, $4D,
    $6B, $A6, $32, $FF, $7E, $B3, $27, $EA, $CC, $01, $95, $58, $54, $99, $0D,
    $C0, $E6, $2B, $BF, $72, $F3, $3E, $AA, $67, $41, $8C, $18, $D5, $71, $BC,
    $28, $E5, $C3, $0E, $9A, $57, $D6, $1B, $8F, $42, $64, $A9, $3D, $F0, $FC,
    $31, $A5, $68, $4E, $83, $17, $DA, $5B, $96, $02, $CF, $E9, $24, $B0, $7D,
    $A8, $65, $F1, $3C, $1A, $D7, $43, $8E, $0F, $C2, $56, $9B, $BD, $70, $E4,
    $29, $25, $E8, $7C, $B1, $97, $5A, $CE, $03, $82, $4F, $DB, $16, $30, $FD,
    $69, $A4, $E2, $2F, $BB, $76, $50, $9D, $09, $C4, $45, $88, $1C, $D1, $F7,
    $3A, $AE, $63, $6F, $A2, $36, $FB, $DD, $10, $84, $49, $C8, $05, $91, $5C,
    $7A, $B7, $23, $EE, $3B, $F6, $62, $AF, $89, $44, $D0, $1D, $9C, $51, $C5,
    $08, $2E, $E3, $77, $BA, $B6, $7B, $EF, $22, $04, $C9, $5D, $90, $11, $DC,
    $48, $85, $A3, $6E, $FA, $37, $93, $5E, $CA, $07, $21, $EC, $78, $B5, $34,
    $F9, $6D, $A0, $86, $4B, $DF, $12, $1E, $D3, $47, $8A, $AC, $61, $F5, $38,
    $B9, $74, $E0, $2D, $0B, $C6, $52, $9F, $4A, $87, $13, $DE, $F8, $35, $A1,
    $6C, $ED, $20, $B4, $79, $5F, $92, $06, $CB, $C7, $0A, $9E, $53, $75, $B8,
    $2C, $E1, $60, $AD, $39, $F4, $D2, $1F, $8B, $46, $00, $CE, $5F, $91, $BE,
    $70, $E1, $2F, $BF, $71, $E0, $2E, $01, $CF, $5E, $90, $BD, $73, $E2, $2C,
    $03, $CD, $5C, $92, $02, $CC, $5D, $93, $BC, $72, $E3, $2D, $B9, $77, $E6,
    $28, $07, $C9, $58, $96, $06, $C8, $59, $97, $B8, $76, $E7, $29, $04, $CA,
    $5B, $95, $BA, $74, $E5, $2B, $BB, $75, $E4, $2A, $05, $CB, $5A, $94, $B1,
    $7F, $EE, $20, $0F, $C1, $50, $9E, $0E, $C0, $51, $9F, $B0, $7E, $EF, $21,
    $0C, $C2, $53, $9D, $B2, $7C, $ED, $23, $B3, $7D, $EC, $22, $0D, $C3, $52,
    $9C, $08, $C6, $57, $99, $B6, $78, $E9, $27, $B7, $79, $E8, $26, $09, $C7,
    $56, $98, $B5, $7B, $EA, $24, $0B, $C5, $54, $9A, $0A, $C4, $55, $9B, $B4,
    $7A, $EB, $25, $A1, $6F, $FE, $30, $1F, $D1, $40, $8E, $1E, $D0, $41, $8F,
    $A0, $6E, $FF, $31, $1C, $D2, $43, $8D, $A2, $6C, $FD, $33, $A3, $6D, $FC,
    $32, $1D, $D3, $42, $8C, $18, $D6, $47, $89, $A6, $68, $F9, $37, $A7, $69,
    $F8, $36, $19, $D7, $46, $88, $A5, $6B, $FA, $34, $1B, $D5, $44, $8A, $1A,
    $D4, $45, $8B, $A4, $6A, $FB, $35, $10, $DE, $4F, $81, $AE, $60, $F1, $3F,
    $AF, $61, $F0, $3E, $11, $DF, $4E, $80, $AD, $63, $F2, $3C, $13, $DD, $4C,
    $82, $12, $DC, $4D, $83, $AC, $62, $F3, $3D, $A9, $67, $F6, $38, $17, $D9,
    $48, $86, $16, $D8, $49, $87, $A8, $66, $F7, $39, $14, $DA, $4B, $85, $AA,
    $64, $F5, $3B, $AB, $65, $F4, $3A, $15, $DB, $4A, $84, $00, $CF, $5D, $92,
    $BA, $75, $E7, $28, $B7, $78, $EA, $25, $0D, $C2, $50, $9F, $AD, $62, $F0,
    $3F, $17, $D8, $4A, $85, $1A, $D5, $47, $88, $A0, $6F, $FD, $32, $99, $56,
    $C4, $0B, $23, $EC, $7E, $B1, $2E, $E1, $73, $BC, $94, $5B, $C9, $06, $34,
    $FB, $69, $A6, $8E, $41, $D3, $1C, $83, $4C, $DE, $11, $39, $F6, $64, $AB,
    $F1, $3E, $AC, $63, $4B, $84, $16, $D9, $46, $89, $1B, $D4, $FC, $33, $A1,
    $6E, $5C, $93, $01, $CE, $E6, $29, $BB, $74, $EB, $24, $B6, $79, $51, $9E,
    $0C, $C3, $68, $A7, $35, $FA, $D2, $1D, $8F, $40, $DF, $10, $82, $4D, $65,
    $AA, $38, $F7, $C5, $0A, $98, $57, $7F, $B0, $22, $ED, $72, $BD, $2F, $E0,
    $C8, $07, $95, $5A, $21, $EE, $7C, $B3, $9B, $54, $C6, $09, $96, $59, $CB,
    $04, $2C, $E3, $71, $BE, $8C, $43, $D1, $1E, $36, $F9, $6B, $A4, $3B, $F4,
    $66, $A9, $81, $4E, $DC, $13, $B8, $77, $E5, $2A, $02, $CD, $5F, $90, $0F,
    $C0, $52, $9D, $B5, $7A, $E8, $27, $15, $DA, $48, $87, $AF, $60, $F2, $3D,
    $A2, $6D, $FF, $30, $18, $D7, $45, $8A, $D0, $1F, $8D, $42, $6A, $A5, $37,
    $F8, $67, $A8, $3A, $F5, $DD, $12, $80, $4F, $7D, $B2, $20, $EF, $C7, $08,
    $9A, $55, $CA, $05, $97, $58, $70, $BF, $2D, $E2, $49, $86, $14, $DB, $F3,
    $3C, $AE, $61, $FE, $31, $A3, $6C, $44, $8B, $19, $D6, $E4, $2B, $B9, $76,
    $5E, $91, $03, $CC, $53, $9C, $0E, $C1, $E9, $26, $B4, $7B, $00, $D0, $63,
    $B3, $C6, $16, $A5, $75, $4F, $9F, $2C, $FC, $89, $59, $EA, $3A, $9E, $4E,
    $FD, $2D, $58, $88, $3B, $EB, $D1, $01, $B2, $62, $17, $C7, $74, $A4, $FF,
    $2F, $9C, $4C, $39, $E9, $5A, $8A, $B0, $60, $D3, $03, $76, $A6, $15, $C5,
    $61, $B1, $02, $D2, $A7, $77, $C4, $14, $2E, $FE, $4D, $9D, $E8, $38, $8B,
    $5B, $3D, $ED, $5E, $8E, $FB, $2B, $98, $48, $72, $A2, $11, $C1, $B4, $64,
    $D7, $07, $A3, $73, $C0, $10, $65, $B5, $06, $D6, $EC, $3C, $8F, $5F, $2A,
    $FA, $49, $99, $C2, $12, $A1, $71, $04, $D4, $67, $B7, $8D, $5D, $EE, $3E,
    $4B, $9B, $28, $F8, $5C, $8C, $3F, $EF, $9A, $4A, $F9, $29, $13, $C3, $70,
    $A0, $D5, $05, $B6, $66, $7A, $AA, $19, $C9, $BC, $6C, $DF, $0F, $35, $E5,
    $56, $86, $F3, $23, $90, $40, $E4, $34, $87, $57, $22, $F2, $41, $91, $AB,
    $7B, $C8, $18, $6D, $BD, $0E, $DE, $85, $55, $E6, $36, $43, $93, $20, $F0,
    $CA, $1A, $A9, $79, $0C, $DC, $6F, $BF, $1B, $CB, $78, $A8, $DD, $0D, $BE,
    $6E, $54, $84, $37, $E7, $92, $42, $F1, $21, $47, $97, $24, $F4, $81, $51,
    $E2, $32, $08, $D8, $6B, $BB, $CE, $1E, $AD, $7D, $D9, $09, $BA, $6A, $1F,
    $CF, $7C, $AC, $96, $46, $F5, $25, $50, $80, $33, $E3, $B8, $68, $DB, $0B,
    $7E, $AE, $1D, $CD, $F7, $27, $94, $44, $31, $E1, $52, $82, $26, $F6, $45,
    $95, $E0, $30, $83, $53, $69, $B9, $0A, $DA, $AF, $7F, $CC, $1C, $00, $D1,
    $61, $B0, $C2, $13, $A3, $72, $47, $96, $26, $F7, $85, $54, $E4, $35, $8E,
    $5F, $EF, $3E, $4C, $9D, $2D, $FC, $C9, $18, $A8, $79, $0B, $DA, $6A, $BB,
    $DF, $0E, $BE, $6F, $1D, $CC, $7C, $AD, $98, $49, $F9, $28, $5A, $8B, $3B,
    $EA, $51, $80, $30, $E1, $93, $42, $F2, $23, $16, $C7, $77, $A6, $D4, $05,
    $B5, $64, $7D, $AC, $1C, $CD, $BF, $6E, $DE, $0F, $3A, $EB, $5B, $8A, $F8,
    $29, $99, $48, $F3, $22, $92, $43, $31, $E0, $50, $81, $B4, $65, $D5, $04,
    $76, $A7, $17, $C6, $A2, $73, $C3, $12, $60, $B1, $01, $D0, $E5, $34, $84,
    $55, $27, $F6, $46, $97, $2C, $FD, $4D, $9C, $EE, $3F, $8F, $5E, $6B, $BA,
    $0A, $DB, $A9, $78, $C8, $19, $FA, $2B, $9B, $4A, $38, $E9, $59, $88, $BD,
    $6C, $DC, $0D, $7F, $AE, $1E, $CF, $74, $A5, $15, $C4, $B6, $67, $D7, $06,
    $33, $E2, $52, $83, $F1, $20, $90, $41, $25, $F4, $44, $95, $E7, $36, $86,
    $57, $62, $B3, $03, $D2, $A0, $71, $C1, $10, $AB, $7A, $CA, $1B, $69, $B8,
    $08, $D9, $EC, $3D, $8D, $5C, $2E, $FF, $4F, $9E, $87, $56, $E6, $37, $45,
    $94, $24, $F5, $C0, $11, $A1, $70, $02, $D3, $63, $B2, $09, $D8, $68, $B9,
    $CB, $1A, $AA, $7B, $4E, $9F, $2F, $FE, $8C, $5D, $ED, $3C, $58, $89, $39,
    $E8, $9A, $4B, $FB, $2A, $1F, $CE, $7E, $AF, $DD, $0C, $BC, $6D, $D6, $07,
    $B7, $66, $14, $C5, $75, $A4, $91, $40, $F0, $21, $53, $82, $32, $E3, $00,
    $D2, $67, $B5, $CE, $1C, $A9, $7B, $5F, $8D, $38, $EA, $91, $43, $F6, $24,
    $BE, $6C, $D9, $0B, $70, $A2, $17, $C5, $E1, $33, $86, $54, $2F, $FD, $48,
    $9A, $BF, $6D, $D8, $0A, $71, $A3, $16, $C4, $E0, $32, $87, $55, $2E, $FC,
    $49, $9B, $01, $D3, $66, $B4, $CF, $1D, $A8, $7A, $5E, $8C, $39, $EB, $90,
    $42, $F7, $25, $BD, $6F, $DA, $08, $73, $A1, $14, $C6, $E2, $30, $85, $57,
    $2C, $FE, $4B, $99, $03, $D1, $64, $B6, $CD, $1F, $AA, $78, $5C, $8E, $3B,
    $E9, $92, $40, $F5, $27, $02, $D0, $65, $B7, $CC, $1E, $AB, $79, $5D, $8F,
    $3A, $E8, $93, $41, $F4, $26, $BC, $6E, $DB, $09, $72, $A0, $15, $C7, $E3,
    $31, $84, $56, $2D, $FF, $4A, $98, $B9, $6B, $DE, $0C, $77, $A5, $10, $C2,
    $E6, $34, $81, $53, $28, $FA, $4F, $9D, $07, $D5, $60, $B2, $C9, $1B, $AE,
    $7C, $58, $8A, $3F, $ED, $96, $44, $F1, $23, $06, $D4, $61, $B3, $C8, $1A,
    $AF, $7D, $59, $8B, $3E, $EC, $97, $45, $F0, $22, $B8, $6A, $DF, $0D, $76,
    $A4, $11, $C3, $E7, $35, $80, $52, $29, $FB, $4E, $9C, $04, $D6, $63, $B1,
    $CA, $18, $AD, $7F, $5B, $89, $3C, $EE, $95, $47, $F2, $20, $BA, $68, $DD,
    $0F, $74, $A6, $13, $C1, $E5, $37, $82, $50, $2B, $F9, $4C, $9E, $BB, $69,
    $DC, $0E, $75, $A7, $12, $C0, $E4, $36, $83, $51, $2A, $F8, $4D, $9F, $05,
    $D7, $62, $B0, $CB, $19, $AC, $7E, $5A, $88, $3D, $EF, $94, $46, $F3, $21,
    $00, $D3, $65, $B6, $CA, $19, $AF, $7C, $57, $84, $32, $E1, $9D, $4E, $F8,
    $2B, $AE, $7D, $CB, $18, $64, $B7, $01, $D2, $F9, $2A, $9C, $4F, $33, $E0,
    $56, $85, $9F, $4C, $FA, $29, $55, $86, $30, $E3, $C8, $1B, $AD, $7E, $02,
    $D1, $67, $B4, $31, $E2, $54, $87, $FB, $28, $9E, $4D, $66, $B5, $03, $D0,
    $AC, $7F, $C9, $1A, $FD, $2E, $98, $4B, $37, $E4, $52, $81, $AA, $79, $CF,
    $1C, $60, $B3, $05, $D6, $53, $80, $36, $E5, $99, $4A, $FC, $2F, $04, $D7,
    $61, $B2, $CE, $1D, $AB, $78, $62, $B1, $07, $D4, $A8, $7B, $CD, $1E, $35,
    $E6, $50, $83, $FF, $2C, $9A, $49, $CC, $1F, $A9, $7A, $06, $D5, $63, $B0,
    $9B, $48, $FE, $2D, $51, $82, $34, $E7, $39, $EA, $5C, $8F, $F3, $20, $96,
    $45, $6E, $BD, $0B, $D8, $A4, $77, $C1, $12, $97, $44, $F2, $21, $5D, $8E,
    $38, $EB, $C0, $13, $A5, $76, $0A, $D9, $6F, $BC, $A6, $75, $C3, $10, $6C,
    $BF, $09, $DA, $F1, $22, $94, $47, $3B, $E8, $5E, $8D, $08, $DB, $6D, $BE,
    $C2, $11, $A7, $74, $5F, $8C, $3A, $E9, $95, $46, $F0, $23, $C4, $17, $A1,
    $72, $0E, $DD, $6B, $B8, $93, $40, $F6, $25, $59, $8A, $3C, $EF, $6A, $B9,
    $0F, $DC, $A0, $73, $C5, $16, $3D, $EE, $58, $8B, $F7, $24, $92, $41, $5B,
    $88, $3E, $ED, $91, $42, $F4, $27, $0C, $DF, $69, $BA, $C6, $15, $A3, $70,
    $F5, $26, $90, $43, $3F, $EC, $5A, $89, $A2, $71, $C7, $14, $68, $BB, $0D,
    $DE, $00, $D4, $6B, $BF, $D6, $02, $BD, $69, $6F, $BB, $04, $D0, $B9, $6D,
    $D2, $06, $DE, $0A, $B5, $61, $08, $DC, $63, $B7, $B1, $65, $DA, $0E, $67,
    $B3, $0C, $D8, $7F, $AB, $14, $C0, $A9, $7D, $C2, $16, $10, $C4, $7B, $AF,
    $C6, $12, $AD, $79, $A1, $75, $CA, $1E, $77, $A3, $1C, $C8, $CE, $1A, $A5,
    $71, $18, $CC, $73, $A7, $FE, $2A, $95, $41, $28, $FC, $43, $97, $91, $45,
    $FA, $2E, $47, $93, $2C, $F8, $20, $F4, $4B, $9F, $F6, $22, $9D, $49, $4F,
    $9B, $24, $F0, $99, $4D, $F2, $26, $81, $55, $EA, $3E, $57, $83, $3C, $E8,
    $EE, $3A, $85, $51, $38, $EC, $53, $87, $5F, $8B, $34, $E0, $89, $5D, $E2,
    $36, $30, $E4, $5B, $8F, $E6, $32, $8D, $59, $3F, $EB, $54, $80, $E9, $3D,
    $82, $56, $50, $84, $3B, $EF, $86, $52, $ED, $39, $E1, $35, $8A, $5E, $37,
    $E3, $5C, $88, $8E, $5A, $E5, $31, $58, $8C, $33, $E7, $40, $94, $2B, $FF,
    $96, $42, $FD, $29, $2F, $FB, $44, $90, $F9, $2D, $92, $46, $9E, $4A, $F5,
    $21, $48, $9C, $23, $F7, $F1, $25, $9A, $4E, $27, $F3, $4C, $98, $C1, $15,
    $AA, $7E, $17, $C3, $7C, $A8, $AE, $7A, $C5, $11, $78, $AC, $13, $C7, $1F,
    $CB, $74, $A0, $C9, $1D, $A2, $76, $70, $A4, $1B, $CF, $A6, $72, $CD, $19,
    $BE, $6A, $D5, $01, $68, $BC, $03, $D7, $D1, $05, $BA, $6E, $07, $D3, $6C,
    $B8, $60, $B4, $0B, $DF, $B6, $62, $DD, $09, $0F, $DB, $64, $B0, $D9, $0D,
    $B2, $66, $00, $D5, $69, $BC, $D2, $07, $BB, $6E, $67, $B2, $0E, $DB, $B5,
    $60, $DC, $09, $CE, $1B, $A7, $72, $1C, $C9, $75, $A0, $A9, $7C, $C0, $15,
    $7B, $AE, $12, $C7, $5F, $8A, $36, $E3, $8D, $58, $E4, $31, $38, $ED, $51,
    $84, $EA, $3F, $83, $56, $91, $44, $F8, $2D, $43, $96, $2A, $FF, $F6, $23,
    $9F, $4A, $24, $F1, $4D, $98, $BE, $6B, $D7, $02, $6C, $B9, $05, $D0, $D9,
    $0C, $B0, $65, $0B, $DE, $62, $B7, $70, $A5, $19, $CC, $A2, $77, $CB, $1E,
    $17, $C2, $7E, $AB, $C5, $10, $AC, $79, $E1, $34, $88, $5D, $33, $E6, $5A,
    $8F, $86, $53, $EF, $3A, $54, $81, $3D, $E8, $2F, $FA, $46, $93, $FD, $28,
    $94, $41, $48, $9D, $21, $F4, $9A, $4F, $F3, $26, $BF, $6A, $D6, $03, $6D,
    $B8, $04, $D1, $D8, $0D, $B1, $64, $0A, $DF, $63, $B6, $71, $A4, $18, $CD,
    $A3, $76, $CA, $1F, $16, $C3, $7F, $AA, $C4, $11, $AD, $78, $E0, $35, $89,
    $5C, $32, $E7, $5B, $8E, $87, $52, $EE, $3B, $55, $80, $3C, $E9, $2E, $FB,
    $47, $92, $FC, $29, $95, $40, $49, $9C, $20, $F5, $9B, $4E, $F2, $27, $01,
    $D4, $68, $BD, $D3, $06, $BA, $6F, $66, $B3, $0F, $DA, $B4, $61, $DD, $08,
    $CF, $1A, $A6, $73, $1D, $C8, $74, $A1, $A8, $7D, $C1, $14, $7A, $AF, $13,
    $C6, $5E, $8B, $37, $E2, $8C, $59, $E5, $30, $39, $EC, $50, $85, $EB, $3E,
    $82, $57, $90, $45, $F9, $2C, $42, $97, $2B, $FE, $F7, $22, $9E, $4B, $25,
    $F0, $4C, $99, $00, $D6, $6F, $B9, $DE, $08, $B1, $67, $7F, $A9, $10, $C6,
    $A1, $77, $CE, $18, $FE, $28, $91, $47, $20, $F6, $4F, $99, $81, $57, $EE,
    $38, $5F, $89, $30, $E6, $3F, $E9, $50, $86, $E1, $37, $8E, $58, $40, $96,
    $2F, $F9, $9E, $48, $F1, $27, $C1, $17, $AE, $78, $1F, $C9, $70, $A6, $BE,
    $68, $D1, $07, $60, $B6, $0F, $D9, $7E, $A8, $11, $C7, $A0, $76, $CF, $19,
    $01, $D7, $6E, $B8, $DF, $09, $B0, $66, $80, $56, $EF, $39, $5E, $88, $31,
    $E7, $FF, $29, $90, $46, $21, $F7, $4E, $98, $41, $97, $2E, $F8, $9F, $49,
    $F0, $26, $3E, $E8, $51, $87, $E0, $36, $8F, $59, $BF, $69, $D0, $06, $61,
    $B7, $0E, $D8, $C0, $16, $AF, $79, $1E, $C8, $71, $A7, $FC, $2A, $93, $45,
    $22, $F4, $4D, $9B, $83, $55, $EC, $3A, $5D, $8B, $32, $E4, $02, $D4, $6D,
    $BB, $DC, $0A, $B3, $65, $7D, $AB, $12, $C4, $A3, $75, $CC, $1A, $C3, $15,
    $AC, $7A, $1D, $CB, $72, $A4, $BC, $6A, $D3, $05, $62, $B4, $0D, $DB, $3D,
    $EB, $52, $84, $E3, $35, $8C, $5A, $42, $94, $2D, $FB, $9C, $4A, $F3, $25,
    $82, $54, $ED, $3B, $5C, $8A, $33, $E5, $FD, $2B, $92, $44, $23, $F5, $4C,
    $9A, $7C, $AA, $13, $C5, $A2, $74, $CD, $1B, $03, $D5, $6C, $BA, $DD, $0B,
    $B2, $64, $BD, $6B, $D2, $04, $63, $B5, $0C, $DA, $C2, $14, $AD, $7B, $1C,
    $CA, $73, $A5, $43, $95, $2C, $FA, $9D, $4B, $F2, $24, $3C, $EA, $53, $85,
    $E2, $34, $8D, $5B, $00, $D7, $6D, $BA, $DA, $0D, $B7, $60, $77, $A0, $1A,
    $CD, $AD, $7A, $C0, $17, $EE, $39, $83, $54, $34, $E3, $59, $8E, $99, $4E,
    $F4, $23, $43, $94, $2E, $F9, $1F, $C8, $72, $A5, $C5, $12, $A8, $7F, $68,
    $BF, $05, $D2, $B2, $65, $DF, $08, $F1, $26, $9C, $4B, $2B, $FC, $46, $91,
    $86, $51, $EB, $3C, $5C, $8B, $31, $E6, $3E, $E9, $53, $84, $E4, $33, $89,
    $5E, $49, $9E, $24, $F3, $93, $44, $FE, $29, $D0, $07, $BD, $6A, $0A, $DD,
    $67, $B0, $A7, $70, $CA, $1D, $7D, $AA, $10, $C7, $21, $F6, $4C, $9B, $FB,
    $2C, $96, $41, $56, $81, $3B, $EC, $8C, $5B, $E1, $36, $CF, $18, $A2, $75,
    $15, $C2, $78, $AF, $B8, $6F, $D5, $02, $62, $B5, $0F, $D8, $7C, $AB, $11,
    $C6, $A6, $71, $CB, $1C, $0B, $DC, $66, $B1, $D1, $06, $BC, $6B, $92, $45,
    $FF, $28, $48, $9F, $25, $F2, $E5, $32, $88, $5F, $3F, $E8, $52, $85, $63,
    $B4, $0E, $D9, $B9, $6E, $D4, $03, $14, $C3, $79, $AE, $CE, $19, $A3, $74,
    $8D, $5A, $E0, $37, $57, $80, $3A, $ED, $FA, $2D, $97, $40, $20, $F7, $4D,
    $9A, $42, $95, $2F, $F8, $98, $4F, $F5, $22, $35, $E2, $58, $8F, $EF, $38,
    $82, $55, $AC, $7B, $C1, $16, $76, $A1, $1B, $CC, $DB, $0C, $B6, $61, $01,
    $D6, $6C, $BB, $5D, $8A, $30, $E7, $87, $50, $EA, $3D, $2A, $FD, $47, $90,
    $F0, $27, $9D, $4A, $B3, $64, $DE, $09, $69, $BE, $04, $D3, $C4, $13, $A9,
    $7E, $1E, $C9, $73, $A4, $00, $D8, $73, $AB, $E6, $3E, $95, $4D, $0F, $D7,
    $7C, $A4, $E9, $31, $9A, $42, $1E, $C6, $6D, $B5, $F8, $20, $8B, $53, $11,
    $C9, $62, $BA, $F7, $2F, $84, $5C, $3C, $E4, $4F, $97, $DA, $02, $A9, $71,
    $33, $EB, $40, $98, $D5, $0D, $A6, $7E, $22, $FA, $51, $89, $C4, $1C, $B7,
    $6F, $2D, $F5, $5E, $86, $CB, $13, $B8, $60, $78, $A0, $0B, $D3, $9E, $46,
    $ED, $35, $77, $AF, $04, $DC, $91, $49, $E2, $3A, $66, $BE, $15, $CD, $80,
    $58, $F3, $2B, $69, $B1, $1A, $C2, $8F, $57, $FC, $24, $44, $9C, $37, $EF,
    $A2, $7A, $D1, $09, $4B, $93, $38, $E0, $AD, $75, $DE, $06, $5A, $82, $29,
    $F1, $BC, $64, $CF, $17, $55, $8D, $26, $FE, $B3, $6B, $C0, $18, $F0, $28,
    $83, $5B, $16, $CE, $65, $BD, $FF, $27, $8C, $54, $19, $C1, $6A, $B2, $EE,
    $36, $9D, $45, $08, $D0, $7B, $A3, $E1, $39, $92, $4A, $07, $DF, $74, $AC,
    $CC, $14, $BF, $67, $2A, $F2, $59, $81, $C3, $1B, $B0, $68, $25, $FD, $56,
    $8E, $D2, $0A, $A1, $79, $34, $EC, $47, $9F, $DD, $05, $AE, $76, $3B, $E3,
    $48, $90, $88, $50, $FB, $23, $6E, $B6, $1D, $C5, $87, $5F, $F4, $2C, $61,
    $B9, $12, $CA, $96, $4E, $E5, $3D, $70, $A8, $03, $DB, $99, $41, $EA, $32,
    $7F, $A7, $0C, $D4, $B4, $6C, $C7, $1F, $52, $8A, $21, $F9, $BB, $63, $C8,
    $10, $5D, $85, $2E, $F6, $AA, $72, $D9, $01, $4C, $94, $3F, $E7, $A5, $7D,
    $D6, $0E, $43, $9B, $30, $E8, $00, $D9, $71, $A8, $E2, $3B, $93, $4A, $07,
    $DE, $76, $AF, $E5, $3C, $94, $4D, $0E, $D7, $7F, $A6, $EC, $35, $9D, $44,
    $09, $D0, $78, $A1, $EB, $32, $9A, $43, $1C, $C5, $6D, $B4, $FE, $27, $8F,
    $56, $1B, $C2, $6A, $B3, $F9, $20, $88, $51, $12, $CB, $63, $BA, $F0, $29,
    $81, $58, $15, $CC, $64, $BD, $F7, $2E, $86, $5F, $38, $E1, $49, $90, $DA,
    $03, $AB, $72, $3F, $E6, $4E, $97, $DD, $04, $AC, $75, $36, $EF, $47, $9E,
    $D4, $0D, $A5, $7C, $31, $E8, $40, $99, $D3, $0A, $A2, $7B, $24, $FD, $55,
    $8C, $C6, $1F, $B7, $6E, $23, $FA, $52, $8B, $C1, $18, $B0, $69, $2A, $F3,
    $5B, $82, $C8, $11, $B9, $60, $2D, $F4, $5C, $85, $CF, $16, $BE, $67, $70,
    $A9, $01, $D8, $92, $4B, $E3, $3A, $77, $AE, $06, $DF, $95, $4C, $E4, $3D,
    $7E, $A7, $0F, $D6, $9C, $45, $ED, $34, $79, $A0, $08, $D1, $9B, $42, $EA,
    $33, $6C, $B5, $1D, $C4, $8E, $57, $FF, $26, $6B, $B2, $1A, $C3, $89, $50,
    $F8, $21, $62, $BB, $13, $CA, $80, $59, $F1, $28, $65, $BC, $14, $CD, $87,
    $5E, $F6, $2F, $48, $91, $39, $E0, $AA, $73, $DB, $02, $4F, $96, $3E, $E7,
    $AD, $74, $DC, $05, $46, $9F, $37, $EE, $A4, $7D, $D5, $0C, $41, $98, $30,
    $E9, $A3, $7A, $D2, $0B, $54, $8D, $25, $FC, $B6, $6F, $C7, $1E, $53, $8A,
    $22, $FB, $B1, $68, $C0, $19, $5A, $83, $2B, $F2, $B8, $61, $C9, $10, $5D,
    $84, $2C, $F5, $BF, $66, $CE, $17, $00, $DA, $77, $AD, $EE, $34, $99, $43,
    $1F, $C5, $68, $B2, $F1, $2B, $86, $5C, $3E, $E4, $49, $93, $D0, $0A, $A7,
    $7D, $21, $FB, $56, $8C, $CF, $15, $B8, $62, $7C, $A6, $0B, $D1, $92, $48,
    $E5, $3F, $63, $B9, $14, $CE, $8D, $57, $FA, $20, $42, $98, $35, $EF, $AC,
    $76, $DB, $01, $5D, $87, $2A, $F0, $B3, $69, $C4, $1E, $F8, $22, $8F, $55,
    $16, $CC, $61, $BB, $E7, $3D, $90, $4A, $09, $D3, $7E, $A4, $C6, $1C, $B1,
    $6B, $28, $F2, $5F, $85, $D9, $03, $AE, $74, $37, $ED, $40, $9A, $84, $5E,
    $F3, $29, $6A, $B0, $1D, $C7, $9B, $41, $EC, $36, $75, $AF, $02, $D8, $BA,
    $60, $CD, $17, $54, $8E, $23, $F9, $A5, $7F, $D2, $08, $4B, $91, $3C, $E6,
    $33, $E9, $44, $9E, $DD, $07, $AA, $70, $2C, $F6, $5B, $81, $C2, $18, $B5,
    $6F, $0D, $D7, $7A, $A0, $E3, $39, $94, $4E, $12, $C8, $65, $BF, $FC, $26,
    $8B, $51, $4F, $95, $38, $E2, $A1, $7B, $D6, $0C, $50, $8A, $27, $FD, $BE,
    $64, $C9, $13, $71, $AB, $06, $DC, $9F, $45, $E8, $32, $6E, $B4, $19, $C3,
    $80, $5A, $F7, $2D, $CB, $11, $BC, $66, $25, $FF, $52, $88, $D4, $0E, $A3,
    $79, $3A, $E0, $4D, $97, $F5, $2F, $82, $58, $1B, $C1, $6C, $B6, $EA, $30,
    $9D, $47, $04, $DE, $73, $A9, $B7, $6D, $C0, $1A, $59, $83, $2E, $F4, $A8,
    $72, $DF, $05, $46, $9C, $31, $EB, $89, $53, $FE, $24, $67, $BD, $10, $CA,
    $96, $4C, $E1, $3B, $78, $A2, $0F, $D5, $00, $DB, $75, $AE, $EA, $31, $9F,
    $44, $17, $CC, $62, $B9, $FD, $26, $88, $53, $2E, $F5, $5B, $80, $C4, $1F,
    $B1, $6A, $39, $E2, $4C, $97, $D3, $08, $A6, $7D, $5C, $87, $29, $F2, $B6,
    $6D, $C3, $18, $4B, $90, $3E, $E5, $A1, $7A, $D4, $0F, $72, $A9, $07, $DC,
    $98, $43, $ED, $36, $65, $BE, $10, $CB, $8F, $54, $FA, $21, $B8, $63, $CD,
    $16, $52, $89, $27, $FC, $AF, $74, $DA, $01, $45, $9E, $30, $EB, $96, $4D,
    $E3, $38, $7C, $A7, $09, $D2, $81, $5A, $F4, $2F, $6B, $B0, $1E, $C5, $E4,
    $3F, $91, $4A, $0E, $D5, $7B, $A0, $F3, $28, $86, $5D, $19, $C2, $6C, $B7,
    $CA, $11, $BF, $64, $20, $FB, $55, $8E, $DD, $06, $A8, $73, $37, $EC, $42,
    $99, $B3, $68, $C6, $1D, $59, $82, $2C, $F7, $A4, $7F, $D1, $0A, $4E, $95,
    $3B, $E0, $9D, $46, $E8, $33, $77, $AC, $02, $D9, $8A, $51, $FF, $24, $60,
    $BB, $15, $CE, $EF, $34, $9A, $41, $05, $DE, $70, $AB, $F8, $23, $8D, $56,
    $12, $C9, $67, $BC, $C1, $1A, $B4, $6F, $2B, $F0, $5E, $85, $D6, $0D, $A3,
    $78, $3C, $E7, $49, $92, $0B, $D0, $7E, $A5, $E1, $3A, $94, $4F, $1C, $C7,
    $69, $B2, $F6, $2D, $83, $58, $25, $FE, $50, $8B, $CF, $14, $BA, $61, $32,
    $E9, $47, $9C, $D8, $03, $AD, $76, $57, $8C, $22, $F9, $BD, $66, $C8, $13,
    $40, $9B, $35, $EE, $AA, $71, $DF, $04, $79, $A2, $0C, $D7, $93, $48, $E6,
    $3D, $6E, $B5, $1B, $C0, $84, $5F, $F1, $2A, $00, $DC, $7B, $A7, $F6, $2A,
    $8D, $51, $2F, $F3, $54, $88, $D9, $05, $A2, $7E, $5E, $82, $25, $F9, $A8,
    $74, $D3, $0F, $71, $AD, $0A, $D6, $87, $5B, $FC, $20, $BC, $60, $C7, $1B,
    $4A, $96, $31, $ED, $93, $4F, $E8, $34, $65, $B9, $1E, $C2, $E2, $3E, $99,
    $45, $14, $C8, $6F, $B3, $CD, $11, $B6, $6A, $3B, $E7, $40, $9C, $BB, $67,
    $C0, $1C, $4D, $91, $36, $EA, $94, $48, $EF, $33, $62, $BE, $19, $C5, $E5,
    $39, $9E, $42, $13, $CF, $68, $B4, $CA, $16, $B1, $6D, $3C, $E0, $47, $9B,
    $07, $DB, $7C, $A0, $F1, $2D, $8A, $56, $28, $F4, $53, $8F, $DE, $02, $A5,
    $79, $59, $85, $22, $FE, $AF, $73, $D4, $08, $76, $AA, $0D, $D1, $80, $5C,
    $FB, $27, $B5, $69, $CE, $12, $43, $9F, $38, $E4, $9A, $46, $E1, $3D, $6C,
    $B0, $17, $CB, $EB, $37, $90, $4C, $1D, $C1, $66, $BA, $C4, $18, $BF, $63,
    $32, $EE, $49, $95, $09, $D5, $72, $AE, $FF, $23, $84, $58, $26, $FA, $5D,
    $81, $D0, $0C, $AB, $77, $57, $8B, $2C, $F0, $A1, $7D, $DA, $06, $78, $A4,
    $03, $DF, $8E, $52, $F5, $29, $0E, $D2, $75, $A9, $F8, $24, $83, $5F, $21,
    $FD, $5A, $86, $D7, $0B, $AC, $70, $50, $8C, $2B, $F7, $A6, $7A, $DD, $01,
    $7F, $A3, $04, $D8, $89, $55, $F2, $2E, $B2, $6E, $C9, $15, $44, $98, $3F,
    $E3, $9D, $41, $E6, $3A, $6B, $B7, $10, $CC, $EC, $30, $97, $4B, $1A, $C6,
    $61, $BD, $C3, $1F, $B8, $64, $35, $E9, $4E, $92, $00, $DD, $79, $A4, $F2,
    $2F, $8B, $56, $27, $FA, $5E, $83, $D5, $08, $AC, $71, $4E, $93, $37, $EA,
    $BC, $61, $C5, $18, $69, $B4, $10, $CD, $9B, $46, $E2, $3F, $9C, $41, $E5,
    $38, $6E, $B3, $17, $CA, $BB, $66, $C2, $1F, $49, $94, $30, $ED, $D2, $0F,
    $AB, $76, $20, $FD, $59, $84, $F5, $28, $8C, $51, $07, $DA, $7E, $A3, $FB,
    $26, $82, $5F, $09, $D4, $70, $AD, $DC, $01, $A5, $78, $2E, $F3, $57, $8A,
    $B5, $68, $CC, $11, $47, $9A, $3E, $E3, $92, $4F, $EB, $36, $60, $BD, $19,
    $C4, $67, $BA, $1E, $C3, $95, $48, $EC, $31, $40, $9D, $39, $E4, $B2, $6F,
    $CB, $16, $29, $F4, $50, $8D, $DB, $06, $A2, $7F, $0E, $D3, $77, $AA, $FC,
    $21, $85, $58, $35, $E8, $4C, $91, $C7, $1A, $BE, $63, $12, $CF, $6B, $B6,
    $E0, $3D, $99, $44, $7B, $A6, $02, $DF, $89, $54, $F0, $2D, $5C, $81, $25,
    $F8, $AE, $73, $D7, $0A, $A9, $74, $D0, $0D, $5B, $86, $22, $FF, $8E, $53,
    $F7, $2A, $7C, $A1, $05, $D8, $E7, $3A, $9E, $43, $15, $C8, $6C, $B1, $C0,
    $1D, $B9, $64, $32, $EF, $4B, $96, $CE, $13, $B7, $6A, $3C, $E1, $45, $98,
    $E9, $34, $90, $4D, $1B, $C6, $62, $BF, $80, $5D, $F9, $24, $72, $AF, $0B,
    $D6, $A7, $7A, $DE, $03, $55, $88, $2C, $F1, $52, $8F, $2B, $F6, $A0, $7D,
    $D9, $04, $75, $A8, $0C, $D1, $87, $5A, $FE, $23, $1C, $C1, $65, $B8, $EE,
    $33, $97, $4A, $3B, $E6, $42, $9F, $C9, $14, $B0, $6D, $00, $DE, $7F, $A1,
    $FE, $20, $81, $5F, $3F, $E1, $40, $9E, $C1, $1F, $BE, $60, $7E, $A0, $01,
    $DF, $80, $5E, $FF, $21, $41, $9F, $3E, $E0, $BF, $61, $C0, $1E, $FC, $22,
    $83, $5D, $02, $DC, $7D, $A3, $C3, $1D, $BC, $62, $3D, $E3, $42, $9C, $82,
    $5C, $FD, $23, $7C, $A2, $03, $DD, $BD, $63, $C2, $1C, $43, $9D, $3C, $E2,
    $3B, $E5, $44, $9A, $C5, $1B, $BA, $64, $04, $DA, $7B, $A5, $FA, $24, $85,
    $5B, $45, $9B, $3A, $E4, $BB, $65, $C4, $1A, $7A, $A4, $05, $DB, $84, $5A,
    $FB, $25, $C7, $19, $B8, $66, $39, $E7, $46, $98, $F8, $26, $87, $59, $06,
    $D8, $79, $A7, $B9, $67, $C6, $18, $47, $99, $38, $E6, $86, $58, $F9, $27,
    $78, $A6, $07, $D9, $76, $A8, $09, $D7, $88, $56, $F7, $29, $49, $97, $36,
    $E8, $B7, $69, $C8, $16, $08, $D6, $77, $A9, $F6, $28, $89, $57, $37, $E9,
    $48, $96, $C9, $17, $B6, $68, $8A, $54, $F5, $2B, $74, $AA, $0B, $D5, $B5,
    $6B, $CA, $14, $4B, $95, $34, $EA, $F4, $2A, $8B, $55, $0A, $D4, $75, $AB,
    $CB, $15, $B4, $6A, $35, $EB, $4A, $94, $4D, $93, $32, $EC, $B3, $6D, $CC,
    $12, $72, $AC, $0D, $D3, $8C, $52, $F3, $2D, $33, $ED, $4C, $92, $CD, $13,
    $B2, $6C, $0C, $D2, $73, $AD, $F2, $2C, $8D, $53, $B1, $6F, $CE, $10, $4F,
    $91, $30, $EE, $8E, $50, $F1, $2F, $70, $AE, $0F, $D1, $CF, $11, $B0, $6E,
    $31, $EF, $4E, $90, $F0, $2E, $8F, $51, $0E, $D0, $71, $AF, $00, $DF, $7D,
    $A2, $FA, $25, $87, $58, $37, $E8, $4A, $95, $CD, $12, $B0, $6F, $6E, $B1,
    $13, $CC, $94, $4B, $E9, $36, $59, $86, $24, $FB, $A3, $7C, $DE, $01, $DC,
    $03, $A1, $7E, $26, $F9, $5B, $84, $EB, $34, $96, $49, $11, $CE, $6C, $B3,
    $B2, $6D, $CF, $10, $48, $97, $35, $EA, $85, $5A, $F8, $27, $7F, $A0, $02,
    $DD, $7B, $A4, $06, $D9, $81, $5E, $FC, $23, $4C, $93, $31, $EE, $B6, $69,
    $CB, $14, $15, $CA, $68, $B7, $EF, $30, $92, $4D, $22, $FD, $5F, $80, $D8,
    $07, $A5, $7A, $A7, $78, $DA, $05, $5D, $82, $20, $FF, $90, $4F, $ED, $32,
    $6A, $B5, $17, $C8, $C9, $16, $B4, $6B, $33, $EC, $4E, $91, $FE, $21, $83,
    $5C, $04, $DB, $79, $A6, $F6, $29, $8B, $54, $0C, $D3, $71, $AE, $C1, $1E,
    $BC, $63, $3B, $E4, $46, $99, $98, $47, $E5, $3A, $62, $BD, $1F, $C0, $AF,
    $70, $D2, $0D, $55, $8A, $28, $F7, $2A, $F5, $57, $88, $D0, $0F, $AD, $72,
    $1D, $C2, $60, $BF, $E7, $38, $9A, $45, $44, $9B, $39, $E6, $BE, $61, $C3,
    $1C, $73, $AC, $0E, $D1, $89, $56, $F4, $2B, $8D, $52, $F0, $2F, $77, $A8,
    $0A, $D5, $BA, $65, $C7, $18, $40, $9F, $3D, $E2, $E3, $3C, $9E, $41, $19,
    $C6, $64, $BB, $D4, $0B, $A9, $76, $2E, $F1, $53, $8C, $51, $8E, $2C, $F3,
    $AB, $74, $D6, $09, $66, $B9, $1B, $C4, $9C, $43, $E1, $3E, $3F, $E0, $42,
    $9D, $C5, $1A, $B8, $67, $08, $D7, $75, $AA, $F2, $2D, $8F, $50, $00, $E0,
    $03, $E3, $06, $E6, $05, $E5, $0C, $EC, $0F, $EF, $0A, $EA, $09, $E9, $18,
    $F8, $1B, $FB, $1E, $FE, $1D, $FD, $14, $F4, $17, $F7, $12, $F2, $11, $F1,
    $30, $D0, $33, $D3, $36, $D6, $35, $D5, $3C, $DC, $3F, $DF, $3A, $DA, $39,
    $D9, $28, $C8, $2B, $CB, $2E, $CE, $2D, $CD, $24, $C4, $27, $C7, $22, $C2,
    $21, $C1, $60, $80, $63, $83, $66, $86, $65, $85, $6C, $8C, $6F, $8F, $6A,
    $8A, $69, $89, $78, $98, $7B, $9B, $7E, $9E, $7D, $9D, $74, $94, $77, $97,
    $72, $92, $71, $91, $50, $B0, $53, $B3, $56, $B6, $55, $B5, $5C, $BC, $5F,
    $BF, $5A, $BA, $59, $B9, $48, $A8, $4B, $AB, $4E, $AE, $4D, $AD, $44, $A4,
    $47, $A7, $42, $A2, $41, $A1, $C0, $20, $C3, $23, $C6, $26, $C5, $25, $CC,
    $2C, $CF, $2F, $CA, $2A, $C9, $29, $D8, $38, $DB, $3B, $DE, $3E, $DD, $3D,
    $D4, $34, $D7, $37, $D2, $32, $D1, $31, $F0, $10, $F3, $13, $F6, $16, $F5,
    $15, $FC, $1C, $FF, $1F, $FA, $1A, $F9, $19, $E8, $08, $EB, $0B, $EE, $0E,
    $ED, $0D, $E4, $04, $E7, $07, $E2, $02, $E1, $01, $A0, $40, $A3, $43, $A6,
    $46, $A5, $45, $AC, $4C, $AF, $4F, $AA, $4A, $A9, $49, $B8, $58, $BB, $5B,
    $BE, $5E, $BD, $5D, $B4, $54, $B7, $57, $B2, $52, $B1, $51, $90, $70, $93,
    $73, $96, $76, $95, $75, $9C, $7C, $9F, $7F, $9A, $7A, $99, $79, $88, $68,
    $8B, $6B, $8E, $6E, $8D, $6D, $84, $64, $87, $67, $82, $62, $81, $61, $00,
    $E1, $01, $E0, $02, $E3, $03, $E2, $04, $E5, $05, $E4, $06, $E7, $07, $E6,
    $08, $E9, $09, $E8, $0A, $EB, $0B, $EA, $0C, $ED, $0D, $EC, $0E, $EF, $0F,
    $EE, $10, $F1, $11, $F0, $12, $F3, $13, $F2, $14, $F5, $15, $F4, $16, $F7,
    $17, $F6, $18, $F9, $19, $F8, $1A, $FB, $1B, $FA, $1C, $FD, $1D, $FC, $1E,
    $FF, $1F, $FE, $20, $C1, $21, $C0, $22, $C3, $23, $C2, $24, $C5, $25, $C4,
    $26, $C7, $27, $C6, $28, $C9, $29, $C8, $2A, $CB, $2B, $CA, $2C, $CD, $2D,
    $CC, $2E, $CF, $2F, $CE, $30, $D1, $31, $D0, $32, $D3, $33, $D2, $34, $D5,
    $35, $D4, $36, $D7, $37, $D6, $38, $D9, $39, $D8, $3A, $DB, $3B, $DA, $3C,
    $DD, $3D, $DC, $3E, $DF, $3F, $DE, $40, $A1, $41, $A0, $42, $A3, $43, $A2,
    $44, $A5, $45, $A4, $46, $A7, $47, $A6, $48, $A9, $49, $A8, $4A, $AB, $4B,
    $AA, $4C, $AD, $4D, $AC, $4E, $AF, $4F, $AE, $50, $B1, $51, $B0, $52, $B3,
    $53, $B2, $54, $B5, $55, $B4, $56, $B7, $57, $B6, $58, $B9, $59, $B8, $5A,
    $BB, $5B, $BA, $5C, $BD, $5D, $BC, $5E, $BF, $5F, $BE, $60, $81, $61, $80,
    $62, $83, $63, $82, $64, $85, $65, $84, $66, $87, $67, $86, $68, $89, $69,
    $88, $6A, $8B, $6B, $8A, $6C, $8D, $6D, $8C, $6E, $8F, $6F, $8E, $70, $91,
    $71, $90, $72, $93, $73, $92, $74, $95, $75, $94, $76, $97, $77, $96, $78,
    $99, $79, $98, $7A, $9B, $7B, $9A, $7C, $9D, $7D, $9C, $7E, $9F, $7F, $9E,
    $00, $E2, $07, $E5, $0E, $EC, $09, $EB, $1C, $FE, $1B, $F9, $12, $F0, $15,
    $F7, $38, $DA, $3F, $DD, $36, $D4, $31, $D3, $24, $C6, $23, $C1, $2A, $C8,
    $2D, $CF, $70, $92, $77, $95, $7E, $9C, $79, $9B, $6C, $8E, $6B, $89, $62,
    $80, $65, $87, $48, $AA, $4F, $AD, $46, $A4, $41, $A3, $54, $B6, $53, $B1,
    $5A, $B8, $5D, $BF, $E0, $02, $E7, $05, $EE, $0C, $E9, $0B, $FC, $1E, $FB,
    $19, $F2, $10, $F5, $17, $D8, $3A, $DF, $3D, $D6, $34, $D1, $33, $C4, $26,
    $C3, $21, $CA, $28, $CD, $2F, $90, $72, $97, $75, $9E, $7C, $99, $7B, $8C,
    $6E, $8B, $69, $82, $60, $85, $67, $A8, $4A, $AF, $4D, $A6, $44, $A1, $43,
    $B4, $56, $B3, $51, $BA, $58, $BD, $5F, $03, $E1, $04, $E6, $0D, $EF, $0A,
    $E8, $1F, $FD, $18, $FA, $11, $F3, $16, $F4, $3B, $D9, $3C, $DE, $35, $D7,
    $32, $D0, $27, $C5, $20, $C2, $29, $CB, $2E, $CC, $73, $91, $74, $96, $7D,
    $9F, $7A, $98, $6F, $8D, $68, $8A, $61, $83, $66, $84, $4B, $A9, $4C, $AE,
    $45, $A7, $42, $A0, $57, $B5, $50, $B2, $59, $BB, $5E, $BC, $E3, $01, $E4,
    $06, $ED, $0F, $EA, $08, $FF, $1D, $F8, $1A, $F1, $13, $F6, $14, $DB, $39,
    $DC, $3E, $D5, $37, $D2, $30, $C7, $25, $C0, $22, $C9, $2B, $CE, $2C, $93,
    $71, $94, $76, $9D, $7F, $9A, $78, $8F, $6D, $88, $6A, $81, $63, $86, $64,
    $AB, $49, $AC, $4E, $A5, $47, $A2, $40, $B7, $55, $B0, $52, $B9, $5B, $BE,
    $5C, $00, $E3, $05, $E6, $0A, $E9, $0F, $EC, $14, $F7, $11, $F2, $1E, $FD,
    $1B, $F8, $28, $CB, $2D, $CE, $22, $C1, $27, $C4, $3C, $DF, $39, $DA, $36,
    $D5, $33, $D0, $50, $B3, $55, $B6, $5A, $B9, $5F, $BC, $44, $A7, $41, $A2,
    $4E, $AD, $4B, $A8, $78, $9B, $7D, $9E, $72, $91, $77, $94, $6C, $8F, $69,
    $8A, $66, $85, $63, $80, $A0, $43, $A5, $46, $AA, $49, $AF, $4C, $B4, $57,
    $B1, $52, $BE, $5D, $BB, $58, $88, $6B, $8D, $6E, $82, $61, $87, $64, $9C,
    $7F, $99, $7A, $96, $75, $93, $70, $F0, $13, $F5, $16, $FA, $19, $FF, $1C,
    $E4, $07, $E1, $02, $EE, $0D, $EB, $08, $D8, $3B, $DD, $3E, $D2, $31, $D7,
    $34, $CC, $2F, $C9, $2A, $C6, $25, $C3, $20, $83, $60, $86, $65, $89, $6A,
    $8C, $6F, $97, $74, $92, $71, $9D, $7E, $98, $7B, $AB, $48, $AE, $4D, $A1,
    $42, $A4, $47, $BF, $5C, $BA, $59, $B5, $56, $B0, $53, $D3, $30, $D6, $35,
    $D9, $3A, $DC, $3F, $C7, $24, $C2, $21, $CD, $2E, $C8, $2B, $FB, $18, $FE,
    $1D, $F1, $12, $F4, $17, $EF, $0C, $EA, $09, $E5, $06, $E0, $03, $23, $C0,
    $26, $C5, $29, $CA, $2C, $CF, $37, $D4, $32, $D1, $3D, $DE, $38, $DB, $0B,
    $E8, $0E, $ED, $01, $E2, $04, $E7, $1F, $FC, $1A, $F9, $15, $F6, $10, $F3,
    $73, $90, $76, $95, $79, $9A, $7C, $9F, $67, $84, $62, $81, $6D, $8E, $68,
    $8B, $5B, $B8, $5E, $BD, $51, $B2, $54, $B7, $4F, $AC, $4A, $A9, $45, $A6,
    $40, $A3, $00, $E4, $0B, $EF, $16, $F2, $1D, $F9, $2C, $C8, $27, $C3, $3A,
    $DE, $31, $D5, $58, $BC, $53, $B7, $4E, $AA, $45, $A1, $74, $90, $7F, $9B,
    $62, $86, $69, $8D, $B0, $54, $BB, $5F, $A6, $42, $AD, $49, $9C, $78, $97,
    $73, $8A, $6E, $81, $65, $E8, $0C, $E3, $07, $FE, $1A, $F5, $11, $C4, $20,
    $CF, $2B, $D2, $36, $D9, $3D, $A3, $47, $A8, $4C, $B5, $51, $BE, $5A, $8F,
    $6B, $84, $60, $99, $7D, $92, $76, $FB, $1F, $F0, $14, $ED, $09, $E6, $02,
    $D7, $33, $DC, $38, $C1, $25, $CA, $2E, $13, $F7, $18, $FC, $05, $E1, $0E,
    $EA, $3F, $DB, $34, $D0, $29, $CD, $22, $C6, $4B, $AF, $40, $A4, $5D, $B9,
    $56, $B2, $67, $83, $6C, $88, $71, $95, $7A, $9E, $85, $61, $8E, $6A, $93,
    $77, $98, $7C, $A9, $4D, $A2, $46, $BF, $5B, $B4, $50, $DD, $39, $D6, $32,
    $CB, $2F, $C0, $24, $F1, $15, $FA, $1E, $E7, $03, $EC, $08, $35, $D1, $3E,
    $DA, $23, $C7, $28, $CC, $19, $FD, $12, $F6, $0F, $EB, $04, $E0, $6D, $89,
    $66, $82, $7B, $9F, $70, $94, $41, $A5, $4A, $AE, $57, $B3, $5C, $B8, $26,
    $C2, $2D, $C9, $30, $D4, $3B, $DF, $0A, $EE, $01, $E5, $1C, $F8, $17, $F3,
    $7E, $9A, $75, $91, $68, $8C, $63, $87, $52, $B6, $59, $BD, $44, $A0, $4F,
    $AB, $96, $72, $9D, $79, $80, $64, $8B, $6F, $BA, $5E, $B1, $55, $AC, $48,
    $A7, $43, $CE, $2A, $C5, $21, $D8, $3C, $D3, $37, $E2, $06, $E9, $0D, $F4,
    $10, $FF, $1B, $00, $E5, $09, $EC, $12, $F7, $1B, $FE, $24, $C1, $2D, $C8,
    $36, $D3, $3F, $DA, $48, $AD, $41, $A4, $5A, $BF, $53, $B6, $6C, $89, $65,
    $80, $7E, $9B, $77, $92, $90, $75, $99, $7C, $82, $67, $8B, $6E, $B4, $51,
    $BD, $58, $A6, $43, $AF, $4A, $D8, $3D, $D1, $34, $CA, $2F, $C3, $26, $FC,
    $19, $F5, $10, $EE, $0B, $E7, $02, $E3, $06, $EA, $0F, $F1, $14, $F8, $1D,
    $C7, $22, $CE, $2B, $D5, $30, $DC, $39, $AB, $4E, $A2, $47, $B9, $5C, $B0,
    $55, $8F, $6A, $86, $63, $9D, $78, $94, $71, $73, $96, $7A, $9F, $61, $84,
    $68, $8D, $57, $B2, $5E, $BB, $45, $A0, $4C, $A9, $3B, $DE, $32, $D7, $29,
    $CC, $20, $C5, $1F, $FA, $16, $F3, $0D, $E8, $04, $E1, $05, $E0, $0C, $E9,
    $17, $F2, $1E, $FB, $21, $C4, $28, $CD, $33, $D6, $3A, $DF, $4D, $A8, $44,
    $A1, $5F, $BA, $56, $B3, $69, $8C, $60, $85, $7B, $9E, $72, $97, $95, $70,
    $9C, $79, $87, $62, $8E, $6B, $B1, $54, $B8, $5D, $A3, $46, $AA, $4F, $DD,
    $38, $D4, $31, $CF, $2A, $C6, $23, $F9, $1C, $F0, $15, $EB, $0E, $E2, $07,
    $E6, $03, $EF, $0A, $F4, $11, $FD, $18, $C2, $27, $CB, $2E, $D0, $35, $D9,
    $3C, $AE, $4B, $A7, $42, $BC, $59, $B5, $50, $8A, $6F, $83, $66, $98, $7D,
    $91, $74, $76, $93, $7F, $9A, $64, $81, $6D, $88, $52, $B7, $5B, $BE, $40,
    $A5, $49, $AC, $3E, $DB, $37, $D2, $2C, $C9, $25, $C0, $1A, $FF, $13, $F6,
    $08, $ED, $01, $E4, $00, $E6, $0F, $E9, $1E, $F8, $11, $F7, $3C, $DA, $33,
    $D5, $22, $C4, $2D, $CB, $78, $9E, $77, $91, $66, $80, $69, $8F, $44, $A2,
    $4B, $AD, $5A, $BC, $55, $B3, $F0, $16, $FF, $19, $EE, $08, $E1, $07, $CC,
    $2A, $C3, $25, $D2, $34, $DD, $3B, $88, $6E, $87, $61, $96, $70, $99, $7F,
    $B4, $52, $BB, $5D, $AA, $4C, $A5, $43, $23, $C5, $2C, $CA, $3D, $DB, $32,
    $D4, $1F, $F9, $10, $F6, $01, $E7, $0E, $E8, $5B, $BD, $54, $B2, $45, $A3,
    $4A, $AC, $67, $81, $68, $8E, $79, $9F, $76, $90, $D3, $35, $DC, $3A, $CD,
    $2B, $C2, $24, $EF, $09, $E0, $06, $F1, $17, $FE, $18, $AB, $4D, $A4, $42,
    $B5, $53, $BA, $5C, $97, $71, $98, $7E, $89, $6F, $86, $60, $46, $A0, $49,
    $AF, $58, $BE, $57, $B1, $7A, $9C, $75, $93, $64, $82, $6B, $8D, $3E, $D8,
    $31, $D7, $20, $C6, $2F, $C9, $02, $E4, $0D, $EB, $1C, $FA, $13, $F5, $B6,
    $50, $B9, $5F, $A8, $4E, $A7, $41, $8A, $6C, $85, $63, $94, $72, $9B, $7D,
    $CE, $28, $C1, $27, $D0, $36, $DF, $39, $F2, $14, $FD, $1B, $EC, $0A, $E3,
    $05, $65, $83, $6A, $8C, $7B, $9D, $74, $92, $59, $BF, $56, $B0, $47, $A1,
    $48, $AE, $1D, $FB, $12, $F4, $03, $E5, $0C, $EA, $21, $C7, $2E, $C8, $3F,
    $D9, $30, $D6, $95, $73, $9A, $7C, $8B, $6D, $84, $62, $A9, $4F, $A6, $40,
    $B7, $51, $B8, $5E, $ED, $0B, $E2, $04, $F3, $15, $FC, $1A, $D1, $37, $DE,
    $38, $CF, $29, $C0, $26, $00, $E7, $0D, $EA, $1A, $FD, $17, $F0, $34, $D3,
    $39, $DE, $2E, $C9, $23, $C4, $68, $8F, $65, $82, $72, $95, $7F, $98, $5C,
    $BB, $51, $B6, $46, $A1, $4B, $AC, $D0, $37, $DD, $3A, $CA, $2D, $C7, $20,
    $E4, $03, $E9, $0E, $FE, $19, $F3, $14, $B8, $5F, $B5, $52, $A2, $45, $AF,
    $48, $8C, $6B, $81, $66, $96, $71, $9B, $7C, $63, $84, $6E, $89, $79, $9E,
    $74, $93, $57, $B0, $5A, $BD, $4D, $AA, $40, $A7, $0B, $EC, $06, $E1, $11,
    $F6, $1C, $FB, $3F, $D8, $32, $D5, $25, $C2, $28, $CF, $B3, $54, $BE, $59,
    $A9, $4E, $A4, $43, $87, $60, $8A, $6D, $9D, $7A, $90, $77, $DB, $3C, $D6,
    $31, $C1, $26, $CC, $2B, $EF, $08, $E2, $05, $F5, $12, $F8, $1F, $C6, $21,
    $CB, $2C, $DC, $3B, $D1, $36, $F2, $15, $FF, $18, $E8, $0F, $E5, $02, $AE,
    $49, $A3, $44, $B4, $53, $B9, $5E, $9A, $7D, $97, $70, $80, $67, $8D, $6A,
    $16, $F1, $1B, $FC, $0C, $EB, $01, $E6, $22, $C5, $2F, $C8, $38, $DF, $35,
    $D2, $7E, $99, $73, $94, $64, $83, $69, $8E, $4A, $AD, $47, $A0, $50, $B7,
    $5D, $BA, $A5, $42, $A8, $4F, $BF, $58, $B2, $55, $91, $76, $9C, $7B, $8B,
    $6C, $86, $61, $CD, $2A, $C0, $27, $D7, $30, $DA, $3D, $F9, $1E, $F4, $13,
    $E3, $04, $EE, $09, $75, $92, $78, $9F, $6F, $88, $62, $85, $41, $A6, $4C,
    $AB, $5B, $BC, $56, $B1, $1D, $FA, $10, $F7, $07, $E0, $0A, $ED, $29, $CE,
    $24, $C3, $33, $D4, $3E, $D9, $00, $E8, $13, $FB, $26, $CE, $35, $DD, $4C,
    $A4, $5F, $B7, $6A, $82, $79, $91, $98, $70, $8B, $63, $BE, $56, $AD, $45,
    $D4, $3C, $C7, $2F, $F2, $1A, $E1, $09, $F3, $1B, $E0, $08, $D5, $3D, $C6,
    $2E, $BF, $57, $AC, $44, $99, $71, $8A, $62, $6B, $83, $78, $90, $4D, $A5,
    $5E, $B6, $27, $CF, $34, $DC, $01, $E9, $12, $FA, $25, $CD, $36, $DE, $03,
    $EB, $10, $F8, $69, $81, $7A, $92, $4F, $A7, $5C, $B4, $BD, $55, $AE, $46,
    $9B, $73, $88, $60, $F1, $19, $E2, $0A, $D7, $3F, $C4, $2C, $D6, $3E, $C5,
    $2D, $F0, $18, $E3, $0B, $9A, $72, $89, $61, $BC, $54, $AF, $47, $4E, $A6,
    $5D, $B5, $68, $80, $7B, $93, $02, $EA, $11, $F9, $24, $CC, $37, $DF, $4A,
    $A2, $59, $B1, $6C, $84, $7F, $97, $06, $EE, $15, $FD, $20, $C8, $33, $DB,
    $D2, $3A, $C1, $29, $F4, $1C, $E7, $0F, $9E, $76, $8D, $65, $B8, $50, $AB,
    $43, $B9, $51, $AA, $42, $9F, $77, $8C, $64, $F5, $1D, $E6, $0E, $D3, $3B,
    $C0, $28, $21, $C9, $32, $DA, $07, $EF, $14, $FC, $6D, $85, $7E, $96, $4B,
    $A3, $58, $B0, $6F, $87, $7C, $94, $49, $A1, $5A, $B2, $23, $CB, $30, $D8,
    $05, $ED, $16, $FE, $F7, $1F, $E4, $0C, $D1, $39, $C2, $2A, $BB, $53, $A8,
    $40, $9D, $75, $8E, $66, $9C, $74, $8F, $67, $BA, $52, $A9, $41, $D0, $38,
    $C3, $2B, $F6, $1E, $E5, $0D, $04, $EC, $17, $FF, $22, $CA, $31, $D9, $48,
    $A0, $5B, $B3, $6E, $86, $7D, $95, $00, $E9, $11, $F8, $22, $CB, $33, $DA,
    $44, $AD, $55, $BC, $66, $8F, $77, $9E, $88, $61, $99, $70, $AA, $43, $BB,
    $52, $CC, $25, $DD, $34, $EE, $07, $FF, $16, $D3, $3A, $C2, $2B, $F1, $18,
    $E0, $09, $97, $7E, $86, $6F, $B5, $5C, $A4, $4D, $5B, $B2, $4A, $A3, $79,
    $90, $68, $81, $1F, $F6, $0E, $E7, $3D, $D4, $2C, $C5, $65, $8C, $74, $9D,
    $47, $AE, $56, $BF, $21, $C8, $30, $D9, $03, $EA, $12, $FB, $ED, $04, $FC,
    $15, $CF, $26, $DE, $37, $A9, $40, $B8, $51, $8B, $62, $9A, $73, $B6, $5F,
    $A7, $4E, $94, $7D, $85, $6C, $F2, $1B, $E3, $0A, $D0, $39, $C1, $28, $3E,
    $D7, $2F, $C6, $1C, $F5, $0D, $E4, $7A, $93, $6B, $82, $58, $B1, $49, $A0,
    $CA, $23, $DB, $32, $E8, $01, $F9, $10, $8E, $67, $9F, $76, $AC, $45, $BD,
    $54, $42, $AB, $53, $BA, $60, $89, $71, $98, $06, $EF, $17, $FE, $24, $CD,
    $35, $DC, $19, $F0, $08, $E1, $3B, $D2, $2A, $C3, $5D, $B4, $4C, $A5, $7F,
    $96, $6E, $87, $91, $78, $80, $69, $B3, $5A, $A2, $4B, $D5, $3C, $C4, $2D,
    $F7, $1E, $E6, $0F, $AF, $46, $BE, $57, $8D, $64, $9C, $75, $EB, $02, $FA,
    $13, $C9, $20, $D8, $31, $27, $CE, $36, $DF, $05, $EC, $14, $FD, $63, $8A,
    $72, $9B, $41, $A8, $50, $B9, $7C, $95, $6D, $84, $5E, $B7, $4F, $A6, $38,
    $D1, $29, $C0, $1A, $F3, $0B, $E2, $F4, $1D, $E5, $0C, $D6, $3F, $C7, $2E,
    $B0, $59, $A1, $48, $92, $7B, $83, $6A, $00, $EA, $17, $FD, $2E, $C4, $39,
    $D3, $5C, $B6, $4B, $A1, $72, $98, $65, $8F, $B8, $52, $AF, $45, $96, $7C,
    $81, $6B, $E4, $0E, $F3, $19, $CA, $20, $DD, $37, $B3, $59, $A4, $4E, $9D,
    $77, $8A, $60, $EF, $05, $F8, $12, $C1, $2B, $D6, $3C, $0B, $E1, $1C, $F6,
    $25, $CF, $32, $D8, $57, $BD, $40, $AA, $79, $93, $6E, $84, $A5, $4F, $B2,
    $58, $8B, $61, $9C, $76, $F9, $13, $EE, $04, $D7, $3D, $C0, $2A, $1D, $F7,
    $0A, $E0, $33, $D9, $24, $CE, $41, $AB, $56, $BC, $6F, $85, $78, $92, $16,
    $FC, $01, $EB, $38, $D2, $2F, $C5, $4A, $A0, $5D, $B7, $64, $8E, $73, $99,
    $AE, $44, $B9, $53, $80, $6A, $97, $7D, $F2, $18, $E5, $0F, $DC, $36, $CB,
    $21, $89, $63, $9E, $74, $A7, $4D, $B0, $5A, $D5, $3F, $C2, $28, $FB, $11,
    $EC, $06, $31, $DB, $26, $CC, $1F, $F5, $08, $E2, $6D, $87, $7A, $90, $43,
    $A9, $54, $BE, $3A, $D0, $2D, $C7, $14, $FE, $03, $E9, $66, $8C, $71, $9B,
    $48, $A2, $5F, $B5, $82, $68, $95, $7F, $AC, $46, $BB, $51, $DE, $34, $C9,
    $23, $F0, $1A, $E7, $0D, $2C, $C6, $3B, $D1, $02, $E8, $15, $FF, $70, $9A,
    $67, $8D, $5E, $B4, $49, $A3, $94, $7E, $83, $69, $BA, $50, $AD, $47, $C8,
    $22, $DF, $35, $E6, $0C, $F1, $1B, $9F, $75, $88, $62, $B1, $5B, $A6, $4C,
    $C3, $29, $D4, $3E, $ED, $07, $FA, $10, $27, $CD, $30, $DA, $09, $E3, $1E,
    $F4, $7B, $91, $6C, $86, $55, $BF, $42, $A8, $00, $EB, $15, $FE, $2A, $C1,
    $3F, $D4, $54, $BF, $41, $AA, $7E, $95, $6B, $80, $A8, $43, $BD, $56, $82,
    $69, $97, $7C, $FC, $17, $E9, $02, $D6, $3D, $C3, $28, $93, $78, $86, $6D,
    $B9, $52, $AC, $47, $C7, $2C, $D2, $39, $ED, $06, $F8, $13, $3B, $D0, $2E,
    $C5, $11, $FA, $04, $EF, $6F, $84, $7A, $91, $45, $AE, $50, $BB, $E5, $0E,
    $F0, $1B, $CF, $24, $DA, $31, $B1, $5A, $A4, $4F, $9B, $70, $8E, $65, $4D,
    $A6, $58, $B3, $67, $8C, $72, $99, $19, $F2, $0C, $E7, $33, $D8, $26, $CD,
    $76, $9D, $63, $88, $5C, $B7, $49, $A2, $22, $C9, $37, $DC, $08, $E3, $1D,
    $F6, $DE, $35, $CB, $20, $F4, $1F, $E1, $0A, $8A, $61, $9F, $74, $A0, $4B,
    $B5, $5E, $09, $E2, $1C, $F7, $23, $C8, $36, $DD, $5D, $B6, $48, $A3, $77,
    $9C, $62, $89, $A1, $4A, $B4, $5F, $8B, $60, $9E, $75, $F5, $1E, $E0, $0B,
    $DF, $34, $CA, $21, $9A, $71, $8F, $64, $B0, $5B, $A5, $4E, $CE, $25, $DB,
    $30, $E4, $0F, $F1, $1A, $32, $D9, $27, $CC, $18, $F3, $0D, $E6, $66, $8D,
    $73, $98, $4C, $A7, $59, $B2, $EC, $07, $F9, $12, $C6, $2D, $D3, $38, $B8,
    $53, $AD, $46, $92, $79, $87, $6C, $44, $AF, $51, $BA, $6E, $85, $7B, $90,
    $10, $FB, $05, $EE, $3A, $D1, $2F, $C4, $7F, $94, $6A, $81, $55, $BE, $40,
    $AB, $2B, $C0, $3E, $D5, $01, $EA, $14, $FF, $D7, $3C, $C2, $29, $FD, $16,
    $E8, $03, $83, $68, $96, $7D, $A9, $42, $BC, $57, $00, $EC, $1B, $F7, $36,
    $DA, $2D, $C1, $6C, $80, $77, $9B, $5A, $B6, $41, $AD, $D8, $34, $C3, $2F,
    $EE, $02, $F5, $19, $B4, $58, $AF, $43, $82, $6E, $99, $75, $73, $9F, $68,
    $84, $45, $A9, $5E, $B2, $1F, $F3, $04, $E8, $29, $C5, $32, $DE, $AB, $47,
    $B0, $5C, $9D, $71, $86, $6A, $C7, $2B, $DC, $30, $F1, $1D, $EA, $06, $E6,
    $0A, $FD, $11, $D0, $3C, $CB, $27, $8A, $66, $91, $7D, $BC, $50, $A7, $4B,
    $3E, $D2, $25, $C9, $08, $E4, $13, $FF, $52, $BE, $49, $A5, $64, $88, $7F,
    $93, $95, $79, $8E, $62, $A3, $4F, $B8, $54, $F9, $15, $E2, $0E, $CF, $23,
    $D4, $38, $4D, $A1, $56, $BA, $7B, $97, $60, $8C, $21, $CD, $3A, $D6, $17,
    $FB, $0C, $E0, $0F, $E3, $14, $F8, $39, $D5, $22, $CE, $63, $8F, $78, $94,
    $55, $B9, $4E, $A2, $D7, $3B, $CC, $20, $E1, $0D, $FA, $16, $BB, $57, $A0,
    $4C, $8D, $61, $96, $7A, $7C, $90, $67, $8B, $4A, $A6, $51, $BD, $10, $FC,
    $0B, $E7, $26, $CA, $3D, $D1, $A4, $48, $BF, $53, $92, $7E, $89, $65, $C8,
    $24, $D3, $3F, $FE, $12, $E5, $09, $E9, $05, $F2, $1E, $DF, $33, $C4, $28,
    $85, $69, $9E, $72, $B3, $5F, $A8, $44, $31, $DD, $2A, $C6, $07, $EB, $1C,
    $F0, $5D, $B1, $46, $AA, $6B, $87, $70, $9C, $9A, $76, $81, $6D, $AC, $40,
    $B7, $5B, $F6, $1A, $ED, $01, $C0, $2C, $DB, $37, $42, $AE, $59, $B5, $74,
    $98, $6F, $83, $2E, $C2, $35, $D9, $18, $F4, $03, $EF, $00, $ED, $19, $F4,
    $32, $DF, $2B, $C6, $64, $89, $7D, $90, $56, $BB, $4F, $A2, $C8, $25, $D1,
    $3C, $FA, $17, $E3, $0E, $AC, $41, $B5, $58, $9E, $73, $87, $6A, $53, $BE,
    $4A, $A7, $61, $8C, $78, $95, $37, $DA, $2E, $C3, $05, $E8, $1C, $F1, $9B,
    $76, $82, $6F, $A9, $44, $B0, $5D, $FF, $12, $E6, $0B, $CD, $20, $D4, $39,
    $A6, $4B, $BF, $52, $94, $79, $8D, $60, $C2, $2F, $DB, $36, $F0, $1D, $E9,
    $04, $6E, $83, $77, $9A, $5C, $B1, $45, $A8, $0A, $E7, $13, $FE, $38, $D5,
    $21, $CC, $F5, $18, $EC, $01, $C7, $2A, $DE, $33, $91, $7C, $88, $65, $A3,
    $4E, $BA, $57, $3D, $D0, $24, $C9, $0F, $E2, $16, $FB, $59, $B4, $40, $AD,
    $6B, $86, $72, $9F, $8F, $62, $96, $7B, $BD, $50, $A4, $49, $EB, $06, $F2,
    $1F, $D9, $34, $C0, $2D, $47, $AA, $5E, $B3, $75, $98, $6C, $81, $23, $CE,
    $3A, $D7, $11, $FC, $08, $E5, $DC, $31, $C5, $28, $EE, $03, $F7, $1A, $B8,
    $55, $A1, $4C, $8A, $67, $93, $7E, $14, $F9, $0D, $E0, $26, $CB, $3F, $D2,
    $70, $9D, $69, $84, $42, $AF, $5B, $B6, $29, $C4, $30, $DD, $1B, $F6, $02,
    $EF, $4D, $A0, $54, $B9, $7F, $92, $66, $8B, $E1, $0C, $F8, $15, $D3, $3E,
    $CA, $27, $85, $68, $9C, $71, $B7, $5A, $AE, $43, $7A, $97, $63, $8E, $48,
    $A5, $51, $BC, $1E, $F3, $07, $EA, $2C, $C1, $35, $D8, $B2, $5F, $AB, $46,
    $80, $6D, $99, $74, $D6, $3B, $CF, $22, $E4, $09, $FD, $10, $00, $EE, $1F,
    $F1, $3E, $D0, $21, $CF, $7C, $92, $63, $8D, $42, $AC, $5D, $B3, $F8, $16,
    $E7, $09, $C6, $28, $D9, $37, $84, $6A, $9B, $75, $BA, $54, $A5, $4B, $33,
    $DD, $2C, $C2, $0D, $E3, $12, $FC, $4F, $A1, $50, $BE, $71, $9F, $6E, $80,
    $CB, $25, $D4, $3A, $F5, $1B, $EA, $04, $B7, $59, $A8, $46, $89, $67, $96,
    $78, $66, $88, $79, $97, $58, $B6, $47, $A9, $1A, $F4, $05, $EB, $24, $CA,
    $3B, $D5, $9E, $70, $81, $6F, $A0, $4E, $BF, $51, $E2, $0C, $FD, $13, $DC,
    $32, $C3, $2D, $55, $BB, $4A, $A4, $6B, $85, $74, $9A, $29, $C7, $36, $D8,
    $17, $F9, $08, $E6, $AD, $43, $B2, $5C, $93, $7D, $8C, $62, $D1, $3F, $CE,
    $20, $EF, $01, $F0, $1E, $CC, $22, $D3, $3D, $F2, $1C, $ED, $03, $B0, $5E,
    $AF, $41, $8E, $60, $91, $7F, $34, $DA, $2B, $C5, $0A, $E4, $15, $FB, $48,
    $A6, $57, $B9, $76, $98, $69, $87, $FF, $11, $E0, $0E, $C1, $2F, $DE, $30,
    $83, $6D, $9C, $72, $BD, $53, $A2, $4C, $07, $E9, $18, $F6, $39, $D7, $26,
    $C8, $7B, $95, $64, $8A, $45, $AB, $5A, $B4, $AA, $44, $B5, $5B, $94, $7A,
    $8B, $65, $D6, $38, $C9, $27, $E8, $06, $F7, $19, $52, $BC, $4D, $A3, $6C,
    $82, $73, $9D, $2E, $C0, $31, $DF, $10, $FE, $0F, $E1, $99, $77, $86, $68,
    $A7, $49, $B8, $56, $E5, $0B, $FA, $14, $DB, $35, $C4, $2A, $61, $8F, $7E,
    $90, $5F, $B1, $40, $AE, $1D, $F3, $02, $EC, $23, $CD, $3C, $D2, $00, $EF,
    $1D, $F2, $3A, $D5, $27, $C8, $74, $9B, $69, $86, $4E, $A1, $53, $BC, $E8,
    $07, $F5, $1A, $D2, $3D, $CF, $20, $9C, $73, $81, $6E, $A6, $49, $BB, $54,
    $13, $FC, $0E, $E1, $29, $C6, $34, $DB, $67, $88, $7A, $95, $5D, $B2, $40,
    $AF, $FB, $14, $E6, $09, $C1, $2E, $DC, $33, $8F, $60, $92, $7D, $B5, $5A,
    $A8, $47, $26, $C9, $3B, $D4, $1C, $F3, $01, $EE, $52, $BD, $4F, $A0, $68,
    $87, $75, $9A, $CE, $21, $D3, $3C, $F4, $1B, $E9, $06, $BA, $55, $A7, $48,
    $80, $6F, $9D, $72, $35, $DA, $28, $C7, $0F, $E0, $12, $FD, $41, $AE, $5C,
    $B3, $7B, $94, $66, $89, $DD, $32, $C0, $2F, $E7, $08, $FA, $15, $A9, $46,
    $B4, $5B, $93, $7C, $8E, $61, $4C, $A3, $51, $BE, $76, $99, $6B, $84, $38,
    $D7, $25, $CA, $02, $ED, $1F, $F0, $A4, $4B, $B9, $56, $9E, $71, $83, $6C,
    $D0, $3F, $CD, $22, $EA, $05, $F7, $18, $5F, $B0, $42, $AD, $65, $8A, $78,
    $97, $2B, $C4, $36, $D9, $11, $FE, $0C, $E3, $B7, $58, $AA, $45, $8D, $62,
    $90, $7F, $C3, $2C, $DE, $31, $F9, $16, $E4, $0B, $6A, $85, $77, $98, $50,
    $BF, $4D, $A2, $1E, $F1, $03, $EC, $24, $CB, $39, $D6, $82, $6D, $9F, $70,
    $B8, $57, $A5, $4A, $F6, $19, $EB, $04, $CC, $23, $D1, $3E, $79, $96, $64,
    $8B, $43, $AC, $5E, $B1, $0D, $E2, $10, $FF, $37, $D8, $2A, $C5, $91, $7E,
    $8C, $63, $AB, $44, $B6, $59, $E5, $0A, $F8, $17, $DF, $30, $C2, $2D, $00,
    $F0, $23, $D3, $46, $B6, $65, $95, $8C, $7C, $AF, $5F, $CA, $3A, $E9, $19,
    $DB, $2B, $F8, $08, $9D, $6D, $BE, $4E, $57, $A7, $74, $84, $11, $E1, $32,
    $C2, $75, $85, $56, $A6, $33, $C3, $10, $E0, $F9, $09, $DA, $2A, $BF, $4F,
    $9C, $6C, $AE, $5E, $8D, $7D, $E8, $18, $CB, $3B, $22, $D2, $01, $F1, $64,
    $94, $47, $B7, $EA, $1A, $C9, $39, $AC, $5C, $8F, $7F, $66, $96, $45, $B5,
    $20, $D0, $03, $F3, $31, $C1, $12, $E2, $77, $87, $54, $A4, $BD, $4D, $9E,
    $6E, $FB, $0B, $D8, $28, $9F, $6F, $BC, $4C, $D9, $29, $FA, $0A, $13, $E3,
    $30, $C0, $55, $A5, $76, $86, $44, $B4, $67, $97, $02, $F2, $21, $D1, $C8,
    $38, $EB, $1B, $8E, $7E, $AD, $5D, $17, $E7, $34, $C4, $51, $A1, $72, $82,
    $9B, $6B, $B8, $48, $DD, $2D, $FE, $0E, $CC, $3C, $EF, $1F, $8A, $7A, $A9,
    $59, $40, $B0, $63, $93, $06, $F6, $25, $D5, $62, $92, $41, $B1, $24, $D4,
    $07, $F7, $EE, $1E, $CD, $3D, $A8, $58, $8B, $7B, $B9, $49, $9A, $6A, $FF,
    $0F, $DC, $2C, $35, $C5, $16, $E6, $73, $83, $50, $A0, $FD, $0D, $DE, $2E,
    $BB, $4B, $98, $68, $71, $81, $52, $A2, $37, $C7, $14, $E4, $26, $D6, $05,
    $F5, $60, $90, $43, $B3, $AA, $5A, $89, $79, $EC, $1C, $CF, $3F, $88, $78,
    $AB, $5B, $CE, $3E, $ED, $1D, $04, $F4, $27, $D7, $42, $B2, $61, $91, $53,
    $A3, $70, $80, $15, $E5, $36, $C6, $DF, $2F, $FC, $0C, $99, $69, $BA, $4A,
    $00, $F1, $21, $D0, $42, $B3, $63, $92, $84, $75, $A5, $54, $C6, $37, $E7,
    $16, $CB, $3A, $EA, $1B, $89, $78, $A8, $59, $4F, $BE, $6E, $9F, $0D, $FC,
    $2C, $DD, $55, $A4, $74, $85, $17, $E6, $36, $C7, $D1, $20, $F0, $01, $93,
    $62, $B2, $43, $9E, $6F, $BF, $4E, $DC, $2D, $FD, $0C, $1A, $EB, $3B, $CA,
    $58, $A9, $79, $88, $AA, $5B, $8B, $7A, $E8, $19, $C9, $38, $2E, $DF, $0F,
    $FE, $6C, $9D, $4D, $BC, $61, $90, $40, $B1, $23, $D2, $02, $F3, $E5, $14,
    $C4, $35, $A7, $56, $86, $77, $FF, $0E, $DE, $2F, $BD, $4C, $9C, $6D, $7B,
    $8A, $5A, $AB, $39, $C8, $18, $E9, $34, $C5, $15, $E4, $76, $87, $57, $A6,
    $B0, $41, $91, $60, $F2, $03, $D3, $22, $97, $66, $B6, $47, $D5, $24, $F4,
    $05, $13, $E2, $32, $C3, $51, $A0, $70, $81, $5C, $AD, $7D, $8C, $1E, $EF,
    $3F, $CE, $D8, $29, $F9, $08, $9A, $6B, $BB, $4A, $C2, $33, $E3, $12, $80,
    $71, $A1, $50, $46, $B7, $67, $96, $04, $F5, $25, $D4, $09, $F8, $28, $D9,
    $4B, $BA, $6A, $9B, $8D, $7C, $AC, $5D, $CF, $3E, $EE, $1F, $3D, $CC, $1C,
    $ED, $7F, $8E, $5E, $AF, $B9, $48, $98, $69, $FB, $0A, $DA, $2B, $F6, $07,
    $D7, $26, $B4, $45, $95, $64, $72, $83, $53, $A2, $30, $C1, $11, $E0, $68,
    $99, $49, $B8, $2A, $DB, $0B, $FA, $EC, $1D, $CD, $3C, $AE, $5F, $8F, $7E,
    $A3, $52, $82, $73, $E1, $10, $C0, $31, $27, $D6, $06, $F7, $65, $94, $44,
    $B5, $00, $F2, $27, $D5, $4E, $BC, $69, $9B, $9C, $6E, $BB, $49, $D2, $20,
    $F5, $07, $FB, $09, $DC, $2E, $B5, $47, $92, $60, $67, $95, $40, $B2, $29,
    $DB, $0E, $FC, $35, $C7, $12, $E0, $7B, $89, $5C, $AE, $A9, $5B, $8E, $7C,
    $E7, $15, $C0, $32, $CE, $3C, $E9, $1B, $80, $72, $A7, $55, $52, $A0, $75,
    $87, $1C, $EE, $3B, $C9, $6A, $98, $4D, $BF, $24, $D6, $03, $F1, $F6, $04,
    $D1, $23, $B8, $4A, $9F, $6D, $91, $63, $B6, $44, $DF, $2D, $F8, $0A, $0D,
    $FF, $2A, $D8, $43, $B1, $64, $96, $5F, $AD, $78, $8A, $11, $E3, $36, $C4,
    $C3, $31, $E4, $16, $8D, $7F, $AA, $58, $A4, $56, $83, $71, $EA, $18, $CD,
    $3F, $38, $CA, $1F, $ED, $76, $84, $51, $A3, $D4, $26, $F3, $01, $9A, $68,
    $BD, $4F, $48, $BA, $6F, $9D, $06, $F4, $21, $D3, $2F, $DD, $08, $FA, $61,
    $93, $46, $B4, $B3, $41, $94, $66, $FD, $0F, $DA, $28, $E1, $13, $C6, $34,
    $AF, $5D, $88, $7A, $7D, $8F, $5A, $A8, $33, $C1, $14, $E6, $1A, $E8, $3D,
    $CF, $54, $A6, $73, $81, $86, $74, $A1, $53, $C8, $3A, $EF, $1D, $BE, $4C,
    $99, $6B, $F0, $02, $D7, $25, $22, $D0, $05, $F7, $6C, $9E, $4B, $B9, $45,
    $B7, $62, $90, $0B, $F9, $2C, $DE, $D9, $2B, $FE, $0C, $97, $65, $B0, $42,
    $8B, $79, $AC, $5E, $C5, $37, $E2, $10, $17, $E5, $30, $C2, $59, $AB, $7E,
    $8C, $70, $82, $57, $A5, $3E, $CC, $19, $EB, $EC, $1E, $CB, $39, $A2, $50,
    $85, $77, $00, $F3, $25, $D6, $4A, $B9, $6F, $9C, $94, $67, $B1, $42, $DE,
    $2D, $FB, $08, $EB, $18, $CE, $3D, $A1, $52, $84, $77, $7F, $8C, $5A, $A9,
    $35, $C6, $10, $E3, $15, $E6, $30, $C3, $5F, $AC, $7A, $89, $81, $72, $A4,
    $57, $CB, $38, $EE, $1D, $FE, $0D, $DB, $28, $B4, $47, $91, $62, $6A, $99,
    $4F, $BC, $20, $D3, $05, $F6, $2A, $D9, $0F, $FC, $60, $93, $45, $B6, $BE,
    $4D, $9B, $68, $F4, $07, $D1, $22, $C1, $32, $E4, $17, $8B, $78, $AE, $5D,
    $55, $A6, $70, $83, $1F, $EC, $3A, $C9, $3F, $CC, $1A, $E9, $75, $86, $50,
    $A3, $AB, $58, $8E, $7D, $E1, $12, $C4, $37, $D4, $27, $F1, $02, $9E, $6D,
    $BB, $48, $40, $B3, $65, $96, $0A, $F9, $2F, $DC, $54, $A7, $71, $82, $1E,
    $ED, $3B, $C8, $C0, $33, $E5, $16, $8A, $79, $AF, $5C, $BF, $4C, $9A, $69,
    $F5, $06, $D0, $23, $2B, $D8, $0E, $FD, $61, $92, $44, $B7, $41, $B2, $64,
    $97, $0B, $F8, $2E, $DD, $D5, $26, $F0, $03, $9F, $6C, $BA, $49, $AA, $59,
    $8F, $7C, $E0, $13, $C5, $36, $3E, $CD, $1B, $E8, $74, $87, $51, $A2, $7E,
    $8D, $5B, $A8, $34, $C7, $11, $E2, $EA, $19, $CF, $3C, $A0, $53, $85, $76,
    $95, $66, $B0, $43, $DF, $2C, $FA, $09, $01, $F2, $24, $D7, $4B, $B8, $6E,
    $9D, $6B, $98, $4E, $BD, $21, $D2, $04, $F7, $FF, $0C, $DA, $29, $B5, $46,
    $90, $63, $80, $73, $A5, $56, $CA, $39, $EF, $1C, $14, $E7, $31, $C2, $5E,
    $AD, $7B, $88, $00, $F4, $2B, $DF, $56, $A2, $7D, $89, $AC, $58, $87, $73,
    $FA, $0E, $D1, $25, $9B, $6F, $B0, $44, $CD, $39, $E6, $12, $37, $C3, $1C,
    $E8, $61, $95, $4A, $BE, $F5, $01, $DE, $2A, $A3, $57, $88, $7C, $59, $AD,
    $72, $86, $0F, $FB, $24, $D0, $6E, $9A, $45, $B1, $38, $CC, $13, $E7, $C2,
    $36, $E9, $1D, $94, $60, $BF, $4B, $29, $DD, $02, $F6, $7F, $8B, $54, $A0,
    $85, $71, $AE, $5A, $D3, $27, $F8, $0C, $B2, $46, $99, $6D, $E4, $10, $CF,
    $3B, $1E, $EA, $35, $C1, $48, $BC, $63, $97, $DC, $28, $F7, $03, $8A, $7E,
    $A1, $55, $70, $84, $5B, $AF, $26, $D2, $0D, $F9, $47, $B3, $6C, $98, $11,
    $E5, $3A, $CE, $EB, $1F, $C0, $34, $BD, $49, $96, $62, $52, $A6, $79, $8D,
    $04, $F0, $2F, $DB, $FE, $0A, $D5, $21, $A8, $5C, $83, $77, $C9, $3D, $E2,
    $16, $9F, $6B, $B4, $40, $65, $91, $4E, $BA, $33, $C7, $18, $EC, $A7, $53,
    $8C, $78, $F1, $05, $DA, $2E, $0B, $FF, $20, $D4, $5D, $A9, $76, $82, $3C,
    $C8, $17, $E3, $6A, $9E, $41, $B5, $90, $64, $BB, $4F, $C6, $32, $ED, $19,
    $7B, $8F, $50, $A4, $2D, $D9, $06, $F2, $D7, $23, $FC, $08, $81, $75, $AA,
    $5E, $E0, $14, $CB, $3F, $B6, $42, $9D, $69, $4C, $B8, $67, $93, $1A, $EE,
    $31, $C5, $8E, $7A, $A5, $51, $D8, $2C, $F3, $07, $22, $D6, $09, $FD, $74,
    $80, $5F, $AB, $15, $E1, $3E, $CA, $43, $B7, $68, $9C, $B9, $4D, $92, $66,
    $EF, $1B, $C4, $30, $00, $F5, $29, $DC, $52, $A7, $7B, $8E, $A4, $51, $8D,
    $78, $F6, $03, $DF, $2A, $8B, $7E, $A2, $57, $D9, $2C, $F0, $05, $2F, $DA,
    $06, $F3, $7D, $88, $54, $A1, $D5, $20, $FC, $09, $87, $72, $AE, $5B, $71,
    $84, $58, $AD, $23, $D6, $0A, $FF, $5E, $AB, $77, $82, $0C, $F9, $25, $D0,
    $FA, $0F, $D3, $26, $A8, $5D, $81, $74, $69, $9C, $40, $B5, $3B, $CE, $12,
    $E7, $CD, $38, $E4, $11, $9F, $6A, $B6, $43, $E2, $17, $CB, $3E, $B0, $45,
    $99, $6C, $46, $B3, $6F, $9A, $14, $E1, $3D, $C8, $BC, $49, $95, $60, $EE,
    $1B, $C7, $32, $18, $ED, $31, $C4, $4A, $BF, $63, $96, $37, $C2, $1E, $EB,
    $65, $90, $4C, $B9, $93, $66, $BA, $4F, $C1, $34, $E8, $1D, $D2, $27, $FB,
    $0E, $80, $75, $A9, $5C, $76, $83, $5F, $AA, $24, $D1, $0D, $F8, $59, $AC,
    $70, $85, $0B, $FE, $22, $D7, $FD, $08, $D4, $21, $AF, $5A, $86, $73, $07,
    $F2, $2E, $DB, $55, $A0, $7C, $89, $A3, $56, $8A, $7F, $F1, $04, $D8, $2D,
    $8C, $79, $A5, $50, $DE, $2B, $F7, $02, $28, $DD, $01, $F4, $7A, $8F, $53,
    $A6, $BB, $4E, $92, $67, $E9, $1C, $C0, $35, $1F, $EA, $36, $C3, $4D, $B8,
    $64, $91, $30, $C5, $19, $EC, $62, $97, $4B, $BE, $94, $61, $BD, $48, $C6,
    $33, $EF, $1A, $6E, $9B, $47, $B2, $3C, $C9, $15, $E0, $CA, $3F, $E3, $16,
    $98, $6D, $B1, $44, $E5, $10, $CC, $39, $B7, $42, $9E, $6B, $41, $B4, $68,
    $9D, $13, $E6, $3A, $CF, $00, $F6, $2F, $D9, $5E, $A8, $71, $87, $BC, $4A,
    $93, $65, $E2, $14, $CD, $3B, $BB, $4D, $94, $62, $E5, $13, $CA, $3C, $07,
    $F1, $28, $DE, $59, $AF, $76, $80, $B5, $43, $9A, $6C, $EB, $1D, $C4, $32,
    $09, $FF, $26, $D0, $57, $A1, $78, $8E, $0E, $F8, $21, $D7, $50, $A6, $7F,
    $89, $B2, $44, $9D, $6B, $EC, $1A, $C3, $35, $A9, $5F, $86, $70, $F7, $01,
    $D8, $2E, $15, $E3, $3A, $CC, $4B, $BD, $64, $92, $12, $E4, $3D, $CB, $4C,
    $BA, $63, $95, $AE, $58, $81, $77, $F0, $06, $DF, $29, $1C, $EA, $33, $C5,
    $42, $B4, $6D, $9B, $A0, $56, $8F, $79, $FE, $08, $D1, $27, $A7, $51, $88,
    $7E, $F9, $0F, $D6, $20, $1B, $ED, $34, $C2, $45, $B3, $6A, $9C, $91, $67,
    $BE, $48, $CF, $39, $E0, $16, $2D, $DB, $02, $F4, $73, $85, $5C, $AA, $2A,
    $DC, $05, $F3, $74, $82, $5B, $AD, $96, $60, $B9, $4F, $C8, $3E, $E7, $11,
    $24, $D2, $0B, $FD, $7A, $8C, $55, $A3, $98, $6E, $B7, $41, $C6, $30, $E9,
    $1F, $9F, $69, $B0, $46, $C1, $37, $EE, $18, $23, $D5, $0C, $FA, $7D, $8B,
    $52, $A4, $38, $CE, $17, $E1, $66, $90, $49, $BF, $84, $72, $AB, $5D, $DA,
    $2C, $F5, $03, $83, $75, $AC, $5A, $DD, $2B, $F2, $04, $3F, $C9, $10, $E6,
    $61, $97, $4E, $B8, $8D, $7B, $A2, $54, $D3, $25, $FC, $0A, $31, $C7, $1E,
    $E8, $6F, $99, $40, $B6, $36, $C0, $19, $EF, $68, $9E, $47, $B1, $8A, $7C,
    $A5, $53, $D4, $22, $FB, $0D, $00, $F7, $2D, $DA, $5A, $AD, $77, $80, $B4,
    $43, $99, $6E, $EE, $19, $C3, $34, $AB, $5C, $86, $71, $F1, $06, $DC, $2B,
    $1F, $E8, $32, $C5, $45, $B2, $68, $9F, $95, $62, $B8, $4F, $CF, $38, $E2,
    $15, $21, $D6, $0C, $FB, $7B, $8C, $56, $A1, $3E, $C9, $13, $E4, $64, $93,
    $49, $BE, $8A, $7D, $A7, $50, $D0, $27, $FD, $0A, $E9, $1E, $C4, $33, $B3,
    $44, $9E, $69, $5D, $AA, $70, $87, $07, $F0, $2A, $DD, $42, $B5, $6F, $98,
    $18, $EF, $35, $C2, $F6, $01, $DB, $2C, $AC, $5B, $81, $76, $7C, $8B, $51,
    $A6, $26, $D1, $0B, $FC, $C8, $3F, $E5, $12, $92, $65, $BF, $48, $D7, $20,
    $FA, $0D, $8D, $7A, $A0, $57, $63, $94, $4E, $B9, $39, $CE, $14, $E3, $11,
    $E6, $3C, $CB, $4B, $BC, $66, $91, $A5, $52, $88, $7F, $FF, $08, $D2, $25,
    $BA, $4D, $97, $60, $E0, $17, $CD, $3A, $0E, $F9, $23, $D4, $54, $A3, $79,
    $8E, $84, $73, $A9, $5E, $DE, $29, $F3, $04, $30, $C7, $1D, $EA, $6A, $9D,
    $47, $B0, $2F, $D8, $02, $F5, $75, $82, $58, $AF, $9B, $6C, $B6, $41, $C1,
    $36, $EC, $1B, $F8, $0F, $D5, $22, $A2, $55, $8F, $78, $4C, $BB, $61, $96,
    $16, $E1, $3B, $CC, $53, $A4, $7E, $89, $09, $FE, $24, $D3, $E7, $10, $CA,
    $3D, $BD, $4A, $90, $67, $6D, $9A, $40, $B7, $37, $C0, $1A, $ED, $D9, $2E,
    $F4, $03, $83, $74, $AE, $59, $C6, $31, $EB, $1C, $9C, $6B, $B1, $46, $72,
    $85, $5F, $A8, $28, $DF, $05, $F2, $00, $F8, $33, $CB, $66, $9E, $55, $AD,
    $CC, $34, $FF, $07, $AA, $52, $99, $61, $5B, $A3, $68, $90, $3D, $C5, $0E,
    $F6, $97, $6F, $A4, $5C, $F1, $09, $C2, $3A, $B6, $4E, $85, $7D, $D0, $28,
    $E3, $1B, $7A, $82, $49, $B1, $1C, $E4, $2F, $D7, $ED, $15, $DE, $26, $8B,
    $73, $B8, $40, $21, $D9, $12, $EA, $47, $BF, $74, $8C, $AF, $57, $9C, $64,
    $C9, $31, $FA, $02, $63, $9B, $50, $A8, $05, $FD, $36, $CE, $F4, $0C, $C7,
    $3F, $92, $6A, $A1, $59, $38, $C0, $0B, $F3, $5E, $A6, $6D, $95, $19, $E1,
    $2A, $D2, $7F, $87, $4C, $B4, $D5, $2D, $E6, $1E, $B3, $4B, $80, $78, $42,
    $BA, $71, $89, $24, $DC, $17, $EF, $8E, $76, $BD, $45, $E8, $10, $DB, $23,
    $9D, $65, $AE, $56, $FB, $03, $C8, $30, $51, $A9, $62, $9A, $37, $CF, $04,
    $FC, $C6, $3E, $F5, $0D, $A0, $58, $93, $6B, $0A, $F2, $39, $C1, $6C, $94,
    $5F, $A7, $2B, $D3, $18, $E0, $4D, $B5, $7E, $86, $E7, $1F, $D4, $2C, $81,
    $79, $B2, $4A, $70, $88, $43, $BB, $16, $EE, $25, $DD, $BC, $44, $8F, $77,
    $DA, $22, $E9, $11, $32, $CA, $01, $F9, $54, $AC, $67, $9F, $FE, $06, $CD,
    $35, $98, $60, $AB, $53, $69, $91, $5A, $A2, $0F, $F7, $3C, $C4, $A5, $5D,
    $96, $6E, $C3, $3B, $F0, $08, $84, $7C, $B7, $4F, $E2, $1A, $D1, $29, $48,
    $B0, $7B, $83, $2E, $D6, $1D, $E5, $DF, $27, $EC, $14, $B9, $41, $8A, $72,
    $13, $EB, $20, $D8, $75, $8D, $46, $BE, $00, $F9, $31, $C8, $62, $9B, $53,
    $AA, $C4, $3D, $F5, $0C, $A6, $5F, $97, $6E, $4B, $B2, $7A, $83, $29, $D0,
    $18, $E1, $8F, $76, $BE, $47, $ED, $14, $DC, $25, $96, $6F, $A7, $5E, $F4,
    $0D, $C5, $3C, $52, $AB, $63, $9A, $30, $C9, $01, $F8, $DD, $24, $EC, $15,
    $BF, $46, $8E, $77, $19, $E0, $28, $D1, $7B, $82, $4A, $B3, $EF, $16, $DE,
    $27, $8D, $74, $BC, $45, $2B, $D2, $1A, $E3, $49, $B0, $78, $81, $A4, $5D,
    $95, $6C, $C6, $3F, $F7, $0E, $60, $99, $51, $A8, $02, $FB, $33, $CA, $79,
    $80, $48, $B1, $1B, $E2, $2A, $D3, $BD, $44, $8C, $75, $DF, $26, $EE, $17,
    $32, $CB, $03, $FA, $50, $A9, $61, $98, $F6, $0F, $C7, $3E, $94, $6D, $A5,
    $5C, $1D, $E4, $2C, $D5, $7F, $86, $4E, $B7, $D9, $20, $E8, $11, $BB, $42,
    $8A, $73, $56, $AF, $67, $9E, $34, $CD, $05, $FC, $92, $6B, $A3, $5A, $F0,
    $09, $C1, $38, $8B, $72, $BA, $43, $E9, $10, $D8, $21, $4F, $B6, $7E, $87,
    $2D, $D4, $1C, $E5, $C0, $39, $F1, $08, $A2, $5B, $93, $6A, $04, $FD, $35,
    $CC, $66, $9F, $57, $AE, $F2, $0B, $C3, $3A, $90, $69, $A1, $58, $36, $CF,
    $07, $FE, $54, $AD, $65, $9C, $B9, $40, $88, $71, $DB, $22, $EA, $13, $7D,
    $84, $4C, $B5, $1F, $E6, $2E, $D7, $64, $9D, $55, $AC, $06, $FF, $37, $CE,
    $A0, $59, $91, $68, $C2, $3B, $F3, $0A, $2F, $D6, $1E, $E7, $4D, $B4, $7C,
    $85, $EB, $12, $DA, $23, $89, $70, $B8, $41, $00, $FA, $37, $CD, $6E, $94,
    $59, $A3, $DC, $26, $EB, $11, $B2, $48, $85, $7F, $7B, $81, $4C, $B6, $15,
    $EF, $22, $D8, $A7, $5D, $90, $6A, $C9, $33, $FE, $04, $F6, $0C, $C1, $3B,
    $98, $62, $AF, $55, $2A, $D0, $1D, $E7, $44, $BE, $73, $89, $8D, $77, $BA,
    $40, $E3, $19, $D4, $2E, $51, $AB, $66, $9C, $3F, $C5, $08, $F2, $2F, $D5,
    $18, $E2, $41, $BB, $76, $8C, $F3, $09, $C4, $3E, $9D, $67, $AA, $50, $54,
    $AE, $63, $99, $3A, $C0, $0D, $F7, $88, $72, $BF, $45, $E6, $1C, $D1, $2B,
    $D9, $23, $EE, $14, $B7, $4D, $80, $7A, $05, $FF, $32, $C8, $6B, $91, $5C,
    $A6, $A2, $58, $95, $6F, $CC, $36, $FB, $01, $7E, $84, $49, $B3, $10, $EA,
    $27, $DD, $5E, $A4, $69, $93, $30, $CA, $07, $FD, $82, $78, $B5, $4F, $EC,
    $16, $DB, $21, $25, $DF, $12, $E8, $4B, $B1, $7C, $86, $F9, $03, $CE, $34,
    $97, $6D, $A0, $5A, $A8, $52, $9F, $65, $C6, $3C, $F1, $0B, $74, $8E, $43,
    $B9, $1A, $E0, $2D, $D7, $D3, $29, $E4, $1E, $BD, $47, $8A, $70, $0F, $F5,
    $38, $C2, $61, $9B, $56, $AC, $71, $8B, $46, $BC, $1F, $E5, $28, $D2, $AD,
    $57, $9A, $60, $C3, $39, $F4, $0E, $0A, $F0, $3D, $C7, $64, $9E, $53, $A9,
    $D6, $2C, $E1, $1B, $B8, $42, $8F, $75, $87, $7D, $B0, $4A, $E9, $13, $DE,
    $24, $5B, $A1, $6C, $96, $35, $CF, $02, $F8, $FC, $06, $CB, $31, $92, $68,
    $A5, $5F, $20, $DA, $17, $ED, $4E, $B4, $79, $83, $00, $FB, $35, $CE, $6A,
    $91, $5F, $A4, $D4, $2F, $E1, $1A, $BE, $45, $8B, $70, $6B, $90, $5E, $A5,
    $01, $FA, $34, $CF, $BF, $44, $8A, $71, $D5, $2E, $E0, $1B, $D6, $2D, $E3,
    $18, $BC, $47, $89, $72, $02, $F9, $37, $CC, $68, $93, $5D, $A6, $BD, $46,
    $88, $73, $D7, $2C, $E2, $19, $69, $92, $5C, $A7, $03, $F8, $36, $CD, $6F,
    $94, $5A, $A1, $05, $FE, $30, $CB, $BB, $40, $8E, $75, $D1, $2A, $E4, $1F,
    $04, $FF, $31, $CA, $6E, $95, $5B, $A0, $D0, $2B, $E5, $1E, $BA, $41, $8F,
    $74, $B9, $42, $8C, $77, $D3, $28, $E6, $1D, $6D, $96, $58, $A3, $07, $FC,
    $32, $C9, $D2, $29, $E7, $1C, $B8, $43, $8D, $76, $06, $FD, $33, $C8, $6C,
    $97, $59, $A2, $DE, $25, $EB, $10, $B4, $4F, $81, $7A, $0A, $F1, $3F, $C4,
    $60, $9B, $55, $AE, $B5, $4E, $80, $7B, $DF, $24, $EA, $11, $61, $9A, $54,
    $AF, $0B, $F0, $3E, $C5, $08, $F3, $3D, $C6, $62, $99, $57, $AC, $DC, $27,
    $E9, $12, $B6, $4D, $83, $78, $63, $98, $56, $AD, $09, $F2, $3C, $C7, $B7,
    $4C, $82, $79, $DD, $26, $E8, $13, $B1, $4A, $84, $7F, $DB, $20, $EE, $15,
    $65, $9E, $50, $AB, $0F, $F4, $3A, $C1, $DA, $21, $EF, $14, $B0, $4B, $85,
    $7E, $0E, $F5, $3B, $C0, $64, $9F, $51, $AA, $67, $9C, $52, $A9, $0D, $F6,
    $38, $C3, $B3, $48, $86, $7D, $D9, $22, $EC, $17, $0C, $F7, $39, $C2, $66,
    $9D, $53, $A8, $D8, $23, $ED, $16, $B2, $49, $87, $7C, $00, $FC, $3B, $C7,
    $76, $8A, $4D, $B1, $EC, $10, $D7, $2B, $9A, $66, $A1, $5D, $1B, $E7, $20,
    $DC, $6D, $91, $56, $AA, $F7, $0B, $CC, $30, $81, $7D, $BA, $46, $36, $CA,
    $0D, $F1, $40, $BC, $7B, $87, $DA, $26, $E1, $1D, $AC, $50, $97, $6B, $2D,
    $D1, $16, $EA, $5B, $A7, $60, $9C, $C1, $3D, $FA, $06, $B7, $4B, $8C, $70,
    $6C, $90, $57, $AB, $1A, $E6, $21, $DD, $80, $7C, $BB, $47, $F6, $0A, $CD,
    $31, $77, $8B, $4C, $B0, $01, $FD, $3A, $C6, $9B, $67, $A0, $5C, $ED, $11,
    $D6, $2A, $5A, $A6, $61, $9D, $2C, $D0, $17, $EB, $B6, $4A, $8D, $71, $C0,
    $3C, $FB, $07, $41, $BD, $7A, $86, $37, $CB, $0C, $F0, $AD, $51, $96, $6A,
    $DB, $27, $E0, $1C, $D8, $24, $E3, $1F, $AE, $52, $95, $69, $34, $C8, $0F,
    $F3, $42, $BE, $79, $85, $C3, $3F, $F8, $04, $B5, $49, $8E, $72, $2F, $D3,
    $14, $E8, $59, $A5, $62, $9E, $EE, $12, $D5, $29, $98, $64, $A3, $5F, $02,
    $FE, $39, $C5, $74, $88, $4F, $B3, $F5, $09, $CE, $32, $83, $7F, $B8, $44,
    $19, $E5, $22, $DE, $6F, $93, $54, $A8, $B4, $48, $8F, $73, $C2, $3E, $F9,
    $05, $58, $A4, $63, $9F, $2E, $D2, $15, $E9, $AF, $53, $94, $68, $D9, $25,
    $E2, $1E, $43, $BF, $78, $84, $35, $C9, $0E, $F2, $82, $7E, $B9, $45, $F4,
    $08, $CF, $33, $6E, $92, $55, $A9, $18, $E4, $23, $DF, $99, $65, $A2, $5E,
    $EF, $13, $D4, $28, $75, $89, $4E, $B2, $03, $FF, $38, $C4, $00, $FD, $39,
    $C4, $72, $8F, $4B, $B6, $E4, $19, $DD, $20, $96, $6B, $AF, $52, $0B, $F6,
    $32, $CF, $79, $84, $40, $BD, $EF, $12, $D6, $2B, $9D, $60, $A4, $59, $16,
    $EB, $2F, $D2, $64, $99, $5D, $A0, $F2, $0F, $CB, $36, $80, $7D, $B9, $44,
    $1D, $E0, $24, $D9, $6F, $92, $56, $AB, $F9, $04, $C0, $3D, $8B, $76, $B2,
    $4F, $2C, $D1, $15, $E8, $5E, $A3, $67, $9A, $C8, $35, $F1, $0C, $BA, $47,
    $83, $7E, $27, $DA, $1E, $E3, $55, $A8, $6C, $91, $C3, $3E, $FA, $07, $B1,
    $4C, $88, $75, $3A, $C7, $03, $FE, $48, $B5, $71, $8C, $DE, $23, $E7, $1A,
    $AC, $51, $95, $68, $31, $CC, $08, $F5, $43, $BE, $7A, $87, $D5, $28, $EC,
    $11, $A7, $5A, $9E, $63, $58, $A5, $61, $9C, $2A, $D7, $13, $EE, $BC, $41,
    $85, $78, $CE, $33, $F7, $0A, $53, $AE, $6A, $97, $21, $DC, $18, $E5, $B7,
    $4A, $8E, $73, $C5, $38, $FC, $01, $4E, $B3, $77, $8A, $3C, $C1, $05, $F8,
    $AA, $57, $93, $6E, $D8, $25, $E1, $1C, $45, $B8, $7C, $81, $37, $CA, $0E,
    $F3, $A1, $5C, $98, $65, $D3, $2E, $EA, $17, $74, $89, $4D, $B0, $06, $FB,
    $3F, $C2, $90, $6D, $A9, $54, $E2, $1F, $DB, $26, $7F, $82, $46, $BB, $0D,
    $F0, $34, $C9, $9B, $66, $A2, $5F, $E9, $14, $D0, $2D, $62, $9F, $5B, $A6,
    $10, $ED, $29, $D4, $86, $7B, $BF, $42, $F4, $09, $CD, $30, $69, $94, $50,
    $AD, $1B, $E6, $22, $DF, $8D, $70, $B4, $49, $FF, $02, $C6, $3B, $00, $FE,
    $3F, $C1, $7E, $80, $41, $BF, $FC, $02, $C3, $3D, $82, $7C, $BD, $43, $3B,
    $C5, $04, $FA, $45, $BB, $7A, $84, $C7, $39, $F8, $06, $B9, $47, $86, $78,
    $76, $88, $49, $B7, $08, $F6, $37, $C9, $8A, $74, $B5, $4B, $F4, $0A, $CB,
    $35, $4D, $B3, $72, $8C, $33, $CD, $0C, $F2, $B1, $4F, $8E, $70, $CF, $31,
    $F0, $0E, $EC, $12, $D3, $2D, $92, $6C, $AD, $53, $10, $EE, $2F, $D1, $6E,
    $90, $51, $AF, $D7, $29, $E8, $16, $A9, $57, $96, $68, $2B, $D5, $14, $EA,
    $55, $AB, $6A, $94, $9A, $64, $A5, $5B, $E4, $1A, $DB, $25, $66, $98, $59,
    $A7, $18, $E6, $27, $D9, $A1, $5F, $9E, $60, $DF, $21, $E0, $1E, $5D, $A3,
    $62, $9C, $23, $DD, $1C, $E2, $1B, $E5, $24, $DA, $65, $9B, $5A, $A4, $E7,
    $19, $D8, $26, $99, $67, $A6, $58, $20, $DE, $1F, $E1, $5E, $A0, $61, $9F,
    $DC, $22, $E3, $1D, $A2, $5C, $9D, $63, $6D, $93, $52, $AC, $13, $ED, $2C,
    $D2, $91, $6F, $AE, $50, $EF, $11, $D0, $2E, $56, $A8, $69, $97, $28, $D6,
    $17, $E9, $AA, $54, $95, $6B, $D4, $2A, $EB, $15, $F7, $09, $C8, $36, $89,
    $77, $B6, $48, $0B, $F5, $34, $CA, $75, $8B, $4A, $B4, $CC, $32, $F3, $0D,
    $B2, $4C, $8D, $73, $30, $CE, $0F, $F1, $4E, $B0, $71, $8F, $81, $7F, $BE,
    $40, $FF, $01, $C0, $3E, $7D, $83, $42, $BC, $03, $FD, $3C, $C2, $BA, $44,
    $85, $7B, $C4, $3A, $FB, $05, $46, $B8, $79, $87, $38, $C6, $07, $F9, $00,
    $FF, $3D, $C2, $7A, $85, $47, $B8, $F4, $0B, $C9, $36, $8E, $71, $B3, $4C,
    $2B, $D4, $16, $E9, $51, $AE, $6C, $93, $DF, $20, $E2, $1D, $A5, $5A, $98,
    $67, $56, $A9, $6B, $94, $2C, $D3, $11, $EE, $A2, $5D, $9F, $60, $D8, $27,
    $E5, $1A, $7D, $82, $40, $BF, $07, $F8, $3A, $C5, $89, $76, $B4, $4B, $F3,
    $0C, $CE, $31, $AC, $53, $91, $6E, $D6, $29, $EB, $14, $58, $A7, $65, $9A,
    $22, $DD, $1F, $E0, $87, $78, $BA, $45, $FD, $02, $C0, $3F, $73, $8C, $4E,
    $B1, $09, $F6, $34, $CB, $FA, $05, $C7, $38, $80, $7F, $BD, $42, $0E, $F1,
    $33, $CC, $74, $8B, $49, $B6, $D1, $2E, $EC, $13, $AB, $54, $96, $69, $25,
    $DA, $18, $E7, $5F, $A0, $62, $9D, $9B, $64, $A6, $59, $E1, $1E, $DC, $23,
    $6F, $90, $52, $AD, $15, $EA, $28, $D7, $B0, $4F, $8D, $72, $CA, $35, $F7,
    $08, $44, $BB, $79, $86, $3E, $C1, $03, $FC, $CD, $32, $F0, $0F, $B7, $48,
    $8A, $75, $39, $C6, $04, $FB, $43, $BC, $7E, $81, $E6, $19, $DB, $24, $9C,
    $63, $A1, $5E, $12, $ED, $2F, $D0, $68, $97, $55, $AA, $37, $C8, $0A, $F5,
    $4D, $B2, $70, $8F, $C3, $3C, $FE, $01, $B9, $46, $84, $7B, $1C, $E3, $21,
    $DE, $66, $99, $5B, $A4, $E8, $17, $D5, $2A, $92, $6D, $AF, $50, $61, $9E,
    $5C, $A3, $1B, $E4, $26, $D9, $95, $6A, $A8, $57, $EF, $10, $D2, $2D, $4A,
    $B5, $77, $88, $30, $CF, $0D, $F2, $BE, $41, $83, $7C, $C4, $3B, $F9, $06);

const
  kuz_lvec: array [0 .. 15] of u8 = ($94, $20, $85, $10, $C2, $C0, $01, $FB,
    $01, $C0, $C2, $10, $85, $20, $94, $01);

function kuz_mul_gf256(x, y: u8): u8;
var
  z, t: u8;
begin

  z := 0;
  while (y <> 0) do
  begin

    if (y and 1 <> 0) then
      z := z Xor x;

    if (x And $80 <> 0) then
      t := $C3
    else
      t := 0;

    x := (x SHL 1) XOR t;

    y := y SHR 1;
  end;

  result := z;
end;

procedure kuz_l(w: pw128_t);
var
  i, j: longint;
  x: u8;
begin

  for j := 0 to 15 do
  begin

    x := w.b[15];

    for i := 14 downto 0 do
    begin
      w.b[i + 1] := w.b[i];
      x := x xor multTable[w.b[i] * 256 + kuz_lvec[i]];
    end;
    w.b[0] := x;
  end

end;

procedure kuz_l_inv(w: pw128_t);
var
  i, j: longint;
  x: u8;
begin

  for j := 0 to 15 do
  begin
    x := w.b[0];

    for i := 0 to 14 do
    begin
      w.b[i] := w.b[i + 1];
      x := x xor multTable[w.b[i] * 256 + kuz_lvec[i]];
    end;
    w.b[15] := x;
  end;
end;

procedure kuz_init;
begin

end;

procedure kuz_set_encrypt_key(kuz: pkuz_key_t; const key: pw256_t);
var
  i, j: longint;
  c, x, y, z: w128_t;

begin

  for i := 0 to 15 do
  begin

    x.b[i] := key.b[i];
    y.b[i] := key.b[i + 16];
  end;

  kuz.k[0].q[0] := x.q[0];
  kuz.k[0].q[1] := x.q[1];
  kuz.k[1].q[0] := y.q[0];
  kuz.k[1].q[1] := y.q[1];

  for i := 1 to 32 do
  begin

    c.q[0] := 0;
    c.q[1] := 0;
    c.b[15] := i;
    kuz_l(@c);

    z.q[0] := x.q[0] xor c.q[0];
    z.q[1] := x.q[1] xor c.q[1];

    for j := 0 to 15 do
      z.b[j] := kuz_pi[z.b[j]];

    kuz_l(@z);
    z.q[0] := z.q[0] xor y.q[0];
    z.q[1] := z.q[1] xor y.q[1];

    y.q[0] := x.q[0];
    y.q[1] := x.q[1];

    x.q[0] := z.q[0];
    x.q[1] := z.q[1];

    if ((i and 7) = 0) then
    begin
      kuz.k[(i SHR 2)].q[0] := x.q[0];
      kuz.k[(i SHR 2)].q[1] := x.q[1];
      kuz.k[(i SHR 2) + 1].q[0] := y.q[0];
      kuz.k[(i SHR 2) + 1].q[1] := y.q[1];
    end;
  end;
end;

procedure kuz_encrypt_block(key: kuz_key_t; blk: pw128_t);
var
  i, j: longint;
  x: w128_t;
begin

  x.q[0] := blk.q[0];
  x.q[1] := blk.q[1];

  for i := 0 to 8 do
  begin

    x.q[0] := x.q[0] xor key.k[i].q[0];
    x.q[1] := x.q[1] xor key.k[i].q[1];

    for j := 0 to 15 do
      x.b[j] := kuz_pi[x.b[j]];
    kuz_l(@x);
  end;

  blk.q[0] := x.q[0] xor key.k[9].q[0];
  blk.q[1] := x.q[1] xor key.k[9].q[1];

end;

procedure kuz_decrypt_block(key: kuz_key_t; blk: pw128_t);
var
  i, j: longint;
  x: w128_t;
begin

  x.q[0] := blk.q[0] xor key.k[9].q[0];
  x.q[1] := blk.q[1] xor key.k[9].q[1];

  for i := 8 downto 0 do
  begin

    kuz_l_inv(@x);

    for j := 0 to 15 do
      x.b[j] := kuz_pi_inv[x.b[j]];

    x.q[0] := x.q[0] xor key.k[i].q[0];
    x.q[1] := x.q[1] xor key.k[i].q[1];

  end;

  blk.q[0] := x.q[0];
  blk.q[1] := x.q[1];

end;



//

procedure setup(usrkey: pw256_t)stdcall; export;
begin
  kuz_init();

  kuz_set_encrypt_key(@key, usrkey);
end;

procedure crypt(data: pw128_t)stdcall; export;
begin
  kuz_encrypt_block(key, data);
end;

procedure decrypt(data: pw128_t)stdcall; export;
begin
  kuz_decrypt_block(key, data);
end;

function getblocksize(): u32; stdcall; export;
begin
  result := 128;
end;

function getkeysize(): u32; stdcall; export;
begin
  result := 256;
end;

procedure getciphername(p: pU8)stdcall; export;
begin
  StrCopy(PAnsiChar(p), AnsiString('Kuznechik'));
end;

exports
  getciphername,
  getkeysize,
  getblocksize,
  decrypt,
  crypt, setup;

end.
